(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1652453,      30579]
NotebookOptionsPosition[   1603940,      29313]
NotebookOutlinePosition[   1634524,      30004]
CellTagsIndexPosition[   1634395,      29998]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Updated to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v7"
}], "Subsubtitle",
 CellChangeTimes->{{3.460678721338853*^9, 3.460678732854478*^9}},
 FontWeight->"Bold",
 FontColor->RGBColor[0.6, 0.4, 0.2],
 Background->RGBColor[0.9, 1, 1]],

Cell[CellGroupData[{

Cell["\<\


Laplace Flow Near 
An Ellipsoidal Conductor\
\>", "Title",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["by M.G. Trefry",
  FontFamily->"Times",
  FontSize->14],
 StyleBox["1",
  FontFamily->"Times",
  FontSize->10,
  FontVariations->{"CompatibilityType"->"Superscript"}],
 StyleBox[" and L.R. Townley",
  FontFamily->"Times",
  FontSize->14],
 StyleBox["2",
  FontFamily->"Times",
  FontSize->10,
  FontVariations->{"CompatibilityType"->"Superscript"}],
 StyleBox["\n",
  FontFamily->"Times",
  FontSize->9,
  FontVariations->{"CompatibilityType"->"Superscript"}],
 StyleBox["This notebook accompanies an article published in ",
  FontFamily->"Times",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->"Superscript"}],
 StyleBox["Computers in Physics",
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Superscript"}],
 StyleBox[", vol. 12, no. 5, pp.503-511 (1998).",
  FontFamily->"Times",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->"Superscript"}]
}], "Input",
 CellMargins->{{18, Inherited}, {Inherited, Inherited}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["1",
  FontFamily->"Times",
  FontSize->9,
  FontVariations->{"CompatibilityType"->"Superscript"}],
 StyleBox["Centre for Groundwater Studies\nCSIRO Land and Water\nPrivate Bag, \
PO Wembley 6014\nWestern Australia\nE-mail address:    mike.trefry@csiro.au\n\
\n",
  FontFamily->"Times"],
 StyleBox["2",
  FontFamily->"Times",
  FontSize->9,
  FontVariations->{"CompatibilityType"->"Superscript"}],
 StyleBox["Townley and Associates Pty Ltd\nPO Box 425\nClaremont 6010\n\
Western Australia",
  FontFamily->"Times"],
 StyleBox["\n",
  FontFamily->"Times",
  FontSize->9,
  FontVariations->{"CompatibilityType"->"Superscript"}],
 StyleBox["E-mail address:   ",
  FontFamily->"Times"],
 StyleBox[" LTownley@ntec.com.au",
  FontFamily->"Times New Roman"],
 "\n",
 StyleBox["\n\n",
  FontFamily->"Times"]
}], "Subsubtitle",
 CellMargins->{{16, Inherited}, {Inherited, Inherited}},
 Evaluatable->False,
 CellChangeTimes->{{3.460678820135728*^9, 3.460678822323228*^9}, {
  3.460678853135728*^9, 3.460678856854478*^9}},
 AspectRatioFixed->True,
 FontSize->12,
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[CellGroupData[{

Cell["Abstract", "Section",
 CellMargins->{{11, Inherited}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
An existing solution for the steady three-dimensional temperature \
distribution around an ellipsoid embedded in a uniform, isotropic medium is \
used to study the characteristics of Laplace flow near a variety of objects. \
Symbolic integration techniques are used to derive new closed form algebraic \
expressions for flow potentials near general ellipsoids. These expressions \
are used to derive simple algebraic results for various degenerate and \
limiting cases. Flow paths are calculated using numerical particle tracking \
techniques, defining capture and release zones for the embedded objects. The \
application and relevance of these results to the flow of groundwater near \
shallow lakes is discussed, and possibilities for future work are noted.\
\>", "Text",
 Evaluatable->False,
 PageBreakBelow->True,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.  Introduction", "Section",
 CellMargins->{{11, Inherited}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Physical problems involving diffusion and conduction processes are common in \
modern scientific and engineering applications. Often these problems may be \
modelled mathematically in terms of the following parabolic partial \
differential equation:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["                                    ",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["R",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"\[PartialD]", " ", 
     StyleBox["u",
      FontWeight->"Bold"]}], 
    RowBox[{"\[PartialD]", " ", "t"}]], TraditionalForm]]],
 StyleBox[" = \[Del] ",
  FontFamily->"Times"],
 StyleBox[".",
  FontFamily->"Times",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox[" (",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" \[Del]",
  FontFamily->"Times"],
 StyleBox["u",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[")                                                     (1)",
  FontFamily->"Times"]
}], "Text",
 CellMargins->{{Inherited, 73}, {Inherited, Inherited}},
 Evaluatable->False,
 TextAlignment->Right,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["where ",
  FontFamily->"Times"],
 StyleBox["R",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[", ",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" are real, single-valued functions of space and time (and possibly \
",
  FontFamily->"Times"],
 StyleBox["u",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[") and ",
  FontFamily->"Times"],
 StyleBox["u",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" is the dependent variable.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["This equation, variously referred to as the ",
  FontFamily->"Times"],
 StyleBox["heat equation",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" or the ",
  FontFamily->"Times"],
 StyleBox["diffusion equation",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[", can be used to model a wide range of initial value problems in \
areas such as thermal and electrical conduction, diffusive chemical \
transport, hydrology, ",
  FontFamily->"Times"],
 StyleBox["etc",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[". In hydrology, ",
  FontFamily->"Times"],
 StyleBox["R",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" may be identified with",
  FontFamily->"Times"],
 StyleBox[" storage coefficient",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" with ",
  FontFamily->"Times"],
 StyleBox["hydraulic conductivity",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[", and ",
  FontFamily->"Times"],
 StyleBox["u",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" with ",
  FontFamily->"Times"],
 StyleBox["piezometric head",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[". In chemical transport problems, ",
  FontFamily->"Times"],
 StyleBox["R",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" may be identified with a ",
  FontFamily->"Times"],
 StyleBox["retardation coefficient",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" with a ",
  FontFamily->"Times"],
 StyleBox["diffusion coefficient",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" and ",
  FontFamily->"Times"],
 StyleBox["u",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" with",
  FontFamily->"Times"],
 StyleBox[" concentration",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[".",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["In circumstances where ",
  FontFamily->"Times"],
 StyleBox["u",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" is independent of time (",
  FontFamily->"Times"],
 StyleBox["i.e.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" steady) and ",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" is constant, equation (1) reduces to the ",
  FontFamily->"Times"],
 StyleBox["Laplace equation",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[":",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox[" ",
  FontFamily->"Times"],
 StyleBox["                                    ",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["\[Del] ",
  FontFamily->"Times"],
 StyleBox[".",
  FontFamily->"Times",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox[" (",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" \[Del]",
  FontFamily->"Times"],
 StyleBox["u",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[")   =  0                                                           \
   (2)",
  FontFamily->"Times"]
}], "Text",
 CellMargins->{{Inherited, 73}, {Inherited, Inherited}},
 Evaluatable->False,
 TextAlignment->Right,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["and ",
  FontFamily->"Times"],
 StyleBox["u",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" is referred to as the ",
  FontFamily->"Times"],
 StyleBox["potential of flow",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" for the system. Thus steady flow potentials for many different \
physical problems can be related to each other by suitable definitions of ",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[". Equally, it is often possible to deduce solutions for problems \
in one field by appealing to results already calculated in another field, \
related to the topic of interest in the sense of equation (2).",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["The associated velocity field, ",
  FontFamily->"Times"],
 StyleBox["v",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[", related to the flow potential, ",
  FontFamily->"Times"],
 StyleBox["u",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[", by",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["                                     v",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["  ",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox["= -",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" \[Del]",
  FontFamily->"Times"],
 StyleBox["u",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["                                                                   \
(3)",
  FontFamily->"Times"]
}], "Text",
 CellMargins->{{Inherited, 73}, {Inherited, Inherited}},
 Evaluatable->False,
 TextAlignment->Right,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["is often used for analysing the flow properties of ",
  FontFamily->"Times"],
 StyleBox["u",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[". For example, flux vectors can be plotted in two or three \
dimensions, with the field represented by arrays of scaled arrows directed \
along the associated flux vectors. Alternatively, ",
  FontFamily->"Times"],
 StyleBox["flow paths",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" can be calculated by integrating the velocity field to produce \
lists of points along notional trajectories of massless advecting particles.",
  
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["In this paper we consider the application of an algebraic \
expression for steady thermal conduction near an embedded ellipsoid to \
hydrological problems involving ",
  FontFamily->"Times"],
 StyleBox["aquifers",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" overlain by conducting water bodies. We first extend a standard \
formulation of the problem to a general solution in closed form. Properties \
of this solution are discussed and particle tracking techniques are \
introduced to calculate flow paths. Solutions for several limiting cases are \
derived from the algebraic formulae and examined. Finally, a hydrological \
application of the derived results is briefly discussed.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.  Steady Flow Near an Embedded Ellipsoid", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["An expression for the three-dimensional temperature distribution \
near an ellipsoid of thermal conductivity K' embedded in an infinite medium \
of thermal conductivity K is presented by Carslaw and Jaeger [Carslaw and \
Jaeger 1959]. This expression has already been used in a hydrological context \
by Toth [Toth 1962]. Henceforth, K and K' will be referred to simply as ",
  FontFamily->"Times"],
 StyleBox["conductivities",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[", and the temperature will be referred to as the ",
  FontFamily->"Times"],
 StyleBox["potential",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[". Carslaw and Jaeger's expression is written as follows.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Firstly, the ellipsoid is centred at the origin of a \
three-dimensional cartesian coordinate system. The ellipsoid is characterized \
by three semi-axes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 StyleBox[", ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["b", TraditionalForm]]],
 StyleBox[", and ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["c", TraditionalForm]]],
 StyleBox[" for the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox[", ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 StyleBox[", and ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["z", TraditionalForm]]],
 StyleBox[" directions, respectively. The potential (or temperature) solution \
is expressed in terms of the characteristic, ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Lambda]", TraditionalForm]]],
 StyleBox[", where ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Lambda]", TraditionalForm]]],
 StyleBox[" is the positive root of",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["x", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "+", " ", "\[Lambda]"}], ")"}]], 
   TraditionalForm]]],
 StyleBox[" +   ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["y", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", "+", " ", "\[Lambda]"}], ")"}]], 
   TraditionalForm]]],
 StyleBox[" +   ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["z", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", "+", " ", "\[Lambda]"}], ")"}]], 
   TraditionalForm]]],
 StyleBox[" = 1                                           (4)",
  FontFamily->"Times"]
}], "Text",
 CellMargins->{{Inherited, 73}, {Inherited, Inherited}},
 Evaluatable->False,
 TextAlignment->Right,
 AspectRatioFixed->True],

Cell["\<\
The potential distributions inside and outside the ellipsoid are, \
respectively:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["    ",
  FontFamily->"Symbol"],
 StyleBox["u",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["i",
  FontFamily->"Times",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox[" = ",
  FontFamily->"Times"],
 "-",
 StyleBox[" ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     SubscriptBox["V", "1"], " ", "x"}], 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{
      SubscriptBox[
       StyleBox["A",
        FontWeight->"Bold"], "0"], "(", 
      RowBox[{"\[Epsilon]", "-", "1"}], ")"}]}]], TraditionalForm]]],
 " - ",
 StyleBox[" ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     SubscriptBox["V", "2"], " ", "y"}], 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{
      SubscriptBox[
       StyleBox["B",
        FontWeight->"Bold"], "0"], "(", 
      RowBox[{"\[Epsilon]", "-", "1"}], ")"}]}]], TraditionalForm]]],
 " - ",
 StyleBox[" ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     SubscriptBox["V", "3"], " ", "z"}], 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{
      SubscriptBox[
       StyleBox["C",
        FontWeight->"Bold"], "0"], "(", 
      RowBox[{"\[Epsilon]", "-", "1"}], ")"}]}]], TraditionalForm]]],
 " ",
 StyleBox["                             (5)",
  FontFamily->"Times"]
}], "Text",
 CellMargins->{{Inherited, 73}, {Inherited, Inherited}},
 Evaluatable->False,
 TextAlignment->Right,
 AspectRatioFixed->True],

Cell["and", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox[" ",
  FontFamily->"Symbol"],
 StyleBox["u",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["o",
  FontFamily->"Times",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox[" = -",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "1"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", "x"}], TraditionalForm]]],
 StyleBox[" ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox["- ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "2"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", "y"}], TraditionalForm]]],
 StyleBox[" ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox["- ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "3"], TraditionalForm]]],
 StyleBox[" ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["z", TraditionalForm]]],
 StyleBox["                                                                   \
    ",
  FontFamily->"Times"],
 StyleBox[" \n             ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 "+",
 StyleBox[" ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", "1"}], ")"}], " ", 
     SubscriptBox[
      StyleBox["A",
       FontWeight->"Bold"], "\[Lambda]"], 
     SubscriptBox["V", "1"], "x"}], 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{
      SubscriptBox[
       StyleBox["A",
        FontWeight->"Bold"], "0"], "(", 
      RowBox[{"\[Epsilon]", "-", "1"}], ")"}]}]], TraditionalForm]]],
 " + ",
 StyleBox[" ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", "1"}], ")"}], " ", 
     SubscriptBox[
      StyleBox["B",
       FontWeight->"Bold"], "\[Lambda]"], 
     SubscriptBox["V", "2"], "y"}], 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{
      SubscriptBox[
       StyleBox["B",
        FontWeight->"Bold"], "0"], "(", 
      RowBox[{"\[Epsilon]", "-", "1"}], ")"}]}]], TraditionalForm]]],
 " + ",
 StyleBox[" ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", "1"}], ")"}], " ", 
     SubscriptBox[
      StyleBox["C",
       FontWeight->"Bold"], "\[Lambda]"], 
     SubscriptBox["V", "3"], "z"}], 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{
      SubscriptBox[
       StyleBox["C",
        FontWeight->"Bold"], "0"], "(", 
      RowBox[{"\[Epsilon]", "-", "1"}], ")"}]}]], TraditionalForm]]],
 " ",
 StyleBox["                   ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" (6)",
  FontFamily->"Times"]
}], "Text",
 CellMargins->{{Inherited, 73}, {Inherited, Inherited}},
 Evaluatable->False,
 TextAlignment->Right,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["where the auxiliary integral functions ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["A",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["B",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{",", " ", 
    SubscriptBox[
     StyleBox["C",
      FontWeight->"Bold"], "\[Lambda]"]}], TraditionalForm]]],
 " ",
 StyleBox["are given by",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "                      ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["A",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[" = ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    FractionBox[
     StyleBox["abc",
      FontSlant->"Italic"], "2"],
    FontSize->10], TraditionalForm]]],
 "   ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", "\[Lambda]", "\[Infinity]"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"\[CapitalDelta]", "(", "w", ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox["a",
           FontSize->10], "2"], " ", "+", " ", "w"}], ")"}]}]], 
     RowBox[{"\[DifferentialD]", "w"}]}]}], TraditionalForm]]],
 "                                                    \n\n                    \
  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["B",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[" = ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    FractionBox[
     StyleBox["abc",
      FontSlant->"Italic"], "2"],
    FontSize->10], TraditionalForm]]],
 "   ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", "\[Lambda]", "\[Infinity]"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"\[CapitalDelta]", "(", "w", ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "+", " ", "w"}], ")"}]}]], 
     RowBox[{"\[DifferentialD]", "w"}]}]}], TraditionalForm]]],
 "                                                (7)\n                      \
\n                      ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["C",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[" = ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    FractionBox[
     StyleBox["abc",
      FontSlant->"Italic"], "2"],
    FontSize->10], TraditionalForm]]],
 "   ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", "\[Lambda]", "\[Infinity]"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"\[CapitalDelta]", "(", "w", ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["c", "2"], " ", "+", " ", "w"}], ")"}]}]], 
     RowBox[{"\[DifferentialD]", "w"}]}]}], TraditionalForm]]],
 "                                                     "
}], "Text",
 CellMargins->{{Inherited, 73}, {Inherited, Inherited}},
 Evaluatable->False,
 TextAlignment->Right,
 AspectRatioFixed->True],

Cell["and the delta amplitude is", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["\[CapitalDelta](",
  FontFamily->"Times"],
 StyleBox["w",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[") = ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox[
        SuperscriptBox["a", "2"],
        TraditionalForm], " ", "+", " ", "w"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       FormBox[
        SuperscriptBox["b", "2"],
        TraditionalForm], " ", "+", " ", "w"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       FormBox[
        SuperscriptBox["c", "2"],
        TraditionalForm], " ", "+", " ", "w"}], ")"}]}]], TraditionalForm]]],
 StyleBox["                                          (8)",
  FontFamily->"Times"]
}], "Text",
 CellMargins->{{Inherited, 73}, {Inherited, Inherited}},
 Evaluatable->False,
 TextAlignment->Right,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["The parameter ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]]],
 StyleBox[" represents K'/K, and the potential distribution tends to ",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["  ",
  FontFamily->"Symbol"],
 StyleBox["                             ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox["   ",
  FontFamily->"Symbol"],
 StyleBox[" -",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "1"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", "x"}], TraditionalForm]]],
 StyleBox[" ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox["- ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "2"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", "y"}], TraditionalForm]]],
 StyleBox[" ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox["- ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "3"], TraditionalForm]]],
 StyleBox[" ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["z", TraditionalForm]]],
 StyleBox[" ",
  FontFamily->"Times"],
 StyleBox["                                                          ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" (9)",
  FontFamily->"Times"]
}], "Text",
 CellMargins->{{Inherited, 73}, {Inherited, Inherited}},
 Evaluatable->False,
 TextAlignment->Right,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["at large distances from the ellipsoid. The corresponding ",
  FontFamily->"Times"],
 StyleBox["regional",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" velocity field, ",
  FontFamily->"Times"],
 StyleBox["v",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["regional",
  FontFamily->"Times",
  FontSize->9,
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox[", is given by",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["v",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["regional",
  FontFamily->"Times",
  FontSize->9,
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox[" =",
  FontFamily->"Times",
  FontSize->12,
  FontWeight->"Plain"],
 StyleBox[" (K",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], ","}], " "}], TraditionalForm]]],
 StyleBox["K",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], ","}], " "}], TraditionalForm]]],
 StyleBox["K",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["V", "3"], ")"}], TraditionalForm]]],
 StyleBox["                                             ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" (10)",
  FontFamily->"Times"]
}], "Text",
 CellMargins->{{Inherited, 73}, {Inherited, Inherited}},
 Evaluatable->False,
 TextAlignment->Right,
 AspectRatioFixed->True],

Cell["Carslaw and Jaeger also note the identity", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["  ",
  FontFamily->"Symbol"],
 StyleBox["                             ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox["   ",
  FontFamily->"Symbol"],
 StyleBox[" ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox[
      StyleBox["A",
       FontWeight->"Bold"], "0"], " ", "+", " ", 
     SubscriptBox[
      StyleBox["B",
       FontWeight->"Bold"], "0"], " ", "+", " ", 
     SubscriptBox[
      StyleBox["C",
       FontWeight->"Bold"], "0"]}], " ", "=", " ", "1"}], TraditionalForm]]],
 StyleBox[" ",
  FontFamily->"Times"],
 StyleBox["                                                   ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" (11)",
  FontFamily->"Times"]
}], "Text",
 CellMargins->{{Inherited, 73}, {Inherited, Inherited}},
 Evaluatable->False,
 TextAlignment->Right,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["The algebraic solution of the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["A",
      FontWeight->"Bold"], "\[Lambda]"], ",", " ", 
    SubscriptBox[
     StyleBox["B",
      FontWeight->"Bold"], "\[Lambda]"], ",", " ", 
    SubscriptBox[
     StyleBox["C",
      FontWeight->"Bold"], "\[Lambda]"]}], TraditionalForm]]],
 StyleBox["  integrals is problematic. Carslaw and Jaeger only present \
analytic formulae for these functions for cases where some semiaxes of the \
ellipsoid are equal. In the next section we show how to use standard elliptic \
integral functions to develop a general, closed-form expression for these \
integrals. With these results it is straightforward to write down the full 3D \
potential solution for the case where all semiaxes have different, albeit \
ordered, values. The ordering is not restrictive; by simple redefinition of \
the direction of ",
  FontFamily->"Times"],
 StyleBox["v",
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["regional",
  FontFamily->"Times",
  FontSize->9,
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox[" (",
  FontFamily->"Times"],
 StyleBox["i.e.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" of (",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "1"], TraditionalForm]]],
 StyleBox[",",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "2"], TraditionalForm]]],
 StyleBox[",",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "3"], TraditionalForm]]],
 StyleBox[")) and the semiaxes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"a", ",", "b", ",", "c", ","}], TraditionalForm]]],
 StyleBox[" potentials can be generated for any such ellipsoid oriented \
arbitrarily with respect to regional flow.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["2.1  Implementation of the General Formulae", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["We implement Carslaw and Jaeger's formulae for arbitrary values of \
the semi-axes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 StyleBox[", ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["b", TraditionalForm]]],
 StyleBox[", ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["c", TraditionalForm]]],
 StyleBox[" (subject to ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"a", " ", "<", " ", "b", " ", "<", " ", "c"}], TraditionalForm]]],
 StyleBox[") as described below. The solution characteristic, ",
  FontFamily->"Times"],
 StyleBox["\[Lambda]",
  FontFamily->"Courier"],
 StyleBox[", can be fixed for any point ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"x", ",", "y", ",", "z"}], ")"}], TraditionalForm]]],
 StyleBox[" by using ",
  FontFamily->"Times"],
 StyleBox["Solve",
  FontFamily->"Courier"],
 StyleBox[". We first generate the three solutions to the cubic equation (4) \
for ",
  FontFamily->"Times"],
 StyleBox["\[Lambda]",
  FontFamily->"Courier"],
 StyleBox[": ",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Lambda]Solution", "=", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox[
         SuperscriptBox["x", "2"], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", "\[Lambda]"}]], "+", 
        FractionBox[
         SuperscriptBox["y", "2"], 
         RowBox[{
          SuperscriptBox["b", "2"], "+", "\[Lambda]"}]], "+", 
        FractionBox[
         SuperscriptBox["z", "2"], 
         RowBox[{
          SuperscriptBox["c", "2"], "+", "\[Lambda]"}]]}], "==", "1"}], ",", 
      "\[Lambda]"}], "]"}]}], ";"}], TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["and then extract the positive root from ",
  FontFamily->"Times"],
 StyleBox["\[Lambda]Solution",
  FontFamily->"Courier"],
 StyleBox[" to define a function for the solution characteristic, ",
  FontFamily->"Times"],
 StyleBox["\[Lambda]",
  FontFamily->"Courier"],
 StyleBox[":",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[Lambda]", "(", 
     RowBox[{"x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", "c_"}], 
     ")"}], "=", 
    RowBox[{"\[Lambda]", "/.", 
     RowBox[{"(", 
      RowBox[{"\[Lambda]Solution", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ")"}]}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.460671839734494*^9, 3.460671840202314*^9}, {
  3.4606718900066776`*^9, 3.460671912332838*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Figure 1 shows that ",
  FontFamily->"Times"],
 StyleBox["\[Lambda]",
  FontFamily->"Courier"],
 StyleBox[" is a smooth function of ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"x", ",", "y", ",", "z"}], ")"}], TraditionalForm]]],
 StyleBox[" for fixed ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"a", ",", " ", "b", ",", " ", "c"}], TraditionalForm]]],
 StyleBox[":",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"N", "[", 
      RowBox[{"\[Lambda]", "[", 
       RowBox[{"p", ",", 
        RowBox[{"-", "2.4`"}], ",", "0", ",", "4", ",", "1", ",", "3"}], 
       "]"}], "]"}], ",", 
     RowBox[{"Chop", "[", 
      RowBox[{"N", "[", 
       RowBox[{"\[Lambda]", "[", 
        RowBox[{"0", ",", 
         RowBox[{"-", "2.4`"}], ",", "p", ",", "4", ",", "1", ",", "3"}], 
        "]"}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "20"}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x or z coordinate\>\"", ",", "\"\<\[Lambda]\>\""}], "}"}]}],
    ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Dashing", "[", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], "]"}], ",", 
      RowBox[{"Dashing", "[", 
       RowBox[{"{", 
        RowBox[{"0.04`", ",", "0.04`"}], "}"}], "]"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.460671817216758*^9, 3.460671820631844*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Dashing[{1, 0}], LineBox[CompressedData["
1:eJwV1mk4VWsbB3BsKWNYZSpsjmwJsTlliPtGjlDeiIhSCbtBlHKUoULCJWOS
lMxFkhwaqLSRkjm7NqHskgYlhNg4eZ/zYV3r+l3ry3rW+v/v51HzDnT2FRIQ
ECgg13/37FPeIgY+YRaS3QVHzMUofMqhb3aj7wCTpICr/3nhWW00nX4AGmpa
VC2IpdLu3RHrCQJ134ez/zmbnai6iH4SAq+Y6yKxzqhP0gLrNOw56nzfkvit
1LXf891RsENgNtOaWOO66LrZuRhwYhl12RD7mwcfnlaNh4lmwX2biCtf8Qon
rc9DrKu3gwPx7KHN/eOsZBhbtz3BkThXsD9+2iYV2IVv1Z2JN7alrvrVnQar
e2dkthN/ybStmzyQDjPyxe4exOd9/t05MXcRigq//fIi5sztTx9TvQw3ePqm
B4j/fq6iP1qRBZSJ4UAAsdKFVy0j1lfhGrOl7zixtzbSvrFyYO3lx32RxEJz
oR2T4blwtF9hII74Fc9VedImD0wPi5umEJ+4JV79szsfWvc++JVDbJ/2SeRn
bgF8aTrmXky88kSdy/iBQjA42yRTQcy2DhkbnSuCGTNMaCBe3PeBMaJaAk9b
T17+TtzDfhz8/UsJbG2WfjBNfPN6ZsO3ipsgbvyXHk2cQscgx93D1rdg9a5k
tRXEGaI1GZ9Z5WDYe+eP/xFXhdgHHVO4A/XmTgs7ia8Or1ecCL8DURkZzEPE
AZ2yrJ82FeD7msqNI5a92iQ03v0PDJ+dyHhOPCd1r+TIhkr47sdd20P8MbJg
61huJezT8aN/Jb7HOnVt9EAVqD1NWSIhQaGHoZHpj7m7wKGYU67Eec05R7+p
VoOn5n2cJZ7MvKs9cL4a5FNZRrKSFP7Fahns4lcDz9ksWZv4O23atYZTAy1W
LqE7iY3NHU3jYx/BgGekZiNxZ/m8EGP0CbC3J/WUSJH3BVEvST02jIR4QxOx
mWa6aawPGy7Lh0l+Jk6aLJkIfckGml70wKqlFBqlvvb1Lq0D7g8Dz2Li0806
9ga7G8BN37ySLU1hccV9zdKLDSCvE5U8RNyVaUVb1doAO/OMOGIyJL8s90cK
Jk8h3m4kZTtxM+2sngDVCA2nfw/9JJYz75PtePYM7Oss+RYUhbfL4/v89ZrB
RP9nr4YchcOyw+ft9zYD/WGFxzZixt/2FlrpzSCbyjeKIs7dIJ43yG+GwBg9
Po847cV5P4/GFjCvimHny5O8DiaP2+5sA5pA7Zb1ihTmiLdEy9h0gkWNcWjh
SgotzMN2nvHqBO1NwU7viPsD1vw5GtIJmzjF0QrKFCp0JXxqvdkJ1g7C/ETi
1MzNdnHSL4E/x2dEqFAYvapdaqHvJRSJemX50ylkwcvL34M48MrZ6EeyBoUC
+b9q+hI4IOac38EhzhRe2d9cyAHt9QKiCqsobHrhp1LC5cD0suzoPGItl/l8
X9NXsGQxN/OBJunnfsatd4Kv4X2cnu20FoUH0yJqO1O4cLV1jHNPl/RrKn/g
SQkXVqQaPFqkR2GWW5NAeT0XziydmXchbl5JWSdOcmH7Ee24SeI1N4qf27l3
g0dEZeN6fZKfh5zOetUeKN068L6dSfI9tHqw6vYbeCgs9RSMKeR5vVlS9+IN
TJ086J9HvK0nTq/t4xuwvfoogmZC8tby+eSQUi8I7tnd10RMqyiSlovthV9f
AqLdzch6w9UsQnb3wVvPrYkJFhTWUYqXTaTfwnTLhVq0oVBM7SxjwJgHAawN
vl+3ke+xIXXtKRseVIpzzXe5UHjO/dp6ZWcehCSWHntJLJTywNbzEA/mS7Wm
a1zJvPv9ndWdzQOGtZVXmhuF3/pdizuE3kMPu7bS2ZPC1kzGanbrexCOPFup
uI/kW7pFO2/PIETpafTUH6Ower3yXceAQfiqxBvdcZz01SsQ5sMGYSH3Qsg4
sVkZ5eJ2aRCydkt3q/1N/ofdzgjJ9kHY3H+zO/YEhdbRIx0nzT7C5M2ur/sj
KJyZWhrsLDcE1cnGN07HknnY5/KE1voJet7oOwplU3i08ax3IGMYyvLzfCNb
Kaw4IrFNwW4EbuxZE2i1QPofdmhY320MopIMl6SbL8OonHmnye/j8Ny/bLz3
1DIU4PDwUegE3L9hFvmscRlqHvc74aI9BSfHteq6lJbjx6lL28Uf/wKV9qgZ
9aDlaD90MCLt6AwMFFaXD71Zjo4fU9aoqMzCpym1opN2cjjc4H2mqWwOVq5J
Ci6vkUM9Ga6y9e5/4eFfhxtFUB7FYGpv/8RvGLtUe2XqmTzajnhMq7sKIP1Y
5GJbXwXsqfcR9NARxImG7Jj7kop4N+6pF31KEItEjfP17yui36JgXnu7EL7b
pU03iVDCfUFhdyWyaBjX+CPac+MKXMta0755rzCCtpXno+UrsUNWRzzYZBEm
swPHb4kq48PbUVd0aCI4XpRXJPRbGcMEtbe2vhVByfpASlFJFcX6QzcFVC3G
xTRueIc6HYeuq6XnhC/BnoPGuuse0DFdS1G42lUUQ9q23PL2VcOULL/ne+li
OOC4RWKxrDp6pO9ql/gshrMhIv+KPlPHmY1F/JxacSw8ca5n/OIfODhkdaI+
VgLdGW8pfR8NzDc3WNG2VxIX/WA65TmtwrKYYBmWrhSGJvMPvNigibGu+xxo
U1KopOEsYq/PwD/780pi25bi47FSdxtbLcxcfaWszUEar/scruDtWI2n2YmZ
DtXS6JXQL2d+QRu3rHAtataQwU9dy21lutegZcBzT5l4GWzaeHDmEaWLOSu9
NVqnZHB5eDVNNUwPNRpuZDh6yuK6Koe8mjdrMUW3XrurVhaHVhdbtuboo9+E
8MsX2hSGN01zuQcM0LviJz0+mcKguSC7Bl0m+kdtm7dPJXOQYWRrYcDE4G1V
3RIXKHyyIrCr2oiJcVPBSSkZJNdXLVP/MWPibRP+3CWSY1rHh/Kbdkzk1y1w
r5dSuMjY7fBdXyamdEkkPn1OoXOfdbPRNSZmFRzef+4FhUyl1wF1eUwsON5u
vamF7MOpzrmORUy8J5cy29JO4aYTCyUHbzGx34Paz3lNYUdStltJDRMZg4rW
HwbJvuBQL2/ZzUT9qlCVwiEK9wsOxHF7mWga08f3/UyhV+qVc/7vmLiZkX3n
6zCFY2U8RtYQE4MO0VXGx8lcVZYRnJ9gYviGSP4/E+TcIlDAvTjNxBjJD6+O
T5FzhmWZsf4cEzPLCxJmZigMHZDL9xMyxPwzwqyaWQrz//QvERIxxFInX6vw
efK8b5V5jqghVqk/U7b4TdbXaLFrg6Qh1k5o8hdIj2sGK0R7pQ3x/+FVeTA=

     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], Dashing[{0.04, 0.04}], 
    LineBox[CompressedData["
1:eJwd1Hk41dsaB/BtiDLzixA2ncySikrifUtKCFdkqHQpdqordSJTETo4Edvd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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"x or z coordinate\"", TraditionalForm], 
    FormBox["\"\[Lambda]\"", TraditionalForm]},
  PlotRange->{{0, 5}, {0, 20}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic},
  RotateLabel->False]], "Output",
 CellChangeTimes->{3.46067174810415*^9, 3.4606718212400103`*^9, 
  3.4606719219034233`*^9, 3.460677604401353*^9, 3.460677927510728*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 1:",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" Variation of ",
  FontFamily->"Times"],
 StyleBox["\[Lambda]",
  FontFamily->"Courier"],
 StyleBox[" with ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox[" (solid) and ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["z", TraditionalForm]]],
 StyleBox[" (dashed) with ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", 
    RowBox[{"-", "2.4"}]}], TraditionalForm]]],
 StyleBox[" for an ellipsoid with semiaxes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", ",", "b", ",", "c"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{"4", ",", "1", ",", "3"}], ")"}]}], TraditionalForm]]],
 StyleBox[".",
  FontFamily->"Times"]
}], "Special1",
 CellMargins->{{36, 74}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True,
 FontSize->10],

Cell[TextData[{
 StyleBox["It remains to generate algebraic formulae for the integral \
functions ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["A",
      FontWeight->"Bold"], "\[Lambda]"], ",", " ", 
    SubscriptBox[
     StyleBox["B",
      FontWeight->"Bold"], "\[Lambda]"], ",", " ", 
    SubscriptBox[
     StyleBox["C",
      FontWeight->"Bold"], "\[Lambda]"]}], TraditionalForm]]],
 StyleBox[" defined in equation (7). First, following Carslaw and Jaeger, we \
make a definition for the delta amplitude, \[CapitalDelta], equation (8):",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]", "(", 
     RowBox[{"w_", ",", "a_", ",", "b_", ",", "c_"}], ")"}], ":=", 
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", "w"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", "w"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["c", "2"], "+", "w"}], ")"}]}]]}], ";"}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["We may now proceed with evaluating the integrals. Consider the \
function ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["A",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[". The indefinite integral can immediately be evaluated in terms of \
elliptic integrals of the second kind [Abramowitz and Stegun 1965; Gradshteyn \
and Ryzhik 1965]. The integral",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"IndefiniteIntegralA", "=", 
   RowBox[{"\[Integral]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"\[CapitalDelta]", "(", 
        RowBox[{"w", ",", "a", ",", "b", ",", "c"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", "w"}], ")"}]}]], 
     RowBox[{"\[DifferentialD]", "w"}]}]}]}], TraditionalForm]], "Text",
 CellMargins->{{89, Inherited}, {Inherited, Inherited}},
 AspectRatioFixed->True],

Cell["\<\
can be expressed conveniently in the form (given by the integrator in version \
2.2):\
\>", "Text"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"IndefiniteIntegralA", "=", 
    RowBox[{
     RowBox[{"2", " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", "w"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", "w"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["c", "2"], "+", "w"}], ")"}]}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SqrtBox[
             FractionBox[
              RowBox[{
               SuperscriptBox["c", "2"], "-", 
               SuperscriptBox["a", "2"]}], 
              RowBox[{
               SuperscriptBox["c", "2"], "+", "w"}]]], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{
               SuperscriptBox["a", "2"], "+", "w"}], 
              RowBox[{
               SuperscriptBox["c", "2"], "+", "w"}]]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["c", "2"], "+", "w"}], ")"}], " ", 
            RowBox[{"E", "(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["sin", 
                RowBox[{"-", "1"}]], "(", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["a", "2"], "+", "w"}], 
                 RowBox[{
                  SuperscriptBox["c", "2"], "+", "w"}]]], ")"}], 
              "\[VerticalSeparator]", 
              FractionBox[
               RowBox[{
                SuperscriptBox["c", "2"], "-", 
                SuperscriptBox["b", "2"]}], 
               RowBox[{
                SuperscriptBox["a", "2"], "-", 
                SuperscriptBox["b", "2"]}]]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "+", "w"}], ")"}], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["c", "2"], "-", 
                 SuperscriptBox["a", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["b", "2"], "+", "w"}], ")"}]}], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["b", "2"], "-", 
                 SuperscriptBox["a", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["c", "2"], "+", "w"}], ")"}]}]]]}], ")"}]}]}],
         ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "-", 
           SuperscriptBox["a", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["c", "2"], "-", 
           SuperscriptBox["a", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["c", "2"], "+", "w"}], ")"}]}], ")"}]}]}], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", "w"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", "w"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["c", "2"], "+", "w"}], ")"}]}]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", "w"}], ")"}]}]]}]}], ";"}], 
  TraditionalForm]], "Input",
 CellMargins->{{Inherited, 127}, {Inherited, Inherited}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Then, ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["A",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[" ",
  FontFamily->"Times",
  FontSize->10,
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["can be expressed conceptually as",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"a", " ", "b", " ", "c"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"w", "\[Rule]", "\[Infinity]"}]], "\[ThinSpace]", 
      "IndefiniteIntegralA"}], "-", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"w", "\[Rule]", "\[Lambda]"}]], "\[ThinSpace]", 
      "IndefiniteIntegralA"}]}], ")"}]}], TraditionalForm]], "Input",
 AspectRatioFixed->True,
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[{
 StyleBox["The upper limit deserves some special attention. Before taking the \
limit as ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"w", "\[Rule]", "\[Infinity]"}], TraditionalForm]]],
 StyleBox[", we define the symbol ",
  FontFamily->"Times"],
 StyleBox["EllipticFunction",
  FontFamily->"Courier"],
 StyleBox[" as a dummy symbol, and substitute for a simple rational identity:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"IndefiniteIntegralA", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"E", "(", 
       RowBox[{"k__", "\[VerticalSeparator]", "j__"}], ")"}], "\[Rule]", 
      "EllipticFunction"}], "}"}]}], ";"}], TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Cancel", "[", 
    RowBox[{"PowerExpand", "[", "%", "]"}], "]"}], ";"}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["The limit can now be evaluated (leaving the limit for the ",
  FontFamily->"Times"],
 StyleBox["EllipticE",
  FontFamily->"Courier"],
 StyleBox[" function unevaluated for the moment):",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderscriptBox["lim", 
    RowBox[{"w", "\[Rule]", "\[Infinity]"}]], "\[ThinSpace]", "%"}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "EllipticFunction"}], 
  RowBox[{
   SqrtBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "+", 
     SuperscriptBox["b", "2"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a", "2"], "-", 
     SuperscriptBox["c", "2"]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.460671998062174*^9, 3.460677616776353*^9, 
  3.460677938198228*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["It remains to determine the limiting behaviour of the ",
  FontFamily->"Times"],
 StyleBox["EllipticE",
  FontFamily->"Courier"],
 StyleBox[" function appearing in ",
  FontFamily->"Times"],
 StyleBox["IndefiniteIntegralA",
  FontFamily->"Courier"],
 StyleBox[". If we choose the principle branch of ",
  FontFamily->"Times"],
 StyleBox["ArcSin",
  FontFamily->"Courier"],
 StyleBox[", we find that the correct limit involves a complete elliptic \
function of the second kind:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"EllipticFunctionLimit", "=", 
   RowBox[{"E", "(", 
    RowBox[{
     FractionBox["\[Pi]", "2"], "\[VerticalSeparator]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["c", "2"], "-", 
       SuperscriptBox["b", "2"]}], 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"]}]]}], ")"}]}], TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"EllipticE", "[", 
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["b", "2"]}], "+", 
    SuperscriptBox["c", "2"]}], 
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    SuperscriptBox["b", "2"]}]], "]"}]], "Output",
 CellChangeTimes->{3.4606720019341235`*^9, 3.460677618416978*^9, 
  3.460677939307603*^9}]
}, Open  ]],

Cell["Whence ", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"upperlimitA", "=", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"E", "(", 
       FractionBox[
        RowBox[{
         SuperscriptBox["c", "2"], "-", 
         SuperscriptBox["b", "2"]}], 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}]], ")"}]}], 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["a", "2"]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}]]}], ";"}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["yields the following expression for ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["A",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[":",
  FontFamily->"Times",
  FontSize->10]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "\[Lambda]_", "]"}], "[", 
    RowBox[{"a_", ",", "b_", ",", "c_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"a", " ", "b", " ", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"upperlimitA", "-", 
      RowBox[{"(", 
       RowBox[{"IndefiniteIntegralA", "/.", 
        RowBox[{"w", "\[Rule]", "\[Lambda]"}]}], ")"}]}], ")"}]}]}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "a", " ", "b", " ", "c", " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", "\[Lambda]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", "\[Lambda]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["c", "2"], "+", "\[Lambda]"}], ")"}]}]]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", "\[Lambda]"}], ")"}]}]], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"EllipticE", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["b", "2"]}], "+", 
         SuperscriptBox["c", "2"]}], 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}]], "]"}]}], 
     RowBox[{
      SqrtBox[
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}]], "-", 
    FractionBox[
     RowBox[{"2", " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", "\[Lambda]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", "\[Lambda]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["c", "2"], "+", "\[Lambda]"}], ")"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["c", "2"]}], 
            RowBox[{
             SuperscriptBox["c", "2"], "+", "\[Lambda]"}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", "\[Lambda]"}], 
            RowBox[{
             SuperscriptBox["c", "2"], "+", "\[Lambda]"}]]], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["c", "2"], "+", "\[Lambda]"}], ")"}], " ", 
          RowBox[{"EllipticE", "[", 
           RowBox[{
            RowBox[{"ArcSin", "[", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["a", "2"], "+", "\[Lambda]"}], 
               RowBox[{
                SuperscriptBox["c", "2"], "+", "\[Lambda]"}]]], "]"}], ",", 
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["b", "2"]}], "+", 
              SuperscriptBox["c", "2"]}], 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["b", "2"]}]]}], "]"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", "\[Lambda]"}], ")"}], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["a", "2"]}], "+", 
               SuperscriptBox["c", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["b", "2"], "+", "\[Lambda]"}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["a", "2"]}], "+", 
               SuperscriptBox["b", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["c", "2"], "+", "\[Lambda]"}], ")"}]}]]]}]]}], 
       ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["c", "2"], "+", "\[Lambda]"}], ")"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.460672009115966*^9, 3.460677621416978*^9, 
  3.460677942557603*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["For ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["B",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[" and ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["C",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[" we may make use of the symmetry of equations (7) to write:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"B", "[", "\[Lambda]_", "]"}], "[", 
     RowBox[{"a_", ",", "b_", ",", "c_"}], "]"}], "=", 
    RowBox[{
     RowBox[{"A", "[", "\[Lambda]", "]"}], "[", 
     RowBox[{"b", ",", "c", ",", "a"}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{"Unprotect", "[", "C", "]"}], ";"}],
  TraditionalForm], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"C", "[", "\[Lambda]_", "]"}], "[", 
    RowBox[{"a_", ",", "b_", ",", "c_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"A", "[", "\[Lambda]", "]"}], "[", 
    RowBox[{"c", ",", "b", ",", "a"}], "]"}]}], ";"}]}], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["It is straightforward to check these results numerically against \
their (slowly convergent) integral representations. For example, with the \
semiaxes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", ",", "b", ",", "c"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{"1", ",", "2", ",", "3"}], ")"}]}], TraditionalForm]]],
 StyleBox[", the algebraic expressions evaluate to:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "0", "]"}], "[", 
     RowBox[{"1", ",", "2", ",", "3"}], "]"}], " ", "//", " ", "N"}], " ", "//",
    " ", "Chop"}], TraditionalForm], "\n", 
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"B", "[", "0", "]"}], "[", 
     RowBox[{"1", ",", "2", ",", "3"}], "]"}], " ", "//", " ", "N"}], " ", "//",
    " ", "Chop"}], TraditionalForm], "\n", 
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"C", "[", "0", "]"}], "[", 
     RowBox[{"1", ",", "2", ",", "3"}], "]"}], " ", "//", " ", "N"}], " ", "//",
    " ", "Chop"}], TraditionalForm]}], "Input",
 AspectRatioFixed->True],

Cell[BoxData["0.5765452609087243`"], "Output",
 CellChangeTimes->{3.4606720180932684`*^9, 3.460677625901353*^9, 
  3.460677946213853*^9}],

Cell[BoxData["0.2671540402620044`"], "Output",
 CellChangeTimes->{3.4606720180932684`*^9, 3.460677625901353*^9, 
  3.460677946229478*^9}],

Cell[BoxData["0.15630069882927117`"], "Output",
 CellChangeTimes->{3.4606720180932684`*^9, 3.460677625901353*^9, 
  3.460677946229478*^9}]
}, Open  ]],

Cell["\<\
These results may be compared with the respective numerical quadrature \
equivalents:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{"3", " ", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"w", "+", "1"}], ")"}], " ", 
       RowBox[{"\[CapitalDelta]", "(", 
        RowBox[{"w", ",", "1", ",", "2", ",", "3"}], ")"}]}]], ",", 
     RowBox[{"{", 
      RowBox[{"w", ",", "0", ",", "\[Infinity]"}], "}"}]}], "]"}]}], 
  TraditionalForm], "\n", 
 FormBox[
  RowBox[{"3", " ", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"w", "+", "4"}], ")"}], " ", 
       RowBox[{"\[CapitalDelta]", "(", 
        RowBox[{"w", ",", "1", ",", "2", ",", "3"}], ")"}]}]], ",", 
     RowBox[{"{", 
      RowBox[{"w", ",", "0", ",", "\[Infinity]"}], "}"}]}], "]"}]}], 
  TraditionalForm], "\n", 
 FormBox[
  RowBox[{"3", " ", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"w", "+", "9"}], ")"}], " ", 
       RowBox[{"\[CapitalDelta]", "(", 
        RowBox[{"w", ",", "1", ",", "2", ",", "3"}], ")"}]}]], ",", 
     RowBox[{"{", 
      RowBox[{"w", ",", "0", ",", "\[Infinity]"}], "}"}]}], "]"}]}], 
  TraditionalForm]}], "Input",
 AspectRatioFixed->True],

Cell[BoxData["0.576545260908725`"], "Output",
 CellChangeTimes->{3.4606720225428877`*^9, 3.460677627635728*^9, 
  3.460677947854478*^9}],

Cell[BoxData["0.26715404026200473`"], "Output",
 CellChangeTimes->{3.4606720225428877`*^9, 3.460677627635728*^9, 
  3.460677947870103*^9}],

Cell[BoxData["0.15630069882927092`"], "Output",
 CellChangeTimes->{3.4606720225428877`*^9, 3.460677627635728*^9, 
  3.460677947916978*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Although the above numerical evaluations sum to 1, according to \
equation (11), the complexity of the analytical forms of ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["A",
      FontWeight->"Bold"], "\[Lambda]"], ",", " ", 
    SubscriptBox[
     StyleBox["B",
      FontWeight->"Bold"], "\[Lambda]"], ",", " ", 
    SubscriptBox[
     StyleBox["C",
      FontWeight->"Bold"], "\[Lambda]"]}], TraditionalForm]]],
 StyleBox[" prevents easy algebraic verification of the summation identity \
for arbitrary values of ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"a", ",", "b", ",", "c"}], TraditionalForm]]],
 StyleBox[".",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["We can now write down the potential functions (",
  FontFamily->"Times"],
 StyleBox["c.f.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" equations (5) and (6)). The potential inside the ellipsoid is:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"uInner", "[", 
   RowBox[{
   "x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", "c_", ",", 
    "\[Epsilon]_", ",", "V1_", ",", "V2_", ",", "V3_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"V1", " ", "x"}], 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", "1"}], ")"}], " ", 
       RowBox[{
        RowBox[{"A", "[", "0", "]"}], "[", 
        RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], "+", "1"}]]}], "-", 
   FractionBox[
    RowBox[{"V2", " ", "y"}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "-", "1"}], ")"}], " ", 
      RowBox[{
       RowBox[{"B", "[", "0", "]"}], "[", 
       RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], "+", "1"}]], "-", 
   FractionBox[
    RowBox[{"V3", " ", "z"}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "-", "1"}], ")"}], " ", 
      RowBox[{
       RowBox[{"C", "[", "0", "]"}], "[", 
       RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], "+", "1"}]]}]}]], "Input",
 AspectRatioFixed->True],

Cell["and outside is:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"uOuter", "[", 
   RowBox[{
   "x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", "c_", ",", 
    "\[Epsilon]_", ",", "V1_", ",", "V2_", ",", "V3_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "V1"}], " ", "x"}], " ", "-", " ", 
   RowBox[{"V2", " ", "y"}], " ", "-", " ", 
   RowBox[{
    RowBox[{"-", "V3"}], " ", "z"}], " ", "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", "1"}], ")"}], " ", "V1", "  ", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{
        RowBox[{"\[Lambda]", "[", 
         RowBox[{"x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c"}], 
         "]"}], "//", "Chop"}], "]"}], "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", "x"}], 
    RowBox[{"1", "+", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "-", "1"}], ")"}], " ", 
      RowBox[{
       RowBox[{"A", "[", "0", "]"}], "[", 
       RowBox[{"a", ",", "b", ",", "c"}], "]"}]}]}]], " ", "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", "1"}], ")"}], " ", "V2", " ", 
     RowBox[{
      RowBox[{"B", "[", 
       RowBox[{
        RowBox[{"\[Lambda]", "[", 
         RowBox[{"x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c"}], 
         "]"}], "//", "Chop"}], "]"}], "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", "y"}], 
    RowBox[{"1", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "-", "1"}], ")"}], " ", 
      RowBox[{
       RowBox[{"B", "[", "0", "]"}], "[", 
       RowBox[{"a", ",", "b", ",", "c"}], "]"}]}]}]], " ", "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", "1"}], ")"}], "V3", " ", 
     RowBox[{
      RowBox[{"C", "[", 
       RowBox[{
        RowBox[{"\[Lambda]", "[", 
         RowBox[{"x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c"}], 
         "]"}], "//", "Chop"}], "]"}], "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}], "z"}], 
    RowBox[{"1", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"C", "[", "0", "]"}], "[", 
       RowBox[{"a", ",", "b", ",", "c"}], "]"}]}]}]]}]}]], "Input",
 CellChangeTimes->{{3.4606733436544647`*^9, 3.460673381415498*^9}, {
  3.460673667889351*^9, 3.4606736786612463`*^9}}],

Cell[TextData[{
 StyleBox["Note the use of ",
  FontFamily->"Times"],
 StyleBox["Chop",
  FontFamily->"Courier"],
 StyleBox[" to discard small, unphysical, imaginary components from the \
calculated ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Lambda]", TraditionalForm]]],
 StyleBox[" values. If these imaginary components are retained, they \
propagate through the integral function evaluations and dominate the \
potential functions. A single potential function valid for all ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"x", ",", "y", ",", "z"}]}], TraditionalForm]]],
 StyleBox[") can now be defined:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"u", "(", 
    RowBox[{
    "x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", "c_", ",", 
     "\[Epsilon]_", ",", "V1_", ",", "V2_", ",", "V3_"}], ")"}], ":=", "\n", 
   "\t", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Chop", "[", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["x", "a"], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["y", "b"], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["z", "c"], ")"}], "2"]}], "]"}], "\[LessEqual]", "1"}], 
     ",", 
     RowBox[{"uInner", "(", 
      RowBox[{
      "x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c", ",", 
       "\[Epsilon]", ",", "V1", ",", "V2", ",", "V3"}], ")"}], ",", 
     RowBox[{"uOuter", "(", 
      RowBox[{
      "x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c", ",", 
       "\[Epsilon]", ",", "V1", ",", "V2", ",", "V3"}], ")"}]}], "]"}]}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.4606759456688356`*^9, 3.460675953792328*^9}, {
  3.460677708713853*^9, 3.460677720870103*^9}}],

Cell[TextData[{
 StyleBox["With the above closed form expression, we can easily inspect \
various properties of ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 StyleBox[". Figure 2 shows the variation of ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 StyleBox[" on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane near a highly conductive ellipsoid, with regional flow \
directed in the positive ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox[" direction (note that the ",
  FontFamily->"Times"],
 StyleBox["ImplicitPlot.m",
  FontFamily->"Courier"],
 StyleBox[" package is required here):",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y", ",", "0", ",", "2", ",", "2.5`", ",", "3", ",", 
       SuperscriptBox["10", "7"], ",", "1", ",", "0", ",", "0"}], "]"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "30"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}], ",", 
     RowBox[{"Contours", "\[Rule]", "21"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], ",", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["x", "2"], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["y", "2.5`"], ")"}], "2"]}], "\[Equal]", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", "0.01`", "]"}], "}"}]}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.460672148291091*^9, 3.460672151118202*^9}, {
  3.460672186636718*^9, 3.460672291614705*^9}, {3.4606723843158445`*^9, 
  3.460672385268628*^9}, {3.4606724456540995`*^9, 3.460672470352165*^9}, {
  3.4606725152492185`*^9, 3.4606725160303087`*^9}, {3.460672726506957*^9, 
  3.4606727308967953`*^9}, {3.4606735929082074`*^9, 3.4606736362146645`*^9}, {
  3.4606736929508133`*^9, 3.4606736988136005`*^9}, {3.4606737398843813`*^9, 
  3.4606737412289143`*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyE3Xe43VWxN/AkhISEhOSEWG6uoggKCIhXwYKRsy0EpauAgIIUBUWvItjx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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0k9Mz3Ecx/G3sJDYsnXxJ8Wv38ifuZro4mAuITccGnKpZAu12a/tF5li
42AryuaAbORPMWzd+J0c+rX5E8Mmm7qUvzWb8ejw3PP3ev623+/z/fx+xdX1
u+tmRcQTPF0ZsW99xAHsR3ZFRGVZxDAnSiOeeb/BHrWP8hc+xhm9h6fsbp7m
a/xSf8TziiIGeD4/5td62ue/9XoEb/Ae73Be/8bfMYmf+IFOPW9dxEIswCLk
47Y+WRJRvzxi08aI3OKIfnvJzBm1c87djs7VEV0o1Bv1W1ovbmg3UaSn9H5t
AHe0u+jD2JqIV1qt8z+3XyCDCX1CP6V/sD/iE6b1v/pl/Zf9G1P4pxcknVnP
T3gGLMbctRFJfVBP2KVIIk/fomf1cnsrtqFA36mP63vsKuzFMr1a/6Mftmuw
2XNd91xpvRVNWjMq9F79onYJKa0FO/SHevuqiA7Uucsc9zoHs3FBW7oh4oS7
P4njaEYTyvRWPo002nAG2/UrfBVd6EE3qvSM3+u+15X+E/d4Fz/gIT3LB+0h
PsTDPKKPcaP9deb7eZw/6xXud9AZ27RC/4uznPIdLahxN0fwHzxzgV4=
          "]]},
        "4.3`"],
       Annotation[#, 4.3, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0jtszWEYx/FHQgc6qLosrd5PT3vOUZekEiVOJVjcUglJm4hLI624DMTR
ELG0QWIwSTQYDOgJiqjLoBJLDSbScxYRiqmkHSQYyqfDN0+e7+//f//P+77/
moMnOo7PiYg3mKyM6G2O+NkQ8QOTuFQdUZKM6Oa/6b9iAjn+X2PEfr6oL2Ac
h/lpvovvxIEVnsFu/kk6okN93BLR0hQxVuNdz2a5W7KN6n1Zo2xE9k6W4S7K
0uodWZUsY700RuWv8QpL+SWo4B/qh/EA87i5KOWv1JlZPVobMaMeUwe4fgzZ
e/vyiHP2cBYD3u3Hbb6N7+V60M0dwg2+ld/L7cF2bhsW23M5NnHtyOJ9VcQG
WSnfrG9CEqN8ki/hF+nLsBB5vpwP/m99xB/8xjV+JqG3nwn9F3zGeX6Kn+Kn
kTLXW34MRb6Ay+ZN8I+4YTzjRnCBr+bvcXeR54Zwml/GP3VGZe5i3LoFFGe/
wXX6J854rg857NLvRD7jrPRH0IOt3BZc5wexj0uZ91fK9tQ+d5qVf3K/O2SV
3EdZhZqTtcqKss2yBdxL2Xz1ufoCp6x5EjfNtd78bVg3e2ZmX+udQX6NfjVW
4Tu/kr/K1+vrUIsPfIJP+F4D/gOPK31E
          "]]},
        "3.87`"],
       Annotation[#, 3.87, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0UtIlFEYh/HXTW2SFinWwsnpZuaMLitQQapxVomD3cgQgoK0DLIbTRC1
i8oWXYgWFWRQ4CaF7osskLJlbkYMXGQEGZHdyFL7tXg4vM//nO+87/mSuw/m
uooiYhCfyyMOJSJG1kS8xeJ0RBkm+C7+JfcCk6mITxjj9/GjKyMK+FYZMYVd
9rRhmHuNV2itiPgoa+WfqZ/iCRr5Ap/lm/AwGZGpiajlz7qjxnq3NqKiKuKO
bNDeBJeXlVtvy8pkV2XlzvXLB3Af8/l5KOYvq6/gEiZX6x/B55dHzJpxDjPo
9p3j3DH0mq/OfJ367MBeZ/fgBr+W38FtRzO3Gdf5UjNs4jZiA0aWRjTIivm0
OoVqPOer/vfIl6pLsAh9fAlfxM+siPiLP7jGz62KmDbPB/UE3uMU/5Wf4i+6
P6WvN/wwRvkCzvGV/ADXj8fcI5zhk/yDZRFLzD3mG+9wmv/OdXijC/b14Dza
1Dsx5J3y6pM4gRzXgj5+2j/p5Or1tdA/qrPm/aOs/IusXZbmflXr1frTOiQf
l/U4f8/92/S4FVuQsKfZmV4+q25CBgv4DH+Tv4VZPTfw9VjPr0Mj9xtHveUR
HHZXN2q5HzjA7UeOa0G7+/8BaB6BEA==
          "]]},
        "3.44`"],
       Annotation[#, 3.44, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0klsDGAUwPFXDsbB4KCtUl1sbTGdk0gsTRwoLkNtrbQRCa2oJShqC3G1
XiyJpJcSJFSYRqKWOOlBx4mD5WgpoYM4NVG/Hv558/7vfd/35s1UbNu7bk9B
RDxHujRi/byIDWjAJmzE1gURh8TD6EAnjmAn/6ky4jNel6vJc+KIe+rRp+cJ
ztVEnMfYGREZPjMnYi02z4poRBPuVHuHS5VF7JC3og09/HX35t3bXxsxaX7E
Mj2TxTqx3ZlhtYaqiJPqq7kitTXiCbV+Z1+iWb0FF7hLuIhd8r9mH++dBMah
pCLiEVdp1jNmfayvD1m1XlTxZ/n33Ae84gaQwx+z/uZOefuL/CsGMczH3Ihr
/D/5CGJ2xBg7mcLf5QvlRShGgq/hX/ApeS3SSPJ1/Bt+hXwl6lHIZ/jvfJN8
CxaZs8ucrXwb2rndWMrf4DtnRhxFh+87aA8HxW+jO+QKUhFDPudx2dmruIIk
PxEJ36fLrifY+367TorZ0R53FKt1q5Vxx9XKxZQzN9UWm3MJcnrT/D3z9OA+
VvHv+OX8U/kztJh1wKxZ9/TigZ6H2M6/5bvN+lFc6L0DfrPb8lvY572f+ofw
A7+QxzG+xH9hGqaiFNNxmv8PL+l6cA==
          "]]},
        "3.01`"],
       Annotation[#, 3.01, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ktI1FEUx/FjBWoFuuqBOTZZmWnF0GNRFraMbFEUZJTVbEStmSCyBz0Q
hKBoYy1SF06bdokFqYlmteixsqDcRIsgqAZtUdYiDPq4+HLmfn/3nnvun0mm
swcyBRHxCqnyiK7qiOZNER8SEYdrIibVqrURoyvVdRFtsq/cJdk3NSV7LauV
ZWV/uZxsO1+HHWjfEPGUG8cYnuMZOvnvqyIa3Vvr7Gd9BqwL9TjCnXQ2jZbV
Ea1ow4D5TnP1FRHnrNvRr88/Zx+os+pBs1zTr8GeZbUR+9SrzhQlI97Yc1x+
Al3cHdzGKes/7l6s3yIsRJn9w1yleTrNM2rfGAZlQ6jmb/F5M33iM+6Z4N/i
HWb4X3wHn7eewjRm+YKqiB6+YE3EfCyYq+sjlvD9/HLrMqxAMV/Dv+BT1pux
BSV8PT/J77HeiwYs5ffzU/xR62NoQjmfM2+LrBUZLotd3nGfv1wZcQXnvXva
92hXf6gd3LyN3uL3DLqd7Z2bH6X8dfuKvSnnm5f4/md981L1sfyuLGFPt1qh
Jvk+d+ZwDzvNNGFfin9o/QiN5nlpnh739uLM3H9C72IUoY87pNeQe4YxiBE8
QZrfapZtmNH3Pdes92+/P5qhjh/R4wL3U3ZRDW/6ItstG5fd4BL+JzfVQlle
9h8LkH+V
          "]]},
        "2.58`"],
       Annotation[#, 2.58, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0UlI1WEUxuFjbhrIsE0qZWmOpSVS2aIBV5YLA0vbBKUQVJJmBmkbozJa
tIuUygI1aGnmIgearE3RQiQpaNg1iE1GI0b03MWP9573nO+83/e/WfVN1Y1J
ETGOz8siWjIjvuZGfMH5FRFzCyL2r4r4oH6PdzjBT+LX8+twdE1EMw7yJ4si
DtDbayPKCiMmsiKm8iNqeaN6NXRQr0RvtzO1eKX/Gi9RyC9AJf/SyohtdDsq
MGRXF68Td9x1i+zr7tOHXmTbPWZHCT/djsvmM+hi/jHZqbRH9nzeOb1UO6+a
v4Zu/PGm30jmn5Hxze9WczO0jZ7kteOG7K2+U7PMI5hdHtHgfKbcenUd9uIT
v5qfxr9vxx47HtAX/Er957Rcv4ZfTB+pS/kPaZG6ip9Gb6oz+P10ibqCn5y4
s3oO/0pC1Zv43/MiTquncyJO0R/e+jTxvfXeFkf8VE/qPcMEmsy8cWaaP6Ie
xhDu8e6iw1tzvHU4O2KpHQv1UrAIv3iHvafTXBcuol5dhyey5plv5+2Qke77
V9EROY/d55//ot/MqLrNrlYcR7mZRmcG+XWyF8gekDNjfoB3C/v4H3nlcnaa
3YVqbFSXocPes6jgpdg3ttq9aYvcUv1xuzbr/bW7T2+W9tBeNDh3CN1yNrjP
eqzDlJlSZy7w89V5yEUhryCBvf8BS+iGrg==
          "]]},
        "2.15`"],
       Annotation[#, 2.15, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0l1MznEYxvHb1saszetmVHqSQsh6OnEcB9SB17xuRh3YmqlMWHXgrdqc
OompzEQbkgM2qmc2mlkcMZaDbJgDejEUw4HPc/Dd/f9d931f1+///J+8qtrt
R2dExGuU5kR8XBbxCalExKG1EYPqND2JptURzThZFHEKf2hluE7rRgutFW3Y
TN9UGDEn1/PyiHJUoHuVPt8RvkPrIkbt5Zp5rybUSjsf9MpWRoy7xwS+O3fY
6UInMpdGVPGvNVuHRr5NaMYA/z4z95C1JmIJtvLNVrepp83Pzouo5n9G/n5a
vl47/TIupT31fsttlTGP51zk2HlEK5DdRh+V89hstf1+/UGkMEZfpBaav8in
Tv+Vc336Hc2X0DvpW2Sfp5XKblGn9Mbc+Stu6vcgY0XELMzEOP0urQ+LnXOQ
jQn6fdoDFDsnUYJJ+jf00/fKGJGxT32nlukfcI8d6X3ngwXm1WGzh+lZ7pvr
Gx7R/0c/pn8cDUjQe7z/2fyIc2g0P2XvF6Yxn5ZR7L/h+S+6eNTLzfQNr3q+
YD7Tb3TN+y+gNegtVBN28lDCP4knZvPp3TJvYKffPSW3nf8ztcJMOWp9kw7a
FVTYf8i/iH8v/w3pTP4b1T16z/Uq7ezCF/676cO8X+Al3vJ9Y76G3m9mADVy
R+k/6D/xlDaUzqV/pt+SO6mul3fCXe4430Yv/gPT04+z
          "]]},
        "1.72`"],
       Annotation[#, 1.72, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0klI1WEUxuETZFBGgxXUDTXLoSz1ZsOuICXCsEUuisgIsqCgFBJyIWot
sgGHMImWtcg5gmhTVNqqRcOiFk6lpARhiyCobNHwuPjxct7vnPc7//vdrBM1
FdXzImIa29MjOjdFnC6KGM6IOLI5YoTm50YMrotoVM+oG+hFNOFsQUQ37UEX
+tCLOv6X9REHZebLGzP/QD3ffAXvkMzDOJodUYlj6Hd3u7lpvS/NzMopyoz4
TZO0Sv/+jRFl+CZrUP9zPMM/Mw95S+WfkT/Eu6S/wtxl2c14LfsNXiE1K+K7
/krnNfLS1NX0vbN3WC2nTs6AjPvom9sPA5iUnUab9DfipIyn6lP0hd48Wc16
OuSvUSfwaUPEHvVYYUQpHaEldJRO0Q/0I8YxiQnsltMlfxedsVOBnTrslJIX
sQApORSF/E5+grcW6bwMJPm3+EW8JHbwdqKYf5u/xE6JfDsiMfcG7lnOW4YL
yPEGN+2WTTtpLt1Hp5yVepN031WmPjv3nzF7zh1//Aa17vhLR+w+inTZWe64
Mre3d2pw3ogSe/TbI1PeI5qjJ0PvNVmpMuvpVWctNM3vsRIrsEpGi/lWtGGb
ucfm2/XeQI/+In3dNEk7eFtpMbLk9vqOYhnXt5il5fwnesvlHMCEPffyB2UP
4bg938q/I+cuzvvmRTIWIxX3eFUyRuSNYhjjGEMt/yf9hR+olztLP7uvxC5D
5lt5md63jS70e3119h+a/Y/v
          "]]},
        "1.29`"],
       Annotation[#, 1.29, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV00dI12Ecx/FvUGnQLoxomLY3pc1DWo7US9Cl/HuzQQO0okPDoAFZGWm0
Dk0KyqRTw2xARmHjUtGiRUUL8hJ00gp6/Q5vPz7f5/P9fJ/n8WdWZfXiqi4R
0d+PX8MiXk+IeIWXqB8RMWJyxA/1h9YP0IYa9Y5JER/VP4yOeI93WKu+YkrE
SizH86yI9rER5eq3+ZfSq1Mjpo2PSNkvx9mREeewPjsi194TmaesH9LU8IiL
5jUiV2+djFb1+dZNsnP0X6Td9HVHnno+7vAclHGTLpLR4Gz1yJDRx+x6Pb3p
AbqXr4b2sq6jmaMixsgYi1p7l2QUyLjjfM+snyJNzttxEdX8Hd6nilbqX4Y+
YyJ20Qzn2a/nujNOpLfoJNpCb+IGBvHMkjcbZfYKJ0YUoRhf1O6au0bWWqxC
Cc9qetyZcu0t0X9b7THvI7zLNJ8Odoc6+Z3OtY82Je+ELN6T+nrIT8dCZy9G
k3qpty1DCYrUCtHonkf503i7o0BtQVLnz+PLxzzMV8vHBf5D/N14u+K8dV5S
55/JV+t8uXQ3nUFb7Jfbr0AK162zvGszzaYNyffoLq/wybt+xlAMQas569z1
u77p7nmaP4cWmZXyLoX0rDsfwVEcRrraMZpG2/T+8038xTZvWoPh+rfLyaQ7
6C2+e3z30en3F3I76CbnGmz+C7MH8K7nHUg30H7u3RcT+C6b1VN9uXovuoLu
cZda7HKHnVgjq6+sK7Ku4jKacS15a+90hv5O/m+S74v3pO/yBI7jjzmdqFBP
l/GVr4H/G203/yfmmDkXpWb1k3cvOR/d6C456s94N+nZgs3J39HZ8vBP3jw9
BbK3mrUFm9GuvkPGDPV11tWowhv1lHqrvP+szq4E
          "]]},
        "0.86`"],
       Annotation[#, 0.86, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV1FlslVUUxfFdoYgKTSi0gPYW217wFqhEoVXCCyCDFDRCX1TGkMADBHkB
jBHB0NYYhkIYpJRBKyqGlioBosQxzFVSCAhowiiiL2rEWYbi73v4d9299j7r
nPP1u7do5vxJL2RFxGx/KlIRUwZETMVkTMc0zCyLqKY1WIbXUIt5/J+KIyqt
ywyKOPVgRIs6CiPG8w6ZOYzV/SPWIJtfxb/Mu4I3eBtRjyn8Mhk/ynikT8Qt
/XbcRqN9suTONTPITBRF7FHv59/l80dJn35MO/C/Lo34Cq04Ys+xMqpkpgZG
9EEh2sz2Nfuu/gSZzfY9qh7Pn4A8a/LRE7v1etDuyMWH6kozqYwsvORcg2Vs
Tkd0ws2+ETfwsuzDJRGL6Q/ueBUd7bHuYXN0Lc2m5WYaZF6UWeoeF2iGzue/
Ym27rDs42C/iAL6wx5f4xf0ume1vdpL9O+plo9qao9Y2y+8nv4k+RHfRFky1
LqOeRnvTZ619Du/r7UAu7w9n/RN/4YSsGplX9L7HZYwxc5XeS4/p30fr1V3o
JrrffdKeTQkqnHGL+hl7dHC+32UO5b3Nm8jrysvBTnucl9VEe3vOvbBX1h6c
kPsARpjfoH/G3Ho6XH0//y1Zy+lI9Ub+Wf16+oS6gH8ShRitbuCf099ER6lT
/EbrV9An1dv43+m/Scepi/nPe1a57rLNXDe6lXbXe1XvN/e5jjZruql/pcdo
K5ZgqbVL0OAeWe55NzqhNnkveNfwr/X/4G9sl51j3TD5S83U+bwaQ/Cf7DP0
LFahVu5uM7PM1iRnlDvOc6vEcX5aXeBdOWCPg8l7wM+gFBdlXcJgOYf0HqUt
1lzg7aIpMwUo43+qv9m5KvSq1T2S/WgezUueAf862pJzWfu6s9TRU7zTmMNv
Tt5B35UX9eb6vIguRJ7sVd7hKlmdnfcefGNNvpmfk7Mkvyl6Wcg3u8Zsmm6h
xcm5aAmtNfcO7Um3017J95tu1X+MNtEhtALlaMTjyd5+D+qwEuXu+BTvE7NP
+1+0Om8jf0zy26b+ADPc6yT/M/7n2Mvbh9n8b/nvOfMOLLR/V2deQHPoTt4C
2TetuYUbaMdtLOYX+06UoCj5bUIay/j/A/OW438=
          "]]},
        "0.43`"],
       Annotation[#, 0.43, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0z1szVEcxvFfWTAgqt77clt91zZRURVtQwcSRFJiUKUtQaVvYfCS1GDQ
dmorMQkDYsCCRVJCJYoa2oSJliphqYREJBbX5w5Pvv/nec4959xz/v9Ea1dD
Z1pETFNVZsSV4oi2ioj3WRHNpREfsLQgYiQnorgool03K+vV/cBK3Wtdma5b
9092V5fEOt1b3Ut+SXbEKKbjq9S88i+Y4GcwF7/id3msi1jPJ/lKTON/ywfL
I4ZosiRiis5Y4yOexRZrN9j73/yIpdZNp4fylfJVtILW0Grqy43opzrPQ8bc
NudlnGu9OTRRFjFOCxMRY8a8oYvUZC9r7eUQXjV/hr6Ab+bzsQULMUdejMf4
IjyOJVgqL8dTfBmexgrcIN+EfXwV9mM11sm34TV+K17Hetwh34X3+Z34AHfj
HvlefME34Cjuw/3ygzjJN+IUNuFh+RH8ybfiLzyKbfI2TPInMJz9SeyWd+I8
vgPnYxf2yDOdTxbVOL9aGnae03kRj1PvAZ/hvJbTMnoiyzE2QdmUR7l0yZ30
Uq3nAWNq3cEgpvl9UA2/JXU3skXGLKZP7n+azsmeW+88zvCfabN7raZ79jdu
7ATdoY32PWDfVThRaI/6m/x2/kbqfPEWjsmf4QH+KTbiCL5L3Zd37ZG52mWT
sg78Y65JXY1uWNcjS+ou4BzfxzddvW5ENygr8F+GcIFuVvcfXYOKig==
          "]]},
        "0"],
       Annotation[#, 0, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV1ElslWUUgOEDOyOjIAgoHS4KZeiApWAtJBijQlsmKcWoEUojGkcQXVhQ
2oXShAW4hVCjUIYCZWrBBdUqU4drpICpGg0ugFZBJFEoNCY+d/H2vWf6vvP/
96YZFe8seXtARHzgz61HItaNj/hpckQ3Jk2LmIge+Xfl2+XaMEAucFn+Dflf
MyLez474jacnIvKwWnx6asQZfItT+A4vyu/mPdiFeekR9XzS7NKciBZucMc+
bJXfglb3lLnngNqT5g9yEU8w+yjvEOfrn4ECLNK7YErED1zK53khl9p5ARZi
+GMRl9w3jLu5UU+nvQ9xmt7xmIapaJKbzFOQjkXmMzgTR+ywWJzUUyz+nku4
JXW3c+dk2hnn7VnEXVzIP/JsvsCXcBGt7m/BRrM3PMd1DNPzn9rrnClOoMXn
k3jA+R/zX3I3UW0uab6GR0yKGIlZdpuJOnue0j9Kbp/PD3IDj+ZB9t1ppiN1
v7uyU+dzDn/N36AyKyJX/Kd7/kAvtstvw07n3BXfQz9uyF3HW2ZKUIpi9Pue
Nst/5Z4efdcw0Psf7NwX1Ffze/war+MqfIgT+vfbb5w9x6LZGU3o0jcBxZ7r
S/Wf9X3B88UJ+QbcdecycR8fV9+sPls8Ui2JdDwr3i7frb6NnxGnye/FHXNl
4tvcrF6rXiQeodaBFfZbifs9xyDsVa8R7+EufRf01KHRvofwstxhfkVPlvx8
/tfZ8/gfrlU76p6r3s0VhDOXq5VjLTaiGjVmX3JWNd/Ufx9vQKHcR+5+Qq4Q
6+WGy1XxL+LdakO9w4d9742+t3F8kMfwAX6Ix6LCTCVWod7MEDOXnfF76p04
5zba5T8XX0SfuJJ7uZ4nmsvjVs9zy3N9yn9zo/on5s6Kz+EMCvS1pX4X8sv9
VpvsUc7HON0uRznTezinnsFtnOA0taX6yjDDfgU4obZMfJwfF+fjefESTPc5
D6/a7az6cz53epdJ7Er9hu1wD31YYaceu+bqyUE2tsg1mzuNXGe86f/SQLlK
HixX5/vagfy0iM/c1+vMran/n9xjPiF/ha/hKjapdXISbehAO6rk57r7KZQ7
P8tdJe6YI36a+7HBPetRmzoHs+TuYK3cGlTIrcQqZ/0P37X6Jg==
          "]]},
        RowBox[{"-", "0.43`"}]],
       Annotation[#, -0.43, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV00lsDVAUh/FTalMRY7BBSxVt1appax5CjA3VEqlKzGxaDRKEsCMlRWuK
mCpIJBJD2NRQKTY125ha3ZgSU4KSmOr3Fl+/d//33HOH95q2pKKoPCkisvwp
6BexLCuiuX/EUm7h5dyYGrGTPxtX8RfexU3ynKERlSM0GBBxTpbEm4dHbEHd
sIiTmJ4R0Us+Mz1iFgpxRl5sv8mDIqagdGBEW07ET/zAdFmtHh2zI5LRAbl6
dOIytRXWL+I13OYc19XeQD2u4SqK9GjgEmechzRrU1Gsz0rjrmkRK3i5Hnfs
matfnjvkY728j/m13JvX8QL9yvBU7Ti1K60bzxdlFxJ7eZe+7rpXNl6PCZiI
D+Yq1ZZiIVLUdJFfkn/Ve4d+3/hUZsRpZOpT7W1K1M5LvBPmoq93y1UX1rXb
o5KbrM3zeYX5fL4iu4xR+o/EI/MF8se+owLj0XhpXG+PNnWHfW7CduOR3moH
/3WGP0hXOyhxTtlTNc9wBPdQJRulfie3q/2HDLWDcVn2XM0LHEvsjROyaYnf
BHdWk4Kzvrepsruycuefra6/txmAVNQ731UUyb/zHH7Nc/kQCt3ptrVvZG9R
IvvsvsX8hW+Z+yr/hhZZM375vJE3ocB8nXc+pvY4jqJr4qzc7p2vqw3j2c62
W1aNOT7/cuZK8/ftn+7eKe7RoPYmeqEnqhJrfV9JOK1HJz7Fydxurrs+3bAH
dfLdXI29+vaxTw33MN6IDdiOg+pa8Qq/9djPB9DoHjO51Hlm8Qy81eM93qFW
bQYa3XWS807EWPkYNCZ+q3zBfuP4PNf6H8l3pxrej30oNJetx2M9cu1zV91t
axfb+4lsvp4fh/h9W/dgcMRDPMIi+SprV+OVPi0oV9PKFfzTmla9OnrTrcYd
eBsn8zt5JtcYD+NazuJP8v+59sLE
          "]]},
        RowBox[{"-", "0.86`"}]],
       Annotation[#, -0.86, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0klsjWEUxvHTVmsoicRCLdABvVVUJCSGhRpCJGpIWo0FJWmIUGJoa4Ng
0Vu6ELUQw4KVJohpZ+h17dpqRIgG1dq1UjEsW43fXfzzfN/znvOc897vFu0/
urMhKyJGkC6MWLQgon9ORGJeRBkWYtXsiLbyiF/8MwsjzmKMtxH3+Q/Qwksi
S81W/vqSiGpaXhGxuzhis/dNSC6OWJ2IWINhfUOYNzei1txh89ud/6DX6Ar+
YfOPoAHPyiLqZe6Qk/b8Ginsk1+TmYdOfSnskn/O7GoZxYuc09El9sZbPb2o
VT+9KOK02gLaSJvRhL8y9zgfpWOox7D3/XLGPRerP6/uIi7gID9lxzTe4Kf8
7+50kv/RHp94fbSP7qF7UYcr7tNtpx50oTezHyrl35O7lnbQLLOPIxs5uG6H
XDoBJ5CHibjBn0wn4SSmIB+3+NPoVJzCP4zjLj/HTndoNh3j1ZnZav9LSKIN
l9GkphnLfeOb9h62Z5X3IbqN/sj8vnqfZ/JplZ5x2pY599xQ6h6+beN8Ofjq
Xv34jOPqvtDbfpN8Ncd8sxb1rXjPS9J/zgtlPzO7yK6FuKpvhuxO81Mo8x9M
YJaZBZgpa0RPAS2h19COUiTwWH+lukd0Ha1xt7T8DTLemblS3xO7PsV2553q
ttFXtNzch3bbouaefTswoOcbljmrkL8UH9Ue0vOBHpDfJ39A7SBemPMSh/mD
/Fz/3Tx08brRgyF+vru3m/PbHn/wF4ec/QfbqJ5V
          "]]},
        RowBox[{"-", "1.29`"}]],
       Annotation[#, -1.29, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ltojwEYx/HHFju4EVmx7MSONktbIVzN3WZjiQs2c7owtY0apaYQsRU2
ltQkY3fOxf2OSpsktdLGnHJlZmpuKJ9dfPv9n99z/L/vm32wubZpQUS8xe9V
Ea0ZESM5EdPZEZtKI2Z55asj2tZFpJZELEYSUpCMk/yvxRHf8BktWRFf6Lj+
H/kR9eKX4jr63LyywohRuX36xmgdHciN6Eelmk96dhZF1GKvWwbd0q+uRrwD
r9xT6J4cc4bVjmAIbXbk6u+zI13ujp48swuQjy7zO7FCzQv1RWadF5/DWfTy
7uKR+dvsXahnEf4WRJwxK83O5fgonkKL2kSzTulNoM3iRnWjcsfoGD0idwiz
mRG75NPtrBGPu7GabscHuQq5JXK37C6zeyN/A8r5ZbjJX8/P4mXOw8tAN7+U
n8xLQiovBdf5/zyDmTURPzGNdnvm8iL+8CfFE3iPVn63W0vcfIMW02F1jfwB
+aN0SHxR7gIaPIMDyFa3TH7KvEvz+7yn03Sle27ze7Bfb4/eN2o65m/AZezh
D/p2hjCARLNOqKvgL/Uej/tdZVcl+uSr7btH76MXc553Fa8SD81+gIb5fahH
rjkd6ibVtdMJWmlmGv/1Wu+RtnoH5ea/k3vGS+A9pk/xBE36OmkXruAaruIw
f6u9v3wbs5jBbv99C28zvuM/wDqHiw==
          "]]},
        RowBox[{"-", "1.72`"}]],
       Annotation[#, -1.72, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0T1IlXEUx/ETGmHdhigwKk27Ny2v2tILYQSVNUSSWolGcfEmNVjZTcii
6I2ioJfFXpZeFEPHhiCXJpUchEAdGoJMbWgKTIcm6dPw5fec3+/8z/k/z1Oa
7Wi8uCQiJlBTFPFia8RLnEtHnMVUcURVWcRISUTFlogL2yLmeN2yP3S7bEzW
URWRwyXkbYzYl4rYjwPoM++IvkL+UXU9GjDAb7KzRXYSrbwsCsw9za9LugMd
1PcRmU0Rx3nH0G/PAOrc6YY71Zq9ujLiIO00K780olm2lLbQZv5js5/gKcbN
m8BrvW/+w3uL9XZftzNjx4x8Gmv4SXPaeGfw1d4HZj7EZ2fT9rabP+q5Wt8s
vaL+5lwX/aneye/Rv4v20kf8Ofk8FrBoz4pyd+AXbPaMBPIrIkr4H/il6iRS
WM7fwR/l71bXYA9W8Wv5U/x6dSOG7cvaO0Rb6Qn5vLxNtkCb1Of5X+SvfMt8
/7PdO+X4nbiMaVmhd1+L23oX1bfosmrf3Dd775v16XuHe+bex2F+pfukMchf
Z243/xmKvW+v8xtoDy2i/XaX6blpdzkddSbFT6LC3jSG9TbYOURPmT9m74y+
WQybO4Isf5LfbO9vfsascf4EJpHh/+Xn+N/VU7hq5jV04YfZe+385D539CT8
77s0zzv/ktXKhmTPeZWyKqyUJXBI9g8Ya4Eq
          "]]},
        RowBox[{"-", "2.15`"}]],
       Annotation[#, -2.15, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ctvzGEUxvFDmokIVizcTbV0dGbYMNWVoJVGUmUzkUgXrZZEwgYhIa4h
hFCJwUJcEjY2Etc/wCQzFp1GZyFWbbHAjl6w4fNbfHPmec77nvPM+0v3Hdlz
eFZEvEN5VUR+TcTYiojWpogscribidjI/8Uv0G3YjPv8LfyGlRHb6Q7MdqZ7
eUStNWIEQ+sibiHFL/K7Vkf0qvn1EfsaI3roXSjlIra1mIP9Zqaydpk74PeM
XN380+508hbq7VDL7qTSsstRxkVn9/JvyHETQxjl1/FA72EC7xGWyXNKjj67
v+h/xiJ+k3kHeIP4aP4Ve6+i4u57VJP34Y+jxL8g0wk7N8h0Uv2q32bGjHqN
/mnmdfU3vZU/b60M9NxmOdT5dBc/rb6kG/mvkkr38DepFbqdX1ULdJHfoY7R
u/njaifdn7yFTPdkmkreTqZptag3Je8kavojOMo7jmOYoBf7v0tw3ox/9Dl1
Tt5c7/TcOz1x7iku2XcZO/l53zWHt/ylvtFtfgl3UOBn3H9szrA8Z2Rpceas
mlEr7rzQa/buz/TbeSW9D/w6RpHVy8mUR83ZXvOG1X676zJVnK/itV1vcJD/
if/H3b/J+yRvgwn06zck38ueb/R3/MAgfwG/xJ+kpzCNQ/z/JpWCcw==
          "]]},
        RowBox[{"-", "2.58`"}]],
       Annotation[#, -2.58, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0l9MzXEYx/HHlbnQpRuFpIOoZi6cyJ+tyKzZ2GynbGymJoY15k9bYdg0
YagVd04XHasLbdRsLmVLxUrnAleKbLjTqAubVxfvPed5f77f7+/5/n4n/9jZ
g2cWRcQwZvMiLqyI+FwU8QmlxREl+ME38u+5d8jhlmKaP80PrY74kh+xpTRi
ittcEHGqJGJso/V4i1GM4Cj/dW3EN/Tpe1G9KuKZvcXrI147Jysr5zpl29Q+
WUL2XFZh/wu1Us0URvSgyJphe5Jme6x/hC7k8i/5Un7AXNVmbeVvIcP3oJ+v
4pc477pzw3NuqLnusBzT6yIuWXcZFzGhH8cf96/R1yKFerP+Xen5Zh2SH3dG
FT/NHZFNqR2yV7KULCkb4Q4tvB/1vmxQdkBWIBvk9ssG1Duyftk+WY6sm6uU
pdVWWa+sQjafiLjHbZXdVW/K0rIy2XdZE7dJNuN3F9+JKfcY1Y9hBG3cbXzk
G9z/JArtX7bGN/NuZlDHNXtved5bN59ewN4naOSz1rRzD/EAtQuzyN7wV/Qt
aMZe/qnnzPtOGXVOrbeujF9szqTa5A67zfNLdliW4H5u0GMHvx1t9k7qsxjH
B0ygha8066xvm/If/a3WqLu4ndhj1n+45v9xFR32tKOcm8N57hwauBOoc95/
uJWNMQ==
          "]]},
        RowBox[{"-", "3.01`"}]],
       Annotation[#, -3.01, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0V1ozWEcwPGfWzfzdsHFDmNsjG2Yix0teVlNOmRKyYRdLLEXJGk0bzky
EcreuNt2seHCyhzkcpuErbDkwo2xUSNulJfy2cW3X8/3+3/O/3n+J6e6obJ+
WkQMoCw74lBBRC0Ooh51qFkR0Wq2oQUdaMdRvig/ohjrl0RsxAac5t8uiFjD
Hy+KmDs/YtTz88yU/kFbp53Q8rhJLd+s0ia1Vvu/mW1mkm/IjTiMI8gsjTjm
uc38GeuzOIch/hnS2kXc5FowJ+Gc7tXJdU3BdSPBN/EHFkVcMifsHUfNQvfm
6vDe+68451W8sncEw/jIt3MdmLD+ii8Y5yfQyafd7Zozrl0ecd38rW/Kibir
NWtdXLnWbWblRWzR+qbepWW4bdojM1er1DLaDe0Ft1N7aZZqu7SnWos2xu3V
PpkV2k9n+YFBfQi7uT2owi/+NfcGjdancBJj1tnunkDab08vjLhgVvhefb5T
j2d60bw44jJS/EP+MfcEt7jb2M4nlzkjnvMF/s8evhd3UM6P8mX8A+t+7PCu
Qe+qNAfMQv/HffdKeeaee201P9szopVo/do+bljbb37X3mm19pfqSfzh/uEv
GvkZ7j0TWZiNWWjiV5qrUIwSrMZ5/j8+WYct
          "]]},
        RowBox[{"-", "3.44`"}]],
       Annotation[#, -3.44, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0l1ozXEYwPFnF3OL4mblZWOYYbngYtPc2FBCO2pZYW2WwnbqHFyQ9wmh
yWjTcCVc2Khd2DFzgyGLvGyaXVmctVAKpVby2cW3p9/3+/+f85xfJ78uWdWU
ExH9KJ8VcbUoYndJxOfZEcniiFGzZIE+N6J4UUST9pvr0P6YK7UBbbmW0nLn
RHRrU8w12pB2bGnECRxHHl81PyKBLbjj+7Z5roivd96JBnTxu/gyPuWcxj5k
Jr0992sHcJJrxnS7NPJnuLNo49oxk0/zNfMiRrz7CcOoL4jYy+3BoL0O2v8Q
urx7H/cwwrdwF/HW+T3e4QvfwV3DN+cf+I5xvjQ/4iZ/2l1csvuqJRGt5oRe
oXVq57RbXKV225y2MGKD1q21aA+5zVqvWagltIzWqr3mqrU3ZqlWoz3W2rQs
V6uNmeu1Bu2XnV7oL7Gdq8UO/OUHuSEcdj6KI5jgv3LZyT2dL+A8ctxZvrsq
wBWfm7cs4rK50f32uN9HnunD9cKIG6jie/lX3ADucp2o5p/ylYsjPvLl/h8P
+B5kkODH+E38M+d+PMdW/idfx39wHkSTHZJoxLBdyuyYcQ8pz2TdQ9r8551R
bbXWpzVzM/zGU2au3ziuVWhPtDZuhdZuTtXW8WvxH4FNi4w=
          "]]},
        RowBox[{"-", "3.87`"}]],
       Annotation[#, -3.87, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ktIVGEYgOGvIrpBVFSb6GKplZkTbiVqlRBEdIEEi8giJyjbuMsgJ5Mo
KasRHEuoTC1Sy3JRYkwt2kSLmchc1K5AI9BdF3DRM4uXf773Hc75/3NOUd35
gw1zIiKLXWsjurZGJLdH1OP7uoiK4ogEdmC3fm9bxG8+VRZxGS2o5kf4Besj
rpmvow37+Ql+DX/HnEYHavhpfgYZcxcWu+ZxfmF5xCLc5x5gKZ/kV3Gr8ZDr
wQq+gT+yKaLRWpmIqNsYcdRci7z9J7dEnEFvaUQ/+vCFb+IuYtj8Ei/wjb/F
3cZnc7l7nbXvcb8TRRHdfIt7XOAqtSbrtFal9WpXtTS3U+uwzmp7tCGtTXvM
VWtPrMs3R+zTRrR2bYw7oL2xlmqHtVEtreW4Gi1vrdJqtazWqU1xJ7Sf1r3a
ae2Ddlf7y9Vr/wr/0c5pE1q3Nn+Ds2mX+BSaMev8k/oUbpjbcRNLKiLm+ibm
4al5EANYaS72nEvwyLXL/K/Hesh7GfM+ml0/hT7vqr/wzvn3fCeXwQA3iGP8
R36Ie4bn3DBO8eN8jjtpv6+41xjFV36Sb+Sz5rd4hx+F78Q5WvmcOY9P+MUv
c64M/6fEs8EV+21FC2bs+z9k+YTt
          "]]},
        RowBox[{"-", "4.3`"}]],
       Annotation[#, -4.3, "Tooltip"]& ], {}, {}}}], 
   GraphicsComplexBox[CompressedData["
1:eJxdlg9MVXUUxx/vWhi6KToEU3QWKdPVarQkxzqXJZZGMkgTTRFEy0aKL9MZ
On2EgCKLP/4po02hdBZDcSoaIufGH2HUUPCJ8w/CEwWkTP4JKPBuvHfOebV3
997u7u793fPv8/3+7ow18RHrjAaDIWfkbz+/vTKnu/QNG97d/yhi+Ysd2DTb
a83o8cO4tzB3zLXjnRi+50z3xHtDuCDbb2G2Xxeafzv5ln/tEP5sDP7EFN2F
Ly203xjCXRn92zL6u7Btnh4ee3IQh3X70YM1blnWqOcGceXMW5uTFj/BKy/n
PKkPeoZnN9wu2nC7D+Psp6KneC06uTa6sh9TG6PGX+gdcJ7lOb308eDID/12
zsvbcagPs5d3jYv8cAiT9Yqph6P6nHlIXHRbd2/RXB3X17dN+vh+D87fu7R7
bISOO0qqtpdU9eBNe9gN+n91FXattzUbNGsmev54sxMPen75qrdu0DZHDqac
i+/E9x3PuWnTHHH+xmmWYF+L1U1L8816/dvaDgRb1mcrZhi14oT88wn5bejn
eM6onXbk34oNHpFzoguM2o2Y+qydXq04Jd3yqKLcqBU1+V9s8m/BxJUTR36K
9q4jjhUnp8T4pAQrWmFZtmfw9UasDHiYkWRStLyFPpWXI29h4trAu0syFS3f
8f4GLDKORMhXtFHHV5hqCi3o0Rb2XX6xoh3Zbr3UGVWN049kXKlqG7l2PH8Z
C8znjA0dipb0qf3oKXG0TVe0jS2zSkc3lwQZHMcojc7Vzms/961Xh6uuOq9p
/dMgWX+F3g/y/jqKDxLfh/IDya+c8odznP/vVB+Yub5Kqh8quP4w6g/4cH80
6h+YuX9/UX9hMvf3EvUfrnP/L9J8QOaTRfODd3h+s2m+MJXny/MHmX+Ch78a
eKMTVi8+Pv/BsEELJX5gJ/PDfIHwFUf8QTDzpzj61gsXmE/mF4TfWcQ3ZDDf
xcQ/mGGiLXRgEBO22Y8BEN3sJZ1AEuulJHdKce6UZyC6+ZP0B5Gsv3bSJ4hO
/CkumFi/35C+4Sjrm/UPopM75A+Qzf4wj/wDLOwf6a8Vt+fts4Fw/0JQ7dKQ
AB0ep8Yu2XLYigu8V31VF6LDhI+U7VWWZiwcSDs1kKaDcPzQPHY/NOrQfalu
85llNWiaFHNgVIcOnib1sT5QhiWtr7zn1ayDcLmJ74fQfZD100sd6+EUv184
C+H4Uyk+uHN+NsoP9nH+wk0g19dI9cFNrj+H6ocw7o9wkMj9O0b9A+nvJuov
3Of+Cwfsj8D+CH+QP4LM3URzhmryR0jhect5C/Mgz8m6ROIF2C+B/RLMzJvk
JXlcJB7hRP+iaXMe9MDukxeeWiN02MY8NxHP4MK7upX1EE16UD9nvXxAelFd
9KSms97YL9UC1uNM0qPqolc1ttz3Xrx3C8QdvJpmGKeogWsjJ2w8cAsCYjJ7
m/Yoqot/qGd3j1+26gcLNOc939t4XlHt1TW7WcWfVOHm/9dm9wrxP/UorUcr
rxcu5f0+FB/f5PgrKD/8gvMT7m9w/lwfSn01w4a61jsdGN5XkNHpZ1Rd9hPp
H0r/Gnk/OkT7keqyX6lf834m8zlG88NUnp/ovIzny/N36j7+9I67id/3YUt6
QOiqsCGnb+xhfrYSXyh8JbPP7GP+XPZv4dfpW9W8/0cz38y/0wddvh9gF39f
/ML6YX2hcMf+g+w/MJe/X9pYnydCqlef+cmGwpEH6Rv/YX2z/nEW65/9AYWj
dvIPXMT+wf6CXuwvt2Nr4x4+01E4Yn9C6ybyJ/Yf9KX14m8oHLH/oS/73xjO
r4n98VfOXzhy/T77FwDNOhA=
    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {Thickness[0.01], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
         129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142,
          143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155}]},
       RowBox[{
         RowBox[{
           FractionBox[
            SuperscriptBox["x", "2"], "4"], "+", 
           RowBox[{"0.16000000000000003`", " ", 
             SuperscriptBox["y", "2"]}]}], "\[Equal]", "1"}]],
      Annotation[#, 
       Rational[1, 4] $CellContext`x^2 + 
        0.16000000000000003` $CellContext`y^2 == 1, "Tooltip"]& ]}]},
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"y\"", TraditionalForm]},
  PlotRange->{{-5, 5}, {-5, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.4606721998351107`*^9, 3.4606722953165035`*^9}, 
   3.460672387689635*^9, {3.460672447638068*^9, 3.460672473335929*^9}, 
   3.4606725172331867`*^9, 3.4606727322090597`*^9, 3.4606735690333056`*^9, 
   3.4606736276628113`*^9, 3.460673659400035*^9, 3.460673721889532*^9, 
   3.4606737618033895`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 2:",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" Contours of flow potential on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane for an ellipsoid with semiaxes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", ",", "b", ",", "c"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{"2", ",", 
      RowBox[{"5", "/", "2"}], ",", "3"}], ")"}]}], TraditionalForm]]],
 StyleBox[" and conductivity ratio ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Epsilon]", "=", 
    SuperscriptBox["10", "7"]}], TraditionalForm]]],
 StyleBox[".",
  FontFamily->"Times"]
}], "Special1",
 CellMargins->{{36, 74}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True,
 FontSize->10],

Cell[TextData[{
 StyleBox["We can also explore the behaviour of ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 StyleBox[" for varying conductivity ratio (",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]]],
 StyleBox["). Figure 3 shows potential curves along the line ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", 
    RowBox[{"z", "=", "0"}]}], TraditionalForm]]],
 StyleBox[" for regional flow directed along the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox[" axis through an ellipsoid with ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "=", "1"}], TraditionalForm]]],
 StyleBox[" for increasing ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox[" with different values of ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]]],
 StyleBox[", ranging from ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "10"}]], TraditionalForm]]],
 StyleBox[" (a highly resistive ellipsoid) through ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["1", TraditionalForm]]],
 StyleBox[" (a uniform medium) to ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "10"], TraditionalForm]]],
 StyleBox[" (a highly conductive ellipsoid):",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"x", ",", "0", ",", "0", ",", "1", ",", "2", ",", "3", ",", 
     SuperscriptBox["10", "p"], ",", "1", ",", "0", ",", "0"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<x\>\"", ",", "\"\<Log10[\[Epsilon]]\>\"", ",", "\"\<u  \>\""}], 
     "}"}]}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "21"}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"White", "&"}], ")"}]}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJyEnXVcVcv39wnFQJRSVESxu64tyBnjih3X7i5MULETsVsswO7uRDjbwMLu
TuwiVASDn56Zz9qzxy/Pc/+5L9537tpr1mfPnJk1sfN3H/xfLxsrK6uD9lZW
tr//bXYMeJSa6qLxfxfUGm/e3TV8mytzznbxaWqqE/GmYzZ1Db3kzGJyNzuf
mpqN+IBafmVu/nBkAW52V1NT7YmHF8i7cGVgVpbL9djt1NQMxNN9CPkRU9Ce
aZa/bYl7WZcPGZk7I7tosZ9qBh82c6N/fFB6lttiJ4m4/YIOIcfX2bJLlvKf
iE/xaN6zb6wNu2rhj4kHW3iCycryz+Fj4PNi050Ob33BO5qXN4GP5+XNZ7l9
4hO5fc2N+0M8G/dHO8/9Nyn+a1G8vgy8Mq+vsJOBuA2PjzaEx5N4CI+ndo7H
n/hAHn/NietFvAnXS8TXhSn6gmtc5/zaiRlbDbqDt/VYbdAdfJhPN4Pu4Jk2
ZjDoDh5We6RBd3Dn2fYG3cFXlR9m0B08y43sBt3BD+360EPWHfyIheu6gz8w
D46WdQffy8uT7uD7uX3SHdyJ+0O6K/6T7uAOvL6kO/gyHh/SHdyKx5N0V+JP
uoO34XqR7oq+pDvXM5/Wqu1Ag+7gu/xbG3QHP54jg0F38KZniyyQdQefvKHd
d1l38InfQhbKuoO3PDJ2sKw7eImAjgtk3cGv9rLvKusOft3Cdd3BvzULN8u6
g1/g5Ul38IvcPukOXob7Q7or/pPu4GN5fUl3igOPD+kO7svjSbor8SfdwXdy
vUh3RV/SnevmrhX0y9RZ1h28ZOTwTrLu4DdnTCoh6w5eK1/n6bLu4BdHFo2T
dQf3rJQYJOsOfsXuWgdZd/BPq/IGyrqDrw+qWE3WHXyjheu6g7f42S5Y1h18
FS9PuoOv4fZJd/BE7g/prvhPuoPn4fUl3cHP8/iQ7uDVeDxJdyX+pDt4Ca4X
6a7oS7pzfdy0tXkL1JV1B0/Zu5PJuoPXztIgg6w7+LU508rJuoM3iS4/UdYd
fObaNfEjJN3B7QsUXRon6Q5+JXh/L03SHbzgrcv7e0u6gxeycF13cPblhE+o
pDu4By9PuoPn4/ZJd/Cb3B/SHTwz9590Bw/m9SXdwRvx+JDu4Od5PEl38Do8
/qQ7eDLXi3RX9CXdNfHvLja524RJuoOHNX3juVzSHTylq+em65Lu4Gs/FzsR
KukO7rM73POMpDtx+xHVAyTdwX1zTXr9WtIdvIDj8uMHJN3BZ+z+OL2NpDv4
LAvXdQffmiN+bJCkO3gQL0+6gwdz+6Q7eBHuD+kOXpf7T7qDV+P1Jd3BvXl8
SHfwUB5P0h38O48/6U7luV6ku6Iv6X5R6Ok1xd16oaQ7+NZnS57PkXQHT+2V
/CJa0h08/6yNQ0dKuoMHXmzUO0zSHTzpymnXapLu4LUCtucMl3QHXxNXoWND
SXfw+cHdbpuf67qDL7BwXXfw4XfCEla10nUHn8nLk+7gs7l90h18A/eHdFf8
J93BE3h9SXfwYTw+pDt4Th5P0l2JP+kOvoXrRbor+pLuuYU+02+2ia4o6Q6e
ZbT7Bg9Jd3CrIfdneEu6g5+8GnMn/3Bdd3B37fmBl/l13cGvzb3X9Zebrjv4
6e65bVdM1HUHd3iSeKPQKl138H9idiXceKjrDl7RwnXdwed2nBxmbqTrDl6a
lyfdwcty+6Q7uBP3h3RX/CfdwS/x+pLu4Ll4fEh38AgeT9Id3JrHn3QHt+d6
ke6KvqT7JRHvbTv23wzfpOsOvvjBmPznz+m6g4dPfFsx/quuO/iwsdEdPvTR
dQdvVK1urJOTrjt45/0DfVKtdd3B47dEls7SQ9cdPLbYuTvlAnXdwRce9Rrp
v07XHTzEwnXdwbO2qNmjxJcY0h18Di9PuoPP4/ZJd/BX3B/SXfGfdAdvx+tL
uoM34PEh3cEH8HiS7kr8SXeqL9eLdFf0Jd2viviVtOrwOG6arjv4ns0jP2xe
p+sOftE8/6bvWV138Jy+lTPNSnQg3cEfDG2+6sjYzKQ7ePi8xKWeLAPpDr59
YedeIzqnI93BV80YldnkYEO6gzv3KVb0xmor0h3c1cLjSHfw2NqLe/rEnyXd
wbPy8qQ7eDZun3QHX8v9Id3Bt3H/SXfwZby+pDv4PR4f0h3ciceTdFfiT7qD
7+Z6ke6KvqQ7j8fZY8Z5vhNxZ8P8MBvxGMO8wp54gGE8moF4bsM4xpb4ccPv
X6oZ/LKh30wi7mFob5+I3zLo9Jj4XaErdAe343+T7uAXxf8P3cGviOdBd2O9
kszQHfyCqA90N8bZlnQHzyniBd3Bxd+kO7j4m3QHdzLkW12U57qQ7tGifnuK
jRv33xJdd/BxNr2qn56o6w5et0tybPjZrKQ7+LvAtee2jslMuoMXa1NpkZ2T
HekOXvr20hyeo6xJd/C3SXU+O1ZKJt3Be2Y5XG51mQ+kO7hWuvG4tTtPke7g
Jyx8P+kO3ruoVVxi+nmkO/hRXp50Bz/G7ZPu4M24P6Q7+AvuP+kOXorXl3QH
L8LjQ7qDf+DxJN3Ba/H4k+7gY7lepLuiL+l+Vvg77HSrrp5TdN3BB9f0bPrI
T9cdPP2ZmF6pC3Xdwa/0vbTyYlVdd/Ded7+cuxCRnnQHn7q5XkRUJl138Eu7
3uTYlOkb6Q7es5jXiWLxb0h38H9MFb02r1lAuoNXtPBJpDv4nI6lg8cGtCfd
wUvz8qQ7eFlun3QHb8z9Id3Bz3H/SXfwYF5f0p3qxeNDuoNf4/Ek3cGtefxJ
d/BBXC/SXdGXdMfzY6cXO1xqsq47ePCiatFT+uq6g4+MmJ/XNEfXneajlzNO
X1Ne1x186pJrYzbv1XUHP9bNVPXCTyvSHbxA39klZ7xJIt3B42sen1l2ma47
eIkGb7rM7dWRdAcvbeGNSHfKj5bd+q5Eo8KkOz2XlyfdwQtz+6Q7+H3uD+kO
nof7T7or9aX6499TeHxId/CTPJ6kO/gwHn/SnexwvUh3RV/S/bywF3T4U4+U
Sbru4G0fPixdT9IdPHLnP9e2ztZ1B/e06bXkdTldd/A823tqx/bouoP3a2Bf
eNkPXXfw/27aWjV+qesOzha3qVVtnq47+LdPhSeNiyhCuoOnWHgO0h28jNOI
GiuzxHtBd/B4Xp50B0/k9kl38BLcH9IdvAn3n3RX6ku6g+fm8SHdwQvweJLu
4Id5/El38DZcL9Jd0Zd0jxL/fUvEovZfJN3BU+qEetSSdAcPSU5NCZN0B+9u
38P1lqQ7eK2LtYpvkHQHn9pxSbNRku7gNs+H5Et5oesOftTj+5YWc3XdwVc3
ttvysmyCD3QHX2vhz3ygO3hevyYl7/lGkO7gYbx8FHQHX8HtR0F38PXcH9Id
/Oczi/+ku1Jf0h2c8fiQ7uC9eDxJd/B5PP6ku6IX6a7oq/Tzbsz26Jq7nyep
/bwba9yv0+Saf/XzbuxVX4cJobPVft6Ndaowp/qNcmo/78ZuH2t8ce0etZ93
Y/YR9bwCf6j9vBurmbz6ZvwLtZ93Y1uD3u7znqv2826s8HCb3ONzRfoY+3k3
VszCd/gY+3k3tnJUvsN5rwd7Gft5N+bBy0cZ+3k35sntRxn7eTcWwv1R+nk3
5s39V/p5qq/Sz7uxWzw+Sj/vxrryeCr9vBt7xuOv9PNurBHXS+nnSV/SnT/H
nU3ed+yCrDv4/oa3A2TdwYvtzNpO1h380fsS9rLu4AeavZ4v6w4+3q/9++GS
7uDRpQKsZd3Bn7/P3be6pDv4qY9vhiz3nUa6g5+28BGkO/jSjinl9w1vTrqD
R/LypDu4mdsn3cEvcn9Id3CN+0+6K/Ul3SnOPD6kO/hTHk/SHbwgjz/pDr6P
60W6K/qS7txePlZ6eUCMrDu46Vl9f1l38PXWtVrJuoMHvxhoJ+sO/rbko5my
7uBtzg6PlXUHL9eg+vs4SXfwQ4n/lZZ1Bw8/Pa3ZzlX/ke7gKy28FukOzj5s
2RT8yZ10B1/Ky5Pu4Mu5fdIdfDX3h3QHL8n9J92V+pLu4G94fEh38Ok8nqQ7
PZfHn3QH9+F6ke6KvqQ7///ys5lLmht0B59QqIBBd/CykU9ayrqDpyz9nF7W
HXz13NoG3cHzHN72XNYd/Hku97ey7uBjigYUlXUHz7Xp4fwGFzxId7Jv4Q6k
O3jpe4Wcq7Z7WR26gzvx8qQ7uAu3T7qD9+L+kO7gj7j/pLtSX9IdfCWPD+kO
/oPHk3QHL8HjT7qDj+d6ke6Kvpoxf1OQja7fxKA7eL6SeQ26gxe0vW3QHXxV
4GuD7uDjc1Y06A5eP2ipQXfwmmdj38i6g2/cfr+IrDv4qId3+q299aqGsr+O
jbHw2zWgO7j/zG4fkp/sId3BA3j5SGV/HRvO7Ucq++vYPO4P6Q7uzf0n3ZX6
qvvr2DgeH3V/HVvD46nur2N5efzV/XUsL9dL3V8HfbVhFvvfzbdFnJzHfy/4
r5u10CWR+DDrsq1t9vwwuVv8fEW8QKl558pfTjTxvy8TrzS/36Gl/e6ZzJyb
wPNzbs7O7RD34HZEfBKJD+HPNcMfs9CnU7MryzaWfkP+gPc8nzVwVKeb5A94
1R5RCWvGHiN/wAtwTv6Ad+F2zK/n5XuSmuqs8X8X0C7ciisRF4E4uhD/VHaX
ZX8a/AR/MO1ju6lutgx+gvvcbrUkvLUeT+x7rLt9lIXDH5SvwstTfMDvcfsa
OOwMGmnT/g8X/jPFf3ofFP81+O89d/Tz1FRPLbPr67ay/+CNK40Pkf0Er8s5
+Qmekdsh+3lzbbuYmuqhfZ+zqYlsH7zEM6fJsn3wgpyTffBkbofsn87e7UZq
ai7tSqsCr4Ml++C7t946FybZB9/COdkHv8TtkP0Bzm73U1Oza5+bf3o5SbIP
3mnl9KUhkn3w1pyTffAEbofsu4h+t8W6bvfbSfbBX/rUXdNIsg/+mHOyD96M
2yH7w0Q/HT5q9qJz2XX74DYplZuPa6HbB/+ebOFkHzyU2yH76NcbDVpwooqd
bh/8df2xhydX0e2DP+Wc7IM34HZEf/id+Ig5oUUK90+n8Xpaa+7i9+Hl12GV
p/a2Y+DoT0o9mJA9pXY6hn4P5Ve89B770UrnWM8acMffrlM+W2rXKH8wcHn/
Z0NsqF7gFUzpzxUtCf8Syc7JPWcfRlawZqgvypfm5am+4Ae4fQ3lYWdJ6LHq
PvHfzIgDyodz/6kfQPnj/LkUN8TBkffzGn43wUtb+ucUyoOBl7Pwt9RfYd0n
v/APv6cof75azNvyl096ox9G+cei/8XvLMoX4fbN6J9R/oz4//H7i/LFuJ+U
TwMfnbVc/xWNsa7/ifr/cpZ+/gHVC/wfC79A9cou7LWdVS4wcPF6fR++KG+T
5dXyUZ02UL1Q/toRVi/RfxbVC+WLcfukL3h7/vtFHHbGz+2Y5OH/kPRF+Q+t
q2hrjn4ljvIri+24s8QmkX4fwSdyOzQuAj9v8XMbtTvwFry+FGfwaF6e7GP8
0rPsh4yPH92juNG45nPsgrGXh5B98AjOqb7gnbkdso/xjmNlu3nTw3T7tA9x
UKXm3xKrk33ah8452QfPwu2Qfaw3H+3kZT4botsHX9pl8bz8C9KTffAFnJN9
8MPcDtn34/05W9nP+YO7ZB/8x6Fps1LZVR/YB0/iPAr2wcO5HbJ/iv8esZZX
tPWZJfvgvoEbtlUOCyP74Ixzsg/ejNsh+3n47ynbmNT8bUbJPvi+e8++RWfv
TfbBd3JO9sHXcjtk34uPB9iQHS5Rsn3wUd/mOqXfVp7sgw/jnOyDD+B21HEa
c9327MnX4c7qOI1Ndm1qmdco4zTWOsumI7I/4HkLuLW5WedHDRp/ivGzT2oz
Q3lw943dLyc/eVpDGb8xN24nUhm/sf/4c/Xxp7Djxu1EKuM65s2fa1bGdagv
jfdQ/tiFpzKnc0zJAQmWcaxSL20IHzfSvheMD4tXr2Y5r6T4qZn4eJX6DZQv
zMur/uC59LuD8WGFS7+6/7EPO+BlOafyGO+dWXKwtVwe/CTnVB7jtxj/2Pt9
pPLgZzin8hiPLeq3O1sPqTz4fM6pPMZXy2+UyVFBKg++hHMqj/GS9Y9Rs1o8
08uD//xu4VQe45ywqT9Hb7+slwdfyrmyH9hWe9i10fbKi21pXITxQMfZ46eX
O56e9MX4oUCJneWi8+j2wfNyTvbBtz+rtzTCTR+Pwb4fHy9paBfYJ7D6VGJE
YnozzcvAoy37H9ab8J6DL1nm8CU29Cn93oFPaWKbrXimz2bjOo4ta1m3/MDv
/QJNxvUXW9aUc7MxD2zPetW/9CQlqabJmL+1Z905p/Lo5/OWOOM6+XgWKg+e
k3Mqj357fYPMR1ta3/ZBefDVnEehPPrhsutPnhnVZy2VBy/FOZVHv7q84N2G
nQIGUnnwRZxTefSTq1dHDdgztwqVBw/nPErpH9BvqP0Acx2QrfrcOzY+Sntn
jpxHKfNK9Lca8jZ4fzbz94fyPBi/dU45MvHJWhvajwc+ko/rTJRvEeOiOjn2
f7wXHW8+YXnuc/Nz8X41mJw1Ks781sT/NhN3rbShfPve0SaUdxb92fQaqeed
rkdTeXDHX8tubhq+xnTGokeyOa94r2clD/KK3WDN9vHyJtj/XNFiX7Tzd+Z9
Yjz73Ofk9lstntNzwe+0SzC1Cb9v4nZvE39TqXMR6wVXyB/wD77FKmzPcZDK
w0/7cb20MeWOmuAPyl/g5UW528Sfcvvi/Us2wc7ThbWvRkxIMLe8Uu9x6gQX
jf+7oHb3/vyDkyq4MlfLex9vBq84ofGMFfE2DPUFvz3U3Ob+NCvi6P+vJ5+2
8EGcm1D+Bi8v8lfxxMtz+8RhZ2vbVhYu/GSKnxr8PCF+3wo9azIl9JA1+Q8d
q5i0iPjiqaJ9fjGh/C67hOjDjWw0cNJ9cLaBKZOtNPgPvuvojkZxK1LM8BP8
H25f9CPWDO9zCT4P1RCfY6L/W97I+ZHv9/0m2AG/82+meivsr6u6sJ2HEsoV
++Gs6sK6jmyUtXThGJMSZ9a3bGePm7MSIpW4wQ7N3zH/OimeT/lP0e5K8PkU
jVvQPy/j/bx5II8btbu8VRJnnfZMoXE17BvnD4nEjws/eP2f03t7hbcX4nhv
J/H2a8Z4D+/DLU9+Thz+QN+9XF/i0GsO15ch/ijvyd8feg/xe1etcI4uE59Y
0fuG+kY+zv/hx4evJugL3mvukHdzjySQLuDdOKf3B/wIt0P9CfVXx2IOvJhz
iexDl/NLeu93+HCH3mfEbeK/wY8LVNbtw06ZYflPZAvS55uIf4DIgyjtmg3g
708NpZ2yjvx9MyMOaKfbeTul9g5+hfcD1H7BZ/dbYGm/KI/4t/We4HT2wC8a
Z4KPLVCoRcBsa9ih368a/Xm7wO8X/Pyn8vz8Of/5UgN2wMtwHonfL/C5C3me
XLEPP1X7Ws8p9XrK41Lwrpxrin28n5pxfppfOzNqlyFvDB4yLXbxn7wodNl0
ad2z1An5tSeRhSz9KuIPPtJ1+/Q/8Yef4IP2L+0hj+dhfw63r8xz82unuT/0
/sPOMG6f9AJ/yP3REAdwP/5cqi/O/9ac5t9ari/40ZxO8+X6fl7+MyY1Na/W
fG2u5nJ9wau+6TRZri94XMiujnJ9YX8ft0/1BTdxf6i+sFOJ26f6gjfh/lB9
wd/z51J9ce41MqtdZbm+4COiL7WS6xu+ZN+11NTc2qr5W13l+oLvrt6stlxf
8IIdV7rJ9YX9Idw+1Rf8GPeH6gs7O7h9qi94GPeH6gvuyZ9L9cV5z2JjrsdP
keoLXul4lWyhUn1rLep3NzU1h7bTt+XhO1J9wd/ePHMhVKovuGNYQs9eUn1h
vwy3T/UFL8L9ofrCzmtun+oLvpX7Q/UFd+DPVfLeLlrGnC98R7qpee/f896M
vRsHSfV9K8bdWx7l9jgu1Rc849fQkpOl+oK/vNvHr4FUX9g/w+0r+XMXzY77
Q/WFnXTcPtUXfCP3h+oL/pw/l+qL830pm79sTs6h1xe8bT3nk6ta6fX1tMxT
HLT0ezu435yq1xd8Umryx1lxen3BIzvN2eP9XK8v7Dfn9qm+4N+4P1Rf2BnP
7VN9wW24P1Rf8KP8uVRfnGtbWty2WCZnvb7gF3ZnGGBupNeXjy/Sa7l6H9m5
dpxeX/B+4UWGJb7U6wtec3nN90fu6PWF/Whun+oLvpj7Q/WFnd7cPtUXPAf3
h+oL7sOfS/XFea4rAffqNnqqr3eAP1jarmKJL9+pvlg/aZbNb+jVgnp9wd+V
bjynxgy9vuAdz66IdwmwofIYX3nz8RXFAc+9yZ9LcQC/xP2kOMD+a/5cigN4
Y+6nZszDfDe35f7Q+B/+WIVVT1y2zJryG3S+jK/LUBwwntzP5wWUhwfvdrNt
dIf+v2hcDd6Bc9o/gPlCJz4vpnEmxnVP7Ko0CU18S/bBH1vmfS9pHQrj86U8
r2KCHcwvHvD5BdkBn9kmrm5YyiEar4KH8HkKjcfAg3l5yvfivEDHR+ZFkyfc
p3wpeEznS23HBsykuDmJedKnE8ttc/WdRH6CZ5zvmuu47wVln481+1B01uOd
sUE0v4D9aG6f3hPw9twfGg8r9s2oL/g77g/VF/wNfy7VF/s4LpjGHz22Tc8P
g69O+nimRKNWVF8+/87EHtcyJ5g+N6T6gg9rlzChTa0YkzFflIndL5pabWFC
U6ov7Idx+1Rf2ifO/aH6ws4Qbp/qC36X+2M25qMysZv8uVRf7A9f3+/S+z5L
9PrS/vmhDzxXZslP9eV5XUfWYWNpp/xdclB9wb8dupzsVkyvL/j3Yac7NliQ
i+oL+1+5faov+FruD9UXdj5z+1Rf8DbcH6ov+Ff+XGX9y4XlGDM34N8Qdf3L
hfkPm/Hzru87H9Q3ZMGpB6mprmxcno7vH7946oP6go/9stI8orBeX/D8//Zb
PXBYrI9xHc2F+XH7UcZ1NBfmyv2h+sLOMG6f6gs+ivtD+9nAPfhzo4zvsxuz
cjgYkzVEfZ/d2MPbkxblvX6A6vsxJOut1NScrEJMnvoZ1m2n+oJX/BgbXFGq
L7jHMMdjxTrt9jG+z27sNrcfZXyf3divLBZ/qL6wU47bp/qCl+b+UH3Bc/Pn
RhnXH93ZksMrWmYKUdcf3ZnL0F2u+4ZPovrWXdb2cmpqHjb5eu3p118HUn3B
29q9vVBaqi/4w+oRYZvLjPYxrmO6s2zcfpRxHdOdhXB/qL6w05Lbp/qCj+P+
UH3B7/LnUn2x/3P+vf1n5fUs8HdbYkYGf2pI9b3SuHls6gRPVq26j/lBi1pU
X/C4V1c85fqCz6o1/55nQh2qL+zHcvtUX/DZ3B+qL+y85vapvuCVuD9UX/Bp
/LlRSl4I83pa/8J+yMASh47KcQBvUWPj+yrtclAcxjb9+iR1QgGWmG+fz/f/
HCgO4F3Lh2WT4wBey/lGwf3HHX2UPAnrejijJV+H+OC5TfhzKT7gw7ifFB/Y
b8ufS/EB/8D9pPiAm7g/UUp+hkUfX5Hn0v3YSCU/g7wKrU8hT2Vnyat/of6c
zh0jbyvGJdhXEMn3S9B+D4xPDvL1IPIfearJPN9FeT88txbP81McMF66+U/x
YeMnfafxJfJjCXwfhb6PVPBGfB3BhHwgxlFBPG9GeXX48/WnZV2A8pwYB9rw
8SHlf+CnDY8P5cdgpxzPv9F7Ap7esu5w1YS8MfxcdL6I/WgnK/3+RsGnuFUd
nPd3fT0s85aflPcb9ebFLsf63+m5g0Seb7bDl/iv+/T8IXjw61L7lvmGkT/g
duHRF1jpVTQOBJ/Ay1P8wadz+/R7Cm7F7ZiVdQF2nr9vlFcEb8vbBfk/jr+3
WoNDRQzrDuDd64Va8mDwH3xxpryWvBz8B+/Cy9N8Abwut0/zAvCF3A6Nw6/y
fkZr+2+xabI/4G3s97SS/QHv+fpjN9kf8Ja8vJ5nBuf2yR/wrtwO+VOP9/Pa
v9eqDJX9Aa+9JaSW7A/443C3RrI/4IyXJ3/Aa3H75A/4A26H/Injv7NaUNfr
28Ilf8ATn4wMuif5A55waKd/H8kf8DhenvwBn8jtkz/gH7kd8mcJH+doAe/e
Pg2R/AF//bh3luuSP+AjCoW+6Sz5Ax7Ly5M/4IO5ffIHfBi3Q/7U4ONMbUDv
9la+kj/gcSeL9Jku+QNeJWB4aCbJH/APvDz5A+7H7ZM/4BW5HfKHr3Nm0toU
PnnG+6PuD/jIrAODVk7R/QG/vnZssQNPdH/Ah/Py5A94S26f/AG/zO2QP65i
/8KgnDPyOF3R/QEfHl3t6L4+uj/g3ZveuLHZrPsDHsDLkz/gftw++QPemduh
dTqsO3Tm6xHUT4JP4OsRlMfg+YP0bL3jq6T/JsVQfwtuE3aj/AjX3mSHeN9L
n7549aP+FvxnqKU89beKfepvwX/1sdih/pP/PjiwZtmGXO1dRvcHvFWValfq
7ypP/oBPvZqnin3liuQPeHNenvwBb8Ttkz/gk7kd8gf7gx7U+VkzVxHdH/BF
tzvuD2r0w8e4D8GZnVjVLvlwSSvyB3wOLx8Ff8DvcPvKPiVnZuZ2yB/G87rs
c8iy7XUK6/6Ajx8wuu3OdafJH/AC0bV2rn18zgf+gI/i5ckf8Dhun/wB9+B2
ouBPKM+rs8+LuvuVlfwBP/Qkf+E5eRaSP+DTB4UMfbs3hPwB38fLkz/gcdw+
+QMezO2QPwl8XYPFnSzeoLTkD/iOUgfcxqZ0JH/Ar27b3brAvK7kD/gmXp78
AX/P7ZM/4Je4HfJnI19XYg92RLrI/oAfTb838/kyRckf8JvLXE+uGF+C/AE/
wMuTP+B3uH3yB/wKtxNlzGN4aoPGe06X1z3B+31e2frP7yntQxD71n5keTtW
Lg/+9uTjhnJ57Ftrue5cFrk8+NznfZ7ck8pj39qjC1O3LZPK0zmFjkd33JLK
Y9+a86BejwdI5cFtUvru2y6Vx761rDueZz/0SS8PPu5Y5tyZpurlsT+tpf3+
mF2P9PLgp26ueHdwuF4e+4VSctxv09FLLw++/1y57O32plL7xfwi6/gR4zvu
v0LzEewHG7v5YtLjs/q+CPBgj1mpEeFDyQ72gz0p+H1iSCW9PLifVb9MSf4m
fTwv9oMVmp03x9UiennwG3XKXGtePJPZ+LuQnVWcfjJrG2mfBnhD63MFSuS/
Qe8V9oPFxVrVLC+VB99YNmbuzNyrqTz2g80PrTZK3gcC7pnaaa3TqX5UHvvB
lgUG5JTLg0+/UMR0P7xilLHfLsDuJJwy7DMBnzv+YsDYcVZR2HeEec2vsZZ9
Smbk1TE/cuf7QyiPR/so7H6ueDTpG8UN87t7fH5H7R28aOexWs88Sab8lnp+
MBcS+6R2HrrcN2LiV5rfYV7YO8+HX3V+2FAeAHxdj36z3Q7bMOznx3t10jJv
DaP9VMh7r6lZcfjn72vMPpZ4xdFzi5a6bVVhwzeax2FejH2ZvF+wYpivtTta
906GHankB/qNddXb9hs2Qr+nDnyP76BFf+6dRr2wzj6kVUjG7S1sGebXKF/C
sp/2mRn1Ai9j4Qk0v4adKWvGjZ28Ion8Qb80fbpDd9kf8H1fr8yU/cE6+D8b
GtnK/qB8lGW/ru4P+HEL1/2BnSKj7w+V/UG/t2JJgVyyP+Ajr2yrKPuDdeq+
pyZc2ib5g/InLPuBdX/Aoy1c9wd2iiYGe8j+oF91T/li8pf8Ab/WtNrtSMkf
rCP3aDMhaovkD8rPtOw31v0Bn2vhuj+wc7lm2ajxkj/otzvcn3aqpeQP+KDz
ecuHS/5gnTf5fFjexZI/KD/fsp9Z9wc8xMJ1f2Cn/RXr9J0kf/C7UDu2qVPV
QN0f8Cl1Lt1puFb3B+uw+yd0f3/6P90flP9m2S+t+0Pn1Cxc9wd2ih6Ie2gf
rvuD352R/ByZcs+zrXaX76Mmf7BOOvra6NjIBro/KL/Qsh9b9wd8sYXr/sDO
7NTmfV7PTaI8GH7Xcln2Xet2wD0sXLeDegysnv7jsqx6vdBfrePngyjfBZ5v
4Zm7VU+8pf4Q/VjX4hdP2Nx4QXbx+3ht3wb/WXMSlHt1bNmytx9qbtvxhuxg
XSzLjErDa5x+Tnk/lK9v2Y/d2my8P8eWNbbw3lQv2HkWP3DpvYcjqV74/T3V
9VbVhZMSlHs/7FmvCoujui7Q/cG61bbPCUuD5un+oHwny37v/Gbj/R72rKuF
lyd/YCd2pKlnWFJt8ge/73dKHvzVeaLuD/iGmbHXZ87V/cG60th7L56km6n7
g/KOlv3k76OM3/twYtkt/EcU/IGdf5y/JYZ/yUb+YPxwJvh5bSb5Q/vSxxau
WkvyB+s+qwbXKjJyhu4Pyoda9qsfIn/ofJOFnyF/YKfHkqCMMxbcjYI/GJ94
lylXvobkD3i3/C2/VJf8wbpMloUBLn6SPyhfxLIffjL5A17CwheSP7DjucD1
XcCw9eQPxj9Dlk155i35A+5dN8BL9ofWd8qW2NZX8gflZ1n22zcmf8AXWHgn
8gd2zqRr1a14pyHkD8ZX19ZuvCf7A35i1/1isj9Y14iPKzBN9gflF1v287uR
P+ChFl6U/IGdoi0qOm0pU538wfgtoMbDu7I/4E+vpxaR/cE6wpUV04Nkf1De
3nIu4Fkk/AHPZuEJkfAHdi7mOFcqf0K6KD7+0L/rlKN0Ttfi7Z0ZOH2/ppej
hecV/TvKP9xyzMs5jyNxlD82fa+Ff7K8HxmpvF/1pDUTv9kTR/nKeR5YOO5V
Rfnq4jtQ4PSdHfGdIP7cn7QPNteFFqNf2KcnjvLVQ/NYuDmN/Z9mnFMQfJ37
mz/jMbFPF9/FKqhZ/ug7tBo4fZfnzz+7A6oJO7T/9lnPXuP+jFvMaezzFH5S
eXfuP3GU9+b+i7jo342qIr4bBY7yWcV3hUScqXxfHn/iKF+Bx18814HKP+D6
Ekf5CK6vJt4TKu/G3x/iyvsDTt/9+Rx6wkV+r8CH1WhseH/AK328sFp+T8An
iO8HQXfwGZs+j5B1V/fBQnfw2qasI2XdwS1/zB52BDqq+1ehF/gs/lzSBXyc
+O4P4g9egdeL4gw+lMeB4qnEjeKJ/aWtdx92lOMJHtGobRU5nuB+BSotkeMJ
nk98lwfxBHcr3au7HE91ny3iCT5r/SRfOZ7glj/m96N4qvtjEU/wXPy5FE9w
D/E9HcQTvA+vF8UT/AiPA8VTiRvFk77PMqNVQjEpnuBL3pzOJscTfHAV31Jy
PMFniO/dIJ7gP0afnxkrxVPdx4t4gm+Jse0+UYonuOWPnhOrIZ7q/lvEE/wn
fy7FE3yq+E4N4gk+kNeL4gm+mMeB4gnemMeN4on9sYkuI04UleIJvmFg7imO
UjzB2xxPzThWiid4DfEdGcQT/GeOM3kfSPFU9wkjnuBbOpboP1CKJ7jlj67N
KJ7q/l7EE/wXfy7FE7y6+P4L4gneiteL4qnEgeKpxI3iif23E4LKxrpL8QQ/
2+plNmspnuBPvddt+U+KJ/hX8X0WxBP8bvO5b6ZJ8VT3ISOe4PEvq13cFa7H
E9zyh+cgiqe6fxjxBL/Pn0vxBE8U31VBPMEf8XpRPMFP8zhQPMEn8rhRPLG/
d8aIhp03tNPjCe6/3TOit7seT/DgUyvGH/iqxxP8qvjuCeIJ7nZifpJPRj2e
6j5nxBP8Z2SHsg0W6/Gk77NY0ls9qf9U9ycjnvT9Ef5ciif4ZfG9EsQTPIjX
i+IJPoTHgeIJPpPHjeKJfcJLg9u8dGmlxxO8/6re8UOz6/EEz5G5yImzL/V4
gncS3xNBPMF3zJjY9uardBRPdR814gleaUuDW40b6fEE5+O67vR+qvucEU/w
Xfy5FE/w9uI7IIgnuCuvF8UT3I/HgeKpxI3iiX0vI3eO33SllB5P8HbPS7Z3
OJGN4knfrdh8Pnlge3uKA/jNiQnlMp37THGgfdd//skcdAT1BZ9V6XWlt1G2
VF/w5eL7F6gv+Bb+XKoveBvuJ9VXqRfVF/lblEN9wWEX9QWPM4x39e9TiPwQ
vT/gnobx93PipwzjeP28JNafER/FjhnxUZ5L8VH8pPgo9aL4KHGg+GAf15kP
fvU2J+vzL/Cc7xrfLrg2C8WH+Korq3eVzEDxUb5rQPEBHxXRIHL1nK+IA/EQ
sb8dcaPvQYxanafhvSMUN/Dl4p4BxA28csH11h6rvlLclO9KUNzAc3P/KW7g
uXh9KW7gp3l8KG7Yl/55i9Pmqc/0uIG/dWs8+WUvPW7g7GfJ1Cz37ShuyncB
KG7gsZsD+3X/9wvFDbyV2J+PuIH/aGLdwDnzVGqP4JY/Vt89jHiCdxX76hFP
8Kf8uRRP5XsNFE/wmrxeFE/wdzwOFE8lbhRP7Ht3qRs5wv6JHk/aJx/dqMWQ
Lno8wW8UehLV+5oeT/AI8X0BxBO8ZaD1tVIF9HjS9zfE/n/EE7zdpfjvI83N
KZ6G77RoO6oinuBXxL59xBO8OX8uxRM8UnwXAPEEv8XrRfEEX8HjQPFU4kbx
xL76exHbx8Y81uMJPuhOw/3nOuvxBF9xPPbAtKt6PMH7inv7EU/at3+t8evV
efV4kh1xvgDxpHv1+w9+2tEvD8UTnMdzMcUTfLM4F4B4gq/hz6V4gvuJ+/YR
T/CVvF4UT/DBPA4UT/C7PG4UT+zb/7h3UfZoKZ7goyfvyXBEiif4+QeZe/pL
8QQPFvfhI57gXx1uZKkrxRM8mzi/gHiC2z31bfEk4qUP4gnO4/kvxRM8tzh3
gHiCJ/LnUjzBp4l77BFP8BheL4on+FgeB4on+CceN6W9uzG3Y5v8Tz1W27sb
y9/kYsdDndX27sZGhq4oNviq2t7dWGZxz7yxvbuxHvYHv3rnVdu7G0vm5xGU
9u7GKs+oeeVj2b0+xvbuxuMZ56G0dzeWjp+zUNq7G+vGn6u0dzeWRdwPb2zv
bmw0r5fS3t1YQR4Hpb27sRw8bhRPnDuY3aR2NzmedE/4xTz/yPGk+8+TRn4a
JMUTfJy4vx3xBC+dmjOrHE/weeL8BeIJHuBX6OKEXOMonuCWPyburYJ4goeK
cxOIJ3hJ/lyKJ/gEce864gl+nNeL4gk+hceB4qnEjeKpn3dY1UWOJ3hI4u3S
cjzBm+U+8UaOJ3hrcS864gmeM8etr15SPMFniPMdiCd4zcNbYpf7+lI8wS1/
hJw+hHiCLxTnMhBP8Oz8uRRP8LbiPnPEE7wFrxfFE3wJjwPFU4kbxRPnINLv
G26IJ3jIVj9DPMG/XilriCe4u7hvHPEEb71s8mc5nuCDxTkRxBN80PSZoTtX
OVM8wflfgyie4KPFOQ7EE7wlfy7FE9xD3BOOeIIn8XpRPMEX8zhQPJW4UTzp
3qeJ/oZ4gj851sUQT3C7cvkN8QSvJ+7xVtZB2Al7Xymez4nfcG2aruGFhzUQ
N3DLH3l6ULsGryXuwVPWKZjG7VPcwBuIe7aVdQeWkfuvri+wp7y+6joCi+Dx
objhHo+c77Mb1qFwD97hzIcM6wU4R9Ah4qlhXYn/runrSohbC9xr1LGWtE70
nM41jDyZf9z/Xg/aHbBkfUJ1xE29Lxpxg50xmcoY1nHgD9ZxEDf4Uzss3rAu
A/tPih42rAuIdT1t5UZnwzoL9hftvZ9sWGfBfqQmzUcb4ibWK7X1hdMb4qau
uyE+KD/nYp3Rf+KDOKj3USMOKG9rtW6kHIe01q3E/k8tOnadIQ5ivVV7OizY
EAfYf1rormF95IvY13SkylNnOQ7YB1Xexb2aHAecs9jRqM8yOQ7nlfUmxMFX
lH/xz7pOchzUe7MRB9jfvKZiPzkOsK+uEyXifpWToSvlOHgI+z8DZ1aT4yDW
wbUFLqFOchywnyr+ytsMchyixf6rLpu755fj8Emc74i5711LjoO/sk6EOKB8
H9bCNEmKg3q/N+KA8lOsX1yS1yP801jfEfulNfvxpolyHMT+BC1+zrHCchw+
CPt7+hb8Lq9H1Bb7uEbnbRgqr+9g31eD2mUrOklxwLmSdX2WxsrrETmV9R3E
YbEo77/JyzFQioN6DzniAPt+ny+eeSTFAfbVdZmawv/8C3Y1myDFob+wH++y
t4uTFAexb0Q7PX5SbjkO2D9WsVXp/wpJccB+s3+vj4rLIMUB51lq3q5do8Nf
6/X6ugziIPbPaFWftfC2k+KA713gvnTEAeUjlr+avPav9e6/11Nwn+LnIl2G
D5XiAPtF46auyyTFwUvYN9Ua1TKfFIf8yC/aFZuT3E5dP7XXhmwq22+blP8/
Lc7RPAhoWdg+SV2P1tdTEAeUX9Y9Mf+WZXochgr7uNcdcUB5n9Ndl9fLpK4j
/70OIs59aNPmvrf5mWSvjJ/ttTPtb3c7JuXtTwj7mb78d+CMlLcfJPbL7fbK
NuO/tuo6na3m4fY4LFdOPQ7YX+u3qs/T7G/VdqGvgyAOYn+u5mXTMefogXoc
8P/h/nnj/gdrbb97qa05pXw77KvrF+I8jla2bMcufRP1OIj9b1pkxc2Ox3Pq
ccgm7A85viiid2s9DoFin06P7JPm9quvrv8mmYutDz5yME7Pt+MePZvAQXOn
jtDz7RjPel7P8e3niy8m47phonn9sYtxe8umU/r/v9cRxLlOc6T35NK7z+n1
EvsMzenGDw3y+aHn1Y8I+9vztkodXVWvl6c4b/1oUs9tUSl6Xp1/p/mxOTjG
Jcr3bFaq132+z8h8d3Xu9c/GZlL2S9C5YKrXdcEjohdMWTvLiup1TuT5lynr
BY7CHy08quSsh5n18aHw52O5k/2ik7NSvcKE/ZrfIx857dXz4dvEfqjKSd+C
Xdrp9Toj9kPdq5dc/2YNfb3AVeyTrz5ty7NTs/V8+I/UP//s8jb2O8/NOUX5
CeL+Ury3sN9B3DOPOOQQ5f2K+rS/m5RE42T+verd3uq6wDvh/6XtlULertTX
BcR+e1P7iNT2TXrq6wKFhP0q0dk3hHjqcYhAe6oevOxzgpqfSTJljn1e88BE
NZ/w3XTG6mn9U+/0+cVFZV0AcfAX5XOH/Zzy5OcyigPsTxH36hvzAN9NlQbE
JOWdqs8XYF/N8+MezEVh7q2/5dbz/GJfrik57yG3VtP0+cJIYf9Hx6Q21d/o
8wVHsa91cr0Sqy49VfN+tqx7w7eBzbrrcegvzvHlnLXgVPkbehwuKHl+xGGA
KP/D41mnMh17qv0Y7u2nOMC+5764bw1L63GAfTU/L85Fsl9LRifXvKvPm7CO
VXjhrs52PfQ4DBb2p2xaP/GklE8+KfbTjp1S/uM3ab6J77vHPBp9z0XKz+M5
6Q80TjggzTdzKfl5xAHl0w033+nfvBzFwV/YdxbfBUAcUL5Kxg57zPn0OMC+
mlcX51XZwPIjJleV8upi/zkzmT1KF5Hy6gXEf/cfV9XukTR/FL/7rFKv02vO
PVb3K/7+HXjYYKgmzbtxbnFU+1npAq+q74OeV0cc3ojynxNuVXP3SPFRxjks
Sny/AHGA/djwx+buedX34e98uBh3sU+1e2YPkubRYpzG7o3bW++ENI8W4zoW
kml03GkpDtg/fLdr9pdy/kGMG9nIJadzH5biUBPnKx1dVg3+K/+g58MRB5Rf
Zne2SdnYUxQH7GdeK76zgDig/Lq8I2+a/son/J3HFuNkdr734g9DpDiIcTUr
XP1w/cNSHMQ4n5XKWmSNnE8Q8wJmjn01QI4D9jk/K5HnXzkPg3OaXWY0/y7n
YXIqeWzEIUyU//LtU9Dcg/MpDrDfWnwPAnGA/XQJC9vI+dKcaeSfxbyJ3c8Y
nUfOP4t5HDsZd7G+nFcR8z4WW9i2txwH7Jf+cfhcVzkOYl7JbtWPKivHQcxD
WdGO8W/lOPgr+WfEAeWbXkg3Z09ke4oD9m9vFt+tQBxQ3it72V9yfsk/jbyx
mEezdwfqf5TzS2LezWqNqFxOjoPIA7Bhplxd5Thgn3arSYsMeTns677UKMyQ
l8O51HaFmhjycueVvDHigPItdmztMbdnYYoD7AeI72sgDnTedo/PF6+/1sv+
zvfSvUCn1xnybCIPwzo032TIs4m8EAu5P8mQZ8P+8FNjhhnigP3kL5f3NMQB
9/x0qlrIEAdnJd+LOKD8oe2nv/l4xNdQ8masrfhOB+KA8u732xnyjc5p5GlF
no2tOVvKEIc3wv68i70McWgl7P88FGCJA/KBYnxo7pRxR51HR20oT2jvzsef
kXx8S/uOHovx6nDx/T7UV4zTzKHnOnyzqZqg7Cv+ZO5erNir8tPXi/Hmc5MY
Z5qX8vJm8O9i3NtI3MODuOG5AeL7ffDnkBg3dhbf74MdMW43xYj7vcGziPHk
AsP93n9/X0/RUes8usU4Pd9FeWbse6fntjCWp+cq+VWz8j5QHlXJS9N39+Cn
+h09+IP858SESmNlf8Cni3OX4FeN+UzyR81n4rnI7+H7engu8o3f12X1l5+L
PF4Jcb4SvL4xf0jPVfOHeK763T08d4XIjxVbGmwtP1f8HmklxTlKcNzfIvJ1
9Fw1X4fnqt/jw3ORT6tRvdTGcdJzkae6Ls5Lgi8V+aghPD9Gz1XzY3iuq8jn
4Dt9eC7yVwdG5M7+n/RcMR7TOotzkeA+xnwUPddVyUfhucNF/gTf78NzxThT
O21qFLIyTH8u+suS4vwj+Dlj/oeeO1zJ/+C5x0U/iu/64bnIz8zKvOTmtpn6
c8V8RJuHc46CZzfmW+i5sK/mW2A/38h7rk+/UF4C92DRPkzwu6IfC+fzemX9
9JM5TOG/LPPr++K7A/p+PDFPNNet97Plzz3piJ8x5kmIK/sSqR/2EPkQfDcQ
cRsh7D8du3p1o1dfKW7+OO8oznWCRwt7BXjehuIG+/huIPUbxn2V9PuFPJIv
rxfFuYDo5zvz3xfYofP17ilrrv2aFEe/F+CWP5r50TkjpbzZyvDP2WPG9Sr9
e6/+yu+F8r08vT8X/MfPg1VeXLxK/Aje36G9DndK3qmvi4nylj+eMP08lNEO
xRO/U11F/gTcRcz3g5V8wlHx32s7jnp53f0r+Y/yY8T3+Oi5onwH7ifp21/k
DUryPAbZiRTvpfheHtUX+YTQI0Wm9M40muzjvoEH4vwseD8xH8+c15IfoHrB
PvIDeO5gMZ/NLL7Hh+eKPC1ba1WrTvSnOvTc07jPVpyTBXcX4x1HPh+n5w5W
5uN4Luan+8R3+vBczJdfNR1ZKMMJR3ou5qElxHlY8FdivmmXaJn/RqU1/8Vz
MR9cKr7fh+cuEvO7TcXPD+p95Z4P7Iv1FNZJnHsFx30+G/l8k56rzjfxXMy/
Govv+uG5mA+WXPb20OyhG+i5mGe5i/Ot4MvFfMoq2TK/o+eq8zs8F/OdVeJ7
f3juv2L+4rpzR2Wf4v70XLGeyE6Kc6zguJ+nO59P0XPV+RSei/lFP/EdQDz3
spgvPK3V9G654V70XMwj8ovzquCYj3Tj8xd6rjp/UcaNrKn43h+ei/mFe3jF
le2T0tNzwc+Kc6nKuJGd5POFyLTmC8b2XpDd5PscUJ7Gpfju3v97fPv393Dx
+3X1f/6u/f09WfxOob+tcqz9NeeH1lRe+b42/DdjnI/vaoFjfD5H5J+N/fyd
Y4+dN1hlq7Ca+vsY8dyGm7O18ndZifmFWeTPTffF97DAMS+4JLiV8k9gzfZJ
KRErvPH3PuF/4MbbN5xmLD32/4tzrv/5u5xoviniie/2gov8sPmEkZty/c/f
30TTTWN54rBz3MjTeD/1705WEd+dpPGAcX87vW/4nT2F30uMt0U8HyvzLKwj
jFXmWZeNv8vkj63F/g1hH/OfRNNbvk5xzPhdyTTPNZuUc81UHvsNlPOwJuU8
LJVP47ynSTnvSeWxfq2cZzQp5xmpfBrn9UzKeT0qL/Kl6nk0k3IezWx8D/86
b2VSzlsp9tXzRH9/bxp2lHNG9Purfica4xmlf6D3U9GX3gcxrjYtMpy/SKTv
GCjnC+hcwE9+vkDR5a/98yZl/zyVj/nf+8NNyv5wKp/G/meTsv85SnlP1P29
JmV/L5VPY/+qSdm/GqW85+r+TJOyP5PK/+/9h2n3D8q+RLKD/kGcG1LzP6bs
M9atqxoxhfrVaKHXjfP3P+6M73/MyD/x/7+ZyxFjO71sZiIvhN+d++jnD9eO
btbpO9ZnzRlF/zOAr0sq4/ZPppmtt7227RCs/o6YktqO9B0xc7436oV1z7aG
+cLveauwI74rSuvC+L2rfuiQ2xOPZBrPrxN+jhH3J4OfFBz3KsM+1hlHGcb5
iebTIm6tDe9/mr/vafSTaeWR0A+o/WRa+Z+0+sm08jY4B6r2k2nlW9LqJ2k8
r+RJcC5S7ScTzUP/Z34jUdwHqPaTeP/VvESi+Uoa/aQozzoZ5lOJ5hyinzlt
6H8SzVg3zGSYB6Hfy8ZWGvqftOYvafU/ac074I/a/6Q1X0ir/0lrnI/zX2r/
k9b4PO3+J633M633MK33La33yiWN92dYGu+Jlsb74J7GeA/3Yo1W2q/ynXol
zn+/D2npnpa+aemYll5p6ZLGuNGE8dtgY17FpIzfiOPexShx7yLsYzwwVBkH
qvclov9HPD2GFXOoWnQN9f/YN+tZufeHvT+lvJnIb38f5ff+D0c/r99j83p5
oV52XuDo96yspvYL2J8/As/Fexg1KWqMnE9W8+p4LvLeHzyjX8v+IO+97cyn
R7I/GJdasayNB/7yIn+G4v6QId4T5uZvTf7g/Q/07jlA9ueLkm/Hc5EPP9hk
9FHZn3iRD2/xoFBb2R/sR7XSXAJtJ/iTP+i3rTyLnP64ZRb5g3bnNffhtUmS
PyuUPDyeizy589y573ZL/iBPvnuGl+sOyR+Mq62+Oe0+9mgD+XNc/C5YTV6w
t0CD4+QP2vvXoPDrYyR/aiv5eTwX+yqbjZ5ya6XkD/Lnl4qEDhop+WMWzx0y
/IqzY+v75A9+d5ZNdl53OuwL+YN+JnLG0fsmyZ93St4ez0VevVbJX65vf+j+
nBd59SkFK830+677g3lBy8ScSXNdnGh8lUf8rtUr0ONtSFKJY3gu+rfU0W0H
vQ7V/UGeH/l8PBf7DPPyPDn5k8O4X1HRK4M2p1jGXfu8/yV/rorfzZutJhbK
v6Qr+YN+1fT62PKlQbo/yM/PF3l+4zgt1Vyk++uQxmwU2b8t5h2RXYvMb3R5
AdlH/7xl/92xX9d9JfvIk/uLfDjqJfY3Iu9K40k/4/4u4ti/dHGPb53lDXXe
V+RFkxyWN5np9UUZD6ea2t/3LBOV+T/yH+OEE+87vnz+rTL5j9+Ll0vH1Rud
bgD5jzxtksjH4rnIlw7pWX7vnEq6P7lFvjSj+8DwTxV0fzA/yj7LY1m7vB7k
z1kxDmnqubfLloE25A9+pyLvWy9PHl6Z/EH+9ovI0+K5yKMutOqU2qqC7g/y
qH7TXOaVkvzBvqBZP+zXbGv2itpXpBjnZOj+tHnr8RepfeH3sfnoH43iv1mT
P8jrNhb5WzwX+dVuFbeW95D8MYn86iTTiSy5JH9Ee2cPmzi1ab9pL/mDcZTz
7tjPg5ctJX/ovuWHs19vOX6B8nvI944SeV08F3nXiEV9g9wkf5B3HVe6eS63
v/RyY+0v17Zde2cc+TNYjNPa50pmnZ50J38wHqg2Z3+1ttZLyR/kgcuLfC+e
i3zs0u7f43NI/sSLfGxj/y6vckj+YL9K7gU/WgY98SV/MA6ctMW+77kKZcgf
jEN8DvZpOrpPd/IH+eGbIg+M5yJPOz5wyHPZnw0iT9vmUddnsj+Y/56v6eho
m9uF/ME4M5y1bDWo+LejxvfEk52u9/FMp4DS5A+eW0Pkh/Fc7LvYVPLHU9kf
5G9v2Tx9KvuD534bkqFb+vmPqhvfq4Js4PHr89q2PEn+YNzl5rvo7J65SZHg
yBs/FnljzH/o+8t753QNveRM5wfA+9QIs3yvHPvpwaftb1Dm5g9Hhn3/4KGD
Li9YGZgV+xSJZw8v9yOmoD32ZRIv82rHoj/nYi6Kfhl8douvQ+KD0tP9t+CP
HE5Y7pe+KsZ/4Mzjy5/7okXcDh8DLxibcjK89QVv3PcIHucT2OPPfc6YJ4Mv
G9Pnj336npHiD+2LBS/O/ad7GcCdeX019HfgC3l8NMzTlHiK85+070gbyHWh
fYSKLtiXSeezBrq97CzrCO7dzauLrCN4w2Z1Ssk6gp8demK2rCN4sXnaF1lH
8Cs56sySdQR37rqp1x8doRf4sc+rGsl6gRcpOmbtH72gC7jjjMggWRfFPukC
foH7Q7qAF+b+ky7gGq8v6aLEh3QBH8DjTLoocSZdcG5r6vAnvrIu4JPj3RvJ
uoBvfufmKOsCXuafcXVlXXReNlzWBbxchso5ZF3Ave83Pxsn6aKfL3uTvY+k
C/i/h/peCZV0Ae+Y5fIWTdJFsU+6gJfk/pAu4KW4/6QLeBFeX9JFiQ/pAh7M
40y6KHEmXaBDWNM3nsslXfDvLja524RJuoCndPXcdF3SBXzt52InQiVdwH12
h3uekXQhLs5/QRdw31yTXr+W+j3wAo7Ljx9YZ0vfFQKfsfvj9DaxNqQj+CwL
13UE35ojfmyQ1B+CB/Hy9D0R8GBun85FgBfh/ujffRO8LvefdAevJs6jQXdw
bx4f0h08lMeTdAf/zuNPulN5riPpruio9JMO2uSM3677/9VPOmhzl5XYO/qv
ftJBm/A6fu66v/pJB+3cg08XCvzVTzpo+Wb+U73MX/2kgzZIi+mzNZfaTzpo
PT76tngwOb3y/QIHbWHuSaExa22V/tNBS8lRKe+/z9T+00EbM+rmgz4tdH3B
T2gD92R6rv/egU983+NozbVqv0r+KP2qg9aP+6/0qw6aB6+v0q86aMd5fJR+
leKp9KsO2iSui9Kvki5K+7XVmm1r+DwxRm2/ttrymlMv9t2itl9brcm37o+X
JKvt11Zz31QvdNogtf3aavt+uDYem0ttv7basvzrL//KorZfW62D3YBlN/zT
K+3RVos9MbzSOk1tj7bapdvdUj97XvA2tiOyo7QjW20Rf67Sjmy1PdxPpR3Z
ai68Xko7ojgo7chWa8rjqbQjiqcS/0Tz1uGjqpffocY/0Tyrf/yD+/PU+Cea
rcv1KZ1wXY1/onmw670V6xzV+Ceaq26Yu/vymsxK/BPNF3IurLlsSAYl/onm
cW0Dl4avSqfEP9H82WvgmDH545X4J5p3+rKe1faeU+KfaB7L7SjxTzSf5c9V
4p9orsz9VOKfaO7L66XEn+KgxD/RvIXHU4k/xZPij3mAs9IPqvNOxB8c65OI
PzjOOSH+4GK9l+IPjn2JiD+4WNele9rBcS4Nv1/gl8XvDfQCvybvj/utF7g1
/5v6N/DT4v/H7xc49lei3wPPKfyD7uDYvwndjfHU718z2slAuoPjPDF0N/qT
jXQHdzKOS5TnuqjtzlTt2iJTozFOarszFWhW4Wv0Ahe13ZkqJ5cOrhSRVW13
pp5DP4xP9MustjvToREvPA9/T6+2O1OQ/Smzbydrtd2Znhf+OLby228m47gl
0VTzsil4wLd3JqU9mupNuZ4vg+NutT2a+k8vfidzzunK+CTR5NmxU9N8s7aZ
jeOQRFPT6zlb1ery3qy0X9Mj7o9Zab+mydx/tf2aDvD6qu3X1JvHR22/pn94
PNX2a6rKdVHbL3RRf7/Y6LelZu7pp+poy7YXNc0uEqTqaMt8apaplW++qqMt
qxfef1GVSqqOtuxrldi11Q+pOtqy/OlPjYq2VXW0Zd/svfIvS05S9Po9/rj+
T37rvkPV3y82bu3aZ9Z5GnsbdbFlrpXGF9l+6o2iiy1L4PYVXWyZJ/dH/V1j
n7n/6u8aa8Drq/6useo8PurvGhvF46z+riHO6viQPT+/v0Wbvrou4GHvf36z
m+yijg/Z+/INXlyenVUdH7LpXy5ey1E+szo+ZAeLsF1Je9Kr40Pm0+xO8Rc/
rNTxIbNLeZE5zytdF3CnEyUPfxz+jzoOZJVuHaz1cre9Mo92YK2tAm4ELtB1
Abfm9s3KeA/+qOM9tp/7r4732ExeX3W8x17x+KjjPfaMx1kd7yHO6nyNpdQJ
9ajVV20vLmxLxKL2Xyap7cWFhSSnpoTNVtuLC+tu38P1Vjm1vbiwWhdrFd+w
R20vLmyqOL+pzNeYzfMh+VJeJCn9ngs76vF9S4u5b0zKfI0ta2y35WXZBB9l
vsZWWvgzH2P7cmE5/ZqUvOcb4aXM19hiXj5Kma8JnhClzNfYeu6P0h5d2M9n
Fv+V9kj1VedrjPH4qPM11ovHU52vsXk8/up8DTqq8zXoqOZP2KunY8bXlHQH
7zGy763Pku7gVY7OGR4q6Q4euWZ/mRuS7uCXulWMWivpDv66yJyigZLu4AXq
Ll4dL+kOPvW/VTe8fuuu5FVY/aKZunSYs5H0BXcZtGldurcTSV/wmQUTxq8o
si5KybewZyu+enpLOoJ7cH/MSr4F/qv5FtRXzbcwjcdHzbewf3g81XwLe8l1
UfMt0EXNT7KUJY4BNf/qVz1Y241uF2QdwV+2KdYm9K9+1YP90+9CRllH8GY+
z+es/atf9WB+ufq+Hv5Xv+rBRnvd+hr3Qu1XPdjMVynV54X18zH2qx6sy/dh
s7dVrO2l5CdZ5biDDarPVftVDxbI7Sv9Kvmj5idZE+6/mp9kFXl91fwke8bj
o+Yn2TceZzU/iThrSv6ffXIp5S/rAl7hdrsYWRfwRlmTW8q6gHd652wn6wKe
UMlvpqwLeEnvR89lXcC/vlj7VtYF/FKrPQ1/VCpGuoAPeOzVZlwxGy8ln8+G
tX9bTNYFPJ7bNyv5fPij5vNZPPdfzeezLry+aj6f1ePxUfP57COPs5rPR5zF
OWF9/SUyaPGTDhVdxfl8O+I3hqTmH9Etsziva0O8++1X528Ny8D4/TW3aX0k
dFrs4vDW78V6lRWtI7TucazaouJ2Gl/XTEfcz/nxwIsPMopzzs7EcwxY9OTe
vy6494Hy/9rM+M7ukS4M91KBn/jZP/rQCyeGc3fgzQduNBVYlYnhXiTwzRMq
JFW8bMcui30/4Nd62XftG/uMzhGBV006lPy7PN1LAr6+aueav+1r+E4eeKdn
92tWupiF7q0Af/OhbJff/ov7EJ0pf36qa/qzv+srzo07Eh/37UbHuv5O4lx9
FuL1Bm+s1q1NNnH/Qjri7jlrx194gPsprIhfKdJ+4cLidoyvuydTHr7y3P6m
UId04vx2PPGgrte3hcfbML5v1Ux8e1DFan1jr4n7dG5THt4224m1oa3fi32W
74gnPBkZ9Oe7zAPEd2/Brw18V2RdJ1sRHxvKny+LKN3o93sl7rmwI87yFzge
2C2zuPchM/GZ0wevfrPGQdyDkJV47sZBS4bOdsR7TryOXVLM7/cc90f/lYfP
aRynaTVEXv2ckveeKvLeF4zjHOTVNTVfgrxxC9HukG/cNcn9bcXf7W6jOO8P
npqe33tWS7RH8As14grt75pZ3LNmQ9zvQAfHa0MziPunblP+tnk955OrWr03
4Xu74L2TD23dX0xvj+CRWbKOK/QA93Xq92x1y5ch/JDUHpGnyHq339AJR13o
Hjfwlj9tBk57pudbwXFfGdopuPfRYikJCzIx3C8G3i1PI9/gSDs2VOyDAcd3
S7HfGrxczK6EGw+fiXugLlOec6n4PinaNfh8+1OeTY7r7Rrcoef8AtND9HYN
XnvljYxvT+ntGvy+S98aD4/q7Rr5tE9bpr3aUEhv1+CpU2f13VxPb9fgq790
euqZkJV9NNw3q99jhvYOnqF6xncdK2YU/aEV8bOn3lwc3z09tXdwj6odTubI
YEvtHbzgsyZTQg9Zi/tuzMTnH/Ua6b/umjgnc5vylp5jJ5gr73oj9ge/I97e
e4LT2QO/zGjv4LvsEqIPN9K/2wKO+9bQD4CXzdF73P2zdtQPgKcE5cxg/ygT
9QMUt9op5vfV9X4AvI9pw6wKPfR+ALxuledl++R0pXau5MGoHwDHfUhp5dPQ
rpGHefLxhf9wexdq1+BR4h4wtGvwCSWrr6h4OR39zoJ3cLucmCWPFfSlPE+5
rHdctw/4bkb7BY9oM7h2zAwbar/goys8PRlu7ay2X/Zj+5mF/wU6q+2XLW5a
8VNUW/U+ZFvWTdzTpbRfNn9F7kkXOtqq7ZctfpC1edCvHyal/bKr4ru6Svtl
ZUwVvTav8VfbL/MV389V2i9bW23/yVU2P81K+2XBq+aEVehsq7ZftrhlarFD
XzOo7ZcV77U+KDjQmdov8gNe04c0O/7Ridov+JULtSaeWJGN2i94YNzgqr98
9XYKPsQjsnqeEjbUTsHvzy/wYFX/FBPaKXi3kjb3ytT/JPZlxhOvlW3I1d5l
YsQ5JTPxQg3edJnbqxT9LoP/V7PbmiOtPMS+7XfEm1SpdqX+rvLUTsHd2344
NX7QczPaI/iGTMMm1x2eakZ7BA9q12GlNiUdtUeKWx9tXlunTNQewb9X3jzh
9XAHao/gtcvW+hH+3Vn9XWabRb5F+V1mNUX+RPldZitEfkP5XWZWPH9iVn6X
2XeRH0D7xbxyUN5PqdO+O1P7BY8S91OJOBA3vXZc3GZKOvpdpvLr6i8vPSzV
5Ch+l8Gv3p60KO/1DT5inEbz2XJxvVrv9ksxi/eH+IjVu5sdL663a/B7Xl9a
7vzopI6T2ZMGtvnch+vtGrxWkWNNfNs40v2k4DfFvVL9jeNnNiXLrupZ2ujt
GnzhvBHdB336gfsEaT7rJ74vbDaOq9mBj2+GLPft4/NYtGvwieI7wrhnEPy4
ODftYhyHs4hHZXr9fi7d9wdeqWG4128/xb3JNA5nnu7bGnrFZ9DeGMfhzD+h
0J/4YN5B88QtNQ/67pTaO7j1hMYjQ36397qivYN3TzizPPp3e/8gfq/B24h7
qEJEPwDu0Gqkw28dhS5WxOdXubxml1+K6aToB8CnHOzysZ3vJ7GPNp74xh2R
LqULx5gOWeJG9+qwKuI+qzDRP4APPz2t2c5VBXwKiP4B3O7okvb9q7tEBYr+
AXx9+r2Zz5cpGjVY9A/g7qk1aucbgPtWfhJ/Ju7Feiv6DfCjReY7/n7/xX00
dsSzeVzp+ru9iPuvMxNP+VFmU4bf/cZn0W+A18lQ5/jm3/1GK9FvgI/ccvnz
73aqGc7jWWFf5ydxP8sXmr9c4fMO8Z5/oXHy/gnd35/+D9/DeEfcdm8H95tT
rdgZEWfwy+KeGT9jv6pZ8fLiHt544uNTkz/OirOhe2kxbsQ5HQ9x/wj42/pj
D0+u8kPcu/GKxrGPORf3Yvx9T+9gsf8bfAQfJ4t7pWlcYa5Vu2KfFtft2DDD
73KieUqXNscLz8f3MvVzzN6uewo1u2Yt5hevaPz29P0T6wpZU8S9GMnE8/Jx
pujP9fOyXtyO5i7qC73yCLu3Rb8BfgfjAPFvcE2UE+NPWu9b0Mj5ke/3/eK+
GLrv19RL3IsixrHEP9Zp9fJJns2mn8ZxrynDUVYv0X+MKUZ5r3B+XYyfaR3w
yb+Z6q2wvy7Ozarfh0wyRxvjY+q1dMrIxAtx4rwTjYdNJnGPivhdJn86FL94
wubGC3FPCo23TbN5fc3Ke8X8xLkt5b1ixz7HLhh7eYj6XrHDnKvvFWsj7kUZ
ZGwvrCgfJ5j6G9sXsxPfr0c7Ai8Uk6d+hnXbfdCOwPOI+z38jHkDlpeXj0I7
Am/wMTa4YuEYM85voT83i/NiBUV9wdffe/YtOntvHwdRX/AVnEfh/hrw6eJ3
x1/UC/1MEd7vKesstlqYZV5pw4zrI5hvqvvZbLWHXRttr7zYlu7pRrtYc3xU
l/sudkxZdzYXrfy02biFNnQvMHgQb6fUjvA+5E0/dUybzfupHYGXsaxrh5mU
9mh686nTtyPFn5gV+6YFXncSHwfjnCrVlzW1jMMDTUp9WQPOqTziOcHy+z7Q
B+XBR3Eepazjmwvy+jLcx4d2dAH/v9JviPeb7ukzztdemXDvhrH9PqbzfuBP
DP2Lfk/TtUOuaybWO+Udo5QXeUPTPqVfOoS4K/tGjgs/YpTyZ0X5HMp8vJCY
j/dV5tE7xTx6hNLvhYh+z1Hply6Ifgn9OfWf4r8r/bkpJ39/zOAoL+7PNuP9
ARd/m2OU+p4X9R1k7MfMe7n/TOnfzHsEV/w35+Nx0JT+1uwpuFMa5XMo/bD4
G3FQvi+dSO8/OMa1Sn9rbinyG8b3P9E8pkChFgGzrTXYQx779emGlvPsaKfg
QzqXXxze+gfFn/LhnFOcwV9xO2Qf45mxr1MGBEv2Ke9aadr7UMk++HvOyT74
aG5HM/7u6+fZjf2Mi3YpY+/GQb/tn1f2CU8T+4TzKeWvi/LX0thXHJnGc43v
p4t2htsxG/sx/TvgFwy66PuKj6VR/pRSPkiUz6U894J4LuKDcV1Dp5oru+XQ
4wNeek2hmXNb/jCNVMaTGcR40tk4r9cm8fEhM/afDlpkpzl7vJ/bUBzAi3D7
FAfw+twfLVsa488AZbyaToxXjf2zg3aUP1d5H/TxqvF9sNVei/Gqaxp5RaOO
ttpTMY416qiPY/3S6PeU3zvzKz7+NF1Vfi/Ee4bfO+J4njK+Nb3lv4MmJS9q
usL7T+V3P9E0uU1c3bCUQyYl/2maJ8ZjSv9gGsfLm5V44t45k3sa47TsaYzT
lLjhnL76frJ7Td/W+LZMt0/7fG5c3V0wsrxJea+YDefqe8VuczuK/y4sh7jP
QekfWN9hM37e9X3no/QPbKnYl5IvjfJK/8Bq7M1kKa/0D8xGPFfpH1g3bidK
6R+Yq/hep9I/sOrcfpTSP7AMorzSP7AQse8lVxrPVfpntnWQ1+EsUnzA21bq
7/P+yHafkco4ubgYJyvrcSwXH/fSewieY5jjsWKddvso/Txrzu1HKf0828T9
MWdTxtXZxbhaWb9jBcU4HO8z7Sfhz40yvm8ebKMYhxvfN30cbnzfPNgqMQ43
vm8ebK0Yhyu/pyyxf69jsn3wg9MOZ2lRs6iP8nvKdnEepfyesjhux4z+Cv1D
dhEXPk40U/vdf8QyHxT3vtE6iGl5zYrDP39fY8b8FDw3H2+b8yj7k8V9paac
Chf3qJnwPXNw3FM0MI3xEu6vNPZvtqKf18czuFc1RxrrvMp7qH3h67ZMmcdp
8YIr76GWcGinf5/fv+PKPE77KNZ/lfdNm8ifq7mkwZX3TfvI7WtX0ph/XVB4
qOBuyu/Oc/G7c1qZry0R87XzaczjlPG2uSsfB5qU/APWv9TfC/N4Pj5kiv/M
uh6fTyn+syZinuWWRv+v+M/qi/mX4j/74ct5dmUdoZNYRwg0jk/Yf3xdQNwf
p/NmgivjEzb5ap4q9pUrmgYo6wuNxPqCo3Ecwnz4cyl/At5OcGUcwsZz++YI
pZ8JFv3MLWW+mfto/3Z/5punFT5GzEM90uh/NGV+OlzMT68o3JXbj8qp5GMd
d/J87FgRN8on8zyqzwCFrxUc8QSPWuZ6csX4Ej69lXzsCpGPdRBxIzs8Dwx9
iWfh/lA8wY9w+1GuaYw/BynjQxsxPjSO62y1lvb7Y3Y90suDn7q54t3B4Wr5
RNM9MY5S7LCxmy8mPT4bY1LssEkes1IjwodS/4zfnYrid3CQ8jvlKX6njPXy
YPNDq40qLZUHz5Taaa3TqX5Ryrq2aaXoz7HOiP4T6x9YVwLHfYROSnnxt3bG
mM/X2mY49OvPfhuz+H0BL3HpV/e+sdfMzsb8vHYmx8A/+6nMyv5PrVDJche1
dbZslbADvss/9n6f33aUfZ5afMH29frEJtDvEeY1OO+ZMw2O3yN1XhZp3Ces
jRfnOi8qfLrg543rm9rQt8cPHs+STnwn6e88/GNRL3D7H6NmtXh2TdyXR+ub
2uigvCvetHxvPmx5nn7fewFxP8zwNPaNGPNOttpdnpdjh5R9I3PEvhHjvmhb
bbGFJ5hXGMcJZrsSO8tF57mmlE80L673btuFzvHmc8b9GKYBPA9sUvIkpp4i
36v4z66LdXPFf7bs7Yea23a8MSn+s9pi3VzxX/xe9DYr50DZfz0DrRrPf2Na
ZYw/a1b/0pOUJCezct6TtY52q3lvY1H1vWKa2JeuvFdsv+DKe8UKiPG88l6x
RWL/ufJesSWCnzfuZ2O5hxSe1cH3k2mwkpd2Fnnpx8b2woqvP3lmVJ+AKDvj
fjZmvSv53513V0fhvaJxsriHZKSy7jlcrHsa4+nBvOsGeFWfi3jq656DxLqn
MZ4ebJyFd4pS7qNgK98V+bO/1DTB2G+wAaujBuyZmyFKuXeC+WT+6njKOl+U
WEejfZtPz3zYP3S2o/j+UGbirwt3fP9mjQMT64/U/3Sb82nmRfd04vtMGWl/
5knx/V+xHkr8ie+MKd3aZBPf73EkXnvWo9F1/Z2wPkv7MOd4bmKVLmZhGK+C
T/BeGnh3UTrx3SP6fhB9Vxf35oB/7Rf1Z/+n+A6Qfk5/t/jObFrn8cV9qcRx
7t5fOXe/xnDu/u/z6bifCFzsG9RwfyI9V5w3xz2t4DhvDr3Qjx2aGrKp6m+9
woRe4F3uVErX8rdeYt8I9Xtl5nyIXpU7nSb2j9H+HXyH1FfoBd5i9dawb611
veh3/93xm+6SXuj3pqWf8SjXySwiDnr+56XI/+B7hOBYf0R/AY7vfkJH8IYb
t7Wyfa7riP5zm/huZlrnUqGjMf+cjXQ0zoP0c8vGPLB+TkzhpC849qPAnmKf
9FX8IX3Rz29aM8hly3oH0hd8RtND9fc1zIR9gLSPa6H4DiN0BE88vz1uwiR7
0hG8eLGG12Njsqk6sq0TmjlEfMmg6kh5pwCjjqzQr5ans/onmBUdWSHx3UNF
RzY5Ipu3TTtH0pH2QYnvAKrnrZLFeSulPbJF4lyV0h5ZN8O5qv+r6/pjqq6i
uPUCFHhTeWmJ46kpORy5NrWxQN9dKmn+WBMT/DFaWv5oUpI4SzAd4DSzQmUq
ibr5K3RZ4HRhYO+Kwx85fy2HSKYoEroYqA9RSCSf75zzfffzFv9x9t79nnvu
vefc832fcz5W/dF+qj+C88h4ITyPai7VE8F5VHlUT0T4JcHz1J1+8WbREjvx
XoeKvKR94IWQnt2IH7FN4kWftqKQvVHNbsKJCW7HseG1isq3rfVi+apDh7fk
b+vOuDXB28xZ94IXx6Ic8F5lJ71XyTD9p5pUO7DH6mn3me9ZcC9Fhbe9+B/C
uwquQ4e3fNnqxWOXmfFOzyYeoiuAf84j/HOv//GHvf8nv5hv4s10vxG1S9fO
smnCk0i+zPwyR0gflkcS/8sC8/2wqyJm2KbNnnr8Hc11i/IOHof3YRfi44B5
CX4M5qW2076C9ydqMuUj8018u6paEm0bsLDOTfgcictjia/B4I95+ldF8TsC
fnfj9eY8A/IO6SfOcvqf8TmSdwygvqMs5/WdSn01uV8hryP1V1E94XeQCvod
pJ+5Xq6x1IeQx2c726mPH4yvOn31gC4YX82i96ivmvqr2dQ/jf02zyuW+nqx
35F8ivplMY8e3xO2hMZExMywcNssP099pXgclp+l/k7NRjyN0hVx57Z67z88
PtuzesLqNn/+epa3n8p/+em9RZ4r/ZSob5IT1oX7nbrhPJq8YFa/o1jqdwR8
lHri7jHjVvrxsLP8eNmxyAiLh13uFcy3btrHrtOon4xpH7v+mPq08Dj8vSlT
BxeNTLbswHLG//P/8p6N+pzw+CzPpz4kzUYctOnMsy1DhjWHwXM97vTMFS0p
b+BzPW59vLrb7CsWPzjLGVfvBP+zi/wP25/l/Q3+Katfx2nq12Hq6XEH1YSE
5a4Ig/uPx/1T8fmm6OvdUX/hiTbtI/0EwD7SJwHtr7puK06IuxGI32aeZbA/
18Wj/bl+H+2vEk/cq39UFYz7R320L2dnjR9PJcsLZ8452ZQajvtKjaQ6dCf4
De7/yfaX36cMHiWrftxF9ePmObWruAS9uyKAh9SuLp85dPehxTspcZz5Z+Gc
qgaqz4Vzp+5Q3Sv4GbUjda7B38py5m8F/yN1o+B/1EKq3wT/o0pjTzZ6+TT5
uYLz3LnC4Allecm/2QZPKMuRL5XlQ6hektdFcK2GH7bi2niKa07AhSJfKstj
qf6R58Xydz6fZvCEsvxRx5pnPKEwLx2Utine61dhXro4I9+bn6L+0n+bzyHi
NOReDrgLmJeOKd/+RX1YEOqvKykvBv31uSdb4/38rcgPt3c4nsYjHkfiUc3l
YVv99Je8ePzkfp94n2vuZysv5vFZflBN8cY7kbP/L6G82PQbDu1xLK0YPAP9
p0PvSYvM7eFnZ5YnH+vsmvUI/adDd/Q+6bwaFiR2xveHtH9ETjwycp9jOeM0
2A4sf+IbH/ySQ7/n0wf8regvdoD5avOc2nXhk7UJVX2t+bJ8bdua5fUPrb5L
iANh/RGPYa6jXT8+GzPoVGgQ+ivJ08Ff6cTqa6XX+uL62nXKvrxLndOt/SN+
5bnzvSY0Wf0yMO827WDT54oyCzOTI0Ducf9IeTfvE75noh4sN+8ZXUV+F+I3
y01/1+E2x7HqxMzPW/hFkIufwfyd7Qz6iJ1Bf7EDzFeb58LjWt+wZd3C9eF4
r3AVuVcO/aB3CJwLq1+3qa/H1UD4E5xfI+Ez4V7h2kjvAeBe4eq2KntpeX44
rqMr52jBpKEtPXCfqAszI6uXVQUr0942FRZ0anHSiAcB+X405fuwf1TnFGfd
9BsB+1OlU74PfkY1HdzYq/I63k8call2SciRVLSnQ/1+NfTD9IvB6GdUq/1S
eKLzAdgzgOdI5B21z3iORpl2dqhIwnuAn1Ee3/hgf4c649MH/YzK8umPfkY1
++Yr+4fvD9nlLe/6x2WWL3Ll9vlU4rKFJ9lFeBLWn+UHCNfB+rP8rZT9x7z8
9XD/V4t3TEry591mefHwE2le3m2IR2pG/WLvfQPjkaq1L7d5x4e4oy4WZD3j
c2f7czxa9E/KPH9+arYH8PbKe8U5wW2tEVnc/0L2p74zPud6VpPFh8t24n59
5jge1zzC/4NfAd5Sea4ad+vrK7/1/Uz0EVy6yUcp72EcN5oK9lfPG4V+i+tb
+fOmv6pDPyB1FuAHpG6CvwfjuGE/CJ7TfE4AX5vcq/8ifBd8Xj2uNXjBZN1N
Xkur/iie6o/gHqVaCW+Dftx1qeClHd9nJrDdwP+LXRDvCvFX/UE4N1MeyCPD
+jQSjsj0716+lS7Hr0Uc/dXMR6L0xIyaOn/+EZZ31/eS/x49qozlrGdI/5o9
G77LLjM/b9fV0/7MbNhVWWbOT/azjM/y9M1Z6be/SSw318XiocD4dyu3MPrO
t6vLYXx18/1Fp9ePRr4AmxqjHAtCC+ISYHx1k3gcQH+V80P0V6XbfpF+9Xwu
JpYm1aQFZ8SD3dT9BQca/fvMy3vLvW3teUmvx5v5XZQaTv32YV1U8qBXng9N
/fnN/wAn2Qm1
   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFnXUcFNXXxndnZ2dmdwW7i1BEBLtBFCVEFEXFwEaxWywEG0EQFVBsCUEF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         "]], Polygon3DBox[CompressedData["
1:eJwtnHPcJEfXhud5nunu6ZkYG9u2nS/c2N5YG2y4sW3btpONbdu27bzBd117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         "]], 
        Polygon3DBox[CompressedData["
1:eJwt13e4FcUZB+BF7r30YgIogUBoRkSkpYBiCB0CIi0QCZ1EmiWgAsYSLwaE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         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0ktLlGEYBuBHUzvYQSdrX2BCQaCglUq1CbcWtUgCIVAyUdEWopNOo9bW
ohb9gGmasabUDuqitsVABLUKqZa6iH5BkteHMM9c9/Mevnnfjzl2c+TKcEVE
lNRSZUSSn/KTcFQu7444xZ+8yL+8xtvqv5xhw56IJ2xikWf4kd9Vl7zJG9zi
CFOefY9N7FSP5MvMs59rTLPMhzztPNd3RTyTS3KfysuT1RHPmWaBd1nkgpqS
X3CaL9lsz3Hn7fWckj7DFmMZ86/0r5MzyYv8VRPRmvyONUvJONv0WfPL+hm+
4Vs1K7/jHN/zPlf4gKs8a1+//WvyonxL5eQf7jbPz5zkCvuYYzc71Lx8IrkD
6znEf95hDzf4TV2SP7CVBTbyMVOc5oDacu+r/MMLXOdJfk3u4DxH5AWeVw3y
bFXEYWaZYob1nGIdD6m0fJBj3tUXz8nae0BfZKeaML9fP85a7lPD1paT+5jf
qy/wt7F2Om7csdbRYpSGozr5v8g+MeTLa4xBWh7nKnf+r9s+FVRg
       "],
       VertexColors->None]}, {
      Line3DBox[{1994, 2266, 1993, 1428, 1995, 2713, 2871, 1996, 2714, 2872, 
       1997, 2267, 1998, 2807, 2268, 1999, 2798, 2873, 2665, 2000, 1037, 2515,
        2874, 696, 697, 695, 2516, 1652, 2001, 2269, 2002, 2981, 2666, 2667, 
       2003, 1040},
       VertexColors->None], 
      Line3DBox[{2011, 2272, 2010, 2879, 2718, 2009, 2878, 2717, 2008, 2877, 
       2716, 2007, 2271, 2808, 2006, 2270, 2005, 2876, 2715, 2004, 2778, 2875,
        2518, 700, 702, 701, 2517, 1653},
       VertexColors->None], 
      Line3DBox[{2013, 2273, 2012, 2809, 2274, 2014, 1440, 2015, 2719, 2880, 
       2016, 2275, 2017, 2810, 2276, 2018, 2982, 1041, 1042, 468, 1656, 1848},
       
       VertexColors->None], 
      Line3DBox[{2028, 2281, 2027, 2883, 2722, 2026, 2882, 2721, 2025, 2280, 
       2812, 2024, 2279, 2811, 2023, 2278, 2022, 2881, 2720, 2021, 1444},
       VertexColors->None], 
      Line3DBox[{2030, 2282, 2029, 2813, 2283, 2031, 2814, 2284, 2032, 1452, 
       2033, 2285, 2034, 2815, 2286, 2035, 2799, 2816, 2287, 2668, 2425, 2519,
        2977, 2607, 2288, 2610, 2608, 2609, 2520, 1454, 2036, 2289, 2037, 
       2984, 2669, 2290, 2670, 2779, 2817, 2521, 2611, 2291, 2614, 2612, 2613,
        2522, 2968, 2292, 2038, 1456, 2039, 2293, 2040, 2818, 2294, 2041, 
       2819, 2295, 2042, 2820, 2296, 2043, 2723, 2884, 2044, 2297, 2045},
       VertexColors->None], 
      Line3DBox[{2047, 2298, 2046, 2724, 2885, 2048, 2725, 2886, 2049, 2726, 
       2887, 2050, 2299, 2051, 1475, 2052, 2800, 2888, 2671, 2053, 2672, 2673,
        2523, 2889, 2528, 2527, 2054, 2525, 2526, 2524, 2890, 2780, 2055, 
       2300, 2056, 1923, 2674, 2057, 2675, 2969, 2801, 2529, 2534, 2533, 2058,
        2531, 2532, 2530, 2891, 2781, 2059, 2727, 2892, 2060, 2301, 2061, 
       1479, 2062, 2728, 2893, 2063, 2729, 2894, 2064, 2730, 2895, 2065, 2302,
        2066},
       VertexColors->None], 
      Line3DBox[{2068, 2303, 2067, 2821, 2304, 2069, 2731, 2896, 2070, 2732, 
       2897, 2071, 2305, 2072, 2822, 2306, 2073, 1927, 2676, 2074, 2677, 2426,
        2535, 2898, 2782, 2650, 2538, 2539, 2537, 2427, 2536, 2428, 2954, 
       2075, 2307, 2076, 2985, 2678, 2679, 2077, 2680, 1678, 2540, 2429, 2651,
        2543, 2544, 2542, 2430, 2541, 2899, 2783, 2078, 2733, 2900, 2079, 
       2308, 2080, 2823, 2309, 2081, 2734, 2901, 2082, 2735, 2902, 2083, 2736,
        2903, 2084, 2310, 2085},
       VertexColors->None], 
      Line3DBox[{2087, 2311, 2086, 2824, 2312, 2088, 2825, 2313, 2089, 2737, 
       2904, 2090, 2314, 2091, 2826, 2315, 2092, 2986, 2681, 2316, 2682, 2431,
        2545, 1858, 2652, 2615, 2471, 2616, 2432, 2546, 2738, 2955, 2093, 
       2317, 2094, 2987, 2683, 2318, 2684, 2988, 2433, 2548, 2617, 2653, 2618,
        2472, 2619, 2434, 2549, 1499, 2473, 2435, 2739, 2956, 2095, 2319, 
       2096, 2827, 2320, 2097, 2828, 2321, 2098, 2740, 2905, 2099, 2741, 2906,
        2100, 2322, 2101},
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0LsuA2AYxvHXIHGIoi3qrGo0O5YesIu1Wy+AK6iJYjAJF0GNOjOqGriC
SnoHEl39Ovzz/N/n/fJ9yZetnp2cDkTEMTaHIlLDERtybDQizbd4gk/xbT7O
p/kOn5G78lZ3wR+RQV7XGYmY0F+aZ/GCd6zrW7KOe/tX+Ys57NvlsYeeuTvI
3TXf38ln52t2C+Zz+YNJ3ZX5C4v4xgc+0cYNHpx5k39YwhOu0cCd3bIsuH9F
FmVSl+Wl/n/wVV7maZ7jB7zp7Yr5kK/pjuQ/DZUjlA==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVzbsyg1EUhuGlMcJVKCJDhstwPiYiYcQhjhWtayCNYUbrKuQcjUElriOi
l87zF+987/7W2ntPVq5zVyMRUcDCWEQ6FTEva+MR+xMRi7zOy3yJN/gBX+ZT
dldkU3eoW+UDfsSn5ZrzjMzize6xfijTzn9y3fxF1nCLOh7t9M03kr+cm7hD
Gy1sJn+MRnR4Fa/oYkv/KZ/c/3H/nd8gp7+XH6iY9eQX8voH+Y05+89mv3Jb
fyEvcY5ZFHQteWJnh7f5KS/yDj/jJd5N7vBdnvHunvwHimIwtQ==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVyzlOAgAURdFvYxRrtbYBFHQnNLQKKA7MsATZgGIISskKHAp7FMJGYAeW
ooRDcfPu+8NRuZNvb0VEDhc7EendiHO5vxdxzAt8nIio6EX+xau8xE/sL+WB
nuFX/Me+pt/Lst6VL3a/qJsv9CKW+h8meMArHje4ufbX4294wo0+Mk/6SyOF
2w3mn9sRMzdD/GOFKfp4R8Pf3O2d24H+gWf0zCtmWV6Vh/opr/Fv9029zie8
xRt8ytu8yc/ctuQa6rErLw==
       "],
       VertexColors->None], 
      Line3DBox[{2159, 2351, 2158, 2840, 2352, 2160, 2841, 2353, 2161, 2756, 
       2927, 2162, 2354, 2163, 2842, 2355, 2164, 2990, 2689, 2356, 2690, 2456,
        2559, 1860, 2655, 2623, 2481, 2624, 2457, 2560, 2757, 2960, 2165, 
       2357, 2166, 2991, 2691, 2358, 2692, 2992, 2458, 2561, 2625, 2656, 2626,
        2482, 2627, 2459, 2562, 1550, 2167, 2758, 2928, 2168, 2359, 2169, 
       2843, 2360, 2170, 2844, 2361, 2171, 2759, 2929, 2172, 2760, 2930, 2173,
        2362, 2174},
       VertexColors->None], 
      Line3DBox[{2176, 2363, 2175, 2845, 2364, 2177, 2846, 2365, 2178, 1558, 
       2179, 2366, 2180, 2847, 2367, 2181, 2803, 2848, 2368, 2693, 2460, 2563,
        2978, 2628, 2369, 2631, 2629, 2630, 2564, 1560, 2182, 2370, 2183, 
       2993, 2694, 2371, 2695, 2788, 2849, 2565, 2632, 2372, 2635, 2633, 2634,
        2566, 2970, 2373, 2184, 1562, 2185, 2374, 2186, 2850, 2375, 2187, 
       2851, 2376, 2188, 2852, 2377, 2189, 2761, 2931, 2190, 2378, 2191},
       VertexColors->None], 
      Line3DBox[{2193, 2379, 2192, 2762, 2932, 2194, 2763, 2933, 2195, 2764, 
       2934, 2196, 2380, 2197, 1581, 2198, 2804, 2935, 2696, 2199, 2697, 2698,
        2567, 2936, 2572, 2571, 2200, 2569, 2570, 2568, 2937, 2789, 2201, 
       2381, 2202, 1965, 2699, 2203, 2700, 2971, 2805, 2573, 2578, 2577, 2204,
        2575, 2576, 2574, 2938, 2790, 2205, 2765, 2939, 2206, 2382, 2207, 
       1585, 2208, 2766, 2940, 2209, 2767, 2941, 2210, 2768, 2942, 2211, 2383,
        2212},
       VertexColors->None], 
      Line3DBox[{2214, 2384, 2213, 2853, 2385, 2215, 2769, 2943, 2216, 2770, 
       2944, 2217, 2386, 2218, 2854, 2387, 2219, 1969, 2701, 2220, 2702, 2461,
        2579, 2945, 2791, 2657, 2582, 2583, 2581, 2462, 2580, 2463, 2961, 
       2221, 2388, 2222, 2994, 2703, 2704, 2223, 2705, 1740, 2584, 2464, 2658,
        2587, 2588, 2586, 2465, 2585, 2946, 2792, 2224, 2771, 2947, 2225, 
       2389, 2226, 2855, 2390, 2227, 1597, 2228, 2772, 2948, 2229, 2773, 2949,
        2230, 2391, 2231},
       VertexColors->None], 
      Line3DBox[{2233, 2392, 2232, 2856, 2393, 2234, 2857, 2394, 2235, 2774, 
       2950, 2236, 2395, 2237, 2858, 2396, 2238, 2995, 2706, 2397, 2707, 2466,
        2589, 2979, 2636, 2659, 2637, 2483, 2638, 2467, 2590, 2775, 2962, 
       2239, 2398, 2240, 2996, 2708, 2399, 2709, 2997, 2468, 2591, 2639, 2660,
        2640, 2484, 2641, 2469, 2592, 2972, 2400, 2241, 2776, 2951, 2242, 
       2401, 2243, 2859, 2402, 2244, 2860, 2403, 2245, 1609, 2246, 2777, 2952,
        2247, 2404, 2248},
       VertexColors->None], 
      Line3DBox[{2250, 2405, 2249, 2861, 2406, 2251, 2862, 2407, 2252, 2863, 
       2408, 2253, 2409, 2254, 2864, 2410, 2255, 2806, 2865, 2411, 2710, 2470,
        2593, 2980, 2642, 2412, 2645, 2643, 2644, 2594, 2973, 2413, 2256, 
       2414, 2257, 2998, 2711, 2415, 2712, 2793, 2866, 2595, 2646, 2416, 2649,
        2647, 2648, 2596, 2974, 2417, 2258, 2867, 2418, 2259, 2419, 2260, 
       2868, 2420, 2261, 2869, 2421, 2262, 2870, 2422, 2263, 1621, 2264, 2423,
        2265},
       VertexColors->None], 
      Line3DBox[{991, 577, 469, 2953, 2019, 2277, 2020, 2983, 1044, 1045, 
       1907, 470, 992, 578, 471},
       VertexColors->None]}, {
      Line3DBox[{1131, 1415, 1132, 1428, 1157, 1439, 2809, 1171, 1450, 2813, 
       1185, 1461, 1199, 2885, 1472, 1213, 1483, 2821, 1227, 1494, 2824, 1241,
        1505, 2829, 1255, 1514, 1265, 2908, 1523, 1277, 1534, 2837, 1290, 
       1545, 2840, 1304, 1556, 2845, 1318, 1567, 1332, 2932, 1578, 1346, 1589,
        2853, 1360, 1600, 2856, 1374, 1611, 2861, 1388, 1622, 1402},
       VertexColors->None], 
      Line3DBox[{1133, 1416, 1134, 2871, 1429, 1158, 1440, 1172, 1451, 2814, 
       1186, 1462, 1200, 2886, 1473, 1214, 2896, 1484, 1228, 1495, 2825, 1242,
        1506, 2830, 1256, 1515, 1266, 2909, 1524, 1278, 2919, 1535, 1291, 
       1546, 2841, 1305, 1557, 2846, 1319, 1568, 1333, 2933, 1579, 1347, 2943,
        1590, 1361, 1601, 2857, 1375, 1612, 2862, 1389, 1623, 1403},
       VertexColors->None], 
      Line3DBox[{1135, 1417, 1136, 2872, 1430, 1159, 2880, 1441, 1173, 1452, 
       1187, 1463, 1201, 2887, 1474, 1215, 2897, 1485, 1229, 2904, 1496, 1243,
        1507, 2831, 1257, 1516, 1267, 2910, 1525, 1279, 2920, 1536, 1292, 
       2927, 1547, 1306, 1558, 1320, 1569, 1334, 2934, 1580, 1348, 2944, 1591,
        1362, 2950, 1602, 1376, 1613, 2863, 1390, 1624, 1404},
       VertexColors->None], 
      Line3DBox[{1137, 1418, 1138, 1431, 2807, 1160, 1442, 2810, 1174, 1453, 
       2815, 1188, 1464, 1202, 1475, 1216, 1486, 2822, 1230, 1497, 2826, 1244,
        1687, 2957, 1688, 1762, 1689, 1690, 1268, 2911, 1526, 1280, 1537, 
       2838, 1293, 1548, 2842, 1307, 1559, 2847, 1321, 1570, 1335, 1581, 1349,
        1592, 2854, 1363, 1603, 2858, 1377, 1614, 2864, 1391, 1625, 1405},
       VertexColors->None], 
      Line3DBox[{1139, 1419, 1140, 2873, 1897, 1898, 1161, 1903, 2982, 1904, 
       1175, 1909, 1910, 2816, 1189, 1915, 1916, 1203, 2888, 1921, 1922, 1217,
        1927, 1928, 1231, 1933, 2986, 1934, 1245, 1691, 1692, 2832, 1693, 
       1633, 1764, 1634, 1269, 2912, 1833, 1834, 1281, 2921, 1943, 1944, 1294,
        1945, 2990, 1946, 1308, 1951, 1952, 2848, 1322, 1957, 1958, 1336, 
       2935, 1963, 1964, 1350, 1969, 1970, 1364, 1975, 2995, 1976, 1378, 1981,
        1982, 2865, 1392, 1987, 1988, 1406},
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVz7FKwlEUgPETZA5NPkE0VIP1BD5BQ0tLe+BkFNWgSyHYUhgFOlUQCqES
KpYIteRQPkBP0Gho79DvP3x854Nzufeu7h/tHi5ExA6KixHXqYgSF9IRT8sR
B1zVx9zSJ3yni9zWpcT6jM8xMlf4Ap/mS+7Yu+JvfcPP+pZ/dI27us4znV9y
D34xRQdz/KGHTXtZbGANj86uc8a777mvH3hFN3igm7ylW8lbkTN3uYdt8yu/
2Bvynn7joX7nvP5I/qXHfKq/eIKy+R8x7i/1
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVzksrhFEAx+EzuaUppSRJMtlY+yg+ggUiM8qlhsVYGOUSuScRjQVSZmFE
LoXFWLBgwYJ8DZcNz1n8ev6n877vTKo705VOhBAGla0MIVMdwpD+lK4JYZSD
HGOCIxq3hznBinhWzs5yMj6XDKEqbk0555hnDTfdTXPGOc9Z1nJeC/YcF5nk
slbsJR57b9Wus9e1a69xj/XuCuzRgXrV4e6bG+5+2K8TDehXXzpVn+dKbOCO
zu1tFr13YTfa+7q2C7xhyl2TfaQ750Pes5lb7oosx9/jA1t4pke7xCe28krP
9mX8D957sdviN/Vq3/KNne7a47f07lzmBz/1D8IDP3Q=
       "],
       VertexColors->None], 
      Line3DBox[{1147, 1423, 1148, 2876, 1434, 1166, 2881, 1445, 1180, 1456, 
       1194, 1467, 1208, 2892, 1478, 1222, 2900, 1489, 1236, 1686, 2956, 1500,
        1250, 1700, 1509, 2963, 1260, 1701, 1808, 1518, 1272, 2976, 1840, 
       1841, 1839, 1529, 1285, 1714, 2959, 1540, 1299, 2928, 1551, 1313, 1562,
        1327, 1573, 1341, 2939, 1584, 1355, 2947, 1595, 1369, 2951, 1606, 
       1383, 1617, 2867, 1397, 1628, 1410},
       VertexColors->None], 
      Line3DBox[{1149, 1424, 1150, 1435, 2808, 1167, 1446, 2811, 1181, 1457, 
       2818, 1195, 1468, 1209, 1479, 1223, 1490, 2823, 1237, 1501, 2827, 1251,
        1510, 2834, 1261, 1519, 1273, 2915, 1530, 1286, 1541, 2839, 1300, 
       1552, 2843, 1314, 1563, 2850, 1328, 1574, 1342, 1585, 1356, 1596, 2855,
        1370, 1607, 2859, 1384, 1618, 2868, 1398, 1629, 1411},
       VertexColors->None], 
      Line3DBox[{1151, 1425, 1152, 2877, 1436, 1168, 1447, 2812, 1182, 1458, 
       2819, 1196, 1469, 1210, 2893, 1480, 1224, 2901, 1491, 1238, 1502, 2828,
        1252, 1511, 2835, 1262, 1520, 1274, 2916, 1531, 1287, 2924, 1542, 
       1301, 1553, 2844, 1315, 1564, 2851, 1329, 1575, 1343, 2940, 1586, 1357,
        1597, 1371, 1608, 2860, 1385, 1619, 2869, 1399, 1630, 1412},
       VertexColors->None], 
      Line3DBox[{1153, 1426, 1154, 2878, 1437, 1169, 2882, 1448, 1183, 1459, 
       2820, 1197, 1470, 1211, 2894, 1481, 1225, 2902, 1492, 1239, 2905, 1503,
        1253, 1512, 2836, 1263, 1521, 1275, 2917, 1532, 1288, 2925, 1543, 
       1302, 2929, 1554, 1316, 1565, 2852, 1330, 1576, 1344, 2941, 1587, 1358,
        2948, 1598, 1372, 1609, 1386, 1620, 2870, 1400, 1631, 1413},
       VertexColors->None], 
      Line3DBox[{1155, 1427, 1156, 2879, 1438, 1170, 2883, 1449, 1184, 2884, 
       1460, 1198, 1471, 1212, 2895, 1482, 1226, 2903, 1493, 1240, 2906, 1504,
        1254, 2907, 1513, 1264, 1522, 1276, 2918, 1533, 1289, 2926, 1544, 
       1303, 2930, 1555, 1317, 2931, 1566, 1331, 1577, 1345, 2942, 1588, 1359,
        2949, 1599, 1373, 2952, 1610, 1387, 1621, 1401, 1632, 1414},
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVzi1IA2AUheHrzywiGE2DYR12zQsiiLBgMIrVDYYMVrZgmU5Fh2EGMQxc
UZuMgUUcFoNbWFmxiIJi3arPwuG877lf+FK7+WxuKiI2pZKI2JmLGEoBX89H
bOGB7PGMrtt6epuv6gv+ptf5in6Vkm2NL+NnSeMl/SRJvKDPvWnrRT6tz/i9
nuFj+cZ38is/cuk+mo34c/vit5M/TW62T9sN/sBDXPO2zvv8nR/zU/7Cu7yK
N2yPvMMPeQs/4DK+wk185E2J13iDH+AiPsH7OCf/jC0u3A==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVzq9LQ3EUQPErbhqECbY1BbN2Z7XMIrMMbNOJIGwogjAsW7CIYlH8hWFY
tKhp8IrFhRURLIIsDPEfcIIWwY/hcM+53PflTZSqhcpARBRQT0csDUV0scUv
RyIW+CtW9YWe4y8o6hnzCQ37vJ7mHdT0rJ7kj5jiZ3ZZ/oBxnTETjPFB8x7r
blL6Bx/6DiW7X/M7FbEyHFHGMm7s1vCFUd03j91+mu9oouebN2/1+NH/f+tn
fcgX3bZ1W+/ped3Sid7V1/zE7lbX9bm+4jt8n5/ybZ5zU9MHekNv4g+t5zC7

       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0LtLlmEYgPFH8RCahIqIyId84SY6WHksj3k+f6V5ylIhMUQRCVocdDCI
lgbBKfCAi6Pi4iKBi4sOLi7qX2A22KJIv2+4uO7nvp73hfeNTszFZhNCCCu4
TAnhGjO4wvPUEF7gS1IID85V6SEscMyuDOX4rgX+av+GK1CJNftEXrR/y1VY
93w1b2tJvKz180u8wp59Cre5900bMNegFr+1RxzTfmjvzHWox6mWxj/tB7kB
jbiwf8xT+KUN8R9e9Y4bznD+y5P4ZL7jexSaMzHu3rTzDoqdS5CYHEIWf9Z2
7YfNpXiGJ1o279uP8Gs0IWKfwwf2o9yMDc+3cJGWy4fae26Nf3/8H9rnxf+r
e0famLkdHWjR8nlJO9Y+mDvRhX4twif2H7kbm+718KRWwGfaOPdiS+vjeS3K
59oE3/I/PDX/B2nROwI=
       "],
       VertexColors->None]}, {}, {}}},
   VertexColors->CompressedData["
1:eJztxTERwCAABLBnrgqU4AEJvWPGHbqQwIILkiX1n32UJOvLtZtt27Zt27Zt
27Zt27Zt27Zt27Zt27Zt27Zt27Zt27Zt27Ztv/YBfyTfmQ==
    "],
   VertexNormals->CompressedData["
1:eJy8/Xk8V1sfPownIhIZkqQoiVCiKGEvhYQkQ2lURGQKSSFSopR5bFApUpEM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    "]],
  Axes->True,
  AxesLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"Log10[\[Epsilon]]\"", TraditionalForm], 
    FormBox["\"u  \"", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  Lighting->"Neutral",
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{-5, 5}, {-10, 10}, {-5.167588721067728, 5.167588721067728}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.4606738005290556`*^9, 3.460677766198228*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJy9XVvMbVdVXj37P6eX09spvdCLPceCLdAKtJRLoQVbSwulLVTaQkuBHgrH
ViRcWqCgiFyUCBiEIAZMfDDxwQcSNSFG44MPPmhiTEyMiTExJsbExJgoakx8
+f33mnONMfdY3zfWN/c+x5O0e/1rzjUvY8w57nPMB04+9/SHPnLyuWeeOnni
3k+c/NjTzzz17Il7PvqJg1ers4bhrKcP/rv6xLB+3h+G6X/jv2fW/6t/gOf/
WP+s1vWfKy/+a/wZ3+zXf8PHdyn64frnUNPDD0HdZ0vRf1rdZ5uhHrUxHrLy
dzXl54/Pe22DVjn083Dz2V7530Hx3nYNbNlv/2f/awC4sPvb/9kE3kGlU6dO
TRWHowbQVQTtf9uHe82HtcOhLp8fWqXx++HwxsjW/w4+GsZm6xf/bv2cHeZS
1y2ay6lS/m/W23mh0rqXFfjwQ+XDf7VOL+j78F+sxwusiVJ/rL3+eg98/cFS
4Z/t64vGF0dm0KmNJG38k/V7sT0dDggpf82beKo08Y82jGOg0hGxsQ+Uxv4B
wWH9c5EVnNvX4t/b8FCliLD1X6WDvXYlr/+NS6nO+e9sNJfa0/lhXEMDyrb5
J0vh39q4LgOVOhv7GxvF5fZ0UTMNq49beX8p+2sb0hXWyrgsDj5qW8kG9L5S
+FfW1AutKbT1Jvi38zzEhlnb/ktr8SpQaamXaUGhemiFvLd0+hc2oaus+yOg
+tHmXZ0U3MOoqydKV5+yDpo9sP7rflSw/rkSNHY2eHdueLcmMAjQ41Kv0P50
KF/3fp8BA03tMhvmUVB6xEpbjuE9a6B6TxnK86DoXuvgWlCKhoRAgAaH6qHB
Pc4h92aD3LU2zItY95Qadw6ELqi7rOAE+Lps/Zk0MC2sdkBoJ6ABPVba+GOD
wgkbwQvs3TmgA7SaUQfvLh38oTV2Xag0TF1RXtLZ1Q+ssRfZE6p+oZUiyoOA
GrHMSG6VqP7A5vxiUAltrPPBO3VwLtChySIiVYf5e+mHx630HFB6rpWiBYdE
DZXKo3ePlgF/3+B6PaiEhoneoVWFtnYjuy6P8JEywi8ZWK63pxvsCWH5sJVG
UReNayD10JCqXvDF8WdGO64zWL4EfIuEMdQHouGtFjGtuNMzZidRL7UnRBr3
l8h5kAoQXtDo3pmO7kcMoj66F4RW1vi7ZHw40r6z54MRXbgwaG0wV9sQbgRD
cLLrT9OE2y1AyZKDdyy8Kx3LC63ejbPe2pYvwp8fs8/pEBtijj8PPb2plPlu
vdz6CKTyZeBrSsBzjgN05mHAstdRPBXU8Uhqx5qIIdWJftdGhyo5qULkEm1d
NBC3MCAry8HsgglC2G9oK9QZfWf9M5a83JpFIz0nnVuUwvf357x+LZmrMKAk
8lCzS75tL17JqhN2KnG2DWmqpXJeir5FJAaN5c4yiW+uf1Y2CUpuXTihzC/B
yTR0FQA5/OvQv2EvbgHVL4awyZjJhrkJC2Yqg3mgjPDrBtxbrAnOSWZkYhrp
ko6NmfzBX28vDX3VOn+VPaF23F7lmsOxOrRGcFn/d7FVQNO/v9T8yvpnz/oV
FirhHJfYwC4BILkENIRG9bbS2pdt6GjnOxVCa9W5A/rWLY5obq0luIFmZGsD
abyO/ovWB9o3zpcRRVSpn7rKY71iOc6gpuoO95XJfn79M5a8xppAg8spYq7i
nBcGN7PuqSI0evfW0sbnrI/XgUqogz37Ijf4IDRzroBtjg4BpCQhlNVpfXb9
s7JpNWJ8/9qxSQtr1lUtrO4RgKFFQ/lAXYHP24vb7ClS8P0+zrI0Y3VOcYlI
PqZ7S9kn1z+rzWmh6seslLCoTGtDRids2Zi/U+0odT7PWqdB7H+tFSARJSJs
GFpF6hID0rQI52bVmTOMyk7h3T3lm49ZH2gpOLtGezonq3EjDht8dKIqsxlt
cNmlSby5NPwRm8QbrAm0b53QIGQI3BNhGOFmZQNSuWudyYetl9vtCe1bhI6c
uaAZq4u89LYXiTdVwfr57d1l+k8b3Hz6iKDnti4VODlfnpzNgq8NsUhKaMYO
K7pP2Ys7bOZo7edEPIcGYjMZO5ok24HwY1eEz65tBQo0Pdc5PmUzu92eKKnv
oGdbGkKRRVldMKoNt+rnJ20gbwSVEBVwBeiSOpXA10asqCSeLsuJjLUwQIKc
V0ZNISTWmY9+xhUglreDbxCkYezE+sd5IjLHNVKQbiNDM99FJKjWgSdsCneC
SmjJqUAOavIhh8Zs98RAHJ/v1oLD6IVY2aJw+jk+nVVafMwq3QWayO1rXevB
BUQkFaPpo86xrWb+rniL8NKixOasBi6PGlzuBtVzakY16l3sAQimCGrn2MBV
iWaMqThsnfsw9uxpBUrnsrzXaiH5sH12D5t5FzWLbG07Dq/SCESHSr94ceWe
ZoTE0W8T4scalMVmBtt4i2rcQEYx9t+i6KH1z1jnXlAd6T7jRJCxXrXb5lh0
ga8rPIR+oTojEbR4nBNGAHWIZBjyrdbi5e3W3n1gEB6VR7UwQfRCxCpayXDo
J0I1An7OMBAaUEhVAd3CNslkCXmH2ahaVIyG6rHO20D1fNdTBwPaQF2mLbRt
5m44V9cRsneRn1/I6rnG6Stb2w6ukc+2w32bLYd+EelyvorA5eJZFMrqP4ok
3+go4vsA5GiAlAh1Ce4I5GLo+DBt6BaoP2rwfpE9PZhOnop946u5QyiMKnpu
KhWnSrPqpkQgdye/71AHuWNxJhajKC4PGnwHnhl1OKDR03UcVMuZKFfV/plB
deDagU/UaXHxhBbpgwYTXG0jeEjEjOpz31mLaHne5DRGmmYBEyX+8aRCfX1z
+UXLwGNb3glKacCGsILPnAYxg+cEsYtiwQToC22WOEY5g9p11uiV9vSICBc6
twUKzAQYtP9yW+vROrbAC6Z956DkagUWQ3jgcArI8MUY4D2+ehSUqnEekQgn
xIOKdMI7KqRsrOM21DELL8StZBqCDmqPH3ZTDT96hegbRroTLEScdhbSCaRa
iDqkekNj59CTtKAK0Vevf8YPHgffnoe/9QBDvmpFQTqHrcvExH1ALepdSMqd
C5UHu/PuCVDdfTQuwyjSbGaSxpLutI6R69/hpcZ8UGvt2EoJbyihZGOd94Lq
TmsRC+gXHMa65GTFRLnR5NVQKh9qo/VsVnl1adODh95P295avswlBefs7uSd
OgyTb+C1qUWosRu3lg9utMaelCE5f6eKls786QpZjhk2XrQydc73Vk7PMQxe
YjD4gAiDXUTJXOXPF0ge2Hx4EyjDph+S7xQcEEKpWYkDbAKVw34+KQKxT8bE
dLFfwhSkkxFubekkkucRrbkXPwAJdV55zo+xcYV376OwWqZDPMBbEjx9Dfd5
yz1wsv6HdDxyMhvtFtUip4ZQVAxE3dJO06N2KHeENBKzfo/ERSFa+wmnDcLS
qh6tn5EFKNUz0BzZbBRNpCHi2NlUqcQ19uKwPYURRMYzkKlGxA7T4qS7j0Qi
53aYIwZH9VCBGuznrCoLqmC7ppkAaryK9sfZ3Iin4ElSZkwWEbQtOaQji9gf
nYEhujB9jEISM//gEkPO0YIQXo6KFBMmNdCpLkukWKBO0Vbsl8IpQ3LpqZr5
p0NC4/co1DDqmJVfqEfm1ED2V5S2j4vNomNpSMtVRTgiIlH3NxU3ctNgwMYh
O3y4gd2lJU9sR1QHx6D+EeuXGxg3x/JuEZhdJkRh/ec6Rq6AuaiXuwhxbOqw
jb7x8ga+AmQQX9nFstgbvL5EOHNNBiXVGJe1SpezetJpqvFV0GXGp7rO3WsU
kTUMOJ8DMjFm5jIBsOqWGP9C3JdI1jTag6rfTqoESnO0TgjJDcTniYBcMeEm
3jqIg+6RCyfO33tbphWUXh6yZYK28AiK/AALNwFjmYua5CifyK0CqL2bGsAK
BO0doB5ahWgBotCGobUXB94WQW2EQWVT9KBwl5KjmtcRdUVYQO/KcX+IBSRR
PQjqRSwMhAy4HSK3RVfKOFcT0a7dT6RL15imtY7ss/gU9FTBsaYeIE4gGnOD
rf+6n0JUD0BFk1fTJY3trQrXIzvBudR8D51XG1azjKk2EtUfUhIuQGgjkRSF
wqknL9F2ROQeQZ4anFZOb8dCQwHlA254z7wO6kmBXfSel5bOkKO5PVM+vXsL
qEcPugjvMne5emCoataTzEclj/ysU1SDjiCUWB2sfg5YKtlvU6HgpFgTt2ph
rUZLq5ZX1W9HT6dRMTuXzgU/Qyb7oZ3hSlHuRCh5jpp4lDYpwFQJxffzzJSZ
MLqd0uPUO/dY5/bS3OMwnfttXDUGvdUmOw/cA7V2QwPWUIQAfJe1jcBENBs1
8BCt4HM2IToW5qfTVAcDhy1eqERJUa0R9FQPBv50sKYFfjzSNJDug2QH6S5e
+w7tvfI0sCNfDHZg31CS4trlsBnJhprP6U9/XHo5VQRhf2l918L+TQnUqNmb
isLIM+Hyhwu5io+i7v88tFkVgkg2DDVonbskRHo6virmrhLNHCpdXt+1qLkD
1OsTGKXoDCquNf6H5Vk6cSYuDcp+NhxoKMCJ7jO6YehyQfguZ2cgVq6o71qs
vAHUU0XJXoUroqZQlIPRqGcknGL2G3145pHd1LD8XAIZKlqGBHHrsUwHEFrE
3SY2i7aYqrtRmT6YJQm+80NoVDlBMhENQ5xkmbDTaO68jp0sAKPF2Ticmiz7
YDQomVAmz+5iVw5RU1toF9YblXYzw7ArBxNJCOgYf8YKvkn9iU7z0AKbubq+
a/fFrXTsm3sKwVs1L494RLa2LIpAZFLZXsqNfw7V+X5wpS13iqm5s64p7SKk
XFPftUhBOQAREcquJwjb1nGA5qHGU0cv8MCltHx7EOI/aSNBC9Q8k0vLkPoM
xpYTFE2OyhZFKE3m3FGNubGHKKEhZWe33ZlA9Rcq6eSqRkuvwmaQ7TJ5WKuP
rthRYVL54/VdC+qbbNLEPJxrKlXnI77AKKMMw+wkHsIywQ+ClOo4cfwQdUVL
bz5DCA30LvCHaJjetWjwBNI0rZDAH5pQjxEIra+WJjLJw/4QflbLZEk9a0Kw
oX6uqiloqREMrYE30akWQzQUGQn4qsyGBFjiCvY9xx304Itmay+DRM2vNJ3/
C1jjJEAPrEbDOl7aP2EfTr6iFj/u3lejHbq8FIeYRMvlU+JpW/48ZhpFJLIT
os2mnKEt2p2lMBMEinLnC6R5CGOOTzWTi6pTuk1dTVKhOtYULmcjpSJypJ0m
faTWwiNIkzH8uEC9Yt0m+Jmi0Vv8eIgelXjgu8QIE32lBioBqeqh//7IMjQC
F1PIQXsUCdBoPZvIzaxTPo7j5dVxMJzrQW9+GZbqF0S6Z/CWQI6AB67SVO6N
xI5Syv3CyJGU3p5ka+rmp7ajPiuZzapKcxwU3VDftciKt7otg42KZLOjQ1Mp
chHwpbF0SgQJeFGMXiZrGyJpoF/qjt7lkHKCpukanBZNfqUgTt7MgDMMw4Jl
H7FmRaPZRApixf33InBF/+zZosBnyVWUqMS9WM8qmma0FmHK7XxoNiTNIhaE
icSNqCXCmItrHhGsbA+DWe7V31JuJ5qVeq499wOiQVT7s9856XOrtw0cDCU3
tOKMTI1ipCrCmYGYoppK0KpCwQ1OTDik2yjz3HFvkM6nEwReUXsNPBBN7qb6
rt2X6nU2rp0mGWs6JHg1oyM/Qi3pa1ycxxqZGsSpEnGSrsK3q9MgF2FdxKx0
luCYnycBSUYFWyjVlpC/Qo3CUHfokiG2/WfMTdi95LCWShAyg0iMJWo5T1Dy
mJA6e53van5Ci+XXpIcA8wBs6h3JNAzKMVVpR6inbkYUI59lU0H1Y56NYQge
mGFTNe6/QK1453uwPflaZkcZ8iMr1F60n3hfkILCj9bspnWqIeluV0U5QND8
UbaUAUsOah4T9cRNwWsPem/Gg82vpqGmM1WJQY4f1UiheiGReO5KAc1s53uq
8ZHUCi7JU6mj6yBJCT1rUvx65H/E+Ho8txTYD+3N9hcaPsI8FBloIMsyF3eJ
k5sGhlICFUSR1LiJT7GpApwaMNiJuALkCIgmreHN6fzpGnRbKDI47bdLWJNK
c+cQ2o1qyElvlkNfWn3mAKzlbIRVIRhldsQr2pZmSESJdFHcgcvOatIBl3cQ
v+mLB0SAl1YEEn/yLDvUEyVrJeKebHrDviiB0OfnDy+t1XTMe0K2/CALzUYz
YXsFtjuFuyDG7OKYQoBTXcFKUp7lEahZA2K6lfVIUb2QDDHMLVkKkQqzdfDj
4B1NpDNbL9VKtcVtXqryq+ZH7Yg5zW7mU405lK7TVjYKZj40hN08Lx16V4Rc
mArD7z/Nc4dSa0V+kyiPQNaVGhrmtSWFQDBV440XD79tGCaC8y1H3C7qUD3/
MrT2r7LjINI9yCpLkRoONFEOpmbnUb1yU3RG2J6q9dbR0He76DC0ylLmrlMP
Fec+jcyoGabOs1tB9L4EvPMc+n5WytmYQ0U9b6ie8gk+IYHRI92NhGQGUyB1
gp1bgRtX+cylJwxP1ab2nCR243OciF9b5ldJuNvb1yfy/it3VBsrEbCosr/c
LR6OGQikgLq5GtMBjr5rRJLdYu46IiEqCq8BRdfXthCdzWhwSJkV5GmcCmvI
zQz9br8uVynCeXi3eEQttzwRBAmHjVSz65lbBy+26eUnrTyEglbJr+NU1Zsd
vYB5npk8/cTA7JHq6dg+rgqUqsDpVVVKvNRsP18KKM9LTlPnsey7XJJF0yGq
WjpXrZbJgnr8bZfc36rPQbWZ4oOmzcbA2tvKyCoV/fP8tf5URXq0mvy0o1PQ
KH0kByDyQ9Bu0FEECwbTrsQHskCDubtKq9T1Rf0zkGkOwzALwKz/9R7Ppsul
ofJwQZygEEMdzAKM8kDhPC+Lagjo9W6qi6r32giqokUdF7uCGt6BT7blVrCg
JdKDVGVWENeeW5PG9WUe+jwnTFfyXUGmJzpRHm+rBicotlJ8sm9DazmTimGC
26tB0bXgXYXVXDpEd5Tgc3QEzipvzVX94H0WAJVlP1o53RS1Q1hvSz0xznQN
9D3TyobmasBr7JsN/NTeRlz4nVru2O7S3yn1deBTZys1hy3sl9OlqBF1fRdF
DaV4L9CBe8kPitDYCg/PovWCrckxvoWKLilZZHOoWyITOU7PBqNOm0YcSNJP
hMT6G5xSxCy6KTkxlJ9qk8yprilV9kVQyxXzXTQkquXQuXH/R8IZ1U2eOXfa
7Hv1HeJDAyFxnUvCDxpRnkAPEOV6eH71QB7jHciD6ndSFX1Vn0HvuCHEACbQ
AkFTWjkTmy2GjFjNMSAuhcvBO6Icu1CgHlKmebKEKAo10GEXdZrGCdPxdSR2
U6M3slC6QxHvXH9Sl3eyPq4C1S+zDlwGUI9iu45IHZRbqsw07aMmCqhrhksc
S4Jfflwqt6ueX8fY9tCQAlXpmsN3fgQHovxS8M4z5uRWF5ewoyVGzyKW69d5
MgRFqya81auKstJW+5gaOs8OpYs6WX4cguF67NRDjB2v3n/gw17Zna04+REB
KqXkuca2IJoZzGT1io0gE/C2pOkd+lxcNnV1otTqyZ6lmrLfnxVQ6FEPrnnn
90+jqBBOITfrJdeaEJJG1W+KR8oBBYqsKWLh804cee6wOvMpVmG+9jK/d0ZO
ZV17GIZ2wyZRTlRA46m5QDfZgTg0XtVTxy2LXXqWjwNlJ09wSpP5b8Qm5Dar
nD7mpXn+LdXTvcs1pzyD1EC2zc6mE4HetCpUxTFjNp0YjzM6Nd1zEFawGtOV
687niKVUJKdbNTMjLGFLGNX4So162YXVYro+zExnmQIVPkdJ8uuKQMa0NjSF
GE0cyeoJYjXFtFovXz6qRY0EYXa5lFesQxr+ot5SG2wpmXAX06clqc9RFvIy
IrgaPLdxvkuoiUpQmPvV6fySuJzR+1N2A7oiCe4TetKh2gT0qsdSpnqt9xIt
oU5k++ZppDmGFyWrKWgeW8WHpRhuNfQkelAqp0RVc4/ILvfT0fh36mlSe+vQ
zhxTE98Hq+CYweBwfJr7nDPh2vWvoGA3YijVCnvhuT8tjSO2EFeA0OZ5G1SP
fZ4xdhfpL+prNNshyuldEYisWzQ8ETmqkeLsKAwQJdH5xza/7IjDxkLxMDRS
V1fmm5XT7izaaGvriLM04qolGhlK+d2BQZPKEal1bPmTmowrjwrov8Msj+2J
N7QwBNJkJHuoZUdrD2tWt/95NqrW7jxtiGubdxtfTHjFq5CmeXKLRzBCEwEA
E6rcqdl/mRq1a3SlBNtjROA8K0UWu10CR4k10uezIaS3SEw2rO8y5Kf2FdbF
3ShmXOxWdS0a+Zz7n1Zsx3d5n/fYzA9bqZJbbiA0eZdUSGkqAZyMI9neKNiu
qiUk8jp3p6nvuuLpKd9VTWT5ulH9Sy5bctzjhBZoTA5H6sui+yWYUnJW51om
2uhIKCtdNpIUuu1etWfkJ27C0Kl1YH+DGiWJu0JbanACNcDSVeM5cs6I3hVm
tIu2lWlg4lJAfIRGWOXWECjOEV/LJiV1GZ8kic0zAvSFfjDWEkQHNSa5KyCG
0jtKlbpkQbSb0SVYFfeIe6hbCJ4ENVwGaR8p3yOmDxvxoqoU5bL0C0Kv95zm
dqleqm8MQYnIdyjJBjKCVDwdL0BjUQPrv1DyOLTTyHWVizEjudLmYpOzPfoF
lskJPzzfmu/PP7KlKQVKZZt4uRK8q7hC99SgPeUmiUB3HNzUjRQ4Ye7azI/8
uPboe8oXmZB5nqpFqlTeoRb5RFEoQIKU60ARtbjmlgV19HTd5VlqVIk6b6WG
GQ1tlKu+FfcTPYg6jVTHmLrt0LvJNN+iEd19WrGOLrihjjBVfMhhrkrIXZJ0
rj1F/TvNoDNg2wsW6QhJ7vIyweW9GDQ6DFi+R7EDaAGUbqYUBxt8U41xFIxQ
uc1dLsUqT/8NRuqpPycJZ069URnzZbVUROj1oIjK5I7ugLLMTURuFhpf722y
xDzIYJeYZ9+sgk4StQTNt8F2mJqOG93gjpy5FXHo+h0EIfVaB9cgXKtAzGK1
ibw+u5aUbndljXeoIisn64QWbq2FOHVBCgVCW0URutDlCB6+Qz+4UXOhtiOj
vLtaXJegEQ/Qbb9umX4WtIou52kM7ZhhCllUEJ2rcH8phfvmZIKNpEu9yu0R
gqxzmJE5b8XDbWmkfy6HBnrdFY44foHMGQngX1Y+3JAOskBg1c2VH0fOo5QC
4yKUI8YtYSevbx9Vj3E9EH6B79iGclNyW/A47hP1yxYtl4J3FVXoUps8pM13
abiGmopUgv8RIR/2kQReU1vlinWNWPfOwjnd8641hlJk2EAoK1OwrL1LKFPP
NvrOyPcXTb/U7JfOu6wpe+izAoJ55+RSkI1y+oNmhJRiFIBb0YiuGsrtEao7
PMuZFH1BQyOFrzY33NHNdx3UiEZfbUk4s3MQaA87npBak+DkFeXDDcbF7RoY
wmp6FprCIz9NrMaJ8msQsPm+iz5GFlpXUXZVAtp3SHdBhoiKnZtBUSZHU0zk
EjWVmn05dG1H1fXiYh6NlFmhaVlpl/0CCcfHwLsK+1tAEZWl3TM159dqgpoQ
GkMF3P6QenpXFbIL7E7KjCDBQeKVi6SyBDmvAkU0xGwGl2FYsM7nYoFTSpcR
nYlkOZ8ySrEQLqTTsCwiVDFarOuhO+KQxbyi49Yy+w0ukl/hkUvISJLWBTQy
z3hqeFn6US/8dBOAcuNvT28+fcQKkOeqYuQ1oEgVmemapwItx01iQewi3ueD
b9Xbxah4AX3BBoGuPhAcVZQV6A2vpUVscyjnkBKheIV4w+b0Ud4LNcioI6mH
4CdEOFghejsMHhYxjvdWANcEDa+jRdsJOepdHS6dIa6ikiw0UvV+MGoIcPoW
oglDvVcD0KGkFhXSt5XGSFaaEBPusQEu6YYlmtsUd7lYEuHVY/Sp6wuJV84W
UaOIBlwA3lUIvgEUubUq9OzAI4E7+SkGFI2pUluViqIbrU63/ZHkvEXDvg2A
F4XwVGzcTouYHtx/IgUd7VTDINzGGC0s+NBAJkNS5thlYVSThyA8vh5AO0HO
HbQISdvLhDYIsOEJRV2rcmCeKWUXb31uJ6SpoilhfiOAKQpHrCh4Y/mQ0Pv8
ZEiXHR0CdLbG+cl3zbdoxElgwarI6AdH1JXhmXiIvHVnrbaEpJqF/ydYEWWx
1L6cuEIHHIdPU2E0i1a/3T31vGNvGI1xOby5l+/qAyrCAQ1ZEIJeYoJ2cQEG
vXyelnaJ5oZ0zFTlde8PMsAg4KHLJirwUHV1j4V8OqtN0BJTDbmYd5dDIuFg
5Spl/lQ5UmnC3QBi54J3FcA/SQE8o5lBAO+INwuqDBVw9FuZBsH8Pn7TYZ2g
RAAR63sA3FCKzgrmu8u8CfvLhcIQyhAEcnpkVT1ViOiOKgh1CR9dRrJ7++CL
0BED9US5Dg6uM+JImKCqFuU58tXMT9TU10+Nxldvq6Vz6yNED8ImtVZQwToE
nFLrY4jZ0KSAIUuPrMoRe2xIVDN6uwjIstOGt4iAVEXmeEsmPWG01Hh+xkQI
Wwk2r+Cipyz14QQgAH5vLR0QOrwYD9XPvujZ3N4U8UvADscCDzO651rGu/pA
h7a8Y65fUg2HjsM6yQI9t7t4aYZMJfMKFhKeYKDAkLsfFDnxJZHinFEuna4T
RHtog7QVSBe4uujHlscZPUmhAiH1AINU6CCnJ4hjoBtOVP+XsN22ZMvUXjq+
+mAf8B4sQyK0jYqDedgP3b59eet3PiibxUMiQI81nwbAihnlGgC+AxTR1JVU
idyfbcOw4nKDIJJ0hJWUS1OusX8EzBFdOVRB8hADiWyy2W7V9Nri1COVwmmj
EUwfF8FUVtPwU6BIsMRQDFP70AKwtUtGspM9CZf8ZB9M3llaNnIkmVqmwfiQ
sy22izkLOUb7ud+na/vN/Md/B39Pus8jAERBNc01mQVCPhBQAg6/T5aWmlio
6+xQePeZOsQWUqemrLvDowBIashKuIEhgPU0WpzURPpkvX8uzLFZI5kojqeK
FEqyClQBhRqCqICfM51f4PN9d6mkRR4jNDo1o0bHfmNKV1aBsZVftHnUiT0e
5mxQCoIAsUComSMpGwuBGn33RWMiiwjBF2zeVU54D5g3Cgd05KnepByNqqGS
H4Jn0sMX4xSR0sf3o0M13WRzva/jVpNdcsQhujWu5r1mNb8XTHmXlG7qMcOc
D/t+Wk7Cs0ysP2eTrtke3leatxdsIWX429kej7C12iTN+TL/eZtWvYgXaeK+
fNXz0l2ZgRscLalIKjlGk/5MAc7BxEps03ASTDW7TCpiaxhm50cph+LXukpq
bWkSr+Dn1w8jCsvxuOEDdF7LSFIP0mQaAlLo8itNAtl1NWKcVknQMDxVKk0b
rsuowpM/GiLQXtwlFRfaxx+zOZUMecOHaqUlVMV9sgO9FL7VKKeTmI/atE6U
wlPitGj8QGZSRzii+06gkqH0Z0vpwdBfXLr5aXEyKHxi5+tEKQmnYZCh3jPr
/4+4KefKirErbKMA0tN2Ja5DWgsWfNoGe2Mp/BkR9rkkIEAX8RlqJ0B9fNCG
Xs7FDB8Wh951FRYlYdvK8stL86RNrByoKhvkjNCs3eX1GeN+0kZfwqaLYTMX
2zoI0pkXwEfZegR2CeQuxJYKaMi0kXtBthOT1389brAtQZ6FvS2sjHVjHWao
XSTfx2x8JTwMWmv7qUkE2DYy6yM2tBKRMnxCHNouF+f138Li6+phG/B95dNn
S9EGG+k3tLhhmsatUobzUPn2YAQPliEhw7Oa2ICQj4xtdZ2xDe8eNHAWz8nw
KTp2yaR9OkjlAzamYoquRuvl7Rx8poj3UDeQSgbfaoN7rHT7fGmW0HE15TH3
REYcblCWt9hoiulj+CwAVTiDl4MA2VNDvbut06K4Dj8HOlU5/aK7lW7Ku0rp
QadFeSkmBGEY3G2Jl7gvnDtt5sVTW4wxDfL/fxyAd9gwigg0fB7M3N3y6n3Q
2Ta/3bosvLXY3rbkE9umLV/D7fU2kOfKqy+IA8kTx6Ir/V5XIHjQ8POlKzex
9uU3laIAbrWJle00fBlMrIty0Q18s3X1+dLVL7GukKUpC4IY67/Smv9SKftl
0Hx+6F11u99kXX2ldPWV0gRBUf+V9jdaB18rHfwKA9VW0uyYim1s7Bvl1VfF
5nPR8wYb9bdKs19jzQY3D1otL7LGvlMa+zpoLOSLGp+usw+/Vz781VJEkIMo
xbXWxG+VJr4hwscnd62B+LdLE7+WwgKtsqtsFL9TmvgmgwChnldaA79bGviW
QWL6bN1UQ+eusC++X958G3QZQ/jWK+pS+/D3y6tfBx+ioKyL7cMflA+/Ayqh
YKQLDMB/VD78DZscqn6u9fMnpfp3GwhM/yZH6/j2T0u974XGTk035o2V/qxU
+s31zxje8OcVImf9H/OXWnE=\
\>"]]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 3:",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" 3D surface map of the flow potential on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"x", ",", "0", ",", "0"}], ")"}], TraditionalForm]]],
 StyleBox[" line for an ellipsoid with semiaxes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", ",", "b", ",", "c"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{"1", ",", "2", ",", "3"}], ")"}]}], TraditionalForm]]],
 StyleBox[" and varying conductivity ratio ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Epsilon]", "=", 
    RowBox[{
     SuperscriptBox["10", 
      RowBox[{"-", "10"}]], "-", 
     SuperscriptBox["10", "10"]}]}], TraditionalForm]]],
 StyleBox[".",
  FontFamily->"Times"]
}], "Special1",
 CellMargins->{{36, 74}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True,
 FontSize->10],

Cell[TextData[{
 StyleBox["For increasing values of ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]]],
 StyleBox[" the potential curve inside the ellipsoid flattens out rapidly to \
zero slope. As ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]]],
 StyleBox[" decreases the slope of the potential inside the ellipsoid rapidly \
tends to a finite limit with modulus greater than ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["V1", TraditionalForm]]],
 StyleBox[". We now turn to a different analysis of the potential function.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2  Particle Tracking Analysis", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Even though the potential is available in closed form, its \
analysis is still problematic. Of particular interest is the nature of ",
  FontFamily->"Times"],
 StyleBox["flow paths",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" near the ellipsoid. Flow paths are loci defined by positions of \
idealised, massless point particles allowed to traverse the system under the \
influence of the gradient of the potential, ",
  FontFamily->"Times"],
 StyleBox["i.e.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" the velocity field. For two-dimensional Laplace systems, these \
flow paths are equivalent to contours of the associated ",
  FontFamily->"Times"],
 StyleBox["streamfunction ",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox["[Bear 1979a], but in three dimensions problems of uniqueness \
prevent the calculation of streamfunctions. In practice, flow paths are \
calculated numerically from the velocity field, according to equation (3), \
where the proportionality constant, ",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[", is the associated conductivity. In the following, for the sake \
of simplicity, we choose to set ",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox["=1 in the calculation of velocity fields.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["In order to proceed, we first calculate the three components of \
the velocity field from the potential solution. This can be done exactly by \
using algebraic derivatives, ",
  FontFamily->"Times"],
 StyleBox["e.g.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox["",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[PartialD]", 
    RowBox[{"(", 
     RowBox[{"-", 
      RowBox[{"u", "(", 
       RowBox[{
       "x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c", ",", 
        "\[Epsilon]", ",", "V1", ",", "V2", ",", "V3"}], ")"}]}], ")"}]}], 
   RowBox[{"\[PartialD]", "x"}],
   MultilineFunction->None], TraditionalForm]], "Input",
 CellMargins->{{108, Inherited}, {Inherited, Inherited}},
 AspectRatioFixed->True,
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell["\<\
but the resulting expressions are long and complicated, and are slow to \
evaluate. It is just as useful to calculate the velocity components by \
numerical differences, remembering that the flow path calculation relies on \
numerical integration of the velocity field anyway. First order central \
differences are used:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"nvx", "(", 
    RowBox[{
    "x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", "c_", ",", 
     "\[Epsilon]_", ",", "V1_", ",", "V2_", ",", "V3_", ",", "\[Delta]_"}], 
    ")"}], ":=", "\n", "\t", 
   RowBox[{"Chop", "[", 
    RowBox[{"N", "[", 
     RowBox[{"-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", "\[Delta]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "(", 
          RowBox[{
           RowBox[{"x", "+", "\[Delta]"}], ",", "y", ",", "z", ",", "a", ",", 
           "b", ",", "c", ",", "\[Epsilon]", ",", "V1", ",", "V2", ",", 
           "V3"}], ")"}], "-", 
         RowBox[{"u", "(", 
          RowBox[{
           RowBox[{"x", "-", "\[Delta]"}], ",", "y", ",", "z", ",", "a", ",", 
           "b", ",", "c", ",", "\[Epsilon]", ",", "V1", ",", "V2", ",", 
           "V3"}], ")"}]}], ")"}]}]}], "]"}], "]"}]}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.460674090090316*^9, 3.4606740934037485`*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"nvy", "(", 
    RowBox[{
    "x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", "c_", ",", 
     "\[Epsilon]_", ",", "V1_", ",", "V2_", ",", "V3_", ",", "\[Delta]_"}], 
    ")"}], ":=", "\n", "\t", 
   RowBox[{"Chop", "[", 
    RowBox[{"N", "[", 
     RowBox[{"-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", "\[Delta]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "(", 
          RowBox[{"x", ",", 
           RowBox[{"y", "+", "\[Delta]"}], ",", "z", ",", "a", ",", "b", ",", 
           "c", ",", "\[Epsilon]", ",", "V1", ",", "V2", ",", "V3"}], ")"}], 
         "-", 
         RowBox[{"u", "(", 
          RowBox[{"x", ",", 
           RowBox[{"y", "-", "\[Delta]"}], ",", "z", ",", "a", ",", "b", ",", 
           "c", ",", "\[Epsilon]", ",", "V1", ",", "V2", ",", "V3"}], ")"}]}],
         ")"}]}]}], "]"}], "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.4606740833696737`*^9, 3.460674086933177*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"nvz", "(", 
    RowBox[{
    "x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", "c_", ",", 
     "\[Epsilon]_", ",", "V1_", ",", "V2_", ",", "V3_", ",", "\[Delta]_"}], 
    ")"}], ":=", "\n", "\t", 
   RowBox[{"Chop", "[", 
    RowBox[{"N", "[", 
     RowBox[{"-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", "\[Delta]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "(", 
          RowBox[{"x", ",", "y", ",", 
           RowBox[{"z", "+", "\[Delta]"}], ",", "a", ",", "b", ",", "c", ",", 
           "\[Epsilon]", ",", "V1", ",", "V2", ",", "V3"}], ")"}], "-", 
         RowBox[{"u", "(", 
          RowBox[{"x", ",", "y", ",", 
           RowBox[{"z", "-", "\[Delta]"}], ",", "a", ",", "b", ",", "c", ",", 
           "\[Epsilon]", ",", "V1", ",", "V2", ",", "V3"}], ")"}]}], 
        ")"}]}]}], "]"}], "]"}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.4606740773836136`*^9, 3.460674081150299*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["A conventional method of analysing a velocity field is to use a ",
  FontFamily->"Times"],
 StyleBox["vector field plot",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[". ",
  FontFamily->"Times"],
 "A",
 StyleBox[" list of velocity vectors on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane is computed for a conducting ellipse (",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Epsilon]", "=", "10"}], TraditionalForm]]],
 StyleBox[") using the numerical derivatives:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.460675372643157*^9, 3.4606753860509515`*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"zVectors", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"nvx", "(", 
         RowBox[{
         "x", ",", "y", ",", "0", ",", "1", ",", "2", ",", "3", ",", "10", 
          ",", "1", ",", "0", ",", "0", ",", "0.0001"}], ")"}], ",", 
        RowBox[{"nvy", "(", 
         RowBox[{
         "x", ",", "y", ",", "0", ",", "1", ",", "2", ",", "3", ",", "10", 
          ",", "1", ",", "0", ",", "0", ",", "0.0001"}], ")"}]}], "}"}], ",", 
      
      RowBox[{"{", 
       RowBox[{"x", ",", "3", ",", 
        RowBox[{"-", "3"}], ",", 
        RowBox[{"-", "0.5"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "3"}], ",", "3", ",", "0.5"}], "}"}]}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.460673835221123*^9, 3.4606738511522713`*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Figure 4 shows the corresponding plot (drawn using ",
  FontFamily->"Times"],
 StyleBox["ListVectorPlot",
  FontFamily->"Courier"],
 StyleBox["):",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.4606753947081985`*^9, 3.4606754005838757`*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["ListVectorPlot[zVectors, Frame->False]", "Input",
 CellChangeTimes->{
  3.460674115378685*^9, {3.460674217076335*^9, 3.46067422904723*^9}, {
   3.4606744312084503`*^9, 3.4606744432574844`*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, 
   {Hue[0.67, 0.6, 0.6], 
    {Arrowheads[{{0.03100963887615296, 1.}}], 
     ArrowBox[{{0.5907476025572181, 1.0192531271566556`}, {
      1.4092523974427817`, 0.9807468728433444}}]}, 
    {Arrowheads[{{0.031409699925223813`, 1.}}], 
     ArrowBox[{{0.5855876258724553, 1.8790442146686057`}, {1.414412374127545, 
      1.8352414996171087`}}]}, 
    {Arrowheads[{{0.031921761965497536`, 1.}}], 
     ArrowBox[{{0.5789022421267996, 2.7378428554889824`}, {
      1.4210977578732003`, 2.690728573082447}}]}, 
    {Arrowheads[{{0.03250738531009462, 1.}}], 
     ArrowBox[{{0.5711460477819275, 3.5948588071736416`}, {
      1.4288539522180725`, 3.5479983356835016`}}]}, 
    {Arrowheads[{{0.0331003210539045, 1.}}], 
     ArrowBox[{{0.5631725182131329, 4.449478226334001}, {1.4368274817868671`, 
      4.407664630808855}}]}, 
    {Arrowheads[{{0.03361335741446798, 1.}}], 
     ArrowBox[{{0.5561755379629039, 5.301520493500586}, {1.4438244620370961`, 
      5.269908077927986}}]}, 
    {Arrowheads[{{0.033962012274073985`, 1.}}], 
     ArrowBox[{{0.5513687205502125, 6.1513849759545955`}, {
      1.4486312794497875`, 6.134329309759688}}]}, 
    {Arrowheads[{{0.034086185980132196`, 1.}}], 
     ArrowBox[{{0.5496470712361211, 6.999999999999999}, {1.4503529287638788`, 
      6.999999999999999}}]}, 
    {Arrowheads[{{0.03396201227407398, 1.}}], 
     ArrowBox[{{0.5513687205502125, 7.848615024045403}, {1.4486312794497875`, 
      7.865670690240309}}]}, 
    {Arrowheads[{{0.03361335741446799, 1.}}], 
     ArrowBox[{{0.5561755379629036, 8.698479506499414}, {1.4438244620370964`, 
      8.730091922072015}}]}, 
    {Arrowheads[{{0.0331003210539045, 1.}}], 
     ArrowBox[{{0.5631725182131329, 9.550521773665999}, {1.4368274817868671`, 
      9.592335369191144}}]}, 
    {Arrowheads[{{0.032507385310094616`, 1.}}], 
     ArrowBox[{{0.5711460477819275, 10.40514119282636}, {1.4288539522180723`, 
      10.4520016643165}}]}, 
    {Arrowheads[{{0.031921761965497536`, 1.}}], 
     ArrowBox[{{0.5789022421267996, 11.262157144511018`}, {
      1.4210977578732003`, 11.309271426917554`}}]}, 
    {Arrowheads[{{0.031409699925223813`, 1.}}], 
     ArrowBox[{{0.5855876258724553, 12.120955785331395`}, {1.414412374127545, 
      12.164758500382892`}}]}, 
    {Arrowheads[{{0.03100963887615296, 1.}}], 
     ArrowBox[{{0.5907476025572181, 12.980746872843346`}, {
      1.4092523974427817`, 13.019253127156658`}}]}, 
    {Arrowheads[{{0.0309266710793359, 1.}}], 
     ArrowBox[{{1.4492442887073882`, 1.0240819769528267`}, {
      2.2650414255783264`, 0.9759180230471732}}]}, 
    {Arrowheads[{{0.03143745100647991, 1.}}], 
     ArrowBox[{{1.4427797400596283`, 1.8858646532890222`}, {2.271505974226086,
       1.8284210609966922`}}]}, 
    {Arrowheads[{{0.03214966324014902, 1.}}], 
     ArrowBox[{{1.4336078016994143`, 2.7466162176888447`}, {
      2.2806779125862997`, 2.6819552108825846`}}]}, 
    {Arrowheads[{{0.03301526549108301, 1.}}], 
     ArrowBox[{{1.422219111748386, 3.604820648756546}, {2.2920666025373286`, 
      3.5380364941005973`}}]}, 
    {Arrowheads[{{0.0339244094990184, 1.}}], 
     ArrowBox[{{1.4099745818484186`, 4.459192915053679}, {2.3043111324372956`,
       4.39794994208918}}]}, 
    {Arrowheads[{{0.03472361020115376, 1.}}], 
     ArrowBox[{{1.3989726865819383`, 5.3092581786951945`}, {2.315313027703776,
       5.262170392733378}}]}, 
    {Arrowheads[{{0.03526796012379734, 1.}}], 
     ArrowBox[{{1.3913521810640364`, 6.155665483751429}, {2.322933533221678, 
      6.1300488019628565`}}]}, 
    {Arrowheads[{{0.035461430793770066`, 1.}}], 
     ArrowBox[{{1.3886199421578695`, 6.999999999999999}, {2.3256657721278446`,
       6.999999999999999}}]}, 
    {Arrowheads[{{0.03526796012379734, 1.}}], 
     ArrowBox[{{1.3913521810640364`, 7.844334516248569}, {2.322933533221678, 
      7.869951198037142}}]}, 
    {Arrowheads[{{0.03472361020115376, 1.}}], 
     ArrowBox[{{1.3989726865819383`, 8.690741821304805}, {2.315313027703776, 
      8.737829607266622}}]}, 
    {Arrowheads[{{0.0339244094990184, 1.}}], 
     ArrowBox[{{1.4099745818484186`, 9.540807084946321}, {2.3043111324372956`,
       9.602050057910821}}]}, 
    {Arrowheads[{{0.03301526549108301, 1.}}], 
     ArrowBox[{{1.422219111748386, 10.395179351243454`}, {2.2920666025373286`,
       10.461963505899403`}}]}, 
    {Arrowheads[{{0.03214966324014902, 1.}}], 
     ArrowBox[{{1.4336078016994143`, 11.253383782311156`}, {
      2.2806779125862997`, 11.318044789117415`}}]}, 
    {Arrowheads[{{0.03143745100647991, 1.}}], 
     ArrowBox[{{1.4427797400596283`, 12.11413534671098}, {2.271505974226086, 
      12.17157893900331}}]}, 
    {Arrowheads[{{0.030926671079335905`, 1.}}], 
     ArrowBox[{{1.4492442887073882`, 12.975918023047175`}, {
      2.2650414255783264`, 13.024081976952829`}}]}, 
    {Arrowheads[{{0.03071459762277709, 1.}}], 
     ArrowBox[{{2.3095685376929547`, 1.029719284356348}, {3.1190028908784737`,
       0.9702807156436519}}]}, 
    {Arrowheads[{{0.03134924460422264, 1.}}], 
     ArrowBox[{{2.3018069156548275`, 1.894775542396329}, {3.1267645129166013`,
       1.8195101718893856`}}]}, 
    {Arrowheads[{{0.03234649257268957, 1.}}], 
     ArrowBox[{{2.2892723700193724`, 2.7590838999533167`}, {
      3.1392990585520564`, 2.669487528618112}}]}, 
    {Arrowheads[{{0.03364653103404434, 1.}}], 
     ArrowBox[{{2.2723771461525333`, 3.619763842002109}, {3.1561942824188955`,
       3.5230933008550345`}}]}, 
    {Arrowheads[{{0.0350614183202221, 1.}}], 
     ArrowBox[{{2.253305155652387, 4.474246971406278}, {3.1752662729190413`, 
      4.38289588573658}}]}, 
    {Arrowheads[{{0.03631976532754904, 1.}}], 
     ArrowBox[{{2.235755298746597, 5.321456592782181}, {3.192816129824832, 
      5.249971978646389}}]}, 
    {Arrowheads[{{0.037174875409581615`, 1.}}], 
     ArrowBox[{{2.223515612137813, 6.162455333666812}, {3.2050558164336156`, 
      6.123258952047473}}]}, 
    {Arrowheads[{{0.03747670581788163, 1.}}], 
     ArrowBox[{{2.219136616779094, 6.999999999999999}, {3.2094348117923355`, 
      6.999999999999999}}]}, 
    {Arrowheads[{{0.037174875409581636`, 1.}}], 
     ArrowBox[{{2.223515612137813, 7.837544666333186}, {3.205055816433616, 
      7.8767410479525255`}}]}, 
    {Arrowheads[{{0.03631976532754903, 1.}}], 
     ArrowBox[{{2.235755298746597, 8.678543407217818}, {3.192816129824832, 
      8.750028021353609}}]}, 
    {Arrowheads[{{0.0350614183202221, 1.}}], 
     ArrowBox[{{2.253305155652387, 9.525753028593721}, {3.1752662729190413`, 
      9.61710411426342}}]}, 
    {Arrowheads[{{0.03364653103404434, 1.}}], 
     ArrowBox[{{2.2723771461525333`, 10.380236157997892`}, {
      3.1561942824188955`, 10.476906699144967`}}]}, 
    {Arrowheads[{{0.03234649257268955, 1.}}], 
     ArrowBox[{{2.2892723700193724`, 11.240916100046684`}, {3.139299058552056,
       11.330512471381889`}}]}, 
    {Arrowheads[{{0.03134924460422264, 1.}}], 
     ArrowBox[{{2.3018069156548275`, 12.105224457603672`}, {
      3.1267645129166013`, 12.180489828110616`}}]}, 
    {Arrowheads[{{0.030714597622777094`, 1.}}], 
     ArrowBox[{{2.3095685376929547`, 12.970280715643653`}, {
      3.1190028908784737`, 13.02971928435635}}]}, 
    {Arrowheads[{{0.030277964403346805`, 1.}}], 
     ArrowBox[{{3.1729621007345767`, 1.0354242815578352`}, {3.969895042122567,
       0.9645757184421647}}]}, 
    {Arrowheads[{{0.030997593298366072`, 1.}}], 
     ArrowBox[{{3.164780982531263, 1.905779918209026}, {3.97807616032588, 
      1.8085057960766884`}}]}, 
    {Arrowheads[{{0.032392081413525634`, 1.}}], 
     ArrowBox[{{3.148073232790341, 2.77696482998723}, {3.994783910066802, 
      2.6516065985841983`}}]}, 
    {Arrowheads[{{0.034407354224583665`, 1.}}], 
     ArrowBox[{{3.1225153474202707`, 3.6430852466166206`}, {4.020341795436872,
       3.499771896240522}}]}, 
    {Arrowheads[{{0.036685817608821315`, 1.}}], 
     ArrowBox[{{3.091821967426436, 4.49865238987519}, {4.051035175430707, 
      4.358490467267668}}]}, 
    {Arrowheads[{{0.038642545466852064`, 1.}}], 
     ArrowBox[{{3.06391604596903, 5.341344975779736}, {4.078941096888113, 
      5.230083595648836}}]}, 
    {Arrowheads[{{0.04025122738026559, 1.}}], 
     ArrowBox[{{3.0404985587491526`, 6.173378687937085}, {4.102358584107991, 
      6.1123355977772}}]}, 
    {Arrowheads[{{0.041908432146500384`, 1.}}], 
     ArrowBox[{{3.0177266944253898`, 6.999999999999999}, {4.1251304484317535`,
       6.999999999999999}}]}, 
    {Arrowheads[{{0.04025122738026559, 1.}}], 
     ArrowBox[{{3.0404985587491526`, 7.826621312062914}, {4.102358584107991, 
      7.887664402222798}}]}, 
    {Arrowheads[{{0.038642545466852064`, 1.}}], 
     ArrowBox[{{3.06391604596903, 8.658655024220263}, {4.078941096888113, 
      8.769916404351164}}]}, 
    {Arrowheads[{{0.036685817608821315`, 1.}}], 
     ArrowBox[{{3.091821967426436, 9.50134761012481}, {4.051035175430707, 
      9.641509532732332}}]}, 
    {Arrowheads[{{0.034407354224583665`, 1.}}], 
     ArrowBox[{{3.1225153474202707`, 10.35691475338338}, {4.020341795436872, 
      10.50022810375948}}]}, 
    {Arrowheads[{{0.032392081413525634`, 1.}}], 
     ArrowBox[{{3.148073232790341, 11.223035170012771`}, {3.994783910066802, 
      11.348393401415803`}}]}, 
    {Arrowheads[{{0.03099759329836607, 1.}}], 
     ArrowBox[{{3.164780982531263, 12.094220081790976`}, {3.97807616032588, 
      12.191494203923313`}}]}, 
    {Arrowheads[{{0.030277964403346805`, 1.}}], 
     ArrowBox[{{3.1729621007345767`, 12.964575718442166`}, {3.969895042122567,
       13.035424281557837`}}]}, 
    {Arrowheads[{{0.029496294578372495`, 1.}}], 
     ArrowBox[{{4.040847433402769, 1.0392980055573062`}, {4.816295423740089, 
      0.9607019944426939}}]}, 
    {Arrowheads[{{0.03014866171600585, 1.}}], 
     ArrowBox[{{4.034917451605384, 1.917995519015906}, {4.822225405537473, 
      1.7962901952698085`}}]}, 
    {Arrowheads[{{0.03192536733085253, 1.}}], 
     ArrowBox[{{4.015910147104487, 2.801630491638831}, {4.841232710038372, 
      2.6269409369325984`}}]}, 
    {Arrowheads[{{0.03658543723816794, 1.}}], 
     ArrowBox[{{3.9603891014156067`, 3.6916585307827465`}, {4.896753755727251,
       3.451198612074397}}]}, 
    {Arrowheads[{{0.04181599523856659, 1.}}], 
     ArrowBox[{{3.89124508878601, 4.557082906223052}, {4.9658977683568475`, 
      4.300059950919806}}]}, 
    {Arrowheads[{{0.045871902596875055`, 1.}}], 
     ArrowBox[{{3.830721248896703, 5.385180621313076}, {5.026421608246156, 
      5.186247950115496}}]}, 
    {Arrowheads[{{0.04587368524026633, 1.}}], 
     ArrowBox[{{3.824780333217929, 6.195613677498179}, {5.032362523924929, 
      6.090100608216106}}]}, 
    {Arrowheads[{{0.03750051899586834, 1.}}], 
     ArrowBox[{{3.933107706998163, 6.999999999999999}, {4.924035150144695, 
      6.999999999999999}}]}, 
    {Arrowheads[{{0.045873685240266276`, 1.}}], 
     ArrowBox[{{3.8247803332179293`, 7.80438632250182}, {5.032362523924928, 
      7.909899391783893}}]}, 
    {Arrowheads[{{0.045871902596875055`, 1.}}], 
     ArrowBox[{{3.830721248896703, 8.614819378686924}, {5.026421608246156, 
      8.813752049884505}}]}, 
    {Arrowheads[{{0.04181599523856659, 1.}}], 
     ArrowBox[{{3.89124508878601, 9.442917093776948}, {4.9658977683568475`, 
      9.699940049080194}}]}, 
    {Arrowheads[{{0.03658543723816795, 1.}}], 
     ArrowBox[{{3.9603891014156067`, 10.308341469217254`}, {4.896753755727251,
       10.548801387925604`}}]}, 
    {Arrowheads[{{0.031925367330852494`, 1.}}], 
     ArrowBox[{{4.015910147104487, 11.19836950836117}, {4.841232710038371, 
      11.373059063067402`}}]}, 
    {Arrowheads[{{0.03014866171600585, 1.}}], 
     ArrowBox[{{4.034917451605384, 12.082004480984095`}, {4.822225405537473, 
      12.203709804730192`}}]}, 
    {Arrowheads[{{0.029496294578372495`, 1.}}], 
     ArrowBox[{{4.040847433402769, 12.960701994442696`}, {4.816295423740089, 
      13.039298005557308`}}]}, 
    {Arrowheads[{{0.028313395141137582`, 1.}}], 
     ArrowBox[{{4.913488012809194, 1.0372124243654346`}, {5.6579405586193765`,
       0.9627875756345653}}]}, 
    {Arrowheads[{{0.02792425246618199, 1.}}], 
     ArrowBox[{{4.922127854640681, 1.919767757040583}, {5.6493007167878915`, 
      1.7945179572451315`}}]}, 
    {Arrowheads[{{0.03111661881847695, 1.}}], 
     ArrowBox[{{4.897130006208095, 2.8485267252560025`}, {5.674298565220477, 
      2.580044703315426}}]}, 
    {Arrowheads[{{0.030734669971332524`, 1.}}], 
     ArrowBox[{{4.904412783096919, 3.7110842298398468`}, {5.667015788331653, 
      3.431772913017297}}]}, 
    {Arrowheads[{{0.03150693021317946, 1.}}], 
     ArrowBox[{{4.8851128748621795`, 4.541724685328319}, {5.686315696566393, 
      4.315418171814538}}]}, 
    {Arrowheads[{{0.03602275464053542, 1.}}], 
     ArrowBox[{{4.818300393567159, 5.375393729058634}, {5.753128177861412, 
      5.196034842369938}}]}, 
    {Arrowheads[{{0.034342660061846615`, 1.}}], 
     ArrowBox[{{4.8343719792342865`, 6.189456299930366}, {5.7370565921942855`,
       6.096257985783919}}]}, 
    {Arrowheads[{{0.02008209975766624, 1.}}], 
     ArrowBox[{{5.020385907618101, 6.999999999999999}, {5.5510426638104695`, 
      6.999999999999999}}]}, 
    {Arrowheads[{{0.03434266006184659, 1.}}], 
     ArrowBox[{{4.8343719792342865`, 7.8105437000696325`}, {5.737056592194285,
       7.903742014216079}}]}, 
    {Arrowheads[{{0.036022754640535413`, 1.}}], 
     ArrowBox[{{4.818300393567159, 8.624606270941365}, {5.753128177861412, 
      8.80396515763006}}]}, 
    {Arrowheads[{{0.03150693021317945, 1.}}], 
     ArrowBox[{{4.8851128748621795`, 9.458275314671681}, {5.686315696566393, 
      9.684581828185461}}]}, 
    {Arrowheads[{{0.030734669971332527`, 1.}}], 
     ArrowBox[{{4.904412783096919, 10.288915770160154`}, {5.667015788331653, 
      10.568227086982704`}}]}, 
    {Arrowheads[{{0.031116618818476948`, 1.}}], 
     ArrowBox[{{4.897130006208095, 11.151473274743998`}, {5.674298565220477, 
      11.419955296684574`}}]}, 
    {Arrowheads[{{0.02792425246618199, 1.}}], 
     ArrowBox[{{4.92212785464068, 12.080232242959418`}, {5.649300716787891, 
      12.20548204275487}}]}, 
    {Arrowheads[{{0.028313395141137582`, 1.}}], 
     ArrowBox[{{4.913488012809194, 12.962787575634566`}, {5.6579405586193765`,
       13.037212424365435`}}]}, 
    {Arrowheads[{{0.027000603749883306`, 1.}}], 
     ArrowBox[{{5.78694946865143, 1.0243096077987424`}, {6.498764817062855, 
      0.9756903922012576}}]}, 
    {Arrowheads[{{0.024841465875604648`, 1.}}], 
     ArrowBox[{{5.817160396939572, 1.897682099431194}, {6.4685538887747125`, 
      1.8166036148545206`}}]}, 
    {Arrowheads[{{0.025707005934550494`, 1.}}], 
     ArrowBox[{{5.838676266741813, 2.8653922148344946`}, {6.447038018972472, 
      2.563179213736934}}]}, 
    {Arrowheads[{{0.012279259854834105`, 1.}}], 
     ArrowBox[{{5.998751386378187, 3.645953702417878}, {6.286962899336098, 
      3.496903440439265}}]}, 
    {Arrowheads[{{0.0027801066543534747`, 1.}}], 
     ArrowBox[{{6.110321034451382, 4.411524773908627}, {6.175393251262903, 
      4.445618083234231}}]}, 
    {Arrowheads[{{0.003355701082417719, 1.}}], 
     ArrowBox[{{6.098751407959896, 5.28120017551225}, {6.1869628777543895`, 
      5.290228395916321}}]}, 
    {Arrowheads[{{0.003396257231945515, 1.}}], 
     ArrowBox[{{6.098046768958712, 6.140506763260389}, {6.187667516755573, 
      6.1452075224538945`}}]}, 
    {Arrowheads[{{0.00406769029276792, 1.}}], 
     ArrowBox[{{6.0891140741043, 6.999999999999999}, {6.196600211609986, 
      6.999999999999999}}]}, 
    {Arrowheads[{{0.003396257231945515, 1.}}], 
     ArrowBox[{{6.098046768958712, 7.859493236739609}, {6.187667516755573, 
      7.854792477546104}}]}, 
    {Arrowheads[{{0.003355701082417719, 1.}}], 
     ArrowBox[{{6.098751407959896, 8.71879982448775}, {6.1869628777543895`, 
      8.709771604083679}}]}, 
    {Arrowheads[{{0.0027801066543534747`, 1.}}], 
     ArrowBox[{{6.110321034451382, 9.588475226091372}, {6.175393251262903, 
      9.554381916765768}}]}, 
    {Arrowheads[{{0.012279259854834149`, 1.}}], 
     ArrowBox[{{5.998751386378187, 10.354046297582123`}, {6.286962899336099, 
      10.503096559560737`}}]}, 
    {Arrowheads[{{0.0257070059345505, 1.}}], 
     ArrowBox[{{5.838676266741813, 11.134607785165507`}, {6.447038018972472, 
      11.436820786263068`}}]}, 
    {Arrowheads[{{0.02484146587560465, 1.}}], 
     ArrowBox[{{5.817160396939572, 12.102317900568808`}, {6.4685538887747125`,
       12.183396385145482`}}]}, 
    {Arrowheads[{{0.027000603749883344`, 1.}}], 
     ArrowBox[{{5.78694946865143, 12.975690392201258`}, {6.498764817062856, 
      13.024309607798743`}}]}, 
    {Arrowheads[{{0.026323890018757404`, 1.}}], 
     ArrowBox[{{6.652203946392958, 1.}, {7.34779605360704, 1.}}]}, 
    {Arrowheads[{{0.024361513005560335`, 1.}}], 
     ArrowBox[{{6.678131230711225, 1.8571428571428572`}, {7.321868769288773, 
      1.8571428571428572`}}]}, 
    {Arrowheads[{{0.009429898589448673, 1.}}], 
     ArrowBox[{{6.875410453660614, 2.7142857142857144`}, {7.124589546339385, 
      2.714285714285714}}]}, 
    {Arrowheads[{{0.0038925058287002405`, 1.}}], 
     ArrowBox[{{6.948571500454541, 3.5714285714285716`}, {7.051428499545457, 
      3.5714285714285716`}}]}, 
    {Arrowheads[{{0.0049040863778782315`, 1.}}], 
     ArrowBox[{{6.935206313065479, 4.428571428571429}, {7.064793686934519, 
      4.428571428571429}}]}, 
    {Arrowheads[{{0.004904086434496838, 1.}}], 
     ArrowBox[{{6.935206312317424, 5.285714285714286}, {7.064793687682575, 
      5.285714285714286}}]}, 
    {Arrowheads[{{0.004904086434496838, 1.}}], 
     ArrowBox[{{6.935206312317424, 6.142857142857142}, {7.064793687682575, 
      6.142857142857142}}]}, 
    {Arrowheads[{{0.004904086434496838, 1.}}], 
     ArrowBox[{{6.935206312317424, 6.999999999999999}, {7.064793687682575, 
      6.999999999999999}}]}, 
    {Arrowheads[{{0.004904086434496838, 1.}}], 
     ArrowBox[{{6.935206312317424, 7.857142857142856}, {7.064793687682575, 
      7.857142857142856}}]}, 
    {Arrowheads[{{0.004904086434496838, 1.}}], 
     ArrowBox[{{6.935206312317424, 8.714285714285714}, {7.064793687682575, 
      8.714285714285714}}]}, 
    {Arrowheads[{{0.0049040863778782315`, 1.}}], 
     ArrowBox[{{6.935206313065479, 9.571428571428571}, {7.064793686934519, 
      9.571428571428571}}]}, 
    {Arrowheads[{{0.0038925058287002405`, 1.}}], 
     ArrowBox[{{6.948571500454541, 10.428571428571429`}, {7.051428499545457, 
      10.428571428571429`}}]}, 
    {Arrowheads[{{0.009429898589448673, 1.}}], 
     ArrowBox[{{6.8754104536606135`, 11.285714285714286`}, {7.124589546339384,
       11.285714285714286`}}]}, 
    {Arrowheads[{{0.02436151300556037, 1.}}], 
     ArrowBox[{{6.678131230711225, 12.142857142857144`}, {7.321868769288774, 
      12.142857142857144`}}]}, 
    {Arrowheads[{{0.026323890018757404`, 1.}}], 
     ArrowBox[{{6.652203946392958, 13.000000000000002`}, {7.34779605360704, 
      13.000000000000002`}}]}, 
    {Arrowheads[{{0.02700060374988327, 1.}}], 
     ArrowBox[{{7.501235182937143, 0.9756903922012576}, {8.213050531348568, 
      1.0243096077987424`}}]}, 
    {Arrowheads[{{0.024841465875604648`, 1.}}], 
     ArrowBox[{{7.531446111225286, 1.8166036148545206`}, {8.182839603060426, 
      1.897682099431194}}]}, 
    {Arrowheads[{{0.02570700593455052, 1.}}], 
     ArrowBox[{{7.552961981027527, 2.5631792137369342`}, {8.161323733258186, 
      2.8653922148344946`}}]}, 
    {Arrowheads[{{0.012279259854834105`, 1.}}], 
     ArrowBox[{{7.7130371006639, 3.496903440439265}, {8.001248613621812, 
      3.645953702417878}}]}, 
    {Arrowheads[{{0.0027801066543534747`, 1.}}], 
     ArrowBox[{{7.824606748737096, 4.445618083234231}, {7.889678965548616, 
      4.411524773908627}}]}, 
    {Arrowheads[{{0.0033557010824176855`, 1.}}], 
     ArrowBox[{{7.81303712224561, 5.290228395916321}, {7.901248592040102, 
      5.28120017551225}}]}, 
    {Arrowheads[{{0.0033962572319454812`, 1.}}], 
     ArrowBox[{{7.812332483244425, 6.145207522453895}, {7.901953231041285, 
      6.14050676326039}}]}, 
    {Arrowheads[{{0.00406769029276792, 1.}}], 
     ArrowBox[{{7.8033997883900135`, 6.999999999999999}, {7.910885925895699, 
      6.999999999999999}}]}, 
    {Arrowheads[{{0.0033962572319454812`, 1.}}], 
     ArrowBox[{{7.812332483244425, 7.854792477546103}, {7.901953231041285, 
      7.859493236739608}}]}, 
    {Arrowheads[{{0.0033557010824176855`, 1.}}], 
     ArrowBox[{{7.81303712224561, 8.709771604083677}, {7.901248592040102, 
      8.718799824487748}}]}, 
    {Arrowheads[{{0.0027801066543534747`, 1.}}], 
     ArrowBox[{{7.824606748737096, 9.55438191676577}, {7.889678965548616, 
      9.588475226091374}}]}, 
    {Arrowheads[{{0.012279259854834119`, 1.}}], 
     ArrowBox[{{7.7130371006639, 10.503096559560735`}, {8.001248613621812, 
      10.354046297582121`}}]}, 
    {Arrowheads[{{0.0257070059345505, 1.}}], 
     ArrowBox[{{7.552961981027527, 11.436820786263066`}, {8.161323733258186, 
      11.134607785165507`}}]}, 
    {Arrowheads[{{0.02484146587560465, 1.}}], 
     ArrowBox[{{7.531446111225286, 12.18339638514548}, {8.182839603060426, 
      12.102317900568806`}}]}, 
    {Arrowheads[{{0.02700060374988328, 1.}}], 
     ArrowBox[{{7.501235182937143, 13.024309607798743`}, {8.213050531348568, 
      12.975690392201258`}}]}, 
    {Arrowheads[{{0.028313395141137617`, 1.}}], 
     ArrowBox[{{8.342059441380622, 0.9627875756345653}, {9.086511987190805, 
      1.0372124243654348`}}]}, 
    {Arrowheads[{{0.027924252466181954`, 1.}}], 
     ArrowBox[{{8.350699283212109, 1.7945179572451315`}, {9.077872145359319, 
      1.919767757040583}}]}, 
    {Arrowheads[{{0.031116618818476924`, 1.}}], 
     ArrowBox[{{8.325701434779523, 2.580044703315426}, {9.102869993791904, 
      2.8485267252560025`}}]}, 
    {Arrowheads[{{0.030734669971332486`, 1.}}], 
     ArrowBox[{{8.332984211668347, 3.431772913017297}, {9.09558721690308, 
      3.7110842298398463`}}]}, 
    {Arrowheads[{{0.031506930213179414`, 1.}}], 
     ArrowBox[{{8.313684303433607, 4.315418171814539}, {9.11488712513782, 
      4.541724685328319}}]}, 
    {Arrowheads[{{0.03602275464053535, 1.}}], 
     ArrowBox[{{8.246871822138587, 5.196034842369938}, {9.181699606432838, 
      5.375393729058634}}]}, 
    {Arrowheads[{{0.03434266006184659, 1.}}], 
     ArrowBox[{{8.262943407805714, 6.096257985783919}, {9.165628020765713, 
      6.189456299930366}}]}, 
    {Arrowheads[{{0.02008209975766621, 1.}}], 
     ArrowBox[{{8.44895733618953, 6.999999999999999}, {8.979614092381897, 
      6.999999999999999}}]}, 
    {Arrowheads[{{0.03434266006184659, 1.}}], 
     ArrowBox[{{8.262943407805714, 7.903742014216079}, {9.165628020765713, 
      7.8105437000696325`}}]}, 
    {Arrowheads[{{0.036022754640535344`, 1.}}], 
     ArrowBox[{{8.246871822138587, 8.803965157630062}, {9.181699606432838, 
      8.624606270941367}}]}, 
    {Arrowheads[{{0.031506930213179414`, 1.}}], 
     ArrowBox[{{8.313684303433607, 9.684581828185461}, {9.11488712513782, 
      9.458275314671681}}]}, 
    {Arrowheads[{{0.0307346699713325, 1.}}], 
     ArrowBox[{{8.332984211668347, 10.568227086982704`}, {9.09558721690308, 
      10.288915770160154`}}]}, 
    {Arrowheads[{{0.031116618818476913`, 1.}}], 
     ArrowBox[{{8.325701434779523, 11.419955296684575`}, {9.102869993791904, 
      11.151473274744}}]}, 
    {Arrowheads[{{0.027924252466181954`, 1.}}], 
     ArrowBox[{{8.350699283212109, 12.20548204275487}, {9.077872145359319, 
      12.080232242959418`}}]}, 
    {Arrowheads[{{0.028313395141137617`, 1.}}], 
     ArrowBox[{{8.342059441380622, 13.037212424365437`}, {9.086511987190805, 
      12.962787575634568`}}]}, 
    {Arrowheads[{{0.029496294578372495`, 1.}}], 
     ArrowBox[{{9.183704576259911, 0.9607019944426939}, {9.959152566597231, 
      1.039298005557306}}]}, 
    {Arrowheads[{{0.03014866171600585, 1.}}], 
     ArrowBox[{{9.177774594462527, 1.7962901952698085`}, {9.965082548394616, 
      1.917995519015906}}]}, 
    {Arrowheads[{{0.0319253673308525, 1.}}], 
     ArrowBox[{{9.158767289961629, 2.626940936932598}, {9.984089852895513, 
      2.8016304916388304`}}]}, 
    {Arrowheads[{{0.03658543723816794, 1.}}], 
     ArrowBox[{{9.103246244272748, 3.4511986120743967`}, {10.039610898584392`,
       3.691658530782746}}]}, 
    {Arrowheads[{{0.04181599523856659, 1.}}], 
     ArrowBox[{{9.034102231643152, 4.300059950919806}, {10.108754911213989`, 
      4.557082906223052}}]}, 
    {Arrowheads[{{0.04587190259687502, 1.}}], 
     ArrowBox[{{8.973578391753845, 5.186247950115495}, {10.169278751103297`, 
      5.385180621313075}}]}, 
    {Arrowheads[{{0.045873685240266276`, 1.}}], 
     ArrowBox[{{8.96763747607507, 6.0901006082161055`}, {10.17521966678207, 
      6.195613677498178}}]}, 
    {Arrowheads[{{0.03750051899586834, 1.}}], 
     ArrowBox[{{9.075964849855305, 6.999999999999999}, {10.066892293001837`, 
      6.999999999999999}}]}, 
    {Arrowheads[{{0.045873685240266276`, 1.}}], 
     ArrowBox[{{8.96763747607507, 7.909899391783892}, {10.17521966678207, 
      7.804386322501819}}]}, 
    {Arrowheads[{{0.04587190259687502, 1.}}], 
     ArrowBox[{{8.973578391753845, 8.813752049884503}, {10.169278751103297`, 
      8.614819378686922}}]}, 
    {Arrowheads[{{0.04181599523856659, 1.}}], 
     ArrowBox[{{9.034102231643152, 9.699940049080194}, {10.108754911213989`, 
      9.442917093776948}}]}, 
    {Arrowheads[{{0.03658543723816795, 1.}}], 
     ArrowBox[{{9.10324624427275, 10.548801387925604`}, {10.039610898584394`, 
      10.308341469217254`}}]}, 
    {Arrowheads[{{0.031925367330852494`, 1.}}], 
     ArrowBox[{{9.158767289961629, 11.373059063067403`}, {9.984089852895513, 
      11.198369508361171`}}]}, 
    {Arrowheads[{{0.03014866171600585, 1.}}], 
     ArrowBox[{{9.177774594462527, 12.203709804730194`}, {9.965082548394616, 
      12.082004480984097`}}]}, 
    {Arrowheads[{{0.029496294578372495`, 1.}}], 
     ArrowBox[{{9.183704576259911, 13.039298005557308`}, {9.959152566597231, 
      12.960701994442696`}}]}, 
    {Arrowheads[{{0.030277964403346784`, 1.}}], 
     ArrowBox[{{10.030104957877434`, 0.9645757184421648}, {
      10.827037899265424`, 1.0354242815578352`}}]}, 
    {Arrowheads[{{0.030997593298366054`, 1.}}], 
     ArrowBox[{{10.02192383967412, 1.8085057960766884`}, {10.835219017468736`,
       1.905779918209026}}]}, 
    {Arrowheads[{{0.03239208141352561, 1.}}], 
     ArrowBox[{{10.005216089933198`, 2.651606598584199}, {10.851926767209658`,
       2.77696482998723}}]}, 
    {Arrowheads[{{0.03440735422458368, 1.}}], 
     ArrowBox[{{9.979658204563128, 3.4997718962405227`}, {10.87748465257973, 
      3.6430852466166206`}}]}, 
    {Arrowheads[{{0.03668581760882133, 1.}}], 
     ArrowBox[{{9.948964824569293, 4.358490467267668}, {10.908178032573565`, 
      4.49865238987519}}]}, 
    {Arrowheads[{{0.0386425454668521, 1.}}], 
     ArrowBox[{{9.921058903111888, 5.230083595648835}, {10.936083954030972`, 
      5.3413449757797355`}}]}, 
    {Arrowheads[{{0.0402512273802655, 1.}}], 
     ArrowBox[{{9.89764141589201, 6.1123355977772}, {10.959501441250847`, 
      6.173378687937085}}]}, 
    {Arrowheads[{{0.04190843214650035, 1.}}], 
     ArrowBox[{{9.874869551568247, 6.999999999999999}, {10.98227330557461, 
      6.999999999999999}}]}, 
    {Arrowheads[{{0.0402512273802655, 1.}}], 
     ArrowBox[{{9.89764141589201, 7.887664402222798}, {10.959501441250847`, 
      7.826621312062914}}]}, 
    {Arrowheads[{{0.0386425454668521, 1.}}], 
     ArrowBox[{{9.921058903111888, 8.769916404351164}, {10.936083954030972`, 
      8.658655024220263}}]}, 
    {Arrowheads[{{0.03668581760882133, 1.}}], 
     ArrowBox[{{9.948964824569293, 9.641509532732332}, {10.908178032573565`, 
      9.50134761012481}}]}, 
    {Arrowheads[{{0.03440735422458368, 1.}}], 
     ArrowBox[{{9.979658204563128, 10.500228103759477`}, {10.87748465257973, 
      10.356914753383379`}}]}, 
    {Arrowheads[{{0.03239208141352561, 1.}}], 
     ArrowBox[{{10.005216089933198`, 11.348393401415802`}, {
      10.851926767209658`, 11.22303517001277}}]}, 
    {Arrowheads[{{0.03099759329836605, 1.}}], 
     ArrowBox[{{10.02192383967412, 12.191494203923313`}, {10.835219017468736`,
       12.094220081790976`}}]}, 
    {Arrowheads[{{0.030277964403346787`, 1.}}], 
     ArrowBox[{{10.030104957877434`, 13.035424281557837`}, {
      10.827037899265424`, 12.964575718442166`}}]}, 
    {Arrowheads[{{0.03071459762277711, 1.}}], 
     ArrowBox[{{10.880997109121527`, 0.9702807156436518}, {
      11.690431462307046`, 1.0297192843563483`}}]}, 
    {Arrowheads[{{0.03134924460422264, 1.}}], 
     ArrowBox[{{10.8732354870834, 1.8195101718893854`}, {11.698193084345174`, 
      1.8947755423963288`}}]}, 
    {Arrowheads[{{0.03234649257268953, 1.}}], 
     ArrowBox[{{10.860700941447945`, 2.669487528618112}, {11.710727629980628`,
       2.7590838999533167`}}]}, 
    {Arrowheads[{{0.03364653103404434, 1.}}], 
     ArrowBox[{{10.843805717581105`, 3.523093300855034}, {11.727622853847468`,
       3.6197638420021088`}}]}, 
    {Arrowheads[{{0.03506141832022212, 1.}}], 
     ArrowBox[{{10.82473372708096, 4.38289588573658}, {11.746694844347614`, 
      4.474246971406278}}]}, 
    {Arrowheads[{{0.036319765327549075`, 1.}}], 
     ArrowBox[{{10.80718387017517, 5.24997197864639}, {11.764244701253405`, 
      5.321456592782182}}]}, 
    {Arrowheads[{{0.0371748754095816, 1.}}], 
     ArrowBox[{{10.794944183566384`, 6.123258952047473}, {11.776484387862187`,
       6.162455333666812}}]}, 
    {Arrowheads[{{0.03747670581788164, 1.}}], 
     ArrowBox[{{10.790565188207665`, 6.999999999999999}, {11.780863383220908`,
       6.999999999999999}}]}, 
    {Arrowheads[{{0.0371748754095816, 1.}}], 
     ArrowBox[{{10.794944183566384`, 7.8767410479525255`}, {
      11.776484387862187`, 7.837544666333186}}]}, 
    {Arrowheads[{{0.03631976532754907, 1.}}], 
     ArrowBox[{{10.80718387017517, 8.750028021353609}, {11.764244701253405`, 
      8.678543407217818}}]}, 
    {Arrowheads[{{0.03506141832022212, 1.}}], 
     ArrowBox[{{10.82473372708096, 9.617104114263421}, {11.746694844347614`, 
      9.525753028593723}}]}, 
    {Arrowheads[{{0.03364653103404434, 1.}}], 
     ArrowBox[{{10.843805717581105`, 10.476906699144966`}, {
      11.727622853847468`, 10.38023615799789}}]}, 
    {Arrowheads[{{0.03234649257268953, 1.}}], 
     ArrowBox[{{10.860700941447945`, 11.330512471381889`}, {
      11.710727629980628`, 11.240916100046684`}}]}, 
    {Arrowheads[{{0.03134924460422264, 1.}}], 
     ArrowBox[{{10.8732354870834, 12.180489828110616`}, {11.698193084345174`, 
      12.105224457603672`}}]}, 
    {Arrowheads[{{0.03071459762277711, 1.}}], 
     ArrowBox[{{10.880997109121527`, 13.02971928435635}, {11.690431462307046`,
       12.970280715643653`}}]}, 
    {Arrowheads[{{0.030926671079335877`, 1.}}], 
     ArrowBox[{{11.734958574421675`, 0.9759180230471732}, {
      12.550755711292613`, 1.0240819769528269`}}]}, 
    {Arrowheads[{{0.03143745100647994, 1.}}], 
     ArrowBox[{{11.728494025773916`, 1.8284210609966922`}, {
      12.557220259940374`, 1.8858646532890222`}}]}, 
    {Arrowheads[{{0.03214966324014904, 1.}}], 
     ArrowBox[{{11.719322087413701`, 2.681955210882584}, {12.566392198300587`,
       2.7466162176888442`}}]}, 
    {Arrowheads[{{0.03301526549108298, 1.}}], 
     ArrowBox[{{11.707933397462673`, 3.5380364941005973`}, {
      12.577780888251615`, 3.604820648756546}}]}, 
    {Arrowheads[{{0.033924409499018385`, 1.}}], 
     ArrowBox[{{11.695688867562705`, 4.397949942089179}, {12.590025418151582`,
       4.459192915053678}}]}, 
    {Arrowheads[{{0.03472361020115378, 1.}}], 
     ArrowBox[{{11.684686972296225`, 5.262170392733377}, {12.601027313418063`,
       5.309258178695194}}]}, 
    {Arrowheads[{{0.035267960123797334`, 1.}}], 
     ArrowBox[{{11.677066466778323`, 6.130048801962856}, {12.608647818935964`,
       6.155665483751428}}]}, 
    {Arrowheads[{{0.03546143079377006, 1.}}], 
     ArrowBox[{{11.674334227872157`, 6.999999999999999}, {12.611380057842132`,
       6.999999999999999}}]}, 
    {Arrowheads[{{0.035267960123797334`, 1.}}], 
     ArrowBox[{{11.677066466778323`, 7.869951198037143}, {12.608647818935964`,
       7.84433451624857}}]}, 
    {Arrowheads[{{0.03472361020115379, 1.}}], 
     ArrowBox[{{11.684686972296225`, 8.737829607266622}, {12.601027313418063`,
       8.690741821304805}}]}, 
    {Arrowheads[{{0.03392440949901839, 1.}}], 
     ArrowBox[{{11.695688867562705`, 9.602050057910821}, {12.590025418151582`,
       9.540807084946321}}]}, 
    {Arrowheads[{{0.03301526549108298, 1.}}], 
     ArrowBox[{{11.707933397462673`, 10.461963505899403`}, {
      12.577780888251615`, 10.395179351243454`}}]}, 
    {Arrowheads[{{0.032149663240149035`, 1.}}], 
     ArrowBox[{{11.719322087413701`, 11.318044789117417`}, {
      12.566392198300587`, 11.253383782311158`}}]}, 
    {Arrowheads[{{0.03143745100647994, 1.}}], 
     ArrowBox[{{11.728494025773916`, 12.17157893900331}, {12.557220259940374`,
       12.11413534671098}}]}, 
    {Arrowheads[{{0.030926671079335877`, 1.}}], 
     ArrowBox[{{11.734958574421675`, 13.024081976952829`}, {
      12.550755711292613`, 12.975918023047175`}}]}, 
    {Arrowheads[{{0.03100963887615299, 1.}}], 
     ArrowBox[{{12.59074760255722, 0.9807468728433444}, {13.409252397442785`, 
      1.0192531271566556`}}]}, 
    {Arrowheads[{{0.03140969992522379, 1.}}], 
     ArrowBox[{{12.585587625872456`, 1.8352414996171087`}, {
      13.414412374127545`, 1.8790442146686057`}}]}, 
    {Arrowheads[{{0.03192176196549753, 1.}}], 
     ArrowBox[{{12.578902242126802`, 2.6907285730824464`}, {
      13.421097757873202`, 2.737842855488982}}]}, 
    {Arrowheads[{{0.03250738531009456, 1.}}], 
     ArrowBox[{{12.57114604778193, 3.5479983356835016`}, {13.428853952218073`,
       3.5948588071736416`}}]}, 
    {Arrowheads[{{0.033100321053904515`, 1.}}], 
     ArrowBox[{{12.563172518213134`, 4.407664630808856}, {13.43682748178687, 
      4.449478226334002}}]}, 
    {Arrowheads[{{0.033613357414467956`, 1.}}], 
     ArrowBox[{{12.556175537962906`, 5.269908077927985}, {13.443824462037098`,
       5.301520493500585}}]}, 
    {Arrowheads[{{0.03396201227407391, 1.}}], 
     ArrowBox[{{12.551368720550215`, 6.134329309759689}, {13.448631279449788`,
       6.1513849759545955`}}]}, 
    {Arrowheads[{{0.03408618598013219, 1.}}], 
     ArrowBox[{{12.549647071236123`, 6.999999999999999}, {13.45035292876388, 
      6.999999999999999}}]}, 
    {Arrowheads[{{0.03396201227407391, 1.}}], 
     ArrowBox[{{12.551368720550215`, 7.865670690240309}, {13.448631279449788`,
       7.848615024045403}}]}, 
    {Arrowheads[{{0.033613357414467956`, 1.}}], 
     ArrowBox[{{12.556175537962906`, 8.730091922072013}, {13.443824462037098`,
       8.698479506499412}}]}, 
    {Arrowheads[{{0.033100321053904515`, 1.}}], 
     ArrowBox[{{12.563172518213134`, 9.592335369191144}, {13.43682748178687, 
      9.550521773665999}}]}, 
    {Arrowheads[{{0.03250738531009462, 1.}}], 
     ArrowBox[{{12.57114604778193, 10.452001664316498`}, {13.428853952218075`,
       10.405141192826358`}}]}, 
    {Arrowheads[{{0.03192176196549753, 1.}}], 
     ArrowBox[{{12.578902242126802`, 11.309271426917554`}, {
      13.421097757873202`, 11.262157144511018`}}]}, 
    {Arrowheads[{{0.03140969992522379, 1.}}], 
     ArrowBox[{{12.585587625872456`, 12.164758500382893`}, {
      13.414412374127545`, 12.120955785331397`}}]}, 
    {Arrowheads[{{0.03100963887615299, 1.}}], 
     ArrowBox[{{12.59074760255722, 13.019253127156658`}, {13.409252397442785`,
       12.980746872843346`}}]}}},
  AspectRatio->1,
  Method->{"TransparentPolygonMesh" -> True},
  PlotRange->{{0.3939084732686736, 13.606091526731326`}, {0.3939084732686736, 
   13.606091526731326`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.460674115831938*^9, {3.460674219842456*^9, 3.460674229812992*^9}, {
   3.4606744373658037`*^9, 3.4606744441638966`*^9}, 3.460677643416978*^9, 
   3.460677967385728*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 4:",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" A vector field map of the flow velocity on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane for an ellipsoid with semiaxes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", ",", "b", ",", "c"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{"1", ",", "2", ",", "3"}], ")"}]}], TraditionalForm]]],
 StyleBox[" and conductivity ratio ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Epsilon]", "=", "10"}], TraditionalForm]]],
 StyleBox[".",
  FontFamily->"Times"]
}], "Special1",
 CellMargins->{{36, 74}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True,
 FontSize->10],

Cell[TextData[{
 StyleBox["This representation of the left-to-right flow conveys the sense of \
convergence to the ellipse in the left half of the picture, and divergence \
away from it in the right half. The length of each arrow indicates the \
velocity magnitude at the base of the arrow. Unfortunately such plots can be \
confusing to the eye. The use of ",
  FontFamily->"Times"],
 StyleBox["critical",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" flow paths can summarise this information much more simply. \
Critical flow paths are flow paths calculated from starting points located at \
critical points in the flow, ",
  FontFamily->"Times"],
 StyleBox["e.g.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" boundaries of objects, or source/sink points.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
To prepare for flow path calculation, we import the appropriate package:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<H:/doc/papers/CIP-Laplace\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{{3.460677649041978*^9, 3.460677675354478*^9}}],

Cell[BoxData["\<\"H:\\\\doc\\\\papers\\\\CIP-Laplace\"\>"], "Output",
 CellChangeTimes->{{3.460677664182603*^9, 3.460677675745103*^9}, 
   3.460677969932603*^9}]
}, Open  ]],

Cell["<<ParticleTrack.m", "Input",
 CellChangeTimes->{{3.460675420070495*^9, 3.4606754215237875`*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["The ",
  FontFamily->"Times"],
 StyleBox["ParticleTrack.m",
  FontFamily->"Courier"],
 StyleBox[" package is a simple adaptation of the standard programming \
example package ",
  FontFamily->"Times"],
 StyleBox["RungeKutta.m",
  FontFamily->"Courier"],
 StyleBox[" [see also Maeder 1991] to the case of potential flow. Two key \
functions are defined in ",
  FontFamily->"Times"],
 StyleBox["ParticleTrack.m",
  FontFamily->"Courier"],
 StyleBox[", together with various useful options (see the accompanying \
package ",
  FontFamily->"Times"],
 StyleBox["ParticleTrack.m",
  FontFamily->"Courier"],
 StyleBox[" for details of function definitions). The first is a \
particle-tracking algorithm that integrates a velocity field via the \
fourth-order Runge-Kutta method; the second uses a simple fixed time-step \
(Eulerian) advecting scheme. Both functions require the Cartesian components \
of the velocity field as input. In this paper we restrict attention to the \
Runge-Kutta technique, implemented in the ",
  FontFamily->"Times"],
 StyleBox["RKParticleTrack",
  FontFamily->"Courier"],
 StyleBox[" function. ",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["?RKParticleTrack", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 StyleBox["\<\"RKParticleTrack[{v1,v2,..}, {x1,x2,..}, {a1,a2,..},\\n\\n\t\t\
{t1, dt}]\\n\\nnumerically integrates the vi as functions of the \
\\n\\ncoordinates xi with initial values ai. The integration \\n\\nproceeds \
in steps of dt from 0 to t1. The vi are to be \\n\\nthought of as holonomic \
gradients of the particle \\n\\npotential. The fourth order Runge-Kutta \
method is used.\\n\\n\\nRKParticleTrack[{v1,v2,..}, {x1,x2,..}, \
{a1,a2,..},\\n\\n\t\t{t, t0, t1, dt}]\\n\\nperforms the calculation over time \
t proceeding in steps \\n\\nof dt from t0 to t1. A negative dt yields \
particle tracking \\n\\nbackwards in \
time.\\n\\n\\nRKParticleTrack[{v1,v2,..}, {x1,x2,..}, {a1,a2,..}, \\n\\n\t\t\
{t1, dt}, {c1,c2,..}, tol, \\n\\n\t\t{{x1min, \
x1max},{x2min,x2max},..}]\\n\\nperforms the particle tracking to within an \
accuracy tol of \\n\\nthe specified critical point(s) with coordinates ci. \
The \\n\\ndomain is bounded by the min and max \
arguments.\\n\\n\\nRKParticleTrack[{v1,v2,..}, {x1,x2,..}, {a1,a2,..},\\n\\n\t\
\t{t, t0, t1, dt}, {c1,c2,..}, tol, \\n\\n\t\t{{x1min, \
x1max},{x2min,x2max},..}]\\n\\nperforms the particle tracking to within \
tolerance tol of \\n\\nthe specified critical point(s) with coordinates ci in \
\\n\\nsteps of dt from t0 to t1. The domain is bounded by the \\n\\nmin and \
max arguments. The critical point coordinates ci\\n\\nmay be given in vector \
or matrix form. That is, an \\n\\narbitrary number of critical points may be \
given.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.460675492594474*^9},
 CellTags->"Info3460704292-7240887"]
}, Open  ]],

Cell[TextData[{
 StyleBox["In the following we restrict attention to ",
  FontFamily->"Times"],
 StyleBox["principal flow paths",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontFamily->"Times"],
 StyleBox["i.e.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" flow paths that are tangential to high symmetry points on the \
surface of the ellipsoid. Tangential flow paths can be calculated by \
considering the paths of two advecting particles, one path integrated forward \
in time and one backward in time, with starting points just outside the \
ellipse boundary. The sum of the two paths gives the overall tangential flow \
path.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["We consider principal flow paths for an ellipsoid immersed in a \
regional flow field directed in the positive ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox[" direction. The calculation takes two parts. The first is to \
accumulate backward-in-time principle flow paths starting from the maximum ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 StyleBox[" and maximum ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["z", TraditionalForm]]],
 StyleBox[" extrema of the ellipsoid. The second is to use the symmetry of \
the problem to generate a full set of principal flow paths (forward and \
backward in time) tangential to these extrema. This latter part is a shortcut \
to reduce the time spent in performing the Runge-Kutta integrations. Also \
note that in each flow path calculation, the unimportant axis is dispensed \
with to reduce calculation time.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
FlowPathz = 
  RKParticleTrack[{Chop[nvx[x,y,0,1,2,3,100,1,0,0,0.0001]],
                   Chop[nvy[x,y,0,1,2,3,100,1,0,0,0.0001]]},
                  {x,y}, {0,2}, {t, 0, -5, -0.1}];         \
\>", "Input",
 CellChangeTimes->{{3.460675515237707*^9, 3.460675527520372*^9}, {
   3.4606757215348797`*^9, 3.460675722752982*^9}, 3.460678011604478*^9},
 AspectRatioFixed->True],

Cell["\<\
FPz1 = Join[Reverse[FlowPathz] /. {x_,y_}->{-x,y,0},
            FlowPathz /. {x_,y_}->{x,y,0}];\
\>", "Input",
 AspectRatioFixed->True],

Cell["\<\
FPz2 = Join[Reverse[FlowPathz] /. {x_,y_}->{-x,-y,0},
            FlowPathz /. {x_,y_}->{x,-y,0}];\
\>", "Input",
 AspectRatioFixed->True],

Cell["\<\
FlowPathy = 
  RKParticleTrack[{nvx[x,0,z,1,2,3,100,1,0,0,0.0001],
                   nvz[x,0,z,1,2,3,100,1,0,0,0.0001]},
                  {x,z}, {0,3}, {t, 0, -5, -0.1}];\
\>", "Input",
 AspectRatioFixed->True],

Cell["\<\
FPy1 = Join[Reverse[FlowPathy] /. {x_,z_}->{-x,0,z},
            FlowPathy /. {x_,z_}->{x,0,z}];\
\>", "Input",
 AspectRatioFixed->True],

Cell["\<\
FPy2 = Join[Reverse[FlowPathy] /. {x_,z_}->{-x,0,-z},
            FlowPathy /. {x_,z_}->{x,0,-z}];\
\>", "Input",
 AspectRatioFixed->True],

Cell["\<\
We can display these flow paths and the corresponding ellipsoid using \
standard graphics utilities. First we define a graphics object for the flow \
paths:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
FlowPathTracks = 
 Show[Graphics3D[{Thickness[0.007],
                  Line /@ {FPz1,FPz2,FPy1,FPy2}}],
      DisplayFunction->Identity
     ];\
\>", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Next we use the ",
  FontFamily->"Times"],
 StyleBox["ParametricPlot",
  FontFamily->"Courier"],
 StyleBox[" to define a graphics object for the ellipsoid:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.460678103510728*^9, 3.460678107057603*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ellipsoid", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "u", "]"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}]}], ",", 
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "u", "]"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}]}], ",", 
       RowBox[{"3", " ", 
        RowBox[{"Sin", "[", "v", "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox["\[Pi]", "2"]}], "}"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{3.460678060276353*^9, 3.460678132416978*^9},
 AspectRatioFixed->True],

Cell["Now we can display both together:", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"FlowPathTracks", ",", "Ellipsoid", ",", 
   RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.460678077963853*^9, 3.460678079995103*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[{
   {Thickness[0.007], 
    Line3DBox[{{3.6041726392702453`, 2.7217520930272077`, 0}, {
      3.501006457165685, 2.7173248336810785`, 0}, {
      3.397773478115965, 2.712613843065803, 0}, {
      3.294478119148939, 2.707598496064693, 0}, {
      3.191126042651685, 2.7022565799135645`, 0}, {
      3.0877243714573783`, 2.696564177659259, 0}, {
      2.984281938959998, 2.6904955460401427`, 0}, {
      2.8808095801220266`, 2.6840229884605695`, 0}, {
      2.777320470329173, 2.6771167241434357`, 0}, {
      2.673830520286857, 2.6697447550239874`, 0}, {
      2.5703588366642136`, 2.661872732658358, 0}, {
      2.4669282600213904`, 2.653463828309599, 0}, {
      2.3635659937038898`, 2.6444786105915163`, 0}, {
      2.260304339999963, 2.634874936676068, 0}, {
      2.1571815629531175`, 2.6246078652227354`, 0}, {
      2.054242900916232, 2.613629602115168, 0}, {
      1.9515417563015773`, 2.601889493976854, 0}, {
      1.849141095050706, 2.5893340897175547`, 0}, {
      1.7471150942052753`, 2.575907297456463, 0}, {
      1.6455510824312507`, 2.561550673768665, 0}, {
      1.5445518251867938`, 2.5462038951656036`, 0}, {
      1.4442382127702318`, 2.529805479214968, 0}, {
      1.3447524143887866`, 2.5122938461827786`, 0}, {
      1.2462615622015147`, 2.4936088433637744`, 0}, {
      1.1489620216021488`, 2.4736938953252094`, 0}, {
      1.0530842801750775`, 2.4524989958648122`, 0}, {
      0.9588984349327048, 2.42998482201755, 0}, {
      0.8667201546614095, 2.406128323658624, 0}, {
      0.776916808769669, 2.3809302123970366`, 0}, {
      0.6899131379026845, 2.3544248111696744`, 0}, {
      0.6061953318757062, 2.3266926686776817`, 0}, {
      0.526311612747636, 2.297876071606936, 0}, {
      0.4508663755850799, 2.2681969025991466`, 0}, {
      0.3805037544138662, 2.237974914961856, 0}, {
      0.3158756591754223, 2.2076421752458026`, 0}, {
      0.257589995414563, 2.1777462853136216`, 0}, {
      0.2061386795298455, 2.1489322209140216`, 0}, {
      0.16181361974745911`, 2.121893147455638, 0}, {
      0.12463064864659947`, 2.097288379911957, 0}, {
      0.09428965454357596, 2.075642831281385, 0}, {
      0.07019384896008482, 2.057259383858509, 0}, {
      0.0515290714839581, 2.0421787648755205`, 0}, {
      0.03737750038535985, 2.030202516025221, 0}, {
      0.02682827272203731, 2.0209650486109587`, 0}, {
      0.019056923744779172`, 2.014022558656824, 0}, {
      0.013365170075486167`, 2.0089295125828195`, 0}, {
      0.009187876948915524, 2.0052888413527827`, 0}, {
      0.0060795876336943635`, 2.0027764172342075`, 0}, {
      0.0036914972421251925`, 2.001147517203976, 0}, {
      0.0017457957991656352`, 2.0002338308950516`, 0}, {0., 2., 0}, {
      0., 2., 0}, {-0.0017457957991656352`, 2.0002338308950516`, 
       0}, {-0.0036914972421251925`, 2.001147517203976, 
       0}, {-0.0060795876336943635`, 2.0027764172342075`, 
       0}, {-0.009187876948915524, 2.0052888413527827`, 
       0}, {-0.013365170075486167`, 2.0089295125828195`, 
       0}, {-0.019056923744779172`, 2.014022558656824, 
       0}, {-0.02682827272203731, 2.0209650486109587`, 
       0}, {-0.03737750038535985, 2.030202516025221, 0}, {-0.0515290714839581,
        2.0421787648755205`, 0}, {-0.07019384896008482, 2.057259383858509, 
       0}, {-0.09428965454357596, 2.075642831281385, 
       0}, {-0.12463064864659947`, 2.097288379911957, 
       0}, {-0.16181361974745911`, 2.121893147455638, 
       0}, {-0.2061386795298455, 2.1489322209140216`, 0}, {-0.257589995414563,
        2.1777462853136216`, 0}, {-0.3158756591754223, 2.2076421752458026`, 
       0}, {-0.3805037544138662, 2.237974914961856, 0}, {-0.4508663755850799, 
       2.2681969025991466`, 0}, {-0.526311612747636, 2.297876071606936, 
       0}, {-0.6061953318757062, 2.3266926686776817`, 
       0}, {-0.6899131379026845, 2.3544248111696744`, 0}, {-0.776916808769669,
        2.3809302123970366`, 0}, {-0.8667201546614095, 2.406128323658624, 
       0}, {-0.9588984349327048, 2.42998482201755, 0}, {-1.0530842801750775`, 
       2.4524989958648122`, 0}, {-1.1489620216021488`, 2.4736938953252094`, 
       0}, {-1.2462615622015147`, 2.4936088433637744`, 
       0}, {-1.3447524143887866`, 2.5122938461827786`, 
       0}, {-1.4442382127702318`, 2.529805479214968, 
       0}, {-1.5445518251867938`, 2.5462038951656036`, 
       0}, {-1.6455510824312507`, 2.561550673768665, 
       0}, {-1.7471150942052753`, 2.575907297456463, 0}, {-1.849141095050706, 
       2.5893340897175547`, 0}, {-1.9515417563015773`, 2.601889493976854, 
       0}, {-2.054242900916232, 2.613629602115168, 0}, {-2.1571815629531175`, 
       2.6246078652227354`, 0}, {-2.260304339999963, 2.634874936676068, 
       0}, {-2.3635659937038898`, 2.6444786105915163`, 
       0}, {-2.4669282600213904`, 2.653463828309599, 
       0}, {-2.5703588366642136`, 2.661872732658358, 0}, {-2.673830520286857, 
       2.6697447550239874`, 0}, {-2.777320470329173, 2.6771167241434357`, 
       0}, {-2.8808095801220266`, 2.6840229884605695`, 
       0}, {-2.984281938959998, 2.6904955460401427`, 
       0}, {-3.0877243714573783`, 2.696564177659259, 0}, {-3.191126042651685, 
       2.7022565799135645`, 0}, {-3.294478119148939, 2.707598496064693, 
       0}, {-3.397773478115965, 2.712613843065803, 0}, {-3.501006457165685, 
       2.7173248336810785`, 0}, {-3.6041726392702453`, 2.7217520930272077`, 
       0}}], Line3DBox[{{3.6041726392702453`, -2.7217520930272077`, 0}, {
      3.501006457165685, -2.7173248336810785`, 0}, {
      3.397773478115965, -2.712613843065803, 0}, {
      3.294478119148939, -2.707598496064693, 0}, {
      3.191126042651685, -2.7022565799135645`, 0}, {
      3.0877243714573783`, -2.696564177659259, 0}, {
      2.984281938959998, -2.6904955460401427`, 0}, {
      2.8808095801220266`, -2.6840229884605695`, 0}, {
      2.777320470329173, -2.6771167241434357`, 0}, {
      2.673830520286857, -2.6697447550239874`, 0}, {
      2.5703588366642136`, -2.661872732658358, 0}, {
      2.4669282600213904`, -2.653463828309599, 0}, {
      2.3635659937038898`, -2.6444786105915163`, 0}, {
      2.260304339999963, -2.634874936676068, 0}, {
      2.1571815629531175`, -2.6246078652227354`, 0}, {
      2.054242900916232, -2.613629602115168, 0}, {
      1.9515417563015773`, -2.601889493976854, 0}, {
      1.849141095050706, -2.5893340897175547`, 0}, {
      1.7471150942052753`, -2.575907297456463, 0}, {
      1.6455510824312507`, -2.561550673768665, 0}, {
      1.5445518251867938`, -2.5462038951656036`, 0}, {
      1.4442382127702318`, -2.529805479214968, 0}, {
      1.3447524143887866`, -2.5122938461827786`, 0}, {
      1.2462615622015147`, -2.4936088433637744`, 0}, {
      1.1489620216021488`, -2.4736938953252094`, 0}, {
      1.0530842801750775`, -2.4524989958648122`, 0}, {
      0.9588984349327048, -2.42998482201755, 0}, {
      0.8667201546614095, -2.406128323658624, 0}, {
      0.776916808769669, -2.3809302123970366`, 0}, {
      0.6899131379026845, -2.3544248111696744`, 0}, {
      0.6061953318757062, -2.3266926686776817`, 0}, {
      0.526311612747636, -2.297876071606936, 0}, {
      0.4508663755850799, -2.2681969025991466`, 0}, {
      0.3805037544138662, -2.237974914961856, 0}, {
      0.3158756591754223, -2.2076421752458026`, 0}, {
      0.257589995414563, -2.1777462853136216`, 0}, {
      0.2061386795298455, -2.1489322209140216`, 0}, {
      0.16181361974745911`, -2.121893147455638, 0}, {
      0.12463064864659947`, -2.097288379911957, 0}, {
      0.09428965454357596, -2.075642831281385, 0}, {
      0.07019384896008482, -2.057259383858509, 0}, {
      0.0515290714839581, -2.0421787648755205`, 0}, {
      0.03737750038535985, -2.030202516025221, 0}, {
      0.02682827272203731, -2.0209650486109587`, 0}, {
      0.019056923744779172`, -2.014022558656824, 0}, {
      0.013365170075486167`, -2.0089295125828195`, 0}, {
      0.009187876948915524, -2.0052888413527827`, 0}, {
      0.0060795876336943635`, -2.0027764172342075`, 0}, {
      0.0036914972421251925`, -2.001147517203976, 0}, {
      0.0017457957991656352`, -2.0002338308950516`, 0}, {0., -2., 0}, {
      0., -2., 0}, {-0.0017457957991656352`, -2.0002338308950516`, 
       0}, {-0.0036914972421251925`, -2.001147517203976, 
       0}, {-0.0060795876336943635`, -2.0027764172342075`, 
       0}, {-0.009187876948915524, -2.0052888413527827`, 
       0}, {-0.013365170075486167`, -2.0089295125828195`, 
       0}, {-0.019056923744779172`, -2.014022558656824, 
       0}, {-0.02682827272203731, -2.0209650486109587`, 
       0}, {-0.03737750038535985, -2.030202516025221, 
       0}, {-0.0515290714839581, -2.0421787648755205`, 
       0}, {-0.07019384896008482, -2.057259383858509, 
       0}, {-0.09428965454357596, -2.075642831281385, 
       0}, {-0.12463064864659947`, -2.097288379911957, 
       0}, {-0.16181361974745911`, -2.121893147455638, 
       0}, {-0.2061386795298455, -2.1489322209140216`, 
       0}, {-0.257589995414563, -2.1777462853136216`, 
       0}, {-0.3158756591754223, -2.2076421752458026`, 
       0}, {-0.3805037544138662, -2.237974914961856, 
       0}, {-0.4508663755850799, -2.2681969025991466`, 
       0}, {-0.526311612747636, -2.297876071606936, 
       0}, {-0.6061953318757062, -2.3266926686776817`, 
       0}, {-0.6899131379026845, -2.3544248111696744`, 
       0}, {-0.776916808769669, -2.3809302123970366`, 
       0}, {-0.8667201546614095, -2.406128323658624, 
       0}, {-0.9588984349327048, -2.42998482201755, 
       0}, {-1.0530842801750775`, -2.4524989958648122`, 
       0}, {-1.1489620216021488`, -2.4736938953252094`, 
       0}, {-1.2462615622015147`, -2.4936088433637744`, 
       0}, {-1.3447524143887866`, -2.5122938461827786`, 
       0}, {-1.4442382127702318`, -2.529805479214968, 
       0}, {-1.5445518251867938`, -2.5462038951656036`, 
       0}, {-1.6455510824312507`, -2.561550673768665, 
       0}, {-1.7471150942052753`, -2.575907297456463, 
       0}, {-1.849141095050706, -2.5893340897175547`, 
       0}, {-1.9515417563015773`, -2.601889493976854, 
       0}, {-2.054242900916232, -2.613629602115168, 
       0}, {-2.1571815629531175`, -2.6246078652227354`, 
       0}, {-2.260304339999963, -2.634874936676068, 
       0}, {-2.3635659937038898`, -2.6444786105915163`, 
       0}, {-2.4669282600213904`, -2.653463828309599, 
       0}, {-2.5703588366642136`, -2.661872732658358, 
       0}, {-2.673830520286857, -2.6697447550239874`, 
       0}, {-2.777320470329173, -2.6771167241434357`, 
       0}, {-2.8808095801220266`, -2.6840229884605695`, 
       0}, {-2.984281938959998, -2.6904955460401427`, 
       0}, {-3.0877243714573783`, -2.696564177659259, 
       0}, {-3.191126042651685, -2.7022565799135645`, 
       0}, {-3.294478119148939, -2.707598496064693, 
       0}, {-3.397773478115965, -2.712613843065803, 
       0}, {-3.501006457165685, -2.7173248336810785`, 
       0}, {-3.6041726392702453`, -2.7217520930272077`, 0}}], 
    Line3DBox[{{4.025855432796515, 0, 3.612271054048372}, {
      3.9238060368463974`, 0, 3.6092407611975763`}, {
      3.8217124693359446`, 0, 3.60604530685663}, {
      3.7195756236072604`, 0, 3.602674065536118}, {
      3.6173967456983953`, 0, 3.5991156219373344`}, {
      3.5151774933536246`, 0, 3.5953577032429616`}, {
      3.412920004604811, 0, 3.591387104683277}, {
      3.3106269776038415`, 0, 3.5871896075801937`}, {
      3.2083017637808866`, 0, 3.58274988903739}, {
      3.1059484767778547`, 0, 3.5780514222735893`}, {
      3.003572120175777, 0, 3.57307636652622}, {
      2.9011787376552465`, 0, 3.567805445297477}, {
      2.7987755900775824`, 0, 3.5622178115978183`}, {
      2.696371364969964, 0, 3.5562908986782555`}, {
      2.5939764252238997`, 0, 3.5500002546323635`}, {
      2.4916031054424685`, 0, 3.543319359101899}, {
      2.3892660664772776`, 0, 3.536219420248505}, {
      2.2869827213873957`, 0, 3.528669150124318}, {
      2.1847737495415585`, 0, 3.520634516679124}, {
      2.082663720079711, 0, 3.5120784709413657`}, {
      1.980681851864886, 0, 3.502960648549486}, {
      1.8788629447836485`, 0, 3.493237045977569}, {
      1.777248527484037, 0, 3.48285967383347}, {
      1.6758882802077133`, 0, 3.4717761930255167`}, {
      1.574841809461648, 0, 3.4599295451762972`}, {
      1.4741808754589834`, 0, 3.4472575977614275`}, {
      1.3739922056673897`, 0, 3.433692839114409}, {
      1.2743810711200354`, 0, 3.4191621820488645`}, {
      1.1754758597136605`, 0, 3.403586972853658}, {
      1.0774339561157025`, 0, 3.3868833636644613`}, {
      0.9804493337981958, 0, 3.3689633049630703`}, {
      0.8847623796523756, 0, 3.349736574072341}, {
      0.7906725921877071, 0, 3.329114510634958}, {
      0.6985548766222365, 0, 3.3070165338758044`}, {
      0.6088800893692535, 0, 3.283381137547539}, {
      0.5222399890737188, 0, 3.258183957044584}, {
      0.43937524021915053`, 0, 3.2314666312522924`}, {
      0.3612014241216731, 0, 3.203381077862059}, {
      0.28882023435835824`, 0, 3.174252826614843}, {
      0.22348934562164435`, 0, 3.144659983027075}, {
      0.16650760960814892`, 0, 3.1155035914081086`}, {
      0.11897117940849791`, 0, 3.0880061232188813`}, {
      0.0814144879492713, 0, 3.0635429941439543`}, {
      0.05348970039327715, 0, 3.0432709811157017`}, {
      0.03393633692911243, 0, 3.027717598896794}, {
      0.02093267126042834, 0, 3.016636430641492}, {
      0.012600452179022038`, 0, 3.009236811153192}, {
      0.00735816908965297, 0, 3.0045691468933593`}, {
      0.004028037392598024, 0, 3.0018090223084966`}, {
      0.0017805642481719894`, 0, 3.0003719732627854`}, {0., 0, 3.}, {
      0., 0, 3.}, {-0.0017805642481719894`, 0, 
       3.0003719732627854`}, {-0.004028037392598024, 0, 
       3.0018090223084966`}, {-0.00735816908965297, 0, 
       3.0045691468933593`}, {-0.012600452179022038`, 0, 
       3.009236811153192}, {-0.02093267126042834, 0, 
       3.016636430641492}, {-0.03393633692911243, 0, 
       3.027717598896794}, {-0.05348970039327715, 0, 
       3.0432709811157017`}, {-0.0814144879492713, 0, 
       3.0635429941439543`}, {-0.11897117940849791`, 0, 
       3.0880061232188813`}, {-0.16650760960814892`, 0, 
       3.1155035914081086`}, {-0.22348934562164435`, 0, 
       3.144659983027075}, {-0.28882023435835824`, 0, 
       3.174252826614843}, {-0.3612014241216731, 0, 
       3.203381077862059}, {-0.43937524021915053`, 0, 
       3.2314666312522924`}, {-0.5222399890737188, 0, 
       3.258183957044584}, {-0.6088800893692535, 0, 
       3.283381137547539}, {-0.6985548766222365, 0, 
       3.3070165338758044`}, {-0.7906725921877071, 0, 
       3.329114510634958}, {-0.8847623796523756, 0, 
       3.349736574072341}, {-0.9804493337981958, 0, 
       3.3689633049630703`}, {-1.0774339561157025`, 0, 
       3.3868833636644613`}, {-1.1754758597136605`, 0, 
       3.403586972853658}, {-1.2743810711200354`, 0, 
       3.4191621820488645`}, {-1.3739922056673897`, 0, 
       3.433692839114409}, {-1.4741808754589834`, 0, 
       3.4472575977614275`}, {-1.574841809461648, 0, 
       3.4599295451762972`}, {-1.6758882802077133`, 0, 
       3.4717761930255167`}, {-1.777248527484037, 0, 
       3.48285967383347}, {-1.8788629447836485`, 0, 
       3.493237045977569}, {-1.980681851864886, 0, 
       3.502960648549486}, {-2.082663720079711, 0, 
       3.5120784709413657`}, {-2.1847737495415585`, 0, 
       3.520634516679124}, {-2.2869827213873957`, 0, 
       3.528669150124318}, {-2.3892660664772776`, 0, 
       3.536219420248505}, {-2.4916031054424685`, 0, 
       3.543319359101899}, {-2.5939764252238997`, 0, 
       3.5500002546323635`}, {-2.696371364969964, 0, 
       3.5562908986782555`}, {-2.7987755900775824`, 0, 
       3.5622178115978183`}, {-2.9011787376552465`, 0, 
       3.567805445297477}, {-3.003572120175777, 0, 
       3.57307636652622}, {-3.1059484767778547`, 0, 
       3.5780514222735893`}, {-3.2083017637808866`, 0, 
       3.58274988903739}, {-3.3106269776038415`, 0, 
       3.5871896075801937`}, {-3.412920004604811, 0, 
       3.591387104683277}, {-3.5151774933536246`, 0, 
       3.5953577032429616`}, {-3.6173967456983953`, 0, 
       3.5991156219373344`}, {-3.7195756236072604`, 0, 
       3.602674065536118}, {-3.8217124693359446`, 0, 
       3.60604530685663}, {-3.9238060368463974`, 0, 
       3.6092407611975763`}, {-4.025855432796515, 0, 3.612271054048372}}], 
    Line3DBox[{{4.025855432796515, 0, -3.612271054048372}, {
      3.9238060368463974`, 0, -3.6092407611975763`}, {
      3.8217124693359446`, 0, -3.60604530685663}, {
      3.7195756236072604`, 0, -3.602674065536118}, {
      3.6173967456983953`, 0, -3.5991156219373344`}, {
      3.5151774933536246`, 0, -3.5953577032429616`}, {
      3.412920004604811, 0, -3.591387104683277}, {
      3.3106269776038415`, 0, -3.5871896075801937`}, {
      3.2083017637808866`, 0, -3.58274988903739}, {
      3.1059484767778547`, 0, -3.5780514222735893`}, {
      3.003572120175777, 0, -3.57307636652622}, {
      2.9011787376552465`, 0, -3.567805445297477}, {
      2.7987755900775824`, 0, -3.5622178115978183`}, {
      2.696371364969964, 0, -3.5562908986782555`}, {
      2.5939764252238997`, 0, -3.5500002546323635`}, {
      2.4916031054424685`, 0, -3.543319359101899}, {
      2.3892660664772776`, 0, -3.536219420248505}, {
      2.2869827213873957`, 0, -3.528669150124318}, {
      2.1847737495415585`, 0, -3.520634516679124}, {
      2.082663720079711, 0, -3.5120784709413657`}, {
      1.980681851864886, 0, -3.502960648549486}, {
      1.8788629447836485`, 0, -3.493237045977569}, {
      1.777248527484037, 0, -3.48285967383347}, {
      1.6758882802077133`, 0, -3.4717761930255167`}, {
      1.574841809461648, 0, -3.4599295451762972`}, {
      1.4741808754589834`, 0, -3.4472575977614275`}, {
      1.3739922056673897`, 0, -3.433692839114409}, {
      1.2743810711200354`, 0, -3.4191621820488645`}, {
      1.1754758597136605`, 0, -3.403586972853658}, {
      1.0774339561157025`, 0, -3.3868833636644613`}, {
      0.9804493337981958, 0, -3.3689633049630703`}, {
      0.8847623796523756, 0, -3.349736574072341}, {
      0.7906725921877071, 0, -3.329114510634958}, {
      0.6985548766222365, 0, -3.3070165338758044`}, {
      0.6088800893692535, 0, -3.283381137547539}, {
      0.5222399890737188, 0, -3.258183957044584}, {
      0.43937524021915053`, 0, -3.2314666312522924`}, {
      0.3612014241216731, 0, -3.203381077862059}, {
      0.28882023435835824`, 0, -3.174252826614843}, {
      0.22348934562164435`, 0, -3.144659983027075}, {
      0.16650760960814892`, 0, -3.1155035914081086`}, {
      0.11897117940849791`, 0, -3.0880061232188813`}, {
      0.0814144879492713, 0, -3.0635429941439543`}, {
      0.05348970039327715, 0, -3.0432709811157017`}, {
      0.03393633692911243, 0, -3.027717598896794}, {
      0.02093267126042834, 0, -3.016636430641492}, {
      0.012600452179022038`, 0, -3.009236811153192}, {
      0.00735816908965297, 0, -3.0045691468933593`}, {
      0.004028037392598024, 0, -3.0018090223084966`}, {
      0.0017805642481719894`, 0, -3.0003719732627854`}, {0., 0, -3.}, {
      0., 0, -3.}, {-0.0017805642481719894`, 
       0, -3.0003719732627854`}, {-0.004028037392598024, 
       0, -3.0018090223084966`}, {-0.00735816908965297, 
       0, -3.0045691468933593`}, {-0.012600452179022038`, 
       0, -3.009236811153192}, {-0.02093267126042834, 
       0, -3.016636430641492}, {-0.03393633692911243, 
       0, -3.027717598896794}, {-0.05348970039327715, 
       0, -3.0432709811157017`}, {-0.0814144879492713, 
       0, -3.0635429941439543`}, {-0.11897117940849791`, 
       0, -3.0880061232188813`}, {-0.16650760960814892`, 
       0, -3.1155035914081086`}, {-0.22348934562164435`, 
       0, -3.144659983027075}, {-0.28882023435835824`, 
       0, -3.174252826614843}, {-0.3612014241216731, 
       0, -3.203381077862059}, {-0.43937524021915053`, 
       0, -3.2314666312522924`}, {-0.5222399890737188, 
       0, -3.258183957044584}, {-0.6088800893692535, 
       0, -3.283381137547539}, {-0.6985548766222365, 
       0, -3.3070165338758044`}, {-0.7906725921877071, 
       0, -3.329114510634958}, {-0.8847623796523756, 
       0, -3.349736574072341}, {-0.9804493337981958, 
       0, -3.3689633049630703`}, {-1.0774339561157025`, 
       0, -3.3868833636644613`}, {-1.1754758597136605`, 
       0, -3.403586972853658}, {-1.2743810711200354`, 
       0, -3.4191621820488645`}, {-1.3739922056673897`, 
       0, -3.433692839114409}, {-1.4741808754589834`, 
       0, -3.4472575977614275`}, {-1.574841809461648, 
       0, -3.4599295451762972`}, {-1.6758882802077133`, 
       0, -3.4717761930255167`}, {-1.777248527484037, 
       0, -3.48285967383347}, {-1.8788629447836485`, 
       0, -3.493237045977569}, {-1.980681851864886, 
       0, -3.502960648549486}, {-2.082663720079711, 
       0, -3.5120784709413657`}, {-2.1847737495415585`, 
       0, -3.520634516679124}, {-2.2869827213873957`, 
       0, -3.528669150124318}, {-2.3892660664772776`, 
       0, -3.536219420248505}, {-2.4916031054424685`, 
       0, -3.543319359101899}, {-2.5939764252238997`, 
       0, -3.5500002546323635`}, {-2.696371364969964, 
       0, -3.5562908986782555`}, {-2.7987755900775824`, 
       0, -3.5622178115978183`}, {-2.9011787376552465`, 
       0, -3.567805445297477}, {-3.003572120175777, 
       0, -3.57307636652622}, {-3.1059484767778547`, 
       0, -3.5780514222735893`}, {-3.2083017637808866`, 
       0, -3.58274988903739}, {-3.3106269776038415`, 
       0, -3.5871896075801937`}, {-3.412920004604811, 
       0, -3.591387104683277}, {-3.5151774933536246`, 
       0, -3.5953577032429616`}, {-3.6173967456983953`, 
       0, -3.5991156219373344`}, {-3.7195756236072604`, 
       0, -3.602674065536118}, {-3.8217124693359446`, 
       0, -3.60604530685663}, {-3.9238060368463974`, 
       0, -3.6092407611975763`}, {-4.025855432796515, 
       0, -3.612271054048372}}]}, GraphicsComplex3DBox[CompressedData["
1:eJyEfXVYVs3zt4Hd3d3dCTJrt2JhYYGF3QrYqCgGdmB3t4iB7JFWQekQRTpU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    "], {{
      {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxNnXXcFVX39s+ZOTNzZg42goLYPnajYiu2GNhdqCBidwuChS12gZSgiIWK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          "]], 
         Polygon3DBox[CompressedData["
1:eJw1nHn8F9P3x2fmPfsHpagQSpE2SnZCSUVEGykklb0iVJIkLXZZs2TJLlvZ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          "]], Polygon3DBox[CompressedData["
1:eJwt1nmUz1UYx/GvMb8xMyWkRMhSaUXJUiQ6lkQlVKej06qVmEqrJVsz9nVs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          "]], 
         Polygon3DBox[{{2276, 2275, 1479, 1191, 1192, 1480}, {2218, 2668, 
          1284, 1159, 1158, 1398}, {2263, 2262, 1458, 1180, 1181, 1459}, {
          2285, 2677, 1313, 1214, 1213, 1502}, {2325, 2324, 1579, 1246, 1247, 
          1580}, {2292, 2679, 1318, 1225, 1224, 
          1523}}]}]}, {}, {}, {}, {}}, {{}, {}, {}, {
       Line3DBox[{1139, 669, 1746, 671, 2860, 1634, 1362, 1391, 1363, 2735, 
        1643, 1394, 1416, 2799, 1395, 1157, 1427, 1651, 1428, 1168, 1441, 
        2802, 1658, 1442, 1179, 1456, 1666, 1457, 1190, 2770, 1477, 1677, 
        1478, 1201, 1498, 1688, 1499, 2745, 1212, 1519, 1699, 1520, 1223, 
        1539, 1709, 2843, 1540, 1234, 1553, 1716, 1554, 1245, 1573, 2819, 
        1724, 1574, 1726, 2848, 1577, 1610, 1578, 1736, 2853, 704, 1760, 706, 
        1625}], Line3DBox[{1140, 1841, 1842, 1747, 1793, 2856, 1792, 1635, 
        1364, 2787, 1366, 1644, 1396, 2794, 1398, 1158, 1289, 2739, 1169, 
        1296, 2741, 1180, 1458, 2806, 1667, 1460, 1191, 1479, 2809, 1678, 
        1481, 1202, 1500, 1689, 2840, 1502, 1213, 1521, 1700, 2841, 1523, 
        1224, 1323, 2756, 1235, 1330, 2758, 1246, 1579, 2821, 1581, 1727, 
        1582, 2823, 1584, 1737, 1811, 2865, 1812, 1761, 1854, 1853, 1839}], 
       Line3DBox[{1145, 1798, 1376, 1753, 1377, 1799, 2861, 1639, 1378, 1405, 
        1379, 2737, 1646, 1408, 1420, 2800, 1409, 1163, 1433, 1654, 1434, 
        1174, 1447, 2804, 1661, 1448, 1185, 2767, 1466, 1671, 1467, 1196, 
        2773, 1487, 1682, 1488, 1207, 1508, 1693, 1509, 2748, 1218, 1529, 
        1704, 1530, 2754, 1229, 1545, 1712, 2844, 1546, 1240, 1559, 1719, 
        1560, 1251, 1593, 2827, 1730, 1594, 1732, 2851, 1597, 1618, 1598, 
        1739, 2854, 1821, 1621, 1767, 1622, 1822, 1627}], 
       Line3DBox[{1146, 1800, 1801, 1754, 1803, 1802, 2862, 1640, 1380, 2789, 
        1381, 1647, 1410, 2798, 1411, 1164, 1293, 2740, 1175, 1300, 2742, 
        1186, 1468, 2807, 1672, 1469, 1197, 2774, 1489, 1683, 1490, 1208, 
        1510, 1694, 1511, 2749, 1219, 1531, 1705, 2842, 1532, 1230, 1327, 
        2757, 1241, 1334, 2759, 1252, 1599, 2828, 1600, 1733, 1601, 2829, 
        1602, 1740, 2855, 1823, 1824, 1768, 1826, 1825, 1628}], 
       Line3DBox[{1267, 1347, 1778, 1755, 1805, 1804, 1260, 1340, 2817, 1562, 
        1253, 1335, 2816, 1561, 1242, 1328, 2778, 1231, 1321, 2775, 1220, 
        1316, 2811, 1695, 1512, 1209, 1311, 1684, 1491, 1198, 1306, 1673, 
        1470, 1187, 1301, 1662, 2838, 1449, 1176, 1294, 2763, 1165, 1287, 
        2760, 1154, 1282, 2790, 1382, 1147, 1275, 2785, 1350, 1136, 1272, 
        1769, 1741, 1786, 1785, 1629}], 
       Line3DBox[{1268, 646, 1756, 693, 2863, 1261, 1341, 1603, 1565, 2781, 
        1254, 1336, 1720, 2845, 1563, 1243, 1329, 1713, 1547, 1232, 1322, 
        2814, 1706, 1533, 1221, 1317, 1696, 1513, 1210, 2743, 1312, 1685, 
        1492, 1199, 1307, 1674, 1471, 2768, 1188, 1302, 1663, 1450, 1177, 
        1295, 1655, 2836, 1435, 1166, 1288, 1648, 1421, 1155, 1283, 2791, 
        1412, 1384, 1148, 2832, 1276, 1383, 1351, 1137, 2830, 633, 1742, 658, 
        1630}], Line3DBox[{1269, 1348, 1932, 1762, 1814, 2857, 1813, 1263, 
        1343, 2822, 1583, 1256, 1337, 2820, 1580, 1247, 1331, 2779, 1236, 
        1324, 2776, 1225, 1318, 2812, 1522, 1214, 1313, 2810, 1501, 1203, 
        1308, 2808, 1480, 1192, 1303, 2805, 1459, 1181, 1297, 2764, 1170, 
        1290, 2761, 1159, 1284, 2793, 1397, 1150, 1278, 2786, 1365, 1141, 
        1273, 2858, 1772, 1748, 1844, 1843, 1840}], 
       Line3DBox[{1270, 1349, 1933, 1763, 1816, 1815, 1264, 1344, 2825, 1586, 
        1257, 1338, 2824, 1585, 1248, 1332, 2780, 1237, 1325, 2777, 1226, 
        1319, 2813, 1701, 1524, 1215, 2746, 1314, 1690, 1503, 1204, 1309, 
        1679, 1482, 2771, 1193, 1304, 1668, 2839, 1461, 1182, 1298, 2765, 
        1171, 1291, 2762, 1160, 1285, 2795, 1399, 1151, 1279, 2788, 1367, 
        1142, 1274, 1773, 1749, 1847, 1846, 1845}], 
       Line3DBox[{1271, 1782, 1781, 1764, 1614, 1817, 2866, 1265, 1345, 1613, 
        1589, 2783, 1258, 1339, 1728, 2849, 1587, 1249, 1333, 1717, 1555, 
        1238, 1326, 2815, 1710, 1541, 1227, 2752, 1320, 1702, 1525, 1216, 
        2747, 1315, 1691, 1504, 1205, 1310, 1680, 1483, 2772, 1194, 1305, 
        1669, 1462, 2766, 1183, 1299, 1659, 2837, 1443, 1172, 1292, 1652, 
        1429, 1161, 1286, 2796, 1417, 1401, 1152, 2834, 1280, 1400, 1369, 
        1143, 2831, 1775, 1774, 1750, 1368, 1794, 1636}], 
       Line3DBox[CompressedData["
1:eJwV0E0rhFEYxvHbwijy8glIlBUpqTEUpSkGi5nNxMbLjjJSlAVlgY0FK1aU
NbOZDVJqiLUVO1+Aj0D8zuLfdd//63k6p9O9slGqNETEIsqZiI6miGn5iSkM
tkS0c6/mXuTRg07+QU7q8ugy3yePnO6QO8AL2rgaWrFn38Ujnpsdyl3jrzFi
m9vCbep139yV7kuOcaOYwJ3ugzvTvcscN4ARPNmP+brMuscy148sqty+7kYO
6xa4eVwmuB3dhRzSlbgiznHKbepOZCG9T3KouUeFO8I6xrk+rPq2qpvj1jCL
Je43nc3P2N/MBfmT3tM//ybQL80=
        "]], Line3DBox[CompressedData["
1:eJwV0D0vQ2EYxvG7TZAwePkCTaVJm9glBolEE4N3qcSgg5dFI4oFE6YaLLWw
VSQmQsQiksZAmG01+QQkvgB+Z/jn/1zXfZ/nnJzscnVuIxURZSy0R/R1REzw
J8bRK+e6It6cCxhDHhldk4vm/fyItC7LR7oaXtEj36MbB/I+npCWR+1fcwq7
uh08JPPOiO+2iAv9F2/qqhixf8cfulOzFlfkNVzhRT7WP/OqPGR/hS9xqzs0
u+FBfVm3iAbOdXtmP97bcJ7XlXCGE3nbrM6Tyb9BHVvysHtqyfehoKsk97tj
Vl7HDJZ0A/b+eFp+5yn+5Zxn/gEVPy+/
        "]], 
       Line3DBox[{445, 430, 2429, 602, 406, 2415, 587, 815, 403, 2605, 963, 
        381, 945, 2595, 371, 927, 2589, 360, 785, 2529, 346, 761, 332, 2526, 
        759, 318, 2562, 869, 305, 2552, 851, 295, 833, 2542, 274, 797, 486, 
        2377, 248, 469, 2363, 247, 468}], Line3DBox[CompressedData["
1:eJwVzb8rxGEcB/CPck5nZmGhLPcPnCKTwXZ+lTvdORnO4iiyOFGUwU1KUUxX
fkzHIJHpmChmM3X/gIHRy/Dq/bzfz7fn27+4OrXSFhF55joi+pIRM7LFNL36
qxxhkmEGuiKe5bi7IdkkZcvImu2AF3r0O7rZ03d5olMf8/21TFK1bfJIMxXx
m4i4tP/Iddsat3zpZ/ZPWdGXafCuH9rf5JJe5ooHfd9+LzP+t2ArUefCtuXu
2//OnXO2WU450TfcHcsJPcsRO/qod2pym7St4rsbb5T+32Oesi3hruj84VyQ
7fogf15iLvM=
        "]], Line3DBox[CompressedData["
1:eJwV0L8rhVEcgPGv8qOQshtYLP4ERSSRjdEgdyJ1lcHGhJGJQUwYMLgLC0qR
QfIrJHGTxO2ShU3kc4an5z3fp/ec874NmdHebElEDGKgPOIHXWUR51zEO8ZK
I7rNhvHrubYqYoIbKyJGzKZRqIyYtZ7DlNbDD5jVTngeC6lrfZzHknaajGUs
av38hE3tjFewijUtw5fOeeYD/YLXsYGcPsQvuNGueAut7prjXT3Lryjq17yN
Nn2Hj/VxLuBPv+U97Kcztcn0Hqr9jzs+xFH6Rm2GP1CnNdvvPu2LdrzpeXeu
1zrQYu9Psxqt0/oRX/hGk9k/Je9Avg==
        "]], Line3DBox[CompressedData["
1:eJwV0D0oRWEcgPH/DVcxMtmMyngzmW5hQwYDpdy6kyKbj+mO7kgUEyUGLBQx
MVFIkk6SfHWTdAsDRr8zPD3v+z7n/57OaS1MDIxnImIUxWxETX3EUF1EYv2J
L0zVRgw7m0EGTY0RJWdtnp21L6PaEDFvv4Cy1ssPWNLOeRkrWNQG+RHrWs5d
l9arWEutj/AzDvQr3sAmtrQiv+JCu+Zt7GBfG+NKOqvd8C72cKJN8ht+tFs+
RN67j9K79Gl+R9b3JtylHaezSPQSf6BZv+NTnOFFm+MqclqnuXvrbvSkM/qT
f9Oh9SHv/d/OWrR++wp+8Yd2Z//Vjj8e
        "]]}, {Line3DBox[CompressedData["
1:eJwV0EdKBVEQBdASzIKuwZmYwPhN30W4AAfm7BrMOeecsy5IJy5AEJyJI88b
HG511evidZf3THZN5EREN98FEe9FER/Usc5vbsSUPOSIejYoLYnoLYyYVh9z
QgNf+RF9+jPqU854LY5olJv0m83Kc6rsuDRrUm8xYDYnL6hOM9nMNoNm87JC
/0pek2EnvWdHpf6C+oZbWtjlz/0X5R33tKb9zpc5P2TnkucHHmnjx/2H9ZfV
TzzTzh4j+ivyhTz/qkPuM6q/mr6TmnQ/+7PqA8bM1tJ99WrN3tSdfDJultH/
B+MjM6M=
        "]], 
       Line3DBox[{2032, 2200, 2367, 2663, 2785, 2031, 2201, 2368, 2832, 2158, 
        2210, 2202, 2369, 2833, 2159, 2212, 2689, 2733, 2370, 2160, 2214, 
        2690, 2734, 2371, 2161, 2215, 2691, 2735, 2372, 2162, 2033, 2787, 
        2203, 2373, 2664, 2786, 2034, 2204, 2374, 2665, 2788, 2035, 2205, 
        2375, 2834, 2163, 2220, 2206, 2376, 2835, 2164, 2222, 2207, 2377, 
        2165, 2224, 2692, 2736, 2378, 2166, 2226, 2693, 2737, 2379, 2167, 
        2036, 2789, 2208, 2380, 2168, 2229}], 
       Line3DBox[{2038, 2209, 2666, 2790, 2037, 2211, 2667, 2791, 2231, 2213, 
        2538, 2728, 2792, 2616, 2232, 2617, 2694, 2738, 2539, 2618, 2619, 
        2233, 2620, 2877, 2216, 2540, 2169, 2234, 2799, 2217, 2170, 2039, 
        2794, 2218, 2668, 2793, 2040, 2219, 2669, 2795, 2041, 2221, 2670, 
        2796, 2235, 2223, 2541, 2729, 2797, 2621, 2236, 2622, 2225, 2542, 
        2623, 2624, 2237, 2625, 2878, 2227, 2543, 2171, 2238, 2800, 2228, 
        2172, 2042, 2798, 2230, 2173, 2043}], 
       Line3DBox[{2045, 2671, 2760, 2044, 288, 1648, 490, 289, 1994, 1082, 
        491, 1649, 290, 492, 1650, 291, 493, 1651, 292, 2046, 2739, 2672, 
        2761, 2047, 2673, 2762, 2048, 293, 1652, 494, 294, 1995, 1083, 495, 
        295, 496, 1653, 296, 497, 1654, 297, 2049, 2740, 2174, 2050}], 
       Line3DBox[{2052, 2674, 2763, 2051, 2239, 2240, 2836, 2053, 2650, 2241, 
        2651, 1436, 2644, 2546, 2547, 2545, 2695, 2867, 2544, 2242, 2548, 
        2551, 2550, 2801, 2243, 2549, 2244, 2054, 2802, 2245, 2246, 2055, 
        2741, 2675, 2764, 2056, 2676, 2765, 2057, 2247, 2248, 2837, 2058, 
        2652, 2249, 2653, 2250, 2868, 2645, 2554, 2555, 2553, 2251, 2552, 
        2252, 2556, 2559, 2558, 2803, 2253, 2557, 2254, 2059, 2804, 2255, 
        2256, 2060, 2742, 2175, 2061}], 
       Line3DBox[{2063, 2257, 2258, 2838, 2062, 2259, 1450, 2064, 1108, 1109, 
        2016, 862, 863, 861, 2869, 2560, 864, 867, 866, 2870, 2561, 2260, 
        2065, 1456, 2261, 2066, 2806, 2262, 2263, 2805, 2067, 2264, 2265, 
        2839, 2068, 2266, 2766, 2696, 2069, 1110, 1111, 2017, 871, 872, 870, 
        2562, 873, 876, 875, 2871, 2563, 2267, 2070, 2697, 2767, 2268, 2071, 
        2807, 2269, 2270, 2072}], 
       Line3DBox[{106, 1198, 107, 1199, 108, 893, 1200, 109, 1838, 760, 976, 
        110, 1897, 896, 111, 1201, 112, 1202, 1203, 113, 1204, 114, 1205, 115,
         899, 1206, 116, 761, 977, 117, 1900, 902, 118, 1207, 119, 1208, 
        120}], Line3DBox[{2074, 2271, 1470, 2073, 2272, 2768, 2698, 2075, 
        2654, 2655, 2564, 2769, 2568, 2567, 2076, 2565, 2566, 2872, 2525, 
        2570, 2613, 2569, 2077, 2572, 2873, 2727, 2571, 2273, 2078, 2699, 
        2770, 2274, 2079, 2809, 2275, 2276, 2808, 2080, 2277, 2771, 2700, 
        2081, 2278, 2772, 2701, 2082, 2656, 2657, 2573, 1893, 2576, 2083, 
        2574, 2575, 2526, 2578, 2614, 2577, 2084, 2580, 1895, 2579, 2279, 
        2085, 2702, 2773, 2280, 2086, 2703, 2774, 2281, 2087}], 
       Line3DBox[{2088, 2282, 1311, 2381, 2283, 2743, 2176, 2382, 2284, 2581, 
        2879, 2627, 2177, 2628, 2532, 2533, 2744, 2528, 2534, 2178, 2630, 
        2629, 2880, 2730, 2582, 2179, 2383, 2704, 2745, 2180, 2384, 2840, 
        2285, 2677, 2810, 2089, 2286, 2746, 2181, 2385, 2287, 2747, 2182, 
        2386, 2288, 2583, 1971, 2183, 2631, 2535, 2536, 2529, 2537, 2184, 
        2633, 2632, 1972, 2584, 2185, 2387, 2705, 2748, 2186, 2388, 2706, 
        2749, 2187, 2090}], 
       Line3DBox[{2091, 2289, 2678, 2811, 2389, 2290, 1317, 2390, 2291, 2585, 
        2881, 1042, 1044, 1043, 2750, 2586, 1045, 1047, 1046, 2751, 2587, 
        2188, 2391, 1520, 2189, 2392, 2841, 2292, 2679, 2812, 2092, 2293, 
        2680, 2813, 2393, 2294, 2752, 2190, 2394, 2295, 2588, 2882, 1048, 
        1050, 1049, 2589, 1051, 1053, 1052, 2753, 2590, 2191, 2395, 2707, 
        2754, 2192, 2396, 2842, 2296, 2193, 2093}], 
       Line3DBox[{2095, 2681, 2775, 2094, 2297, 2682, 2814, 2397, 2298, 2591, 
        1980, 2646, 2634, 2398, 2635, 2708, 2755, 2592, 2636, 2637, 2399, 
        2638, 2883, 2299, 2593, 2194, 2400, 2843, 2300, 2195, 2096, 2756, 
        2683, 2776, 2097, 2684, 2777, 2098, 2301, 2685, 2815, 2401, 2302, 
        2594, 2731, 2885, 2647, 2639, 2402, 2640, 2303, 2595, 2641, 2642, 
        2403, 2643, 2884, 2304, 2596, 2196, 2404, 2844, 2305, 2197, 2099, 
        2757, 2198, 2100}], 
       Line3DBox[{2102, 2686, 2778, 2101, 374, 1713, 562, 375, 2008, 1096, 
        563, 1714, 376, 564, 1715, 377, 565, 1716, 378, 2103, 2758, 2687, 
        2779, 2104, 2688, 2780, 2105, 379, 1717, 566, 380, 2009, 1097, 567, 
        381, 568, 1718, 382, 569, 1719, 383, 2106, 2759, 2199, 2107}], 
       Line3DBox[{2109, 2306, 2307, 2816, 2108, 2310, 2311, 2845, 2110, 2658, 
        2312, 2659, 2313, 2875, 2648, 2599, 2600, 2598, 2710, 2874, 2597, 
        2315, 2601, 2604, 2603, 2818, 2317, 2602, 2318, 2111, 2819, 2320, 
        2321, 2112, 2821, 2324, 2325, 2820, 2113, 2328, 2329, 2824, 2114, 
        2332, 2333, 2849, 2115, 2660, 2334, 2661, 2335, 2876, 2649, 2607, 
        2608, 2606, 2337, 2605, 2338, 2609, 2612, 2611, 2826, 2340, 2610, 
        2341, 2116, 2827, 2344, 2345, 2117, 2828, 2348, 2349, 2118}], 
       Line3DBox[{2132, 2351, 2418, 2350, 2829, 2131, 2347, 2417, 2851, 2718, 
        2130, 2346, 2416, 2850, 2717, 2129, 2343, 2415, 2342, 2128, 2716, 
        2784, 2414, 2339, 2127, 2715, 2783, 2413, 2336, 2126, 2825, 2331, 
        2412, 2330, 2125, 2822, 2327, 2411, 2326, 2823, 2124, 2323, 2410, 
        2848, 2714, 2123, 2322, 2409, 2847, 2713, 2122, 2319, 2408, 2846, 
        2712, 2121, 2711, 2782, 2407, 2316, 2120, 2709, 2781, 2406, 2314, 
        2119, 2817, 2309, 2405, 2308, 2352}], Line3DBox[CompressedData["
1:eJwNzjdOAwEQBdChIlm0SFAhARYV4QgcAYlsDPgAUJic70IoiSbnnHOUoIKL
8IqnPzt/tLsVmf6mvryISJMpiPgujPhhhi+SxRELRRG9ug/Pn0wzb1etezf3
6F7lG1OU50e8yG77J/nMJI88kLa/l2XuJuQdt3TZ38gG753z/nHzNVekdKXu
L81jXHBOp32N+1PzGaOccEy9fYf+0HzECAdU2e/Ldt2u3GOYWd+s1O2Y23Rb
cpsh6uw35QatunVZ4n8GZY41WuxXZK3bVTnAMks06xLuF81Z/vil0Tf/AcXv
Of0=
        "]]}}},
    VertexNormals->CompressedData["
1:eJx0fXVUVd/zNlgYhIGt2IWtiAEyKKKIKHahGNiNYheKgd2YYIONEgbiHQQB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     "]]},
  DisplayFunction->Identity]], "Output",
 CellChangeTimes->{{3.460678066198228*^9, 3.460678082541978*^9}, 
   3.460678135823228*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 5:",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" Composite three-dimensional representation of the principal \
dividing streamlines for an ellipsoid with semiaxes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", ",", "b", ",", "c"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{"1", ",", "2", ",", "3"}], ")"}]}], TraditionalForm]]],
 StyleBox[" and conductivity ratio ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Epsilon]", "=", "100"}], TraditionalForm]]],
 StyleBox[".",
  FontFamily->"Times"]
}], "Special1",
 CellMargins->{{36, 74}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True,
 FontSize->10],

Cell[TextData[{
 StyleBox["Because of their tangential nature, the flow paths depicted in the \
Figure 5 are approximations to ",
  FontFamily->"Times"],
 StyleBox["dividing streamlines",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[", which delineate flow that passes through the ellipsoid from that \
which bypasses the ellipsoid. The full set of dividing streamlines, i.e. all \
flow paths tangential to the boundary of the ellipsoid in the direction of \
regional flow, define ",
  FontFamily->"Times"],
 StyleBox["capture",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" (upstream, integrated backwards in time) and ",
  FontFamily->"Times"],
 StyleBox["release",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" (downstream, integrated forwards in time) ",
  FontFamily->"Times"],
 StyleBox["zones",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" for the flow [see Townley and Davidson 1988 and Nield ",
  FontFamily->"Times"],
 StyleBox["et al.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" 1994 for a hydrological context], and may be visualized as ",
  FontFamily->"Times"],
 StyleBox["dividing streamsurfaces",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" (see section 3.1). Note that since the regional flow gradient in \
this paper is independent of position, capture and release zones for any \
given ellipsoid are related to each other by simple inversion symmetries. ",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3  Limiting Cases", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["With the analytic expressions for the general potential in place \
it is simple to generate expressions for limiting cases of the system \
parameters. We first consider the behaviour of the potential solution as ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]]],
 StyleBox[" tends either to zero (a perfect resistor) or to infinity (a \
perfect conductor). Then we move to different geometrical limiting cases \
where the semiaxes become ",
  FontFamily->"Times"],
 StyleBox["degenerate",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontFamily->"Times"],
 StyleBox["i.e.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" equal.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["2.3.1  A Perfect Ellipsoidal Resistor", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["For the perfect ellipsoidal resistor, the conductivity ratio ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]]],
 StyleBox[" becomes zero. Due to the simple dependence of ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 StyleBox[" on ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]]],
 StyleBox[", evaluating this limit presents no problems. In the following we \
calculate approximations to the dividing streamlines for the resistor and \
display them on a contour plot of the potential on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane, for an ellipsoid generated by semiaxes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", ",", "b", ",", "c"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{"1", ",", "2", ",", "3"}], ")"}]}], TraditionalForm]]],
 StyleBox[".",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
The dividing streamlines are approximated by the following flow path \
calculation\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
FlowPathPERz = 
  RKParticleTrack[{nvx[x,y,0,1,2,3,0,1,0,0,0.0001],
                   nvy[x,y,0,1,2,3,0,1,0,0,0.0001]},
                  {x,y}, {0,2}, {t, 0, -9, -0.1}];\
\>", "Input",
 AspectRatioFixed->True],

Cell["with the full flow paths generated by symmetry:", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
FlowPathPER1 = 
  Join[ Reverse[FlowPathPERz],
                FlowPathPERz /. {x_,y_}->{-x,y} ];
FlowPathPER2 = 
  Join[ Reverse[FlowPathPERz /. {x_,y_}->{x,-y}],
                FlowPathPERz /. {x_,y_}->{-x,-y} ];\
\>", "Input",
 AspectRatioFixed->True],

Cell["The graphical display command is then:", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Show[
  ContourPlot[ u[x,y,0,1,2,3,0,1,0,0], 
               {x,-5,5},{y,-5,5},
               PlotPoints->20,
               ContourShading->False,
               Contours->20,
               FrameLabel->{\"x\",\"y\"},
               Epilog->{Thickness[0.005],
                        Line /@ {FlowPathPER1,FlowPathPER2}}],
 ContourPlot[ (x/1)^2 + (y/2)^2 == 1, {x, -1, 1},{y,-2,2},
               ContourStyle -> {Thickness[0.01]}]
               ]\
\>", "Input",
 CellChangeTimes->{{3.460678181510728*^9, 3.460678255995103*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyEnXm8T9UX96+Za7pTVMqQVJJC+ZWoczI0I1ODMqQJqTSokNJIRZQkESqN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    
    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0c8rH3Acx/H3Ng5bze/5MfPrpMhQJnPAYQdzoORHUyJOvoXDUC44mrLD
rPzIsL9gipNykQNHnCXccdP8KA+Hd49eT9/6fvQtGRhtH3kREZNuOCMi/UNE
V1FEX2ZERUFEP7PzIv5lRVTZQ3YlE6zmjv6J3+0ajrGWu/pnTtl1nGY99/RG
ztsN/MkmHupfuW43c4MtPNa7uGV3cpu3PNW/5Ee0ee+B9+3r5zkRF+7Sdegn
+pF+ZV+7G9etn+tn+n/7zt27Hv1Kv9Zf5ka8ckmuV3/QH/W3dopLdf16wvc/
eEdSYcRrjnvXG04w+Z3/mTn2FHM5wzT9B8vsWZZz7vlz+gIb7F9s5G8W68ts
tZfYxhWW6n/4zV5lD9f4Ud/0rjm/4YD2Vxvk4nu/l789AWiiRUo=
          "]]},
        "4.41`"],
       Annotation[#, 4.41, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0M8rHnAcwPGPA2oceJDnwchNa0paKBfODlgtv2XLmW21DQd5KCUHLsqP
A/YHrKa4iMvagZsfB0cJV2aXKR57Obz79Hm/v4dP3+oPo29HsiJiBiOJiERF
RBFKUxEpJHH0MiJTFvGEBnsTGnHG7xZ7Xx7RUxXxpYjnvpoD+r5WpfVqU1yz
ljYntV/aK61fW+BatUVzTTvU3mhD2ibXpn03f2gnWrM2rG1zXdqO+c+8R4fb
O3Hg7W/+sjTiCtd4x5/yx/wf+x3+opu/4M/5B/sjMujjb/hbPjsZkYNcDPKP
fIYvsBcigfd8dqV3GHPLN+S5d9zMN1/4v5wS/+T+SfenuLRWZhZrhdqEltZe
c/Na7fMfakltWpvVWrglrdWs16q1RW1O6+DWtE6zXavRatyzrm/gI/cZn1DH
/+S2sGxfxQr27P8BsytLPw==
          "]]},
        "3.92`"],
       Annotation[#, 3.92, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwNzytPHAEYRuEPRYG0AmbCZZarIyQQQhClKGorygoSQstlfwArgBrEJrsC
gwFRAwhaPIImOFRTAYqbwEAIosVwSSiS5REnX95zZjcz3YVifr4mIkooNkYk
uYgUba0ROWQ4aReziBq8tz9gBBd8wqWYtmcxg0v+Cl38VGdEuSli1K64Jf13
EtGnfdXWuDFt3d3UjrRhbU77yX3Sdtxd7Uy7s8/de3efP272fjhF3nsfeu4P
/9f+h1tM8Of8Kf9k/8czJvkb/pqv2tHiG/GFf+Af+Td2Heoxw7/wVb7JTpCi
wDe0Rbz1Xpmdw7sOv005t9b95ptKvinzTNm759zUbxq1Za2s9XOr2oDbpbVq
FW1FG+O+ax/dIa3H/3ZjTV/HZy6PcfTy29wPLNhLWMQgv8f9woa9hU0c2K/U
lEa5
          "]]},
        "3.4299999999999997`"],
       Annotation[#, 3.4299999999999997`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0L9LW1EYxvFXsIMoLVRNYmoSops4VKlOSRdLNxe1q2DSH5t2qg4iSjJ0
CQgRi4NNwLb/geIgOBUH3dpGCaV0rpMuddOPw5f3Pt/nnHPvufnS0sxiR0Ss
4f3jiMRgRBKZgYgcsviRieh8EvEABfk5imjzCS6JBbmMEv7yeW4I6/dr5Wpv
xIbn730Ro/x8LqLOTem2zF3dmW5SV9J95aZ138wi19IVzJe+7cjaQ/5nMuIX
WpjlT/kT/p98iQv32USLP8d/7gZtro63zn+Hhr1N/Oa2cWXtNbpTET34w+3g
lou0O3NJpFC2r4d76PsychY5vOEfZSO6+iNq7vP6/p9aU/G+rJmwp1e36k4V
/VOuphsz87q0rqr7qHvBfdI94ycxgWFn1/VbmJVfYQ4j/B73BR/kFSxjnN/n
DvBZbqKBY/kOzQpFeg==
          "]]},
        "2.94`"],
       Annotation[#, 2.94, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0DtMk2EUxvEjNaHGQAuitHLXLmodqjFQoyEBjUwOBLwxmHhh1MHJRBdt
GdloDDGOFLeytHFg5LKwGTVxAYSBsOhIiMYfwz/Pd57nPee87zfw5OX4i2MR
8QGN9ohDXDsTceV0xFBnRBHXMc9rdEW8ORvxFq9RVS8g3xtxX/0A91DhzSHH
H1IXMYgZXhnd/B6c413tiJjtsY+W+syWd9jdKevnzcj6jjJaRpu+NKa79Wci
BtCPVudb8NH9N5F05q++ZvqPNsy8bX6dTnrL1Cm+bF9dN6uBFO+4t7bSTTO3
cNHOC9jJRtzU/0t2g27TkrknaUH9yndBb8q5NFb1ruCEPMFP0iU7ati188Du
Cd6Eu6ypx8xYp3vmpJ25pCePmnzWe77hh/o7vuhbtmPMuTv4436/sci/S6v0
qXmD/uWGeZ+crfBuyeboY9ll2e7Ru/BeXsI75PjnscV/rp7GM2R5Gfzkj6hH
MYwkrxlf+VPumvBds7OJLtFHvIf4jP/XeFLT
          "]]},
        "2.45`"],
       Annotation[#, 2.45, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV07lPVUEYhvGxkKgli6yyxCWgiRYCBYKCCRjtxFiDNkIBaKdsbkFwYVOB
ixEQFCKroo1RLhjp8T/QBBNEG41goxb+bvHkme+dmW/mnHNvzvmGyvotIYSf
eBMfwj9MpYQwibG0EEYxL/uNLlknmmSNmJb9wIHMEPKSQhhPD2E/9+8MoQ8R
9RHrilGEDnU7Mq3frd6Dnl0hdCM/MYS2rBBazSfpkWxNKlKQr1d8cgg5sTXG
BcaFWHX2YfUO6y9khFCDWpxV19lXx2/V77CAL9YuchT15hvw0XgFWQme0bNl
8yYXuMsGF3KmbNDZS+75iN9zrmyRI+oFHuBobN6dJvQbxzOccIcy51TwTW7h
69zMNzhDn4jxE+NBHuU+HuEBHuJ+Ho7Vej/VcwyjOC4vlZfxNW7iVm7kq5ym
913j+8b3+AF3cC/f4W6+zT38UO9hPYfwGCXyY/JibuEr3MSXuTn2XfSeNn5h
PMMv+TnP8RTP8CTPcq/eg3pGMIAieZH8onf22jvr4nnu5Fccp3et+Srraria
f9m3gU0syz5gzPfM8n22cibH8Xa/i21IVP+xL4H/chJP8Lr9X7EW+0bqKX3O
cIXf3Sfnl/NnntNrFqesO4lFPaNYwKT7fXPP71jHivUjqZ5NXq6uwCF9DmLN
+Ja5drRhn2wvVuXV+p/Dkv3p+uY6Jw9VsibvbBmV8tMos7cUl2RRHJWVxP4T
smzE6fkfz4+QWA==
          "]]},
        "1.96`"],
       Annotation[#, 1.96, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ltMiGEcx/HHIZvNYVOhQlMrh81WF4arbMJFjjnbsjmNC7IlF7ZkjM26
obFxpySSuGg2xUYsqejgkByHMBtSrDkMm8978d33/f/e5/9/nvcwedOu3PxB
IYQB1I8J4R9qxodwEWcTQ6hArewHjsmOYr+sGDWyfhTKdmO9bB0qZZ+QNimE
lPgQTiaFkMqlY81AiTrduilIQ+nEEGbGhZCVbLZ7c3ms9SMnhBBvfR2uohUD
yI4NIUlPIuLUceNCiMUC+Wp1HieoU1yn4p2zzDBziZlF9mkw9xZuo1x915wz
3MzF3OlM+zjX+dfoWcareTl3RPP09eAtKuRV8pzojFyr7pP341u0Th5j7z75
UO7nYVxi/hD+qh7EvTw4svW/9f3CT1yR15v71/v9E30XZ7yEy6jBU2d9hiPm
fXD/PXqwV90uX+td3Oc96m75E9fdOKx+pH6IThSq78lXWd/KBeo2+WPXXTio
blE3o0Vdbe8LqEJMQgjPfbdG56yPvptsFEZH5/M8HfI78nZu4k6eZ59NvEG9
kfO4y9pXnvklXkTfRnbevWz5IS6OeuUP8BBt8i/y1/LP/IZ7Od9ZK+29i6/z
Cb7GxznomeU9p9t/hH9kCp/TU6a3kk/zdPk0TEW3nu96q61byg3W3ERd9D1l
i8xajBzM8Q5mo1NPuXdyyv2FespcZ8oz8FG9xRm2osm6ZHtkeJZMbJYd8K+2
Yqd8B7br3YYiWSNWylZgviwbBbIbmCvLQqosBcPt9R8PTp49
          "]]},
        "1.47`"],
       Annotation[#, 1.47, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ltMz2Ecx/FvzGGruXAspUZxyebGxijnDnIRFas5poSVG+5suFBtLpxv
uGFjTmVzp9wYiQ6E1E1S2mIzkcOFK17/i/c++76/3+f5P8/z/y3cV19SlxQR
Q3g4OyInLWLvrIi18yLWYT1SMyI28Yf5UnUZ2mdGnEAtfwh1XD26uNNo5Jpw
hmtAL9eAmrkRq+y3Etn8a79Zyx3EXdxDxZyId3INclGp7pP3rdmdGbEHKQsi
krHCmSbZ5yf3CxP4g9+4Zu8S67aa6TH7ClMwFcu5J2byUYDNKEIh7lhXb12r
mW7ZJo/KYf6T/igW22MJivX69aq4A9iPGlSjxfywHMEis9koMj9gfovMUc/w
RinulYwB93ybbg/ZkRrRiS48M/+Cz+W71XnypTqD75PV6jd8H96jne/kN/D9
6o2yS53J98ta9Sg/hs94znfzBfwXdaHsUQ/Kf84eWf57eSQBN6B3mbuCS/hh
TUfijIl76Y/I4sQZ5VM5aP4DprnrdOS5e6/edvuVYhvKUYbb3izVnmkI75OE
pebHzS+Tk9WT8NhsG3Zx5YlvI/HW3vAjhnBVnc9n63/32/3OMS6/4a/z3lC3
6j9CAxqRwTXpp8sse4/5Xq9j9XzfInZYtxNfuVuo4CpxjDuOCa4ZJ7lTOM9d
wEWcdaabXJVzNatb8ADn+P+4zoqY
          "]]},
        "0.98`"],
       Annotation[#, 0.98, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0rlPk3EcBvCv1yBeUaTl1IhigMRBnVxAo6jRCRxEkYXESeKVaEviFa8A
xsF4rCbU6KjApOLxB6iJ4CCikxR0BG9s0U+HT558n9/x9m27puNYy9E5ETHE
4MqImrKIjuKIHcmIJnZSVhmxS9+p329u5QDV+iP6lP64+QQnqdf36q/ou809
9LJJv5k+axn6dBlqV0fUUc+1FRH5iohZxkoiZmSOvzxMRCxw51B5xDMe85Qn
5Kh0fp49FXK+rJKv3DGyKuKNfCtfy2G50T37rH93rkX+kFN8Y5o86/SL3bNW
LpE18r3zE85/kONyVGblHvfN2vOPpeTJUe791juXKPTePSmXyeUyYa2EBnec
Np+inxRptuvPyjMMcI7z7NZfljfde0kOMlr4THz2PWUZZ699v639KTyTX/xk
hmpni+RCn2WRLJLD9n9yxzs5JkfkR7nBuzXb/8V3skV+lVkmmaDV+UxVxD2e
m1/ygkbnpqw1yFJrSeaaH3hW1u98l1r76thaGrGNSV2X9TSN+ib/yYP6Ng5x
Qd9e+M30KXOaLq7qL+rb9LfMt7nDdf19/WH9I3M/A9zQ/wfAanWC
          "]]},
        "0.49`"],
       Annotation[#, 0.49, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0rtLlXEYB/DneJqCKOminqyQoiG1JIW8RDTkdUrdQi0SXLoNqRzThhR0
EB1cJP8Au7gI2mXRokCpIDIbi4YEg4LModSG08fhw8PzfZ/n/b3ve07B1VtN
NxMRMcnsvojjeRHteyNqcyLqaSCVH1EnvyG/pG+hlaPy6/K0/La+i24K5cPy
QfmwfoRRPhy0dziijcdmpkiamTsQUbE/4oy8gnJWeZaKeM5cbsRDswmzzWYv
HopoZNoZs8xwzr1/mV0j9H/UyiMRJXZ2mP2r32DetZe8IGNng0126QvM1Zt/
5Ywq55/ltWuLLFDsHTpd+2Tms3qCIk7Le9UV+Re1mFOUyvvVdflXtWR7ljL5
D/f7yU7nrqlVnrXaXL5n+K1fJ+F5k2RxTf9NXSHje2yq5XaK7GR8my39P3aT
zR6OOWtBXdx+bztL6kk7WXYe2fmoXyaXFHl8985penhj5i055t+5V5Pf6IK8
hmree6bzdsbds8Z/p9UZl7nCPXttrjXL7+j7uMuQfEDeIh/X32eCUfkDeYd8
Rv+Ep4zJ/wOvEGPq
          "]]},
        "0"],
       Annotation[#, 0, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0clLVXEYBuDPbFcrTfOqIKJgYBgqgtBKF06bUGoVDohimF5BbaFtCprp
KgiBEOXWwI1RK4PMAf0HQlTMjHC2TYPbHhcP7/ne+51zfpdT2DnQkkyLiCkq
syLe5UbcuRTxISeiR06br+kfyzbzpL5VPjKX6jvkLfN9/U3Zbi7W18oGc5u+
XtaYC/SpPLIjrhZEjMlm3Qv5nDl22eOefiU/YpWszIgnumy55DnLfGGRBd5m
RPyk2LuKOJ+ISKfK/o7ff/CN72zzxu4OuXYTXLR7gXr7B853yC777PHa7ja1
zlzuHL3O9lA+YFK/RZnrHv2oHOGVbpNS1136IVnn/kE5oV/n5HLEMcvescR1
e//kKb/5yx/G7a6xYXedc86aRqXznvg/vzjkmCNSdr8yb/cz7+3OcsP+lPfn
kOCAfWboo59qZ7grS5y1V1Z4/4rvl3L/M/e/9LynZ2me1yflqHlYPyL7zZ/0
TXLAfFuflI3mj/orstvcoO+SJeY83/g/rtpjsg==
          "]]},
        RowBox[{"-", "0.49`"}]],
       Annotation[#, -0.49, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0klszWEUxuFTpOhKau4sodUFEb0x1IZeY9QQEVok0oqpuG1VWNjbtGnt
TSUSVOyQkqDVjZW2MXUQlRAJvZtKDJEQz1388n7nPcN3vv+9C+obd6WyImIA
LbkRBQURe4sjjsyMWFoYcZSWz494OCsiJz+iRq6Jt1yuAtVyW/HeOU8+H43i
ZjThE7+Mtxjt4ovoQIU4NSeidG7EIizEoDvKea/t0YYy3pXZET/nRby11zs8
le9BL67KDfGGMYJvvN9qf+FJkVpMdf80JOz8Un63nmr+dmxDlztX81dhHCfF
nfSPGcO0Tv2gXZ+Je9DHe057Mcqvlx/lZXvTDLrJ93nM++G8FuvwRTzJflno
13dY/ErvHjtNzuydeQd/JDMTH/Q84N/HmPiY/Bv1teqn8NLir/xxpPFR/SN+
Nxq86YR80h5/5f5l5vHGUOw7lGCzOZ/1pNQ18U+jGfe8PcmvQhrnxTfphBnX
6SnxIK3EGtwV79d3ADXYh1q8wAp35LhrOgbQjw16NuKWvu/u3mLHCZrtd65U
f8Y5wct17vOWs+a08M7RIe+vojsyb6M76Up9nf4nrWa2oYjXqq6QttEOXona
9swZyTw7YD1K+Zd4l1EnPoR6LOHf5t1Bp52v4aB9L8gtM7eb32rH47wbcg20
Sy4h9x83An8Y
          "]]},
        RowBox[{"-", "0.98`"}]],
       Annotation[#, -0.98, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV01tMz2Ecx/GnC0tygUKlf8lGyNzYbKg2uaWDuXRldCmHuHCjZqixOdvY
uKAyq8ZmNnKITaZymEOmlA2V1JQpReXw+l+89/59vs/3eZ7v71f/jC0lG7fH
hBDGUTorhEhqCGlYmhzCMmShLRJC/LwQpmODXIB8dKmnqkWwSy7FbiyRi+eE
sGBuCBmYjyeJISxWe+mOClTpq0aVtWrUINe9A85cbX+O56z0ELJ5TUIIjfZm
8xzrs3F3dgitaSHc52a+xy3cyE/5AT/jInsy9RfyJue9TwnhjFk6+Cx3crL1
POs/3LGW48w17PmRM2LNtd7zBvyWe8zTjavOrpKPOfNPdFb7/vJx+Yb6Les/
5VF02Dsmf1Yf5W7+xTvdn6I/xvoMM8zELAzJiZyAJn139J/QF5HTMGG9TS3J
bIWeixCLCb1f1Me5jyf5gDveRf+G5nueFMJbbpcj+p95973W29U70YVDco/1
Hn0f5F7uldP1v9C/z3q/+jcMolIejn4vfUPyCI/IY+oN7r8Zncc3mMAkepxT
ql6ivpt38B7Ose+7tYfyXO+V77kA/+QB+/rxFVfkWv2b9R/k/fJr9Tdowyt7
htQ/qg/yJ/4e7TPPNd+ujFu4ipv5Mk/zbeMRizhMxRQzrHLHUz01elq5mrt8
gyOcq+coX1cv50fubkKCPY85kQv0FCIf5f6ny1AS/W05Y6U9eb7XOvT5PVzC
SbOfwiIzn9O7kM/zabVM73DB80Vstb8Y27BcvU6tHoflSlRghfpttQbUyvWo
wwP5P+QFpp0=
          "]]},
        RowBox[{"-", "1.47`"}]],
       Annotation[#, -1.47, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV09tPz2EcB/DHBUUq/aJ0Li4wkgsbd92EzQ0rNi71ByCbuY0ooqPO5TBR
kU5UGJt1EBc2hyG33NnKjVMj5vW7eO/1+3ye7/N5fr+nb3mlx4qPLgkhLMjJ
SAg5mSHkSn5aCAWyVWazQkjICCFR9qsPSIlkq0tTmBpClmTKxOoQNui9NKtC
GjzXKHXW6uWt3gXp0euNRq9Pbkuhc+ecNS8lUiz9yc7jXY55/qP5hc59syaE
D9lqmZUS6xuje3gwJ4Rms1pkUe+zPb/5iX84ae+QtUEZkF69Htlnzov0EPLM
mF7r95szxW2M0XvmmWtmTPM6Z7hTf4pX1RO8wsnoPHew0r5vzlrqjO9cxnKe
d84ZVvI0q5hmTg0r1ZdYxVpW8CLP8QLPspq95ieY/0Mdz59MZA1brNexibVs
Zob5nbys7mATu1jPdjaylQ1sY5/5Seb9Uq/iAiPs4E3rXbzBTnYzK/r34bB6
lCMc5wDvc4gjHOQ93jJ/zD3Vua9R1nOcm8x5xEb1AzbwIZP0n7q/Wt+hzIwi
nuCc3rx8lefmzki32XnWY5nL5Yzzfq2QWM/9tS+G/5hqfZEpfMV39r/mex5m
sr17rUUYb/+h6O/yuVFvjBHPxemd8k6W663zfat83/VMj967HHdWmWz2bu3Q
L/JO7ZIv/g+6Zbf+HjmiVypzer3San6b5Jt/x/wt7Ge7XkH0Ln0ekmp7a6VG
tus/1nsig+phGZIJ9X/4f5or
          "]]},
        RowBox[{"-", "1.96`"}]],
       Annotation[#, -1.96, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0T1IllEUwPHjqBTm+5HmVwluiUkZBJI4qY26WGEGqdSQiUG+YmCLIJiL
Hwj62uYgfg0a1SCIDkFFkyA4qNWm0JKGU9DP4c+553/PPffc56l40tv6Iici
ppFJRLRfjniET6mIiyURH8XdsohNe/1ouRLRio7CiMf4zA3hFdePDDeA79ww
JrkpjHMT2OFGUVsascDPJCMW+SUso4H/wK/wW/JtnLr/L06wZ54Gc3VfjdhQ
c597gG1nttBkr8/8Nc7dQDWOnblbHlGPWf2zKFFTjH/cUTpijVtHnp7hTFgn
9EuiAG18Rp+b7r1gPXL+fcRb8gHrh9bXzVGFtPoULnE5eu3rf+SeA/FYvObe
CnyT/zDvL/zEV/mB+EU8FN+ryVX/3LoHr/UeRL77EsXmUJe0n0YKlXx1kXej
Bi+9oUrdHb5R3oRmDPLz/kGzvXvo5Lrwm1vAU+4Zhrg3+MOt4i03hiw3hzNu
HVlzTuk5iTrvvW2ud9wcNvAfQDpWpQ==
          "]]},
        RowBox[{"-", "2.45`"}]],
       Annotation[#, -2.45, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0LkvZWEYwOHXVhJrrEOmUEosUSjR2CoyEyOxBpNRIFG4lgSFmsRSSOgV
CJmESGYyyUxCMfwB6BRmGo1YKjy3ePKe7/eek3Pu/Tg00TmeEhHznOZGvHJS
FHHMUUnEId+1F3a0bVa1FQ60B5a0Rca0b+xq94xqI7TmR7Tpc2UR7c5tyUaD
XqVP6XXOtdRQqc+URmQVRCTMTDPPfTn6/IeI7OSsiBi3e3OdYRfmpF266xF9
mLTyiKfiiGce6df6SNX/Of/nji9aNyn6tfMNV3RpnYR+4XzJX3q95zwv4qtv
aLG/9e7f+k+tx+6HOWrXZHdl12hem83mn0L3su+eY880+u0HyTN7bOm7er2+
4bzOGpvaBsv+10tmtRkS2jQL2hmD2gCftU8ktF90aO3UaNVk+5Z3OMRLPA==

          "]]},
        RowBox[{"-", "2.94`"}]],
       Annotation[#, -2.94, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0D9IlGEcwPHfNbRKnlZ2arg0RUPZDY1t/rkbJDBMIk6oq6QruKHyhENB
EFxs6ASHmm/xyoKsoQItbbmxhtqCRAeH6rgm+7zDl9/zfL/v8/K870ChNHYv
FRFVvOuMOMTbkxEbeHUqYh2vuX94zj3DE24ZDe4P5rk5THN3UefmeiNuc0Xc
wnBXxIhW4fP2OYziEn+OL/NZ+4sYxBk+k7yPv4OO7ojj/RFpfrYvojOZpyNK
GRfXjnr2CPdAS5kPtZta27rdE9FKu5/21yxrN7Tf2p62yxW1X+Z9bUI70H5o
37iC9jU5r13R9rWm9oW7ru0k57Uh7ae2qX3gJrX35jVzSf+utaxHfM/nExGf
sIU1z7xx5jL/0v4FGljl63yWX7Gv4SkW+Rp/ll/wr5uo8DN4zD9CldvGFFfA
VW48adxH5LkcLnDncczd/wNkN1CQ
          "]]},
        RowBox[{"-", "3.4299999999999997`"}]],
       Annotation[#, -3.4299999999999997`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0T9IlGEcwPHfURBU03Wi2VUEnTdJi2HS6FYHdwkF2RCaItWdUXCDHXcN
alRrDf5pybUlqDuQWgqCThtaU3Fz6M/QIOgJVp8bvu/z/r7f54H34T0zem9o
MhERNXxIehyzdkW8R6M7oo4Gv4cl7hVecM/xNB3xBI+5WczgWiqipE3zRfNd
3MFlPsdX+SvmAvK4yJ/jy/yA+QL6keXTfJHPmnuQQYo/ciriKA4j0RFxyL6D
/IOTEQesU6cjJk5EtLy3jkfsulNJ27GWtRFtW/ul/eRuaz+s97Ub2h9tU1vj
bmnf2+e1q9pv7Zv2lbuprbbPa5e0LW2f+4e/2OiMWMdHez47k3OXFXMTX/CG
X+YH+br5Hd7iJf+a7+cXzQuYxzN+ju/lH5lrqKLCV/izfAZN/2qcH8Mwfx0P
uU8ocHmc5/qQ9N3/Ad1VTcI=
          "]]},
        RowBox[{"-", "3.92`"}]],
       Annotation[#, -3.92, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0T9IlHEcx/GvidEkQZqpSdygmIM4meiNbp6LiQ5FHBJ6nPicf+AGOURF
UGtwchA8F2trcbFsbGgpBWcrNx08hwYHb/Ll8Obz+7w/vwfunic1URhJaiKi
hKOGiHdPI3JPIuqbItqdO5B6HvGmOWKOn+SnkEMHX+JL/LK+glV08zv8R35X
L2MPffwXvswf6l/xDYP8d/6A/6X/xjGG+Z/8D/6v/u/etUZc+p1D8kJmZP6F
++5k2yJO5Klnrm1jtsR2xr23/ZHntv+2t7Z52xWXt1VkxXZjm7AVbbdcYqvK
qq1qy9kWbXXOC7aH8lFLxIPGiFlbrZyTjXzns4iX6MKM/9LmXiffrw8gjSLf
w6f5Ef01RrHED/MZfkZPUMAan/Dj/Lq+gU184Lf5LL+vf8JnbPF7vuE0/9j7
63V+hbTzHd4ZSYM=
          "]]},
        RowBox[{"-", "4.41`"}]],
       Annotation[#, -4.41, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVkTssQ1Ech38SCSYR1LtCiHhFDCoSJQYREvVIqAhDiaFt0sttowlpDHSg
nQ0GjwWLxUY3BoNHG5sBHS3t0MFyDb47fPmf3/e7Jznn3JY1Yz5UJOkQuiql
KYfUzqyokdqYk+RotfTaKL3AM2yTd5zSR4N0XStdwSX4qqTjeinBN0lyAo5g
CW/g43iTvAWbMI334PfwXvIiLIAb34+P4kfJI7aDTrwTH8L3knugGxz4MGeJ
gAnFnK+M70rxkSaphLnbLPnpLNZWnfTH3Qw6ixmlW6f7pcvR5XFBuhwzTLdK
V6DL0n3hNug+7f10Xro83TtdBuejS9v76Wbofuw7MudgFrK86zc88s0Tezzc
JUNOwxvc4lP4cXyKfA93cIq/wQ/hL8jncAZJ/Am+Dx8nH8A+xPAxfAc+SA6A
H0z8Cv6Bs7j4h4O81RhndTEHyGn8Mms3/30YytnTyp4J1gXe+h/nMVHf
          "]]},
        RowBox[{"-", "4.9`"}]],
       Annotation[#, -4.9, "Tooltip"]& ], {}, {}}}], 
   GraphicsComplexBox[CompressedData["
1:eJxdmA1wVNUVx9dIpZ1pKG0dZ4DRSJJGytTaAqHpFP3TwemMrR0JiNrOtKUy
Cs1EtDqYYEoRbAlmMAKFDgQchSmmbPmIEcOH0JNAjcRICCxuEFjYfHST/Q6w
hphk93X3nf/tzL6dO7PZzdv77j3nf/7nd9/Up59f8EyOy+XKv83lyrw/ntey
atytXTiw+nDKN2KJy341HNd3V3Nj4SObCx/ZLfeWrpt9IP3/ZeHg7yp27Zat
N7/jeSX9OdH54Ucr3O9JzaLlRdMjluy2r2+Ug6neSDCU/nzY9bfDrvflndzg
27lBSz6de3zB03cekznngss/u2BJuOm5y03PfShfS7oW1XZasmZiUdVbU05I
R+Kr35v3iSW//Mcb5dG8FonmbZrd+IEldfb8JyXxzWeW9botmVgyfPT1rlNS
8JM7m57dmf5/6aStpZM+kluVb6aHJf/OTH+5VXIjdy+8vcqS9SeWlC2On5a9
azJ/WNJr379dzt6ckx6W9FS3jnQ+dVaa279b+eOvWHLlhf8cum9GpxS8++Cm
NYmUvDUh9M6EUKcctudNyd/t9ZyXaPIHBbI3JYWLt5TdOOKR4pVXfnVyeUqq
pPRlKfXKG42j6ZGUY/bvvFJwdUPlzJ6k7P/jA4MHJ3fJMt/imj95k/JZ89Uf
Fjd0yfLMZU1JuWav77K8fNt7e2f1jclqb+67p5f6ZF/riWYpG5Pf3l718YXm
q/JAcUPFo7ljkmOnzS9dj09+Mfb+qJzLub8z536//OtoXXqMymPjV8wfv8Iv
V+x5R2VhJlxbu2WHfcGIbLH30yPF95zJK58zIr3fj/Wkh2zf2ZYeX8op+9Ur
P9+cufBL+cu8kvTok39u+CQ9hqUo8/PNfXLP5PC8JauGpfjJl9Ljv/Jx1fH0
uCU5z35j24OLA3LE3taQDP3h7fQI8H2I3wd43RB/1895vuC8A7xPgvcd4DoS
XFeQ67zJdQe5jxvcV4j7vMF9hxiH64xLmHEaZNzCjOMg4xpmnAcZ9wjzEGNe
IsxTlHmLMI9hWX/+aPm6aVH59p6XPv96aYh5jjLv/dRBlLrol/aHqi+M641S
NwHqKEpdBaizGHXXSx3GqMse6jRG3fqp4xh17afO49T9NclU1eq5cdbFZdZJ
nHVzUezw1cUlf7Cte4bfwzqMsy7PS/JcatnqQ3HZWP7w7Pwp5+SJ9ikF2wbi
EmsrW7lk3ClZ9fCkS0dCcfrESemefmn7+XBc6qsm//5ofQv9Z5Dvzcf3pLaM
LExfv1avx5Ocr0PnQ4r3e1XvB7OeGl0PzHq/peuFm/tZqfuB2a9H94uTjMcZ
jQcKGS+vxguOeCLGeNdqvDGb+bhb84G26U3T+n8Rk3u1LvAm8/eC5g+fMr+N
ml+Y/Ndr/mH04VF94HXqJ1f1g0rqq0v1hf3U3yuqP8yiPh9VfeJz6nfMyrzi
2Ed9d6i+4dA/drI+5mt9oIT1s1HrBztYX91aX3DUH9ysz7Van8hn/eZr/aKN
9T1T6xuO+scw/SGh/oA76B+H1D9QQn9pVX+Bw39QTX+qV3/CafrXz9S/EKC/
bVN/g8P/sIj+uF39EU/QPy+qf8JDf3Wrv8Lhv5hPf56h/ozX6N9u9W84/B13
2Xm9JNV2npPwsR+Uaz9AA/vFUu0XcPQTVLDf1Gq/QRH70SztR3D0K+xhP9Nl
pODL7nfwsR+2aD+Eo1+iJrufwtFvMdWuu1P0DQuO/o3Hsvs7VmX3fxg+yLhG
XqeFjmx+wK5svoCDPzCUzSdYms0vMHyzzyqpOpb+vFV5SMhDcPDQ3Bf1epCH
cJ/OBzOfV+8Hcz/1rUaY9byq64VZ70HdD8x+2nW/IA/h1xoPmHj8VOOFGONV
Q1808Zyo8YaJd5XmByY/6nPtMPlr0/zS9ywM275wFmPrPnj+qdEUulQP9MEU
6lUvMHqppc/Gqac81RvIPyhTPWIj9ag+50Uh9epWPdP3kriieofR+0StB6xn
PXTRpytYL3/WegJ5CA9pvaGE9aY+d42+NwryEMhDpp5h6nmB1jvqWO8b6esl
9IM+9QvU0S/oJzB+8lf1G+yl3+TT9/PpR+QhkIcwXv0Mxs9uqd/xfYjfB3jd
EH/Xz3m+MH4K46d63wGuI8F1BbnOm1x3kPu4Yfwcxs913yHG4TrjEmacBhm3
MOM4aPoJTD/RuEeYhxjzEmGeosxbBKZfkYeY5xDzHqUO+k0/pE76qZsoTL9U
XUWpswB1F6MOe6nLGEx/VvnEqGO/6e/Uud/0f9bFNdZJHIYPyEOsq4uGL1h3
HsMfMPxBPsEa8gn5BWfIL+QbGL4h/8DBPzC8ZH4fJU+Rt7CJvGXub3jMrG8q
ec2sv4Y8Z/ZneK+F+/eRB8mL7At+MfHbQ54kb8Lw5izGv4g8Wsv8VJBXC5g/
w7NLmd8G8q7Jv488XE193EVeJk/D8LSb+nqNvD2D+ptPHievw/C6m/r1kOcd
+mafD7HvXzfnBZjzwjbWT4DnCUd9kTMGyB0Jc16BOa+0sn5LeJ4x9X0HzzsJ
1v8wz0M8L8Gcl2bSP9p4nnL4Czmrj9w1bM5rMOe1bvrXDp7nHP5Gzusm942Y
8yLMebGD/rmP50mHv5Izr5I7x8ihPnLpmBj/ruR5Npf+rlybJOd2wZx/67P7
gzj6BznaS65Okrs95PCUmP4U4/mc53eY87s3u7+R+//fD8X0y04+H1jJfurm
84MDyjuYwOcLG/T5A4b5/MH6kf18Aub5hKNfC7L7ufwmu9+LgwdkfzYvyNps
nhAHb8iFbB6Radm8IoZnyD/ifB70P2MhOCM=
    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {Thickness[0.01], LineBox[CompressedData["
1:eJwl1FV4EAQUBeANGDBqxIiN2EZ3N0iIdKdISUuOEKSURkC6Q+luBEFppBuL
TqVUQLoR+Pfx8J/7el7OjWrdrV50YEBAQEYRc2MRmzgEEZd4xCeYBCQkEYlJ
QghJSUZyUhBKSlKRmjSEEU5a0pGeDEQQSVRMDzKRmSxkJRvZyUFOcpGbPOQl
H/kpQEEKUZgiFKUYxSlBSUpRmg8oQ1nKUZ4PqcBHVKQSlalCVapRnRrUpBa1
qUNd6lGfBjSkER/TmE9oQlOa0ZwWfEpLWtGaNrSlHe35jA50pBOd6UJXoulG
d3rQk8/pRW++oA996Ud/BvAlXzGQQQxmCEMZxnBG8DUjGcVovmEMYxnHeCYw
kUlMZgpTmcZ0ZjCTWczmW75jDnOZx3wWsJBFLGYJS1nGclawklWsZg1rWcd6
vmcDG/mBTWzmR35iC1vZxnZ2sJNd7OZn9rCXfeznAAc5xGGOcJRjHOcEJ/mF
X/mN3/mDU5zmDGc5x3kucJFLXOYKV/mTv7jGdW5wk1v8zT/8y23ucJf/uMd9
HvCQRzzmCU95xnNe8JJXvOZ/3vCWmPEHEovYxCGIuMQjPsEkICGJSEwSQkhK
MpKTglBSkorUpCGMcNKSjvRkIIJIogLf/6F3VNCDzQ==
         "]]},
       RowBox[{
         RowBox[{
           SuperscriptBox["x", "2"], "+", 
           FractionBox[
            SuperscriptBox["y", "2"], "4"]}], "\[Equal]", "1"}]],
      Annotation[#, $CellContext`x^2 + Rational[1, 4] $CellContext`y^2 == 1, 
       "Tooltip"]& ]}]},
  AspectRatio->1,
  Epilog->{
    Thickness[0.005], {
     LineBox[CompressedData["
1:eJxdlnlQVFcWhxvZFFtWkUAgIItSNRFxARHUc4nbjEsUFBKDgFKCUVE2BUKZ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      "]], 
     LineBox[CompressedData["
1:eJxdlnlQVFcWh5tdsUFAgUggIItSNRFxAReEe4nbjEsUFBLDppRgVJRNhVCk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      "]]}},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"y\"", TraditionalForm]},
  PlotRange->{{-5, 5}, {-5, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.460678250120103*^9, 3.460678267791978*^9}},
 CellTags->"compatibility-yes"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 6:",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" Contour map of the flow potential on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane for a perfect ellipsoidal resistor with semiaxes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", ",", "b", ",", "c"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{"1", ",", "2", ",", "3"}], ")"}]}], TraditionalForm]]],
 StyleBox[". Calculated approximations to the principal dividing streamlines \
are also drawn.",
  FontFamily->"Times"]
}], "Special1",
 CellMargins->{{36, 74}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True,
 FontSize->10],

Cell[TextData[{
 StyleBox["Since the resistor conductivity is zero, no flow traverses the \
resistor. Thus, if the upper and lower flow paths were calculated without \
error, they would both converge rapidly to the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", "0"}], TraditionalForm]]],
 StyleBox[" line just outside the resistor boundary. Figure 6 shows that this \
is not so. The sources of error in the calculated flow paths are the central \
difference approximation for the velocity components, and the Runge-Kutta \
path integration. These error sources are of third order and fourth order \
accuracy, respectively.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["We may gauge the error contributions of the two approximations by \
measuring the departure of the flow path from the exact ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", "0"}], TraditionalForm]]],
 StyleBox[" result near, say, ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{"-", "1.5"}]}], TraditionalForm]]],
 StyleBox[". The flow paths held in ",
  FontFamily->"Times"],
 StyleBox["FlowPathPERz",
  FontFamily->"Courier"],
 StyleBox[" were calculated with a central difference parameter ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Delta]", "=", "0.0001"}], TraditionalForm]]],
 StyleBox[". The relevant entry in ",
  FontFamily->"Times"],
 StyleBox["FlowPathPERz",
  FontFamily->"Courier"],
 StyleBox[" is:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part[FlowPathPERz,34]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.4826147014136342`"}], ",", "0.3715327431434511`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.460678336557603*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Reducing ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Delta]", TraditionalForm]]],
 StyleBox[" by a factor of ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["100", TraditionalForm]]],
 StyleBox[" to ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["0.000001", TraditionalForm]]],
 StyleBox[", yields:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
FPdelta6 = 
  RKParticleTrack[
       {nvx[x,y,0,1,2,3,0,1,0,0,0.000001],
        nvy[x,y,0,1,2,3,0,1,0,0,0.000001]},
       {x,y}, {0,2}, {t, 0, -9, -0.1}];\
\>", "Input",
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part[FPdelta6,34]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.482614716150475`"}], ",", "0.37153274571029593`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.460678354416978*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["i.e.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[", this result is insensitive to reductions in the size of ",
  FontFamily->"Times"],
 "\[Delta]",
 StyleBox[". We now recalculate the flow path with the magnitude of the \
Runge-Kutta time step reduced by a factor of ",
  FontFamily->"Times"],
 StyleBox["5",
  FontFamily->"Courier"],
 StyleBox[" to ",
  FontFamily->"Times"],
 StyleBox["0.02",
  FontFamily->"Courier"],
 StyleBox[":",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
FPRKp2 = 
  RKParticleTrack[
       {nvx[x,y,0,1,2,3,0,1,0,0,0.000001],
        nvy[x,y,0,1,2,3,0,1,0,0,0.000001]},
       {x,y}, {0, 2}, {t, 0, -14, -0.02}];\
\>", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["The relevant entry in ",
  FontFamily->"Times"],
 StyleBox["FPRKp2",
  FontFamily->"Courier"],
 StyleBox[" is:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["np = Part[FPRKp2,347]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.4817279096482676`"}], ",", "0.04286305654610766`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.460678396354478*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Reducing the Runge-Kutta time step has greatly improved the \
accuracy of the resulting flow path, so that near ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{"-", "1.5"}]}], TraditionalForm]]],
 StyleBox[" the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 StyleBox[" value has decreased from ",
  FontFamily->"Times"],
 StyleBox["0.371",
  FontFamily->"Courier"],
 StyleBox[" to less than ",
  FontFamily->"Times"],
 StyleBox["0.043",
  FontFamily->"Courier"],
 StyleBox[". The initial and final approximations to the dividing streamline \
are plotted in Figure 7, where attention is concentrated on only the upper \
left quadrant of Figure 6 (the resistor boundary is at the right of the \
figure).",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"FlowPathPERz", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "5"}], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "2"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Line", "[", "FPRKp2", "]"}], "}"}]}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxdjHs403scx+c2xdxDZIeY8jynpMskiw9dz6kk03RhU56sm5ohtEePSrrJ
rcsZkoMiHbnkWuR8v5XKby4jSpyRFEui2ZppSqfz73k/z+t5/fF6nvf8EB4z
VJNEIgX+5D//b1723jQr4aEWxEhqS+Rf/AG/P25/vOrta2T79ygnWfUdsveF
rDwdOICs40ZFdS7fICFtV8Izv3do6TKeyclINRRvv+FaXDCEjrjXSdXtU0B7
KXpcfEGKnsw0qcO2qOBqtswzmTqCthbMShp6r4Tjkx/UG6M/ImJF/qV1GV+A
kgn0wPxRRKIxfF33KYCS3qNwvfsJSW/V1yVukANr+akrN6+PoUDVXclyjwlo
remJyo4eRxmRBfmCDTKYq0+P6fX+jBTLns6kPRoHnxOpR4QkGdqWHO4dZT4G
XM1HoQOBMlT+INPL6ewokCvSzW2qZEhx9vZdgclHYBluJx/Vm0BNxKGxyOoP
MNbqfKAreAL99kp7cGu4FPZ16Li7VE8gO/6vKr7XMPSZHt6zWV+OjngLOAdp
QxCes4rRFyJHFatW0wet3wPl+mqblIdylBgxyiu0fwe+Y+nvvs5VoHz/Dm6m
+yCcGb4pvxerQLr0yuGqvW/BbtA501OiQF07f5SQhQOw3z/fwm7dF+TG0DkX
VPkGPq2QrRWXf0EG1A7nGr9+yBDmKRvslSiDl9l4TbcPzLyWOezIUqLFt2j8
tM5/YOPpN/0zlpOIfZV9lVnVC7K6sYWm2ZPoctC29BtFPSB9UZs7vECF5LYZ
kvVlr2HcM2Kp6L4KreFtWb/0eTcwZJCryZxClosMI1ifX4GwdGJBq3wKxVB1
kmsWvILJAK4h5/pXFKaKt+aGvQQ9h8mAgc1qlC0+MXkKdcEEOznqmPY0Emo8
ObbctguqL1jS6E+nEdNz4+3Si53g5JXDWZzyDclL2iqWanSCGcX4SEjwd8R2
5vtpn34BabaWv4jdZhA7oCoohvICGNEd1FDrH4jp3RT+/s8OOM/trSFrknD+
Em5OCaMDOA8b47oEJBzh2OPk8aYdHK3y8s+rSJg6u3+LzsV2OLTRV0iJ1cCX
JR4GJxntoLspvn/DNw3MYz/R5gyLwU1XHDfvjCYW7NJlue4Vw7tFG0LDjLRw
QZ8r/85wG6x7dmnIKkcLq3eveTR0rA26lyQaarlo4yxWjNdCwzYYL2dakp9q
4/VUEbm2tBXuDHg+ILF18JByhPgY0ApJ0qCEdpUOdofbATRyK1xLWubof42M
y/ortTrqW8CObVDOpevi3hgn24MxLVASOtM20q2L10s5O3luLRBkU6+sj5uF
ywnJwvCZZohu7D7b4DAbzyuactUgmmFxsmpC3DIbp/HFTVjYDPmpRaKXMXrY
hVA6sg41Q+OB8tcVNH2caO5ICfNqBqvcK/ZbOvVx6L0P9nVWzVB03FZxLoGC
1Stto9VKEbSuqO71oRvg1OUjk2NdImDu1ys5+8EAC5LCtQJrRODRoBFnc8MQ
Fww3KSlZIthr45KmZhphAUO7rjNeBM9rm8rIOsbYPfbo4YT9IrjM4XnP32uM
C/QkU4ptIqh7qdje2GCMjW2fi0mrRVBcmvdcam2C689opZx3EoHXLLEyIdYE
F06XPQizEEFl7tGq9Fcm2C/YPD5dRwRZrFub9OimuNDRNKpPSYCRH++w9Iop
Tp9fu2eVlICUhpglDoqfvaeGktZDwFp9itF9phmefuxr0tZCQMhaliS3wgxz
P28ue4sJSM1qanhtOgf7UbuL6qoJULr1OgVGzsGFu5/+sqmYgDONcolD1xw8
3aDLP53382/PnX5nujkuHDKy35FBALLwjoz9wxxPB7c9fJhKQLbPQZvvKnPc
HmLdUHSOgFIPuPpglwUuiPcXmJwk4Nq6FOKvegsscJaZjccScHGlj6SVaolD
a0eDXSMI+EZjWdudtMTGUtQ7eJiAfwHn/eKI
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  Epilog->{
    LineBox[CompressedData["
1:eJxd13c81W8bwHHZK3uWkmwtRSHVpUJD0TQaRorMEg2RpBCKSp1z7BUhs4wo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     "]]},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"y\"", TraditionalForm]},
  PlotRange->{{-5, 0}, {0, 2}},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.460678401198228*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 7:",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" Plot of two approximations to the dividing streamline on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane for an ellipsoidal resistor with semiaxes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", ",", "b", ",", "c"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{"1", ",", "2", ",", "3"}], ")"}]}], TraditionalForm]]],
 StyleBox[". The lower curve was calculated with a Runge-Kutta time step 5 \
times shorter than that for the higher curve.",
  FontFamily->"Times"]
}], "Special1",
 CellMargins->{{36, 74}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True,
 FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3.2  A Perfect Ellipsoidal Conductor", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["For a perfect ellipsoidal conductor, the conductivity ratio ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]]],
 StyleBox[" becomes infinite. Although the ",
  FontFamily->"Times"],
 StyleBox["Limit",
  FontFamily->"Courier"],
 StyleBox[" function would serve adequately to calculate the necessary limits \
for the inner and outer potentials, the execution is slow. An alternative is \
simply to deduce the correct formulae by inspection. Thus, we can write the \
expression for the total potential for the perfect ellipsoidal conductor:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"uPEC", "(", 
    RowBox[{
    "x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", "c_", ",", "V1_", 
     ",", "V2_", ",", "V3_"}], ")"}], ":=", "\n", "\t", 
   RowBox[{"Which", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["x", "a"], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["y", "b"], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["z", "c"], ")"}], "2"]}], "\[GreaterEqual]", "1"}], ",", 
     "\n", "\t\t                            ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "V1"}], " ", "x"}], "-", 
      RowBox[{"V2", " ", "y"}], "-", 
      RowBox[{"V3", " ", "z"}], "\n", "\t\t\t                          ", "+", 
      FractionBox[
       RowBox[{"V1", " ", "x", "  ", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{
           RowBox[{"\[Lambda]", "[", 
            RowBox[{"x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c"}], 
            "]"}], "//", "Chop"}], "]"}], "[", 
         RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], 
       RowBox[{
        RowBox[{"A", "[", "0", "]"}], "[", 
        RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "\n", 
      "                                ", "+", 
      FractionBox[
       RowBox[{"V2", " ", "y", "  ", 
        RowBox[{
         RowBox[{"B", "[", 
          RowBox[{
           RowBox[{"\[Lambda]", "[", 
            RowBox[{"x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c"}], 
            "]"}], "//", "Chop"}], "]"}], "[", 
         RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], 
       RowBox[{
        RowBox[{"B", "[", "0", "]"}], "[", 
        RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "\n", 
      "                                ", "+", 
      FractionBox[
       RowBox[{"V3", " ", "z", "  ", 
        RowBox[{
         RowBox[{"C", "[", 
          RowBox[{
           RowBox[{"\[Lambda]", "[", 
            RowBox[{"x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c"}], 
            "]"}], "//", "Chop"}], "]"}], "[", 
         RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], 
       RowBox[{
        RowBox[{"C", "[", "0", "]"}], "[", 
        RowBox[{"a", ",", "b", ",", "c"}], "]"}]]}], ",", "\n", 
     "\t\t\t\t                          ", "True", ",", "0"}], "]"}]}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell["\<\
We again construct the velocity field via numerical differences:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"nvxPEC", "(", 
    RowBox[{
    "x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", "c_", ",", "V1_", 
     ",", "V2_", ",", "V3_", ",", "\[Delta]_"}], ")"}], ":=", 
   RowBox[{"N", "[", 
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "\[Delta]"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"uPEC", "(", 
         RowBox[{
          RowBox[{"x", "+", "\[Delta]"}], ",", "y", ",", "z", ",", "a", ",", 
          "b", ",", "c", ",", "V1", ",", "V2", ",", "V3"}], ")"}], "-", 
        RowBox[{"uPEC", "(", 
         RowBox[{
          RowBox[{"x", "-", "\[Delta]"}], ",", "y", ",", "z", ",", "a", ",", 
          "b", ",", "c", ",", "V1", ",", "V2", ",", "V3"}], ")"}]}], 
       ")"}]}]}], "]"}]}], TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"nvyPEC", "(", 
    RowBox[{
    "x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", "c_", ",", "V1_", 
     ",", "V2_", ",", "V3_", ",", "\[Delta]_"}], ")"}], ":=", 
   RowBox[{"N", "[", 
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "\[Delta]"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"uPEC", "(", 
         RowBox[{"x", ",", 
          RowBox[{"y", "+", "\[Delta]"}], ",", "z", ",", "a", ",", "b", ",", 
          "c", ",", "V1", ",", "V2", ",", "V3"}], ")"}], "-", 
        RowBox[{"uPEC", "(", 
         RowBox[{"x", ",", 
          RowBox[{"y", "-", "\[Delta]"}], ",", "z", ",", "a", ",", "b", ",", 
          "c", ",", "V1", ",", "V2", ",", "V3"}], ")"}]}], ")"}]}]}], "]"}]}],
   TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"nvzPEC", "(", 
    RowBox[{
    "x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", "c_", ",", "V1_", 
     ",", "V2_", ",", "V3_", ",", "\[Delta]_"}], ")"}], ":=", 
   RowBox[{"N", "[", 
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "\[Delta]"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"uPEC", "(", 
         RowBox[{"x", ",", "y", ",", 
          RowBox[{"z", "+", "\[Delta]"}], ",", "a", ",", "b", ",", "c", ",", 
          "V1", ",", "V2", ",", "V3"}], ")"}], "-", 
        RowBox[{"uPEC", "(", 
         RowBox[{"x", ",", "y", ",", 
          RowBox[{"z", "-", "\[Delta]"}], ",", "a", ",", "b", ",", "c", ",", 
          "V1", ",", "V2", ",", "V3"}], ")"}]}], ")"}]}]}], "]"}]}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Again, we generate a contour plot on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane of the potential function for a perfectly conducting \
ellipsoid generated by semiaxes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", ",", "b", ",", "c"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{"1", ",", "2", ",", "3"}], ")"}]}], TraditionalForm]]],
 StyleBox[". First we calculate approximations to the dividing streamlines in \
the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane using symmetry arguments as before:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
FlowPathPECz = 
 RKParticleTrack[{nvxPEC[x,y,0,1,2,3,1,0,0,0.000001],
                  nvyPEC[x,y,0,1,2,3,1,0,0,0.000001]},
                 {x,y},{0,2+10^(-7)},
                 {t,0,-10,-0.02}];\
\>", "Input",
 AspectRatioFixed->True],

Cell["\<\
FlowPathPEC1 = 
  Join[Reverse[FlowPathPECz],
               FlowPathPECz /. {x_,y_}->{-x,y} ];
FlowPathPEC2 = 
  Join[ Reverse[FlowPathPECz /. {x_,y_}->{x,-y}],
                FlowPathPECz /. {x_,y_}->{-x,-y} ];\
\>", "Input",
 AspectRatioFixed->True],

Cell["\<\
Again, a composite graphic of the ellipsoid, contours of the flow potential, \
and the calculated flow paths can be generated (see Figure 8):\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Show[
  ContourPlot[ uPEC[x,y,0,1,2,3,1,0,0], 
               {x,-5,5},{y,-5,5},
               PlotPoints->20,
               ContourShading->False,
               Contours->20,
               FrameLabel->{\"x\",\"y\"},
               Epilog->{Thickness[0.005],
                        Line /@ {FlowPathPEC1,
                        FlowPathPEC2}}],
 ContourPlot[ (x/1)^2 + (y/2)^2 == 1, {x, -1, 1},{y,-2,2},
               ContourStyle -> {Thickness[0.01]}]
               ]\
\>", "Input",
 CellChangeTimes->{{3.460678467870103*^9, 3.460678524088853*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyEnXmcT9Uf/5nFjBmMMbJG9pTs2Qr3ZinZiSIqyZZEtsqWNVL2kGzZCi0o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    
    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0bkv33EYwPHHUDYlUceIv0BjMpS4BkeUhJLUEdfg1rqpK660DCrB4oi/
gD+BVZfaDILBYLAZhMXrN7zyzvN8p+/zye0cbhhKiohJMj9G/M6K2MiJ+JAW
UZQdkaw9GREvWmzO0C/6SUs0KT2iXPPMZZqvFZpiX60F5ir9rDWaav9VS811
Wqb1+o9LmvhGIy00859W2vhOB+1c00U3nfTSww39DNDHEIPcM8Iow/zkBw+M
M8EYU0zyyAyzTPOLOZ5YYJF5llnimVXWWGGDdV55Y5MD//tHD3VLK93jr56a
t/VMd7Tefk/Pzbt6ofuJe9gfJm5iPtArPUrcxb7Q2x17u1u7E7s7rc10H9/e
AfuTRCQ=
          "]]},
        "4.23`"],
       Annotation[#, 4.23, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0UsoZnEcx+GflUJeyrVmFpaj3BZjY6dYUrNXM1MuK4qINc2QBbFk51bY
s1AyF1YTKcol5S4LMVHKK56zeOp8P6dz+ndO2feuL50ZEdFHcSpitDhipDQi
My+iriSirSCig3ZW7e6iiB5+2MP8ZE0f1IaYteeZY0Mf08b5a2+xmdCntGnO
7Usu+Kcvacs822le2NVXtFXyCyMKKeBQ/5O8m3K7kgpO9G1th3q7kQbO9D1t
nxb7G1+50o+0Y3rtAfq51U+1M8bsSSa406+1GxbsJRZ50h+1J9bt3/wirae1
Vw7so+TsvOlZvnc29/Z/Hsj0/T9oH8n1TB4pcvRPWjlVdg3VyX39s1ZLkz2T
nNv/a3bdmh/xDr/ST/0=
          "]]},
        "3.7600000000000002`"],
       Annotation[#, 3.7600000000000002`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwN0EkrhVEYwPHHznTTxTVsDGsWMpOFcnNtlGGjiLJDsTB9AEOZiltYSNnI
XDYWlAwrxSexVcTKb/HrvM+/875v59ROzg3N5kTEMhVFEdvlETtMlUbMMM19
RcRCWcQiG+YtNnnU17R1zsxXXPKq72lZ3swfvHNsLij2HRaYJ5WM+CTr3w38
2vdHfom97GstFKciSqjWajjSuqjT6mnSmjnRuunR0vRqGU61DOPaBKPaGFda
P0vaMrPaHLfaMLvaHivaKnfaCOfaBQfaIQ/aGM/aC9faDU/aJK3O2kafs+a6
34w1z9quRWVEoecEX9794ZtcvUqrJunuUpSS0Ou0ehrNzTSR1Du0TgbMQwyS
Nv8DJKU79Q==
          "]]},
        "3.29`"],
       Annotation[#, 3.29, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0c8rZWEYwPGHjQ3hGnSX2FgoWcxQWIrGjmJ1h66FlHEvkkx2ElEsRprx
F1BiyUaNXzO5pZQoYWuarR8LU+Rj8emc5/uet/N2TlU60zWSFxFTJIsjlioj
lhn+EJElw2RFREEiYpQsGfJLI/4xa08N657bYMfaLgtaLSdajgvtkiWtjjvt
L/faA9+1Bl60VwrLIopY1T6x50wV5RGpkogqvZoa9vV6fVD/aG6kiT96uz6i
d5g/00lOT+sTesrcRz+n+jd9Ws+axxjnTF/RZ/RZ8xzznOub+qL+w/yTNa70
lPMeWTtmS9vmlzbAjXbLvnbAoTbEo/bEtXbDb+0rCd++jGft//v5tVGafbMW
vvgHje/vdG1ybdUSSevuW+i2t5ce2sxvpD1IUQ==
          "]]},
        "2.8200000000000003`"],
       Annotation[#, 2.8200000000000003`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0LsrBWAcxvGff8DdOWWTkzrDieP2FxhYxWrAgHJchiO5ZMCCTCxu/wAl
JgaL2yAsihSry4yI4mP49vR8n7fet7eqe6g9VxAR45goirhBfXlEFp2JiA7k
uWskuQSauSaMchf4KYv4RpJLIMed45F7wFdFxCcGuKdkxCl3gmNsFTtne+T3
9T3sYoU/4+/5TX0Da1jkX93RWBLxIhvkqnNz/Lx9Vq7oWX5STusj/JSc0Gv5
Xjmmd/F52aNn+DY5rLfxQ7JVT/NZ2a83832yTq/mz9yfkueyxpZClz1pP/Lu
Er0Yhejgf/3dPv9RGvGON7Twz/w2n/E/y7jjb3HFXyLNLeCQO8DO/3mkuHls
cOtY4hZRyc38b9wcctwg8t75B/58SRE=
          "]]},
        "2.35`"],
       Annotation[#, 2.35, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0M0rpWEYwOF7/oJjmMFJFhbnH3BklGZpo1goYjVSxo6MBYlixQY7hxIW
LBGxwkr5KDGjNIY4RDFNTXaifFwWV8+5f8/7dJ73LWnpqGv/EBG99CUijin7
FJGmKT+ikW7tJ0mtkArtC13aPi95Ec9s5djX7wsirsyXZFnRnz5H3Ol75l22
mdWzelZ/ce7rx4hXa0Zftj9u3bFfqS9aR81T+oh1wVyu//f8hN+TZLgxX/Ov
MGLAPEg/F9o5t/p3cxutnGi/38/oNeZaqjnSfpHV0+YyStnTdjnTU/4/qTW7
T8q9vr2/v7lYD2uDOaHXW1e943wyIt/egbNr5qfciEceqPLMX992QT8zn/KH
tH6oz+mb5g3WWdIWSfn+Q8xo04xpoxRpgwxrQ/zQOulx9zcEhVJ4
          "]]},
        "1.8800000000000001`"],
       Annotation[#, 1.8800000000000001`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0D1oU2EUh/ETXTo11tbUfKAUOlS7GotT0cFW/BikIKSbOCv4MSTQCm6N
S9w6OBhRu6hJcFOwHYSUTgXppqVEl9aP2EUDhdbfHR7O/T/n3HPf947cvHP9
dioiHmEuHXH4eMTEUMRZFNE5ElHKROwPRxTkPHL4zJ/je3xKDhwMRnzis/wu
/13+hg7e8XvHIrb5flwaiEirz/m2fl3d0p/kV9VFecFZqvhn398Ez029Fhr4
w3UT+PGjET89/8IPFO05xY1hxr1aeOA79/HQu/O4xr1G1+wTnDR7AtPcK1w1
eyXB7GVc4Or4bfY0ymYrOM/dcpc1382bKyCHD/J7bDhfSl7KRhxSZ+USbrjj
Xe6NmWH7dvzDKa5n50X1rZ0v9NN6bfMNeVPvK77gjJl177zkV+RlfMQo3+Sf
Jv9XruMZMnyNr/GP5SoW0Mff4yvOUcZ/3WVQIQ==
          "]]},
        "1.4100000000000001`"],
       Annotation[#, 1.4100000000000001`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0TtMlEEUhuEj2FixiyioXEIBJhbScC+MdEIg7m4rEgUEbLQhgQKQChsl
kQIauegiNEhCQoNWYuwl2isRA4mQcKkoDDxbvPnmvGfmzPz5K7ufZ55diIhZ
nCYiBosiLslXhRGvMYk3xeCL+ax6ER8wy6/xVfwX9Sa+Yonf4uv4X+ptLFyN
eIc5JJIR83LqWsQ9ezIlEa3ynzMlequ5vbJd/73skOVyg/9p7w/MFEQ0IGF2
Ep/0D/CWG1YP4Yl3LHGd5vZZ92NZnTIvjX5znmIAO/yK/IgqVGPfrFV5/0rE
YzO68Qh53jpm1guk1Gkc2tvlziN505kM16X/EPn213MN6OUn3N0jX8oT+6fd
fde6BTdQhlKMmHcLK9YTZnRaH9p7hFHrMdxGDb5zx/icewdquV752/3j1nf0
0jKF/97Rog69GbOzZk9yi3Lbt7bpJfQKkcQ6//dyxC72cMxd9y++8Xm+Ix8X
cco35/4RX6YuRwXO+Af8H75R3YTm3Bl3ngOZsljR
          "]]},
        "0.9400000000000001`"],
       Annotation[#, 0.9400000000000001, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0klsjVEchvFTSU0b2muoSGiLGtsNStxKzIva9ValRSp2pl5TVQ29GjtT
DQtTYkH0dodSGyvRXjMhqQ0SKbHRIbQ0aSz8vsWT53vf8z/n3Pb7CnYkK+qy
QgifMTIxhPpJIYznltwQLuAiLk2FPk/fKqfRhpv6dn2RvlPuQiZa06cxNieE
p3khlFr/ql/GH8zn6G9NCeHytBDKdQkzG7nX2j39Xcyy1mCukOdgNoYnhHBb
95f3yoP2/JR7sVz3jft0Oc7LRQxptEbZ/TE8NjNDnol87NT12Lvded3Wavkj
b9HXoNFzg+5odK+z2+15iAcYkOv81n5O8i9+Ym63+X5nbrN/gPfIp/Wj5D45
Lp+XV3ALl/EZPodGz2d5tdlOPiF3Rf9HPEOTnOHfznnFJ+XX/BwvkZJf8Br7
33Cz/JavYJ3na9EaX+W1POScbLM35AX+poVYhFrdfJ6HhPfyLrrLO73O6+3b
gGI0ySWc4sPWG1ApJ9Chq5fbPB/icuds5ir8ce8ud5Q4vxiV1t6bH8YXa5vs
qcIRs0V8TD+Xj/MB3UGk7P/E+3Ffv4+TaNavkpeaL8VinJKXcLX1GmRFZ8h3
om89+ka4Z7Lv0Nw/7pB/xEJ4xOPMVegH7RnCdO86o8/2m0djDEb0cX23Pl8u
QCGCs7fqv+vjchlWIlv/HwcTgDo=
          "]]},
        "0.47000000000000003`"],
       Annotation[#, 0.47000000000000003`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{4347, 5238, 4107, 4754, 4756, 4757, 6035, 5267, 4121, 4777, 
          4779, 4780, 6047, 5299, 4135, 4807, 4809, 4810, 6057, 5331, 4152, 
          6569, 4834, 4835, 5971, 4470, 6502, 4059, 4578, 4456, 6516, 4457, 
          4484, 4485, 6520, 4486, 4469, 4532, 6501, 4056, 4338, 6315, 3227, 
          516, 3227, 489, 490, 402}], 
         LineBox[{6150, 5185, 5184, 5182, 4325, 5725, 6145, 5158, 5157, 5155, 
          4310, 5692, 6139, 5131, 5130, 5128, 4295, 5660, 6133, 5099, 5098, 
          5097, 4279, 5629, 5968, 4468, 6518, 4467, 4697, 4063, 6503, 4477, 
          4481, 4536, 6524, 4537, 4480, 4535, 6523, 4534, 6312, 4057, 6563, 
          3223, 524, 3223, 494, 493, 405}], 
         LineBox[{568, 229, 485, 466, 502, 209, 484, 464, 499, 189, 483, 462, 
          496, 169, 589, 423}], 
         LineBox[{571, 232, 504, 467, 503, 212, 501, 465, 500, 192, 498, 463, 
          497, 172, 606, 461}], LineBox[{3842, 131, 587, 403}], 
         LineBox[{572, 270, 524}], LineBox[{486, 442}], LineBox[{495, 459}], 
         LineBox[{533, 522}], LineBox[{544, 517}], LineBox[{568, 468}], 
         LineBox[{571, 469}], LineBox[{572, 404}], LineBox[{3842, 516}]},
        "0"],
       Annotation[#, 0, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0jdMVWEchvGPwOAlYqUTKepgGSiayB2ATcQCCSXRxUuxBfEKgxFRFxZ1
MwKbbTAhYowVdcDFCcvkYg3GIJcEjXGwYELQ3xmePOd9/185nEtZ5/HmZFoI
YRqHVoaQyA1hdkUIddkhpHi/nNDX8lt5vf4N18j79MX8XI7pJ3mN3KIvzQuh
lcv4++oQvuGJ+WJOCHO6V/JLvMCoflr/WX9weQjL8kPIQnFBCCXY4rkK82Y3
nNmoa0K1LsPeOC+YJXW/5J+4o7uHu/ghF3AhijCGm5iyZ955r1EuV6ASh1eF
cASdzntv1sEfIuvasWhfr+6d7o+zx+15jEcIcqc1/6zps2bMmhT6cELu5b3m
X8275QtymjwnX/O8U3edd/FlbuCrXM9XeEf0t1ub6a4YluCBvll/n8/4hmdx
CqcxgFnrR8xqrKlDLS7JwxjwPBTdY81o9A09H0Ncf5638Tmu5hnz4F0vynv8
3o1owjM5Q5+OJG7LB3iGP2HQ3ik+quvhNm5FvnfPQ4Mz2qL/F/Sgy2ydfi3K
MGHPb3x0/yZnbUauPgfZ6I++iz312I6n/gdLdBNcypXWV6Ecg3JFlJ3Vxbei
98Ju93Zzvq7FGX/Ntzq7zbt1mLUjEX1LsxS+IO63HnZHpn1DHONx6zfqJ803
8EM5XT/CRfKYvjDaJy9wP2fxkH4pn5SH3fMfiAZ8Cw==
          "]]},
        RowBox[{"-", "0.47000000000000003`"}]],
       Annotation[#, -0.47000000000000003`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0stLVVEUx/F1w1ng1fKRYZQRDYygB0KUEj2hsgQhr14fiZRlkY9m0Sh7
KtGsIIIoSiho4MhUMB0X5SChBzVJi6TuP5Bd7HMGX757r9/a65x97q3q6mvs
TUXEOCrTEffKI4YrIgqLImrXRKT5cklEnq+URdyRVVrvk63j+7KC4ohbsruy
arXDsi08Jlspm+Pd9j9WRezhZ3pH8BSjnpeT16svyf8hjzH1VzhofQhV5rzW
P4NppNWOoASleCkv5zIcxWb7LudHuMn8DJrRJPvrnjXescW+FVksqV3Tfx2D
uIkbmEqei3PuNq/ngPMLnLX/oN7Cc9ytfgYXnWlFG46Zu8lzfurPyCr0rsVx
WQNOoDfpV2vDVesObseMmRme5mb+ZcaAey9yj32/db35p9CBlO932/mvyW/B
33iIP/In9DmTd/aC2gv789yDdmefJ/ez3sUN3nMbtmPUfifvQCNq0J18Jx7E
fvkGcy9x2j2LMG/OdyyUmuud3q2OeI9Z5NRT+lfgj/Vp/s0T+nLySV527qR5
G9Ufyt+oPTD3La9356xsq+yR7LPaY9kX3ivrlNXJniTfK/mfyRa5U3ZW9h9z
l2nf
          "]]},
        RowBox[{"-", "0.9400000000000001`"}]],
       Annotation[#, -0.9400000000000001, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0M9LVFEYxvFXolUDOXNnbKaaclKbRWNbCZyIBF3kddEiEhcyum/21a6C
KCIXWhaFKaRoVNAPDZpVu8JABFe1rE1t7B8Y+sziy3PO872c855bmWlevtYV
EfdQPhzx6EjE/VJEd3dEvRiRldfzEW15syfiAXfC+iJ3Uj7mDmYj7nIPuZpu
jBuUW1yGW+DmuGFdytXlHpfjVrlErslU384ZJInowiezHChEXNXn7BMsmvEc
yvrXnVlkVb9h/Qq3cBvPfVPHF2eMyDu6Wesbzj/jvpIs4hKO4hje6MvyOMbR
iwqa+j55Cin6MYC3+qo8jQnUMIgh/b53/kMGh7Bphkm8M+97LJn5BVq6aXzV
fcMH3Uds4pd5f+vWvX/HfhcFXer8RI7LvHzibZ99M++elgz/8kpnZu4Zt617
yn2XvdwUd5Zb4n7olrmf8gLX4M5zK9wf3Uvur2xwY/pR/AfEWkYJ
          "]]},
        RowBox[{"-", "1.4100000000000001`"}]],
       Annotation[#, -1.4100000000000001`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0L0vnWEcxvEfZvV2HI5BcxqDVIKlEganHIN2OKeaSNPRqaFd2HTwMjCx
iIGeFwZqkDYGIqFNysDWRNKk7WRm0z+hPmf45np+3+t+nue+73Rh9vVMTUQs
obMh4lNbRBHziYhFLOB7u+ekNSiayyjhnF/l1vDC8zh6GyPOdPVNEVv8Ripi
mMvpMvKvLqG7lznz/+aIvPxnTvFH3umQx/Itn2iJSKINF/b1uDViiu82P0UP
LvkrPNMNYJAbwp7zjOEVN4Ecl8cB9xLvuQ/V73EFHFbXYplbwRz3EcfcJMpc
BavcGk65P/77Gyf8un3t8p+xjxv+J1/iT83fUMeNOV+tzMpb/Rf9L91XeVfd
J5/Ul93dD27T3Z3LGnfyRtel29FdcxXdNp7o0njE9+n7MWLOYhQtfIZ7joJ5
Gu8wbn4AQJFEjg==
          "]]},
        RowBox[{"-", "1.8800000000000001`"}]],
       Annotation[#, -1.8800000000000001`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzz1PE1AYhuEXqAtLMVBbw4B8VMOoCyEqA4IJWy1MsNFgkEHiRpQAEhKH
AsHERGjLwkAYdCThY2CBpKRA4sLHP3A0/AKvDnee89zvOSfndE7O5j82RMQ8
OpIRW+mIEhbaIpbxFceZiKVH1ijr26jghC9yqzis78MRTvmf3CZu9Dvcosqf
Y4//8Tgi1xIxpr+T/8zbH0YkUhHjeqo1YkI+0Lv4J3JS7+UL8sIdz/iaPPPe
PvMZ/qX5awygyuf5T3xOz2MUNX6Gn+ML+hTe44pf4Rf5Of0zvuAPX+G/8UV9
Deu44e+9v987dv3nWt+wZ8fsu9x35pXZhSzpB3xZXurD9b/av+ncL27DPb/l
X7ME14S0eQaN/phAE5r5LPcU3XoWPUjyz7kXGNLfYhgpfpB7gyn9A6Yxov8H
VhZDrA==
          "]]},
        RowBox[{"-", "2.35`"}]],
       Annotation[#, -2.35, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0T8vnWEch/GfwXEwFFW0XVhQEZFaENHQV6C8AaoMhEQXfxIOQkgwEKfR
hOjISkwSx2AxFIsmTdq9TBjoIj6GK9/7e93P/eT33E9Fz/CnoayImMDki4hL
fCyOaEd/SUQfRrkLFL+O6CmMaCuN+Cw/FEW0okF/57kaVKJar0K+55N6LrLx
lnuDBH/1KuIa/5DgsvFYFnGmn+Mn/jvzgHv+AQfcWkHErPWqTHvPjf1ms2zZ
W+SWXkYsyE39PT8vp/UxPiXn9Hp+UI7rvfyYHNDr+C75Ve/gR2SnXss3yUG9
hR+QjXo1XyG/6N1m6pXrZjo20y/9Ejn2k8/fiH1+D2f8rfu9ww12uR2c8n/0
v/iN79wGTvgjPYNDrHDLyPC57j8PCbOMyG33+ANJ63L/bAbfrNNIOTv1jLNP
mS9GFw==
          "]]},
        RowBox[{"-", "2.8200000000000003`"}]],
       Annotation[#, -2.8200000000000003`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwN0E0oZXEcx+GfBVL3mhjMKJurvDQLe4oVjZ1JKbaWI28lmtUUirCwZOMW
a3ZoTGYxLBR3Gm95LRaIUsQKG8/i6Zzvp06d/z/V2dvakxURQ/z8EHFEU1FE
I10lEd/5oe1RrVXRrH1lQMuQ1BJUa1X0als8fox4IFfLoUvbJLs0oqUgovRT
xDfPusKIWnLtg+KIQ3Z5880rL58j1uzfrPKsPfGsz9sLpLnRrrnXJ+xJxrjU
LrjV++x+ujnVTrjS2+0O2jjQ9rnU6+0G6vinZTjXK+xKytnQ/nKsJ+wkeaxo
y/zXk86XT5nzDnr+ctY1Et5r3Mk0d95vOXeXZ3zRptjRtvmjrVOpjbOkLZLW
5khpI8xqM4xqIwz7h3cb6Ut4
          "]]},
        RowBox[{"-", "3.29`"}]],
       Annotation[#, -3.29, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0D8o5nEcwPEPBkVxca7HyCn51w02d2Hx70yEK5MsjwGP0i1io+4ZhLKg
5EmUBWVxZKBuMDBgZz4MdGb3+g2vvvX+1qc+n6rRTP9kXkRM8/4hYuFjRJl3
vSxig/nSiGq29BwH2iFZrZZz7YIr7ZpFrYF77YG/2iMr2hf+aW/kl0cUsKo1
U1QRUUxKq2RNa+GzVkOj1sSm1spX7RttWjvbWgdD2g8GtEH2tF4mtQxpbYx9
rY9fWpZZbY6jZEayr5ZjSVvmWBvmWPvNjrbLmTbCjXbLiXbKuZbmSXtO/rQ7
/mjjyb6f7MuL9sqlNpXcTmukxI1KudZ+0qN9p06r51abSWZpE3RqXXRTmIr4
DyUXQZA=
          "]]},
        RowBox[{"-", "3.7600000000000002`"}]],
       Annotation[#, -3.7600000000000002`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0asvBWAYwOGXIZnbcRuFxMahaIJLUEgnsDmJhLlsTKWIBCLBZseYwFyK
uW38AQiOJAhG4BSXJHiE377vfdr3fo2jM6npvIiYV5RHFFVEJMoiJp2v5jdt
1ERsVUY08EN+pGNt8Rvezm/Nd7rXHn/m3fzd/KGcDvkPT/GCREShinTGO0oj
SqoiSlXH6rXOOtXEmtXG2rXJuv5j3ephvcqwPg2ztAbZkPbYgGbZnMbZhA5Y
SstsRQtsUSdsSBm2rVW2plOW1jm70A7b1SUbUZY96pxd6JqN6cX7cnzfux94
Vo/K8eLqiCv+af7St354kt/yMvsqV4V+eT9/4i3mViWVX2sP9vvOp5yf/uxL
S+5/jyZG/Q==
          "]]},
        RowBox[{"-", "4.23`"}]],
       Annotation[#, -4.23, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0bsrhXEcx/GvCYPcb4WyUXL7D4QFCxZkMljcFpvBZTRYsNmUwqCESRik
lCIMhyIM1sPgfn2d4d1zPq/nDE+/X+XAWNdoWkRM6j474iM34lN3etE1qyyN
6CyO6FKbiu0itfu9XOB9TsRWXsS2drTMD3k9P7cvdKl1/sCbeNJ+0rM2+Rvv
5un5ERnK1C7PKYzo52V2uSp0wKv5IK+3G9SoI97ER3iz3aJWHfN+Ps577F71
6YSP8wk+ZA9rRKd8js/wKXtaMzrnK3yWz9sLWlSC7/EFvmqvaV03PMGX+J69
n/p2PfIk3+AJ+0rXSvKsIv/hr/ab3lNPXsvPeL5zKlChfngHv+W1dl3qzNXD
q9xPtcpKnJvu3GON/eVOv3WvX/3oT/8DIVIK
          "]]},
        RowBox[{"-", "4.7`"}]],
       Annotation[#, -4.7, "Tooltip"]& ], {}, {}}}], 
   GraphicsComplexBox[CompressedData["
1:eJxdmA1wVNUVx9dIpZ1pKG0dZ4DRSJJGytTaAqHpFP3TwemMrR0JiNrOtKUy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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {Thickness[0.01], LineBox[CompressedData["
1:eJwl1FV4EAQUBeANGDBqxIiN2EZ3N0iIdKdISUuOEKSURkC6Q+luBEFppBuL
TqVUQLoR+Pfx8J/7el7OjWrdrV50YEBAQEYRc2MRmzgEEZd4xCeYBCQkEYlJ
QghJSUZyUhBKSlKRmjSEEU5a0pGeDEQQSVRMDzKRmSxkJRvZyUFOcpGbPOQl
H/kpQEEKUZgiFKUYxSlBSUpRmg8oQ1nKUZ4PqcBHVKQSlalCVapRnRrUpBa1
qUNd6lGfBjSkER/TmE9oQlOa0ZwWfEpLWtGaNrSlHe35jA50pBOd6UJXoulG
d3rQk8/pRW++oA996Ud/BvAlXzGQQQxmCEMZxnBG8DUjGcVovmEMYxnHeCYw
kUlMZgpTmcZ0ZjCTWczmW75jDnOZx3wWsJBFLGYJS1nGclawklWsZg1rWcd6
vmcDG/mBTWzmR35iC1vZxnZ2sJNd7OZn9rCXfeznAAc5xGGOcJRjHOcEJ/mF
X/mN3/mDU5zmDGc5x3kucJFLXOYKV/mTv7jGdW5wk1v8zT/8y23ucJf/uMd9
HvCQRzzmCU95xnNe8JJXvOZ/3vCWmPEHEovYxCGIuMQjPsEkICGJSEwSQkhK
MpKTglBSkorUpCGMcNKSjvRkIIJIogLf/6F3VNCDzQ==
         "]]},
       RowBox[{
         RowBox[{
           SuperscriptBox["x", "2"], "+", 
           FractionBox[
            SuperscriptBox["y", "2"], "4"]}], "\[Equal]", "1"}]],
      Annotation[#, $CellContext`x^2 + Rational[1, 4] $CellContext`y^2 == 1, 
       "Tooltip"]& ]}]},
  AspectRatio->1,
  Epilog->{
    Thickness[0.005], {
     LineBox[CompressedData["
1:eJxtm3dcje//x8+pc59SaS9RRIqMZJTIfb1JlE227FFkFEpkZCSRyEy2ZG+y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      "]], 
     LineBox[CompressedData["
1:eJxtm3lcTdv7x8+ps09pnksUkSJDMpTIXptEmcks81BkKJTMGZJIZExmyTzP
414Pkdk13UTIEBFpkETKbx/3eb5//e4/9/VxTnWGvdd61ufz/riMntp3nJ5K
pSrQV6l0/69XP+9+VpgtjExP61S7vRY2hkUu/x5sC98Ngu5O8dOCzYPiXdbM
FprHRczh7bQwo1uEvZeHLczReHY3U3TJmeoPPWxtwbh0UZuhbbXQU++gxUSV
LayYEtx2j68WRlktXhv32QY+HJnRraiN8vMF66fsyLKBUUPTxnkrusyxbMeF
KzZQMiJu0RwfLSRvO9zoySEbeKHev1n21kLiP48NCjfaQOjKpQf+tFZ+37iZ
bYXFNhDvMm+fqOig3ANQe4oNDLz/OGlOKy10mrRwU8vBNuBXfH7AmZZa8Kxj
fi2okw34LAr4+bWFFgbWnsBGeNqA/Y7pUxsoejmkG81wtIFJXxucGOylhS55
Oa7LBBvwOuR2YUVzLRhdc125udgautdoEHvRUwsvK1M7HsmxhoG7T/3+2EwL
9TIHdYJMa3Af0b2hjaLbquYmPzxuDaFBXSv9mio/f69+o7dbrOFFaNHkMU20
YHopwqg03hp+Hx0eE99YC2FVS1qpp1tDSdx2q/0eWsieFLfHfLg1uG3b0upm
Iy2k9N40winIGu6MrJuV11ALsXsLhnu0soaRh7O/VrtrwTY3Lc27jjXsaN0v
2k7Rjru/NeloZA39bfXGNnbTwsypxr+6f7eCcV+8jrZvoIWrm+oYDXxtBcdW
W/fq4aqFXr3Hh4y8YwU5jqfaDqmvhRstHYvDzlhB9AnVhLH1tMAaxlyL2GkF
ke2uPwh30cLdb1eyZyZagVvEobCIulrYpPZrMn+m8vOZvu7T6mjhykxPefFo
Kyjv/FAv0lkLR459XLmshxVsOHq8ZJKTFjZPP5ea2MYKkieWfRpXWwu9l5e9
W1Vfef7DpDdDa2khI6s8bI2ZFQz90Pd+T0cttDvi1GjdT0s4uDQ/Xaypha99
79Vfn2cJvRs/GNbYQQudw6cOWv+PJdieCf1sY68Fec+0zHUXLMHx1lv/Slst
GLt1m7w23RIC4oJCXtkoz7ed0T15tSWoOsxvJFtrYYDp5DFJcyyh1qA2O1Kt
lPfjIB9fPt4SvJsLp6dbasH3dZn30j6W8Ma2c0iQhRZ+pu4pjfWzhLlfPZfX
MteCJmVq3mx3S6gddq9FgalyP3T7ZjzDyhJ+HKgIOm2iBeeRr8ImVVnAWeNR
GXONlddT+O7XmI8W0GR83BrJSPn+O125MuSxBVxqdvqAqobyfS9td7m3bAFz
T1r8uWSgXG9BLoUB+y2gz8+li6K0Wqj62rVP23UW8Pvff909BOX77pz6qekC
C+hSFv/mub4Wdm2qPF13ogX8qfi+M15PC+drjj9j1d8CBt72H9pcrYVDF3MK
9CULeBE18s+TPwL4vJsQXOZhAUW1tbFR1QJ0ETyK39lagN/Rc/ctqwTI6t7h
yiOVBZRVZrzYXylAkCZz5cKn5vDTzW9z+18ClNTZohdy2BwmXKr6dbdCgLlr
tr9ptdgckk/t+zLwhwBjvZY2NhlsDs530ke++i7AYEu3N2+amYNbTN0uI8sE
2B0SoX9Gozy/zGD1y1IBnh6LXrvsuRmMl80aDygRwOhI+JrBx8xg/929BreL
BOCnd6kbLTUDu7GGtr5fBah9KPlt+VAzqNnDtWPaFwGY7xPvDC8zWLL56DzD
zwI08WqkSjIwgxEJjmfCPgnwxD9aGvjSFDqtXfssI1+AF59v/XQ+aQq5KiGr
5gfl9b8Z3Oz9MlP4cdd608Q8Af60Sni9f7gpjGDOFmfeCvC78p3V5Fam0CrB
r+Hv1wKYHHW92czIFLrUFO/75QpgX9hKvyjXBNyX7Ps686UA7gHNbhw+bQIn
dp+NOpwjwAH/YfbhK0ygyCyk18tnAswbIv1wG2UCX/zbhBpkC2CoWTnxjbcJ
mJ/ata9xlgCbp3hGpZqYgN7HndVBTwSw6NijVt+3xjCzfmHw6EcC1HINGGV4
zhiuNitYM+OBANX1TnW7vNIYoiYdSo+9r+h1UbkRY4zh7Y5vUUvvChA8Ot2l
vq8xPLfzKIy7LYDdwjT7J2bG0OLk2LL5NwV4XGx1Y3GeERQ6jZ4RmSmA2b+5
rVtcMAKrs0v7D7smgHcjcWLuKiO4UePVgo5XBUhbf2TiinFGUNuhZk5dEKBZ
LbXo3c4Ittsn9qy4LMAZt/6fcy2MoGBE0ys3LyqPr3SevexDDRh3f13NNecF
2HbbrdTzUg0oPPOzfb+zAgxtlTw0K7kG/PuuhY35aeX1v3ouzwmtAfeOn1h4
9YQA5V9eu9ZtXwO+Ry0Ln3JMgHZ+bzdkWNWAR6XDzlgdEeC++WLn8R8NIapj
VOejBwXY737/uoFsCDFZ+/747xcg86jvxn1rDeFw1ITrD/YIcNHj4NbACYbQ
+s/F2f13C+D8fHZevmgIYd6+eo92CrDBNWrmUhtD2NzSVOy8XYA+N9+Mdi0w
gPKapeYntggw4OCSk1e4Abj8aDHYNlWAxlZp0cPXG8DOqn2/pm4UIDvJ8MKv
iQbQ4dm5J1fWKd/XacPEDZIB+NkH3zBao/y98qWVXnYG8PBY8fGuqwT4dueH
/b3PyjqzdO30hYkC5HQaXxJ6RQsffmQUHEkQYPXz2Sl6G7WwbV/S90dLBTi2
b57z1klauNMzLrJwsQA394as9+mohcXHLrarjhWg/6pj5o+UdXGHRWZzYb4A
UeMydkwqFGB9/NkmenMEUHmtDTHIEGBrTD3j7zMFaPPr+cBdKQI8qme79+UM
5XqIt9vXfopyX+o55lyMFODrxoQxz/wFyPVrtXCV8u9j1gTsjKopwLrU19MG
hQsQUe05y6pIA5veWCbYhSnXc2gNzbFrGjjSzGvLrbHK32k8Y2jPVOXxRbWX
RI4SIP1Z5abCqRq4tMLVwWy4ANdP18pZGaAB+z0mntuHCJAqd27nWUsDfIDh
dteBAoxYW/z0YbE+dNRcbL8tWLmfg9f+E5WpD63fe7827i3Am3PnO9Taog/N
F/0aMrm7AFf+0fa6GqkPp0+WLLwaqFzPe8Sa4V30oerItIbGAcr9ldc7w9ZJ
H6JE5tKlgwAxniMjr5bqwdtJC8Xo9srn438vMPKmHgjP7/RJ8RXgZIgUUW+b
HqRcqNnkcGvl58tPmmdN14PeoXe3nvIS4MP1+b0Tg/Tg9eZD0UeaCnA+fsSw
gDp60HL9x7jURgIkvVk2Wv1dDUMLrFNjGgjwacfBlXBbDcU+7gsDXZTHF+ib
Ld6hhozNsYZGTsr9ph1nExSthuY2b39fchCgRbfAx1bd1VA4ZbrHKBsBbr14
Ov+1ixp2n4OQcnMBrKZXdz/xQwV93C8On2ssKHPZ9Khl91SwpeD8r1Kt8v42
3fMak6aCMSdn/RqsJ0DZw8TLHWepwOOHs/vxKg0cUnsOcO+lgi5urYMqKjRg
0LR9O8sGKnCre7yhZ5kGgltfCFGX/+FWxSWJ/ZXvObZV5ofPO/9wzxVX/cIL
NKDqlLnjbY8//Gv80Oqp7zUQPm9prQ8/q/nkLuM2jnmtgaTF27+Up1fzntU/
7wbkaGDW7C1HbPtW81Hx+8bYZSnXxaB6av/qKl5SHV3n3wca6BnglLDgQBXv
Uyc/Y+EdDcwx/FR8Z0AVt9tXYV07UwPy5fkfG+pXcdvUpo/SQANn6qQ32Hj0
N7/6MAkcLmrguKPzWPuQ3/z+8mM7Zp/WwDPb7HEHDH/zejlnW946qlH27frf
ep+u5NOGjmyrOaCBLofynhuPruTh9npRjXdroFPA3dIcs0p+zWBTmrhNeX3z
k+yvXvzFffmduPYpGvjk4dyUh/3ipsO+PXdfo4HkxfnOT2x/8WnzXEdXrVD+
/jyz1+qMn/yXd5vnl+M08IofCQ+K+Mm1A7PUExZowDnW6fpBp5+8Y5/YjdUx
Gvj8pWlFozsV/LHllsHzp2mgonF0zesxFXyz6SLtx3ANZP9M6TzfrYJXxiaE
tBunfB5vkvYMePKDF1+2c4wZroGc22UTei36wYe5HKzaOlB5Ph98Z0LzH9xP
W379UG8NVA1PNt/7qpwft/jgtTtIA2E5BksNV5bzV9Il1ZKOys//65Cwql05
vx9Xt7RbOw1oz42f377gO2+0ySezsqUGIs/6PrXe9J3npV9ov7aJBpZE51jY
BH7n6/zNHa0aaCCkU8Up9qOMx2jGOMU4aaDRG70hKXvKeOyWG0bXbTXQb8zm
tDoDyrgU0GdPhakGBqeXd3wqlPGVV71PW2mVdWJX1x9w+htf5l9WZVWtDy1b
+SW9GveN98qbGvjzuz6srtErz8vuG7cprTv8eqE+1J8++P2lzFL+LsrXaOZ7
fTi78GfiwpmlvGnqo5pmL/XhmsYkf2HDUr4ruVbI8if60K7U3QKelfBbeSt2
fb6jD90a1vQWV5TwjFcOV7wy9CHm8rCUar8S/urN5KSQC/rQK3DvMv2iYn7q
g3te+HF9GNh3SHivncV8jond9hH79OHgaotzecHF3Pbl3O0+2/Vh16Lav65r
i7m+atitb+v1IXSL/a7P04t4PQfQrEtUXs+Sfm8Ln3/lKycbig6L9eFQeI3A
lI5f+eVGAeNjZ+mDfVlWcvGBQp4urZx+d6o++Ax9feC3dSGf8yFk1O9x+jAj
+NbBq/O+8N03fja3CNGH7hP25gR+/MwjO7/4ZNBXH1hu0bH1wZ/5qfnOqe+U
dW7qiIGPjvIC3n9s8YC09vrw/ES6/bYmBVxvt1X7Li31wah6zvLQ1E/c1GZg
5D8N9WHrfSHUusYnPsTR3cXPWR8sElJq74/5yE/nWSxeaa0PN5e36dn8Uz6/
+HbI0wxDZV01VD0+NiSfv7u6JSy3SlkHF0w40+LeB77p04jE18o6yiZGtJGl
D9zywrW0G/l6MKht0r2hp9/zfD3P2utf6MHeJ4ucbRq/5wtn/Zga9FBZdxd/
NijemceLl9Zzf39dDwrXbt1UUTOPD3lcOzvsgh40KAFbn7XvuJVmTsN/j+hB
RJNdRadM3/F++ZfveaTpQfHMFrfnJLzl7a84JE3cqAcOPVpFr9e+5Wnqth3W
r9CD7IPaYuO4NzzgpvXDgwv0ADoZDPukecNXFKe1Paqs4+6VSwzbLH3N7a+c
S9oRqry+xDYj9Wq85lXaE6WxQ/Xg1vro1+mOuXx+ctudfXrpgV+9d5fC3F7x
iSUVBdb+elC77tXbo1u/5FlVLX1ueevBJenplv1dXvB7I8I00z30YMnJG1l9
h+XwzoZ3P1o560FuxyLnGdHPOa+6sOaApR5Ypz0yq7/2GV9x3+hWO0EPPEe7
14s6mc072bPwmxVqaBEwfveCp0952zObI/t+UcPL2G9bBv7J4s/CzQtzctXK
3HTvvGXjLP6wdqk29LEarMa/bnN1yL+8/tlkVXmmGv4c/vHP3KQn/LtfQosV
F9SwRT1rbb/Mx/xL9AvjRkfU4NrwZ85Qvcdcinti8WinGlp3fOqxu+Mj7lk3
5dmy9WpwOmViJsY/5G+C51n0TlCD4bVJ+r4PHvCICRYRHvPUsOzM+qFpTg/4
gjX3wTFSDR/ry742uff5OvW6rPrj1LBC63OvZMU9HvDp0srAwWro7G914FuH
uzwwpfLGih5q2Glz+K6H+g73is8PK+6ghkWLAq/uvnWLR5UG9Z3lrYbUjBez
wjff5CPeeY5s1FgNfbdvqRkXfYPbldwaq19XDQsnVT/7NiSTN7rs6mpkq4Z6
X2zzTwde5xeib/SSjNSw+JEQdJ1d437RAYv2/VGBQ5rHE3spg0PR47YB31XQ
bdU6l+1BV/nlyd+yHT6rYNJF39WBIVe4SzOW0uCNCgYHevSqmgncq/f0xMlP
VbCg8vKbTr6cj5xyaWupss/ODWlu3mLdZT747oi4M9dUsHer2/q5qkt8w7m7
ty9cVEH8KL/4p/Mu8D7jXK+oTqogr0ONGkXG57mdxj8u4YAKRnRxvBF24Cw/
VBT8u/8uFfxxCpmbN+gMTxbLH41PVQErKF342+40Hzu3bO6lNSrY1mFUaOe8
kzxq5qrWA1eoIKlEXh0MJ3jIlEEqnyUqWNrnfPbxA8e5x6d1B4bOU8GN9w6t
vuw6xss3udy7Fq0Ck2vu++36HOX/7r59PzJCBQmNXic3iT7M/dsY5Y+aqAK/
GhXN3U4d5KOq67isG6uCXkeTjpkZHeBtHCJGGIxQgaZFw8iS6H08fp7jiAuD
lfff77JVzs89/NGc8xcP9lPBzBkmE58np3P21OfbM2WumCReG6kWd3P16yMT
/Lup4HerK3xc1S5+4bw4+UNnFcSNvPbW5Z+dfIH2ie+Vjiq4vP1x//4ndnD3
vv/8fiiqwDAy61zX7tv5yzZx2XbtVOA/cEvm7OCt/FBhUv5KHxW0fJh8cVvM
Zn5U8561bqWCzA9N6jS8sIm7FfHvRl4qeHe7c8IGuxR+StvO2bSZCk5Oblw8
M3EDnxZ47qFvYxWsjrLMDnNcz9/FaJqtaqiCZe1VoTZ8LQ/39htk7KaCrTdU
I1vNWsN/T5s+/1B9FdQdu8AwuUsyrzru8izCRQWhGy/8UjVaze3u9D80oI4K
vnVd/s/DNkk8dcOpwBAnFdi1nLYxukMi79azs0lsLRVEjkxoUjxhOW/f3G4M
1FRBo+F71g46towX7dh3o5aDCj4sDnF7ZxXPy1Z0y1htp+grp8/krIrjGXUC
vjrZquBVfPyB9AZLeGZ8XtEVaxWoDepYXny0iLuOjpk/x0qZA33OnD64fiF3
Dmg2IshSBdnB/zavPTmWux1+Nc7DQgVNP2eWJRydz1u3uTnDyVwFz2dpfr/d
N5f3/eA318VMeby5Znx1xmwe+Nt/dmtTFRRufht5vjqG7znRYvYgE+XxT2u+
WQ6cydsebr8uwVgF88r373a9E8VrtBAKbxip4EDl1UWNB8/gHxY5nbZSdNzj
SL+5f6bx2E/rGk6ooXze4HZ46aVI/mllTNJtQ+X3rUkMe5wUwU+0HtzGW9G1
J9oe1BRM4UPgwcKDBipInJF3fE3OJL61WY0HjRT92z6tzoeiiTwwMyD5mFYF
b35NbnHRdQJ3fz3Fjyn6SteAV6UzQ/mDOzt6/yuooMnq1C2r88fxluZyv2mK
DjkAg85FjuUjeglPbRVt33ZmzCGbMbyL8cFJXKOC5cun/rlzfxTPCJp5fIqi
tz8vvbt620hu0SO0S31FzwkW39cSRnC3fsFZL/RVcGZOq84vSkN40sQU482K
Du+9emqe/lBu0z5z0zBF19LeTcltPZiHvu3dxlXRSem2uduXDuRBCZ3Tvuqp
YP66ynu1yvrzNZ8NN19StLrvF9NJc/vxRdOM8lYq+u6yIO9bTsH83MekzqMV
nXho1ZWErD78RerUJF9FX2oY5VI3vTefdPPtcmtF+3+Pf+tl0Yvbss5mxWoV
TO/9LKHF7+7cqepL4X1FJ7n8anDBuBu/eblIfUzRn3Z7RIT7BfGVAaoGaxXt
YhvrapnYhdsGs1Yxio7c83Dc5ooAPtjM1nyEorVDqro5xXbiRU+NN3ZRdM9h
Vqm36/pzh0GHj3opekJ2/qbv2R24z9FRopOih6+tcjTdK/Hsfb09jBTdtsda
19bWjJ/M6hRSoVJBVN1mJ2Kr/bhd9Go5X9HLgx9bRpi240sMyvyyFf1U0+v9
zva+fND8pdduKTrvxtbhLxN9uEHJNv9Lig4RGyeb/2zNP57g+48qumZAYVFg
bCte/+qi/DRFr0ua9/1C3ZbcOjr+a4qiLRvM/HY624uHDB51PEnRrW5t1+7d
05z3dV5WP07Rw8TqIU2sPHmzLYG+cxX93nlAdWBVE+5y7Uz+dEWv7DdKZWvS
mOcv2OE6SdGrF/Vxb+rXiLtPXPhhrO757TubDlzhzscEz3QdrmiVb1jY/B8N
uEe8T9ZARY/Md1h4Yr4rf5+hKeuj6HO7TB7Xr1OfT89Jj+6uaMMXF7Ncnrrw
BcUhA7vofr9VSLFDel3ev0vuqo6KFm4/03cxr8OX7+jhKCr6enQfv76/avOl
Nk1LfBUdW9fsVOsatbh76Ehzb0U7zb4UFepbk1+96xLRQvfz7ffNP7TMnhfa
V5l5KvpmbqhecZktd+l6O7+xoovdO7yU5trwJbH7yhvq3s868xb/1Lbmk71/
+rgpulD9pHnBE0uekT10X31F7wqW9Kt3WXD33fs7uSi6x6Co8/WNzfnSWyU1
6ih6XkzOgMRyEx70JOp7bUX377PuQbpgzE/32KOppeiwgqMGJt41eMKmOq1r
6t6veX7O4jgD7mK4d4m9ooObTp1cUSLweY4NS2wV3dht88qYWRr+uux4jI2i
Ty4dP7SVoz43qppR01rR4f2uGs55pObqnfDQUtGZ910yz+1Q8Q/+6h0Wit7y
tFnaJ+0fuU5PeZG5ok1KhvTcXvpbPj08JcZM0Xvbzduhp1cpT93cJdZU0fzk
uu1HW/yU85xSU0wU7eqyPDh80Q951JxpYKzoo3eZgUvRd/nHuMxyI0W37Xbw
XG50mVwydmtbnX5f89Gpp/bfZN808xU1FD1ZfBQy6EGJ7PKoU76holuUW1je
31Ysi3Wm99Tpl7ul2Fj9ItnS7xU30F0fxW+bbi/6IgdEZ7XV6YorDXeE/SmQ
I3PPylpFB9qWs1nNP8ndFn/qqtMX3WbHbIjNl0MOvnglKLrnk+CKg4Xv5e6e
JrN1esWbSy63ovLkogeVtXTacPexPc7272T/NJ9rGt310tSx5+9/3sgn5gRP
0+lJzcXc+9teyzmTChrotOfKl6P8NLmy1HXbK31F258xOmVX8kLu2sp+i04v
mf1NvU2dI5s10R+u0/GR6uSpLZ/JAUdsXXX6wr6FR/oseSpb9jdQlj8VVC1b
XdK89F9ZP3b9RZ0eJrQ+5DTniWygtyhRp6+GrVoW5PRYvvVkzUidXttIT1m5
H8o+D5N9dNoebjyS9zyQb03qbqnTV6wTNNW2/8i+c9YWqhUdvX2D1wPNPXlU
Wdu7Om1XYJQban9Hrrxc87BOZ8R8yRrb7Zb8K6bGap1u0r636eptN+QOfT/M
0OmqkHnvs80y5blZSUP/atNBe/qmXpM/3Xznr9MPnF1rtWAZctbvG011uunb
qcPuVF6Rj3rVranTfh7nrq+6D/L4kkeCTvvsUascJnHZKvLmN5Xu+1zUacnd
UZflbdML3up07sQm/ufnXJSHN3N9rNPn9nYxjT97Xo7wHH1Np+tHekcbWp+T
rwWsOaPThv1TGvgknpGPTUzbr9MtrSwHebmclssOxW3V6cmD5q70eXBStnHy
WKPTI38FjTqw8YRcdGFRvE6Pffihxteo47LDrL3zdLoo6Gqq8YRjconD2Rl/
n58x1svj1RG57cyNk3R65X6z2odNDsszZzQfp9PfAnt22TzkoLxl1OThOn3B
+3WvgOv75dhJfoN0ul5IxqyArvvkBQ2T+ur0n40/CqLy98h9mvbv8ff9OPpM
/piaLkfdiAvU6XU7L0Xkjt4t7z1j20mnm7o3dbjZPk1O+VHJdPrUvJi6rT12
yRkbmvvp9LFXM2Kfu+2Udy8/1Obv69PrsCuhxQ75z9oJrXV6tTzbLyRlm2xb
f3QLnd48oOWN9e+3yOVSsqdOv844Maeo62a55dzSJjrdfGJ+XzlzkxyavdBD
p7sFpWTHDEyRHaBdw7+Pi58fnKzcIK+rqO32V7/d06HOifXy7I31XHX64GP7
R4tnrZMP/wyqp9O1dmZHQe+18uyLq+v+1WmvBt30XiPz42XOOu3Wo1J/p0ey
XPFuutPfv+fe9eTIxqtlw3iT2joNFU2ODo5IkndXXHLU6XCxek7kjkS538XF
NXW6fFfdE8veL5c/TBvhoNOfo9729BYT5L5vetr/fX46D3PbH6/8/t52Oh2b
+WS4Q4OlcovIsbY6fSdM4/Xy2BLZfcMym78/X133d/9ui+W8GZes/74ereeG
ad8Wyns7/rHS6QETSjo33xcrh3Tu/VdvsI7z9no4X/Z/esRSpxvfPJESGzpX
5kMd/+rPA93nJFrOlrsErrHQaVXfPzbp92bK05zt/ur+vSZ2a5waJbtMSjf/
+37jzYxWRU2XM26zvzr8ScapHsMj5YOv8sz+fr4Wo4a9SZ8izx+w7q/OMq8q
sN89UT5Z0OO/x3/9s3HWqfFyvWGWf7VqmWF+7yej5T0xr0z//r0Jjrc+q4fL
dyxO/9Wq59sSN04dIC9Xr/9P/24W8Su7h2znOf+/5zcwjza8314+Ghfx3+P4
X4+f4f+vxueL/3v+f79PpN+Hf0+kv4evR/zf6/nv9Yr0evH9iPR+8P2K/3u/
/30eIn0e+HmJ9Hnh5ynS54mft0ifN34fIn0f+H2J9H3h9ynS94nft0jfN14P
Il0PeL2IdL3g9STS9YTXm0jXG16PIl2PeL2KdL3i9SzS9YzXu0jXO94PIt0P
eL+IdL/g/STS/YT3m0j3G96PIt2PeL+KdL/i/SzS/Yz3u0j3O64HIq0HuF6I
/1sv/ltPRFpPcL0Rab3B9Uik9QjXK5HWK1zPRFrPcL0Tab3D9VCk9RDXS5HW
S1xPRVpPcb0Vab3F9Vik9RjXa5HWa1zPRVrPcb0Xab3H/UCk/QD3C5H2C9xP
RNpPcL8Rab/B/Uik/Qj3K5H2K9zPRNrPcL8Tab/D/VCk/RD3S5H2S9xPRdpP
cb8Vab/F/Vik/Rj3a5H2a9zPRdrPcb8Xab/HeUCkeQDnBZHmBZwnRJoncN4Q
ad7AeUSkeQTnFZHmFZxnRJpncN4Rad7BeUikeQjnJZHmJZynRJqncN4Sad7C
eUykeQznNZHmNZznRJrncN4Tad7DeVCkeRDnRZHmRZwnRZoncd4Uad7EeVSk
eRTnVZHmVZxnRZpncd4Vad7FeVikeRjnZZHmZZynRZqncd4Wad7GeVykeRzn
dZHmdZznRZrncd4Xad7H84BI5wE8L4h0XsDzhEjnCTxviHTewPOISOcRPK8w
Oq/geYbReQbPO4zOO3geYnQewvMSo/MSnqcYnafwvMXovIXnMUbnMTyvMTqv
4XmO0XkOz3uMznt4HmR0HsTzIqPzIp4nGZ0n8bzJ6LyJ51FG51E8rzI6r+J5
ltF5Fs+7jM67eB5mdB7G8zKj8zKepxmdp/G8zei8jedxRudxPK8zOq/jeZ7R
eR7P+4zO++gHMPID0C9g5Begn8DIT0C/gZHfgH4EIz8C/QpGfgX6GYz8DPQ7
GPkd6Icw8kPQL2Hkl6CfwshPQb+Fkd+CfgwjPwb9GkZ+Dfo5jPwc9HsY+T3o
BzHyg9AvYuQXoZ/EyE9Cv4mR34R+FCM/Cv0qRn4V+lmM/Cz0uxj5XeiHMfLD
0C9j5Jehn8bIT0O/jZHfhn4cIz8O/TpGfh36eYz8PPT7GPl96Acy8gPRL2Tk
F6KfyMhPRL+Rkd+IfiQjPxL9SkZ+JfqZjPxM9DsZ+Z3ohzLyQ9EvZeSXop/K
yE9Fv5WR34p+LCM/Fv1aRn4t+rmM/Fz0exn5vegHM/KD0S9m//OL//OTGfnJ
6Dez//nN//nRjPxo9KsZ+dXoZzPys9HvZuR3ox/OyA9Hv5yRX45+OiM/Hf12
Rn47+vGM/Hj06xn59ejnM/Lz0e9n5PdjHsAoD8C8gFFegHkCozwB8wZGeQPm
EYzyCMwrGOUVmGcwyjMw72CUd2AewigPwbyEUV6CeQqjPAXzFkZ5C+YxjPIY
zGsY5TWY5zDKczDvYZT3YB7EKA/CvIhRXoR5EqM8CfMmRnkT5lGM8ijMqxjl
VZhnMcqzMO9ilHdhHsYoD8O8jFFehnkaozwN8zZGeRvmcYzyOMzrGOV1mOcx
yvMw72OU92EeyCgPxLyQUV6IeSKjPBHzRkZ5I+aRjPJIzCsZ5ZWYZzLKMzHv
ZJR3Yh7KKA/FvJRRXop5KqM8FfNWRnkr5rGM8ljMaxnltZjnMspzMe9llPdi
HswoD8a8mFFejHkyozwZ82ZGeTPm0YzyaMyrGeXVmGczyrMx72aUd2MezigP
x7ycUV6OeTqjPB3zdkZ5O+bxjPJ4zOsZ5fWY5zPK8zHvZ5T3Iw/AiAdAXoAR
L4A8ASOeAHkDRrwB8giMeATkFRjxCsgzMOIZkHdgxDsgD8GIh0BeghEvgTwF
I54CeQtGvAXyGIx4DOQ1GPEayHMw4jmQ92DEeyAPwogHQV6EES+CPAkjngR5
E0a8CfIojHgU5FUY8SrIszDiWZB3YcS7IA/DiIdBXoYRL4M8DSOeBnkbRrwN
8jiMeBzkdRjxOsjzMOJ5kPdhxPsgD8SIB0JeiBEvhDwRI54IeSNGvBHySIx4
JOSVGPFKyDMx4pmQd2LEOyEPxYiHQl6KES+FPBUjngp5K0a8FfJYjHgs5LUY
8VrIczHiuZD3YsR7IQ/GiAdDXowRL4Y8GSOeDHkzRrwZ8miMeDTk1Rjxasiz
MeLZkHdjxLshD8eIh0NejhEvhzwdI54OeTtGvB3yeIx4POT1GPF6yPMx4vmQ
92PE+yEPyIgHRF6QES+IPCEjnhB5Q0a8IfKIjHhE5BUZ8YrIMzLiGZF3ZMQ7
Ig/JiIdEXpIRL4k8JSOeEnlLRrwl8piMeEzkNRnxmshzMuI5kfdkxHsiD8qI
B0VelBEvijypRDwp8qYS8abIo0rEoyKvKhGvijyrRDwr8q4S8a7Iw0rEwyIv
KxEvizytRDwt8rYS8bbI40r/43H/43Ul4nWR55WI50XeVyLeF3lgiXhg5IUl
4oWRJ5aIJ0beWCLeGHlkiXhk5JUl4pWRZ5aIZ0beWSLeGXloiXho5KUl4qWR
p5aIp0beWiLeGnlsiXhs5LUl4rWR55aI50beWyLeG3lwiXhw5MUl4sWRJ5eI
J0feXCLeHHl0iXh05NUl4tWRZ5eIZ0feXSLeHXl4iXh45OUl4uWRp5eIp0fe
XiLeHnl8iXh85PUl4vWR55eI50feXyLeH/sAEvUBsC8gUV8A+wQS9QmwbyBR
3wD7CBL1EbCvIFFfAfsMEvUZsO8gUd8B+xAS9SGwLyFRXwL7FBL1KbBvIVHf
AvsYEvUxsK8hUV8D+xzS//oc//U9JOp7YB9Eoj4I9kUk6otgn0SiPgn2TSTq
m2AfRaI+CvZVJOqrYJ9Foj4L9l0k6rtgH0aiPgz2ZSTqy2CfRqI+DfZtJOrb
YB9Hoj4O9nUk6utgn0eiPg/2fSTq+2AfSKI+EPaFJOoLYZ9Ioj4R9o0k6hth
H0miPhL2lSTqK2GfSaI+E/adJOo7YR9Koj4U9qUk6kthn0qiPhX2rSTqW2Ef
S6I+Fva1JOprYZ9Loj4X9r0k6nthH0yiPhj2xSTqi2GfTKI+GfbNJOqbYR9N
oj4a9tUk6qthn02iPhv23STqu2EfTqI+HPblJOrLYZ9Ooj4d9u0k6tthH0+i
Ph729STq62GfT6I+H/b9JOr7YR9Qoj4g9gUl6gtin1CiPiH2DSXqG2IfUaI+
IvYVJeorYp9Roj4j9h0l6jtiH1KiPiT2JSXqS2KfUqI+JfYtJepbYh9Toj4m
9jUl6mtin1OiPif2PSXqe2IfVKI+KPZFJeqLYp9Uoj4p9k0l6ptiH1WiPir2
VSXqq2KfVaI+K/ZdJeq7Yh9Woj4s9mUl6stin1aiPi32bSXq22IfV6I+LvZ1
JerrYp9Xoj4v9n0l6vtiH1iiPjD2hSXqC2OfWKI+MfaNJeobYx9Zoj4y9pUl
6itjn1miPjP2nSXqO2MfWqI+NPalJepLY59aoj419q0l6ltjH1uiPjb2tSXq
a2OfW6I+N/a9Jep7Yx9coj449sUl6otjn1yiPjn2zSXqm2MfXaI++v8BehtG
6w==
      "]]}},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"y\"", TraditionalForm]},
  PlotRange->{{-5, 5}, {-5, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.460678512479478*^9, 3.460678536416978*^9}},
 CellTags->"compatibility-yes"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8:",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" Contour map of the flow potential on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane for a perfect ellipsoidal conductor with semiaxes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", ",", "b", ",", "c"}], ")"}], "=", 
    RowBox[{"(", 
     RowBox[{"1", ",", "2", ",", "3"}], ")"}]}], TraditionalForm]]],
 StyleBox[". Calculated approximations to the principal dividing streamlines \
are also drawn.",
  FontFamily->"Times"]
}], "Special1",
 CellMargins->{{36, 74}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True,
 FontSize->10],

Cell["\<\
Although the contour lines are drawn in Figure 8, they are almost \
superfluous. The outline of the ellipse plus the dividing streamlines provide \
all the information necessary for a qualitative description of the flow \
field; the contours and their spacings provide a reference for determining \
rates of flow. If the geometry of the flow regime is of more interest than \
the flow velocities, then contours can be neglected in favour of dividing \
streamlines.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "2.3.3  An Oblate Spheroid (",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", " ", "=", " ", 
    RowBox[{"b", " ", ">", " ", "c"}]}], TraditionalForm]]],
 ")"
}], "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["The ",
  FontFamily->"Times"],
 StyleBox["oblate",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontFamily->"Times"],
 StyleBox["(prolate)",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontFamily->"Times"],
 StyleBox["spheroid",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" is generated when two of three semiaxes are equal, and greater \
(lesser) than the third semiaxis. The earlier general potential solution \
assumed that the three semiaxes were distinct, hence we cannot determine the \
present solution from the general solution except by taking limits as ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"b", "\[Rule]", "a"}], TraditionalForm]]],
 StyleBox[". It is easier to repeat the earlier analysis with the degeneracy \
built in. For the remainder of this section, reference to semiaxis ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["b", TraditionalForm]]],
 StyleBox[" will be dropped; the oblate spheroid is considered to be \
generated by the semiaxes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"a", ",", " ", "c"}], TraditionalForm]]],
 StyleBox[".",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Again we start by solving for the solution characteristic ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "OS"], TraditionalForm]]],
 StyleBox[":",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Lambda]SolutionOS", "=", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox[
         SuperscriptBox["x", "2"], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", "\[Lambda]"}]], "+", 
        FractionBox[
         SuperscriptBox["y", "2"], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", "\[Lambda]"}]], "+", 
        FractionBox[
         SuperscriptBox["z", "2"], 
         RowBox[{
          SuperscriptBox["c", "2"], "+", "\[Lambda]"}]]}], "==", "1"}], ",", 
      "\[Lambda]"}], "]"}]}], ";"}], TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[Lambda]OS", "[", 
     RowBox[{"x_", ",", "y_", ",", "z_", ",", "a_", ",", "c_"}], "]"}], "=", 
    RowBox[{"\[Lambda]", "/.", 
     RowBox[{"Last", "[", "\[Lambda]SolutionOS", "]"}]}]}], ";"}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["In this degenerate case ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Lambda]OS", TraditionalForm]]],
 StyleBox[" has a quite simple form.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["The definition of the ",
  FontFamily->"Times"],
 "delta",
 StyleBox[" amplitude function, \[CapitalDelta], must also be amended:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]OS", "(", 
     RowBox[{"w_", ",", "a_", ",", "c_"}], ")"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "+", "w"}], ")"}], " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["c", "2"], "+", "w"}]]}]}], ";"}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["We commence the calculation of the auxiliary integrals ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["A",
      FontWeight->"Bold"], "\[Lambda]"], ",", 
    SubscriptBox[
     StyleBox["C",
      FontWeight->"Bold"], "\[Lambda]"]}], TraditionalForm]]],
 StyleBox[":",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"IndefiniteIntegralAOS", "=", 
   RowBox[{"\[Integral]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", "w"}], ")"}], " ", 
       RowBox[{"\[CapitalDelta]OS", "(", 
        RowBox[{"w", ",", "a", ",", "c"}], ")"}]}]], 
     RowBox[{"\[DifferentialD]", "w"}]}]}]}], TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  FractionBox[
   SqrtBox[
    RowBox[{
     SuperscriptBox["c", "2"], "+", "w"}]], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", "w"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"ArcTan", "[", 
    FractionBox[
     SqrtBox[
      RowBox[{
       SuperscriptBox["c", "2"], "+", "w"}]], 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["c", "2"]}]]], "]"}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], 
    RowBox[{"3", "/", "2"}]]]}]], "Output",
 CellChangeTimes->{3.460678571088853*^9}]
}, Open  ]],

Cell["The upper integration limit is then", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"upperlimitAOS", "=", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"w", "\[Rule]", "\[Infinity]"}]], 
    RowBox[{"(", "\[ThinSpace]", 
     RowBox[{"IndefiniteIntegralAOS", "/.", " ", 
      RowBox[{
       RowBox[{"ArcTan", "[", "g_", "]"}], "\[Rule]", 
       RowBox[{"\[Pi]", "/", "2"}]}]}], ")"}]}]}], TraditionalForm]], "Input",\

 AspectRatioFixed->True],

Cell[BoxData[
 FractionBox["\[Pi]", 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{3.460678574823228*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["which yields the following expression for ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["A",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[":",
  FontFamily->"Times",
  FontSize->10]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"AOS", "[", "\[Lambda]_", "]"}], "[", 
    RowBox[{"a", ",", "c"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"upperlimitAOS", "-", 
      RowBox[{"(", 
       RowBox[{"IndefiniteIntegralAOS", "/.", 
        RowBox[{"w", "\[Rule]", "\[Lambda]"}]}], ")"}]}], ")"}]}]}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SuperscriptBox["a", "2"], " ", "c", " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox["\[Pi]", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}]], "-", 
    FractionBox[
     SqrtBox[
      RowBox[{
       SuperscriptBox["c", "2"], "+", "\[Lambda]"}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", "\[Lambda]"}], ")"}]}]], "-", 
    FractionBox[
     RowBox[{"ArcTan", "[", 
      FractionBox[
       SqrtBox[
        RowBox[{
         SuperscriptBox["c", "2"], "+", "\[Lambda]"}]], 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["c", "2"]}]]], "]"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.460678577823228*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["The symmetry in the definition of the auxiliary integral functions \
for the general ellipsoid is now broken, and we must calculate ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["C",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[" ",
  FontFamily->"Symbol",
  FontSize->10,
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["directly:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"IndefiniteIntegralCOS", "=", 
   RowBox[{"\[Integral]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["c", "2"], "+", "w"}], ")"}], " ", 
       RowBox[{"\[CapitalDelta]OS", "(", 
        RowBox[{"w", ",", "a", ",", "c"}], ")"}]}]], 
     RowBox[{"\[DifferentialD]", "w"}]}]}]}], TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  FractionBox["2", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["c", "2"], "+", "w"}]]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"ArcTan", "[", 
     FractionBox[
      SqrtBox[
       RowBox[{
        SuperscriptBox["c", "2"], "+", "w"}]], 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["c", "2"]}]]], "]"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], 
    RowBox[{"3", "/", "2"}]]]}]], "Output",
 CellChangeTimes->{3.460678582807603*^9}]
}, Open  ]],

Cell["Whence", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"upperlimitCOS", "=", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"w", "\[Rule]", "\[Infinity]"}]], "\[ThinSpace]", 
     RowBox[{"(", 
      RowBox[{"%", "/.", 
       RowBox[{
        RowBox[{
         SuperscriptBox["tan", 
          RowBox[{"-", "1"}]], "(", "g__", ")"}], "\[Rule]", 
        FractionBox["\[Pi]", "2"]}]}], ")"}]}], " ", "//", "Simplify"}]}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["\[Pi]", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], 
    RowBox[{"3", "/", "2"}]]]}]], "Output",
 CellChangeTimes->{3.460678582916978*^9}]
}, Open  ]],

Cell["yields", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"COS", "[", "\[Lambda]_", "]"}], "[", 
    RowBox[{"a", ",", "c"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"upperlimitCOS", "-", 
      RowBox[{"(", 
       RowBox[{"IndefiniteIntegralCOS", "/.", 
        RowBox[{"w", "\[Rule]", "\[Lambda]"}]}], ")"}]}], ")"}]}]}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SuperscriptBox["a", "2"], " ", "c", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["\[Pi]", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]]}], "-", 
    FractionBox["2", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["c", "2"], "+", "\[Lambda]"}]]}]], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"ArcTan", "[", 
       FractionBox[
        SqrtBox[
         RowBox[{
          SuperscriptBox["c", "2"], "+", "\[Lambda]"}]], 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["c", "2"]}]]], "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.460678582963853*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["The reduction in complexity of the auxiliary integrals in this \
degenerate case means that we can check these results against the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Lambda]", "=", "0"}], TraditionalForm]]],
 StyleBox[" identity (equation (11)) easily:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"PowerExpand", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{
       RowBox[{"AOS", "[", "0", "]"}], "[", 
       RowBox[{"a", ",", "c"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"COS", "[", "0", "]"}], "[", 
      RowBox[{"a", ",", "c"}], "]"}]}], "]"}], " ", "]"}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.460678586479478*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["The construction of the solution can now proceed as before for the \
general ellipsoid case, with ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["B",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[" and ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["B",
     FontWeight->"Bold"], "0"], TraditionalForm]]],
 StyleBox[" replaced by ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["A",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[" and ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["A",
     FontWeight->"Bold"], "0"], TraditionalForm]]],
 StyleBox[", respectively. The above expressions for ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["A",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[" and ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["C",
     FontWeight->"Bold"], "\[Lambda]"], TraditionalForm]]],
 StyleBox[" are equivalent to Carslaw and Jaeger's expressions for the oblate \
spheroidal case, albeit expressed in terms of different elementary functions.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3.4  A Perfect Thin Disk Conductor", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["A perfectly thin circular disk is a limiting case of an oblate \
spheroid, where the minor semiaxis, in this case ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["c", TraditionalForm]]],
 StyleBox[", tends to zero. Unfortunately, the oblate spheroid potential \
diverges in such a limit, unless ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]]],
 StyleBox[" tends to infinity, ",
  FontFamily->"Times"],
 StyleBox["i.e.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" unless the perfectly thin disk is also a perfect conductor. \
Hence, we first take the limit of the oblate spheroid potential as ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]]],
 StyleBox[" tends to infinity. The inner potential vanishes again, but the \
outer potential tends to",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["V", "1"]}], " ", "x"}], "-", 
   RowBox[{
    SubscriptBox["V", "2"], " ", "y"}], "-", 
   RowBox[{
    SubscriptBox["V", "3"], " ", "z"}]}], TraditionalForm], "\n", 
 FormBox[
  RowBox[{
   RowBox[{"+", 
    FractionBox[
     RowBox[{
      SubscriptBox["V", "1"], " ", 
      RowBox[{
       SubscriptBox[
        StyleBox[
         RowBox[{
          StyleBox["A",
           FontSlant->"Italic"], 
          StyleBox["OS",
           FontSlant->"Plain"]}],
         FontWeight->"Bold"], "\[Lambda]"], 
       StyleBox["(",
        FontWeight->"Bold"], 
       RowBox[{"a", ",", "c"}], ")"}], " ", "x"}], 
     RowBox[{
      SubscriptBox[
       StyleBox[
        RowBox[{
         StyleBox["A",
          FontSlant->"Italic"], "O", "S"}],
        FontWeight->"Bold"], "0"], "(", 
      RowBox[{"a", ",", "c"}], ")"}]]}], "+", 
   FractionBox[
    RowBox[{
     SubscriptBox["V", "2"], " ", 
     RowBox[{
      SubscriptBox[
       StyleBox[
        RowBox[{
         StyleBox["A",
          FontSlant->"Italic"], "O", "S"}],
        FontWeight->"Bold"], "\[Lambda]"], 
      StyleBox["(",
       FontWeight->"Bold"], 
      RowBox[{"a", ",", "c"}], ")"}], " ", "y"}], 
    RowBox[{
     SubscriptBox[
      StyleBox[
       RowBox[{
        StyleBox["A",
         FontSlant->"Italic"], "O", "S"}],
       FontWeight->"Bold"], "0"], "(", 
     RowBox[{"a", ",", "c"}], ")"}]], "+", 
   FractionBox[
    RowBox[{
     SubscriptBox["V", "3"], 
     StyleBox[" ",
      FontWeight->"Bold"], 
     RowBox[{
      SubscriptBox[
       StyleBox[
        RowBox[{
         StyleBox["C",
          FontSlant->"Italic"], "OS"}],
        FontWeight->"Bold"], "\[Lambda]"], 
      StyleBox["(",
       FontWeight->"Bold"], 
      RowBox[{"a", ",", "c"}], ")"}], " ", "z"}], 
    RowBox[{
     SubscriptBox[
      StyleBox[
       RowBox[{
        StyleBox["C",
         FontSlant->"Italic"], "O", "S"}],
       FontWeight->"Bold"], "0"], "(", 
     RowBox[{"a", ",", "c"}], ")"}]]}], TraditionalForm]}], "Input",
 AspectRatioFixed->True,
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[{
 StyleBox["It remains to take the limit as ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "\[Rule]", "0"}], TraditionalForm]]],
 StyleBox[". Let us consider the characteristic ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["\[Lambda]", TraditionalForm]]],
 StyleBox[". The following simple substitution shows that the limit is well \
defined:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Lambda]Disk", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_", ",", "a_"}], "]"}], ":=", 
   RowBox[{"\[Lambda]OS", "[", 
    RowBox[{"x", ",", "y", ",", "z", ",", "a", ",", "0"}], "]"}]}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Now we turn to the limiting behaviour of the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox[
      RowBox[{
       StyleBox["A",
        FontSlant->"Italic"], "OS"}],
      FontWeight->"Bold"], "\[Lambda]"], "/", 
    SubscriptBox[
     StyleBox[
      RowBox[{
       StyleBox["A",
        FontSlant->"Italic"], "OS"}],
      FontWeight->"Bold"], "0"]}], TraditionalForm]]],
 StyleBox[" and ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox[
      RowBox[{
       StyleBox["C",
        FontSlant->"Italic"], "OS"}],
      FontWeight->"Bold"], "\[Lambda]"], "/", 
    SubscriptBox[
     StyleBox[
      RowBox[{
       StyleBox["C",
        FontSlant->"Italic"], "OS"}],
      FontWeight->"Bold"], "0"]}], TraditionalForm]]],
 StyleBox[" ratios. For the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   StyleBox["A",
    FontWeight->"Bold"], TraditionalForm]]],
 StyleBox[" function, the ratio is",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"Simplify", "[", 
   RowBox[{"PowerExpand", "[", 
    FractionBox[
     RowBox[{
      RowBox[{
       StyleBox[
        RowBox[{
         StyleBox["A",
          FontSlant->"Italic"], "OS"}]], "[", "\[Lambda]", "]"}], "[", 
      RowBox[{"a", ",", "c"}], "]"}], 
     RowBox[{
      RowBox[{
       StyleBox[
        RowBox[{
         StyleBox["A",
          FontSlant->"Italic"], "OS"}]], "[", "0", "]"}], "[", 
      RowBox[{"a", ",", "c"}], "]"}]], "]"}], "]"}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["a", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", "\[Pi]"}], "+", 
     RowBox[{"\[Pi]", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["c", "2"]}]], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["c", "2"], "+", "\[Lambda]"}]]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", "\[Lambda]"}], ")"}], " ", 
      RowBox[{"ArcTan", "[", 
       FractionBox[
        SqrtBox[
         RowBox[{
          SuperscriptBox["c", "2"], "+", "\[Lambda]"}]], 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["c", "2"]}]]], "]"}]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a", "2"], "+", "\[Lambda]"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "c", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["c", "2"]}]]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "\[Pi]"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"ArcTan", "[", 
       FractionBox["c", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["c", "2"]}]]], "]"}]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.460678592198228*^9}]
}, Open  ]],

Cell[TextData[{
 "Taking the limit as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "\[Rule]", "0"}], TraditionalForm]]],
 " and simplifying, ultimately yields"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"Aratio", "[", "\[Lambda]_", "]"}], "[", "a_", "]"}], " ", ":=", 
   " ", 
   RowBox[{
    FormBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", "a", " ", 
        SqrtBox["\[Lambda]"]}], 
       RowBox[{"\[Pi]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", "\[Lambda]"}], ")"}]}]]}],
     TraditionalForm], "-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["tan", 
        RowBox[{"-", "1"}]], "(", 
       FractionBox[
        SqrtBox["\[Lambda]"], 
        FormBox["a",
         TraditionalForm]], ")"}]}], "\[Pi]"]}]}], TraditionalForm]], "Input"],

Cell[TextData[{
 StyleBox["We use similar methods for the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["C",
      FontWeight->"Bold"], "\[Lambda]"], "/", 
    SubscriptBox[
     StyleBox["C",
      FontWeight->"Bold"], "0"]}], TraditionalForm]]],
 StyleBox[" ratio:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"Simplify", "[", 
   RowBox[{"PowerExpand", "[", 
    FractionBox[
     RowBox[{
      RowBox[{
       StyleBox[
        RowBox[{
         StyleBox["C",
          FontSlant->"Italic"], "OS"}]], "[", "\[Lambda]", "]"}], "[", 
      RowBox[{"a", ",", "c"}], "]"}], 
     RowBox[{
      RowBox[{
       StyleBox[
        RowBox[{
         StyleBox["C",
          FontSlant->"Italic"], "OS"}]], "[", "0", "]"}], "[", 
      RowBox[{"a", ",", "c"}], "]"}]], "]"}], "]"}], 
  TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 FractionBox[
  RowBox[{"c", " ", 
   RowBox[{"(", 
    RowBox[{"\[Pi]", "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["c", "2"]}]]}], 
      SqrtBox[
       RowBox[{
        SuperscriptBox["c", "2"], "+", "\[Lambda]"}]]], "-", 
     RowBox[{"2", " ", 
      RowBox[{"ArcTan", "[", 
       FractionBox[
        SqrtBox[
         RowBox[{
          SuperscriptBox["c", "2"], "+", "\[Lambda]"}]], 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["c", "2"]}]]], "]"}]}]}], ")"}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["c", "2"]}]]}], "+", 
   RowBox[{"c", " ", "\[Pi]"}], "-", 
   RowBox[{"2", " ", "c", " ", 
    RowBox[{"ArcTan", "[", 
     FractionBox["c", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["c", "2"]}]]], "]"}]}]}]]], "Output",
 CellChangeTimes->{3.460678596120103*^9}]
}, Open  ]],

Cell["Again, we take the limit, yielding", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Limit[%, c\[Rule]0]", "Input",
 AspectRatioFixed->True],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.460678599885728*^9}]
}, Open  ]],

Cell["\<\
We can consolidate the derived results into the following single analytic \
expression for the steady flow potential near a perfectly conducting, \
perfectly thin circular disk:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"uDisk", "(", 
    RowBox[{
    "x_", ",", "y_", ",", "z_", ",", "a_", ",", "V1_", ",", "V2_", ",", 
     "V3_"}], ")"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Aratio", "[", 
          RowBox[{"\[Lambda]Disk", "[", 
           RowBox[{"x", ",", "y", ",", "z", ",", "a"}], "]"}], "]"}], "[", 
         "a", "]"}]}], ")"}]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x", "  ", "V1"}], "+", 
       RowBox[{"y", " ", "V2"}]}], ")"}]}], "-", 
    RowBox[{"z", " ", "V3"}]}]}], TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["This compact expression permits rapid evaluation of gradients, \
either numerically or analytically. Here we take analytical gradients, \
generating the corresponding exact velocity field (for ",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox["=1):",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"vxDisk", "(", 
    RowBox[{
    "x_", ",", "y_", ",", "z_", ",", "a_", ",", "V1_", ",", "V2_", ",", 
     "V3_"}], ")"}], ":=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[PartialD]", 
      RowBox[{"uDisk", "(", 
       RowBox[{
       "x", ",", "y", ",", "z", ",", "a", ",", "V1", ",", "V2", ",", "V3"}], 
       ")"}]}], 
     RowBox[{"\[PartialD]", "x"}],
     MultilineFunction->None]}]}], TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"vyDisk", "(", 
    RowBox[{
    "x_", ",", "y_", ",", "z_", ",", "a_", ",", "V1_", ",", "V2_", ",", 
     "V3_"}], ")"}], ":=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[PartialD]", 
      RowBox[{"uDisk", "(", 
       RowBox[{
       "x", ",", "y", ",", "z", ",", "a", ",", "V1", ",", "V2", ",", "V3"}], 
       ")"}]}], 
     RowBox[{"\[PartialD]", "y"}],
     MultilineFunction->None]}]}], TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"vzDisk", "(", 
    RowBox[{
    "x_", ",", "y_", ",", "z_", ",", "a_", ",", "V1_", ",", "V2_", ",", 
     "V3_"}], ")"}], ":=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[PartialD]", 
      RowBox[{"uDisk", "(", 
       RowBox[{
       "x", ",", "y", ",", "z", ",", "a", ",", "V1", ",", "V2", ",", "V3"}], 
       ")"}]}], 
     RowBox[{"\[PartialD]", "z"}],
     MultilineFunction->None]}]}], TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["and calculate approximations to the dividing streamlines for the \
circular disk. Again this is done by tracking from starting points just \
outside the disk boundary (in the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox["-",
  FontFamily->"Courier"],
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 StyleBox[" plane) and just below the centre point of the disk (in the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox["-",
  FontFamily->"Courier"],
 Cell[BoxData[
  FormBox["z", TraditionalForm]]],
 StyleBox[" plane):",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
DiskPathz = 
  RKParticleTrack[{vxDisk[x,y,0,1,1,0,0],
                   vyDisk[x,y,0,1,1,0,0]},
                  {x,y}, {0,1+1/10^6}, 
                  {t, 0, -25, -0.01}];\
\>", "Input",
 AspectRatioFixed->True],

Cell["\<\
DiskPathy = 
  RKParticleTrack[{vxDisk[x,0,z,1,1,0,0],
                   vzDisk[x,0,z,1,1,0,0]},
                  {x,z}, {0,-1/10^6}, 
                  {t, 0, -25, -0.01}];\
\>", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["It is worth noting that the time integration limit for the ",
  FontFamily->"Times"],
 StyleBox["DiskPathy",
  FontFamily->"Courier"],
 StyleBox[" list is longer than for the ",
  FontFamily->"Times"],
 StyleBox["DiskPathz",
  FontFamily->"Courier"],
 StyleBox[" flow path, even though the ",
  FontFamily->"Times"],
 StyleBox["x",
  FontFamily->"Courier"],
 StyleBox[" components of their respective terminal points will turn out to \
be approximately equal. This indicates that the magnitudes of the velocities \
near to and under the disk are significantly lower than the magnitudes on the \
",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane close to the perimeter of the disk. These differences can \
be missed when flow regimes are represented by simple flow paths alone. \
Returning to the calculation, full flow paths are generated by symmetry:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
DPy1 = Join[Reverse[DiskPathy] /. {x_,z_}->{-x,z},
            DiskPathy];
DPy2 = Join[Reverse[DiskPathy] /. {x_,z_}->{-x,-z},
            DiskPathy /. {x_,z_}->{x,-z}];\
\>", "Input",
 AspectRatioFixed->True],

Cell["\<\
DPz1 = Join[Reverse[DiskPathz] /. {x_,y_}->{-x,y},
            DiskPathz];
DPz2 = Join[Reverse[DiskPathz] /. {x_,y_}->{x,-y},
            DiskPathz /. {x_,y_}->{-x,-y}];\
\>", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Approximations to the dividing streamlines on the vertical plane ",
  
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", "0"}], TraditionalForm]]],
 StyleBox[" are plotted in Figure 9 for a unit circular thin disk \
(represented by a horizontal bar).",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", "[", "0.003`", "]"}], ",", 
       RowBox[{"Line", "/@", 
        RowBox[{"{", 
         RowBox[{"DPy1", ",", "DPy2"}], "}"}]}], ",", 
       RowBox[{"Thickness", "[", "0.005`", "]"}], ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{
   {Thickness[0.003], LineBox[CompressedData["
1:eJwU2nc8lV8YAHCy997z4nKv1UCo8BBpkNJAyIhIlBlFshPJKivZlZlECnFD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     "]], LineBox[CompressedData["
1:eJwU2nc8lV8YAHCy997z4nKvVUKo8BBpkNJAyMhKlBlFshPJKivZlZlECiFU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     "]]}, 
   {Thickness[0.005], LineBox[{{-1, 0}, {1, 0}}]}},
  AspectRatio->Automatic,
  PlotRange->{{-4, 4}, {-2, 2}}]], "Output",
 CellChangeTimes->{3.460678624291978*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 9:",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" Approximate dividing streamlines for a perfect circular disk \
conductor (represented by the horizontal bar) plotted on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane.",
  FontFamily->"Times"]
}], "Text",
 CellMargins->{{36, 74}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True,
 FontSize->10],

Cell[TextData[{
 StyleBox["Approximations to the dividing streamlines on the horizontal plane \
",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" are plotted in Figure 10. ",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", "[", "0.003`", "]"}], ",", 
       RowBox[{"Line", "/@", 
        RowBox[{"{", 
         RowBox[{"DPz1", ",", "DPz2"}], "}"}]}], ",", 
       RowBox[{"Thickness", "[", "0.005`", "]"}], ",", 
       RowBox[{"Circle", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{
   {Thickness[0.003], LineBox[CompressedData["
1:eJwc3Hc4ll0YAHAjSkNWkZGR8np5vXsU5SYjKpGIlJQIERkZJYmsSkmljCJN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     "]], LineBox[CompressedData["
1:eJwc3Hc4ll0YAHAjSkNEkZGR8np5vXsUZVMqkYiUlAgRGVlJIqtSopRRpElG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     "]]}, 
   {Thickness[0.005], CircleBox[{0, 0}]}},
  AspectRatio->Automatic,
  PlotRange->{{-4, 4}, {-2, 2}}]], "Output",
 CellChangeTimes->{3.460678627541978*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 10:",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" Approximate dividing streamlines for a perfect circular disk \
conductor (outlined) plotted on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane.",
  FontFamily->"Times"]
}], "Special1",
 CellMargins->{{36, 74}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True,
 FontSize->10],

Cell["\<\
Figures 9 and 10 depict approximations to the principal dividing streamlines \
for a perfect circular disk conductor. These approximations themselves \
contain information on the corresponding capture and release zones. In \
particular, from the calculated flow paths it is simple to determine \
approximations to the widths and depths of the capture and release zones.  \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.  Lake-Aquifer Interaction", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["The preceding section discussed the mathematical analysis of \
Laplace flow near an embedded ellipsoid, and various limiting and degenerate \
cases. As an example of the application of the preceding theoretical results, \
we consider the problem of steady groundwater flow in the vicinity of a lake. \
We assume that the aquifer underlying the lake is infinitely deep, uniform, \
isotropic and fully saturated, and that the lake can be represented by a \
highly conductive body overlying the aquifer. Furthermore we restrict \
attention to the case where vertical recharge (due to precipitation or \
evaporation) to the lake and aquifer is zero. This lake-aquifer system \
corresponds to a case where the ambient flow in the far field is confined to \
the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox["-",
  FontFamily->"Courier"],
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 StyleBox[" plane,",
  FontFamily->"Times"],
 StyleBox[" i.e.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["V", "3"], "=", "0"}], TraditionalForm]]],
 StyleBox[",  and the lake is represented by the half-ellipsoid for ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "\[LessEqual]", "0"}], TraditionalForm]]],
 StyleBox[" (by symmetry the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane is a no-flow boundary when ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["V", "3"], "=", "0"}], TraditionalForm]]],
 StyleBox["). In a physical lake-aquifer system, there is some slope at the \
water table, which defines the upper boundary of the aquifer flow domain. \
However a solution based on assuming a horizontal water table at ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" is believed to be a good approximation.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Given the mathematical relationship between heat conduction and groundwater \
flow, we can readily transfer the results of section 2 to corresponding \
lake-aquifer systems. For example, the perfect ellipsoidal conductor \
discussed in section 2.3.2 would correspond to an idealised lake with an \
ellipsoidal bathymetry penetrating into the surrounding aquifer. As an aside \
we may also note that the perfect ellipsoidal resistor (section 2.3.1) could \
model the case where an impermeable ellipsoidal rock mass is embedded in a \
permeable aquifer. A topical case is that of the perfect conducting thin \
disk, which may be applied to a deep aquifer overlain by a shallow circular \
water table lake or seasonal wetland. \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Natural lake systems are under increasing threat of damage from pollutants \
associated with human activities, or from other hydrological disturbances. In \
particular, capture zone analysis shows that persistent pollutants entering \
the groundwater flow field upstream (in a regional flow sense) may eventually \
transit the lake, exiting via the release zone before possibly transiting \
another sensitive area further downgradient. For this reason the calculation \
of accurate capture/release zone geometries for lake-aquifer systems is \
critical in the management of natural water resources.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["3.1  Mapping Capture/Release Zones", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["The techniques for calculating flow paths outlined in section 2 \
can easily be adapted to the problem of mapping capture/release zones. In \
essence, for symmetric problems it is sufficient to calculate several flow \
paths and use symmetry arguments to generate from them representations of the \
dividing streamsurfaces that delineate the capture/release zones. In the \
following we concentrate on the capture/release zones for a shallow water \
table lake (",
  FontFamily->"Times"],
 StyleBox["i.e.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" a perfect conducting disk).",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Using the definitions of section 2.3.4, we calculate five \
three-dimensional flow paths with starting points evenly spaced along the \
diameter of the lake perpendicular to the regional flow direction. First, we \
construct a list of three-dimensional starting points with small and negative \
z coordinates, plus a starting point on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{"z", "=", "0"}]}], TraditionalForm]]],
 StyleBox[" line just outside the lake perimeter:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
StartingPoints = 
    Append[Table[{0,y,-0.000001},{y,0,0.9,0.15}],
           {0,1+10^(-6),0}];\
\>", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Second, we define a ",
  FontFamily->"Times"],
 StyleBox["FlowPathCalculator",
  FontFamily->"Courier"],
 StyleBox[" function in terms of ",
  FontFamily->"Times"],
 StyleBox["RKParticleTrack",
  FontFamily->"Courier"],
 StyleBox[" with pre-defined temporal integration parameters:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
FlowPathCalculator[startpoints_List] := 
    RKParticleTrack[{vxDisk[x,y,z,1,1,0,0],
                     vyDisk[x,y,z,1,1,0,0],
                     vzDisk[x,y,z,1,1,0,0]},
                     {x,y,z}, startpoints, 
                     {t, 0, -20, -0.05}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Next we apply ",
  FontFamily->"Times"],
 StyleBox["FlowPathCalculator",
  FontFamily->"Courier"],
 StyleBox[" to the starting points, saving the resulting three-dimensional \
flow paths (clipped at ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{"-", "3"}]}], TraditionalForm]]],
 StyleBox[") to the ",
  FontFamily->"Times"],
 StyleBox["StreamSurface",
  FontFamily->"Courier"],
 StyleBox[" list:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
StreamSurface = 
    MapAll[DeleteCases[#,{x_ /; x < -3,y_,z_}]&,
           FlowPathCalculator /@ StartingPoints];\
\>", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["As calculated, StreamSurface contains flow paths truncated at ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{"-", "3"}]}], TraditionalForm]]],
 StyleBox[". Because of their discrete, time-stepped nature these flow paths \
will not terminate at ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{"-", "3"}]}], TraditionalForm]]],
 StyleBox[" exactly, which will affect later visualization of the stream \
surface. To improve the visualization, each flow path is extrapolated to ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{"-", "3"}]}], TraditionalForm]]],
 StyleBox[" by a simple linear method. The following function, ",
  FontFamily->"Times"],
 StyleBox["Extrapolate",
  FontFamily->"Courier"],
 StyleBox[", operates on a  list of 3-vectors, ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 StyleBox[", using the last two 3-vectors to approximate the true ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 StyleBox[" and ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["z", TraditionalForm]]],
 StyleBox[" coordinates on the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "value"}], TraditionalForm]]],
 StyleBox[" plane:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Extrapolate[p_,value_] := 
    Append[p,{value,p[[-1,2]] + (value-p[[-1,1]])*
             (p[[-2,2]]-p[[-1,2]])/
             (p[[-2,1]]-p[[-1,1]]),
              p[[-1,3]] + (value-p[[-1,1]])*
             (p[[-2,3]]-p[[-1,3]])/
             (p[[-2,1]]-p[[-1,1]])}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["The truncated flow paths in ",
  FontFamily->"Times"],
 StyleBox["StreamSurface",
  FontFamily->"Courier"],
 StyleBox[" can be tidied up in a ",
  FontFamily->"Times"],
 StyleBox["Do",
  FontFamily->"Courier"],
 StyleBox[" loop:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Do[ StreamSurface[[i]] = 
         Extrapolate[StreamSurface[[i]],-3], 
    {i,Length[StreamSurface]}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Next we generate the full capture and release zones by reflecting ",
  FontFamily->"Times"],
 StyleBox["StreamSurface",
  FontFamily->"Courier"],
 StyleBox[" in the mirror symmetry planes ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", "0"}], TraditionalForm]]],
 StyleBox[" and ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0"}], TraditionalForm]]],
 StyleBox[":",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
CaptureZone = 
   Join[Reverse[StreamSurface],
        Drop[StreamSurface,1] /. 
        {x_,y_,z_} -> {x,-y,z}];\
\>", "Input",
 AspectRatioFixed->True],

Cell["ReleaseZone = CaptureZone /. {x_,y_,z_} -> {-x,y,z};", "Input",
 AspectRatioFixed->True],

Cell["\<\
The capture and release zones can then be displayed simultaneously (see \
Figure 11).\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", "0.003`", "]"}], ",", 
      RowBox[{"Line", "/@", "CaptureZone"}], ",", 
      RowBox[{"Line", "/@", "ReleaseZone"}], ",", 
      RowBox[{"Line", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ReleaseZone", "\[LeftDoubleBracket]", 
          RowBox[{"i", ",", 
           RowBox[{"-", "1"}]}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "[", "ReleaseZone", "]"}]}], "}"}]}], "]"}], 
       "]"}], ",", 
      RowBox[{"Line", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"CaptureZone", "\[LeftDoubleBracket]", 
          RowBox[{"i", ",", 
           RowBox[{"-", "1"}]}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "[", "CaptureZone", "]"}]}], "}"}]}], "]"}], 
       "]"}], ",", 
      RowBox[{"Line", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", "p", "]"}], ",", 
           RowBox[{"Sin", "[", "p", "]"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"p", ",", 
           RowBox[{"-", "0.1`"}], ",", 
           RowBox[{"2", " ", "\[Pi]"}], ",", "0.1`"}], "}"}]}], "]"}], 
       "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[
  {Thickness[
   0.003], {Line3DBox[{{0., 1.000001, 0.}, {-0.0011312323423716627`, 
      1.0032898250994993`, 0.}, {-0.0070020263912524815`, 1.0058736690197863`,
       0.}, {-0.01516856240356814, 1.011046050957896, 
      0.}, {-0.026025492597341653`, 1.0182304014537078`, 
      0.}, {-0.03963470155667449, 1.0271707885512913`, 
      0.}, {-0.05598296480284253, 1.037672389672608, 
      0.}, {-0.07502843801875392, 1.0495442357249523`, 
      0.}, {-0.09671088599000162, 1.0625898168231476`, 
      0.}, {-0.12095454840421604`, 1.0766085187990855`, 
      0.}, {-0.1476694336193151, 1.0913997852710215`, 
      0.}, {-0.1767525082673613, 1.1067677334295511`, 
      0.}, {-0.20808918496792728`, 1.1225254102317272`, 
      0.}, {-0.24155517228390255`, 1.1384983478641602`, 
      0.}, {-0.2770186214205868, 1.1545272796254027`, 
      0.}, {-0.31434245274734324`, 1.1704699883125536`, 
      0.}, {-0.3533867317507632, 1.186202329278039, 
      0.}, {-0.39401097210064256`, 1.2016185156582764`, 
      0.}, {-0.4360762639452556, 1.2166307802246765`, 
      0.}, {-0.4794471520017683, 1.2311685405832273`, 
      0.}, {-0.5239932158160809, 1.2451771951713921`, 
      0.}, {-0.5695903304691667, 1.258616669658633, 0.}, {-0.6161216079709821,
       1.2714598197743088`, 0.}, {-0.6634780366182957, 1.2836907797777175`, 
      0.}, {-0.7115588475200119, 1.295303327827025, 0.}, {-0.7602716446973695,
       1.3062993219763022`, 0.}, {-0.8095323383668719, 1.3166872445179647`, 
      0.}, {-0.8592649210781389, 1.3264808785344986`, 
      0.}, {-0.909401124182561, 1.3356981291099805`, 
      0.}, {-0.9598799884452605, 1.3443599926896337`, 
      0.}, {-1.0106473781455716`, 1.3524896713923698`, 
      0.}, {-1.0616554632558046`, 1.3601118243967103`, 
      0.}, {-1.1128621896174355`, 1.3672519455054861`, 
      0.}, {-1.1642307526954905`, 1.3739358543138813`, 
      0.}, {-1.2157290866306674`, 1.3801892877450368`, 
      0.}, {-1.2673293769911262`, 1.3860375788015873`, 
      0.}, {-1.3190076028621371`, 1.3915054099788293`, 
      0.}, {-1.3707431116747844`, 1.396616629709743, 0.}, {-1.422518228415169,
       1.4013941213200645`, 0.}, {-1.4743178995123336`, 1.4058597151562395`, 
      0.}, {-1.5261293707124612`, 1.4100341357344917`, 
      0.}, {-1.5779418975467678`, 1.4139369768942782`, 
      0.}, {-1.6297464865339826`, 1.4175866989922494`, 
      0.}, {-1.6815356649751894`, 1.4210006431259425`, 
      0.}, {-1.733303277056194, 1.424195058222766, 0.}, {-1.7850443039347397`,
       1.4271851375694267`, 0.}, {-1.836754705527748, 1.4299850619946273`, 
      0.}, {-1.8884312818041131`, 1.4326080474612573`, 
      0.}, {-1.9400715515133227`, 1.4350663952825506`, 
      0.}, {-1.9916736464254339`, 1.4373715435594916`, 
      0.}, {-2.0432362193133344`, 1.4395341187537096`, 
      0.}, {-2.094758364066164, 1.441563986570333, 0.}, {-2.1462395464779127`,
       1.4434703015371315`, 0.}, {-2.1976795444038957`, 1.4452615548373213`, 
      0.}, {-2.2490783961176892`, 1.4469456200902573`, 
      0.}, {-2.3004363558308767`, 1.4485297968826982`, 
      0.}, {-2.3517538554569435`, 1.450020851938372, 
      0.}, {-2.4030314718087946`, 1.4514250578794132`, 
      0.}, {-2.454269898516879, 1.4527482295834973`, 0.}, {-2.505469922042308,
       1.4539957581781113`, 0.}, {-2.5566324012372594`, 1.4551726427409093`, 
      0.}, {-2.607758249974119, 1.456283519794529, 0.}, {-2.6588484224259448`,
       1.457332690697312, 0.}, {-2.709903900634728, 1.4583241470394408`, 
      0.}, {-2.7609256840512937`, 1.459261594158208, 
      0.}, {-2.8119147807721965`, 1.4601484728873975`, 
      0.}, {-2.8628722002353113`, 1.4609879796547678`, 
      0.}, {-2.913798947167554, 1.4617830850390348`, 0.}, {-2.964696016605837,
       1.4625365508939467`, 0.}, {-3, 1.4630591811027869`, 0.}}], 
    Line3DBox[{{0., 0.8999999999999999, -1.*^-6}, {-1.465698823428751*^-7, 
      0.8999999999999999, -1.0106843457002216`*^-6}, {-2.962716132545117*^-7, 
      0.8999999999999999, -1.0429655740649054`*^-6}, {-4.523043253880178*^-7, 
      0.8999999999999999, -1.0975334615932973`*^-6}, {-6.180022658837846*^-7, 
      0.8999999999999999, -1.1755540173520624`*^-6}, {-7.969059631159191*^-7, 
      0.8999999999999999, -1.2786945199104919`*^-6}, {-9.928385247413383*^-7, 
      0.8999999999999999, -1.4091588268505606`*^-6}, \
{-1.2099864386585537`*^-6, 
      0.8999999999999999, -1.5697349821063224`*^-6}, {-1.452990187185515*^-6, 
      0.8999999999999999, -1.7638540249057294`*^-6}, \
{-1.7270421258603356`*^-6, 
      0.8999999999999999, -1.995664229217233*^-6}, {-2.0379985252006594`*^-6, 
      0.8999999999999999, -2.27011890837035*^-6}, {-2.3925040374707387`*^-6, 
      0.8999999999999999, -2.5930828060027324`*^-6}, \
{-2.7981340704073425`*^-6, 
      0.8999999999999999, -2.971457080427524*^-6}, {-3.263556290598541*^-6, 
      0.8999999999999999, -3.4133271140037162`*^-6}, {-3.798716013221317*^-6, 
      0.8999999999999999, -3.928135130751879*^-6}, {-4.415048904742475*^-6, 
      0.8999999999999999, -4.52688178142071*^-6}, {-5.12572507030871*^-6, 
      0.8999999999999999, -5.222361478178697*^-6}, {-5.945930650766179*^-6, 
      0.8999999999999999, -6.02943562787205*^-6}, {-6.893192316764313*^-6, 
      0.8999999999999999, -6.9653502103332345`*^-6}, {-7.987751676693452*^-6, 
      0.8999999999999999, -8.050104410339301*^-6}, {-9.252997952341795*^-6, 
      0.8999999999999999, -9.306877832068441*^-6}, {-0.000010715967605819572`,
       0.8999999999999999, -0.000010762525980325966`}, \
{-0.000012407922199866816`, 
      0.8999999999999999, -0.00001244815399544828}, \
{-0.000014365016435613169`, 
      0.9000000001240995, -0.00001439978130316071}, \
{-0.000016629070618201228`, 
      0.9000000002902985, -0.00001665911140813307}, \
{-0.000019248464347268406`, 
      0.9000000005128784, -0.000019274422986232753`}, \
{-0.000022279170328160028`, 
      0.9000000008109659, -0.00002230160152237324}, {-0.00002578595044016695, 
      0.9000000012101756, -0.000025805333490166334`}, \
{-0.00002984373956993924, 
      0.9000000017448123, -0.000029860488645684583`}, \
{-0.00003453924689364828, 
      0.9000000024608177, -0.00003455371985372336}, {-0.00003997280869814209, 
      0.9000000034197188, -0.00003998531476233666}, {-0.00004626053246898117, 
      0.9000000047039146, -0.000046271338756084996`}, \
{-0.000053536777880838855`, 
      0.9000000064237575, -0.000053546115159145205`}, \
{-0.00006195702791390615, 
      0.9000000087270351, -0.000061965095476414}, {-0.00007170121128199128, 
      0.90000001181167, -0.00007170818116847847}, {-0.00008297754725960348, 
      0.9000000159427275, -0.00008298356784567422}, {-0.00009602699500270876, 
      0.900000021475193, -0.00009603219408272723}, {-0.00011112840250803374`, 
      0.9000000288844757, -0.00011113288983837191`}, \
{-0.00012860446515882792`, 
      0.9000000388072614, -0.00012860833455496663`}, \
{-0.00014882862123586239`, 
      0.9000000520962226, -0.00014883195217412997`}, \
{-0.00017223303170731967`, 
      0.9000000698932891, -0.00017223589039690017`}, \
{-0.00019931781480918477`, 
      0.9000000937277741, -0.0001993202546342679}, {-0.00023066173272786548`, 
      0.9000001256477881, -0.00023066379388226772`}, \
{-0.00026693455871396824`, 
      0.900000168396231, -0.0002669362667383926}, {-0.00030891138887053645`, 
      0.9000002256464872, -0.0003089127515869075}, {-0.000357489204361981, 
      0.9000003023180722, -0.00035749020644431707`}, {-0.0004137060378612305, 
      0.9000004049993533, -0.00041370663184000893`}, {-0.0004787631536514389, 
      0.9000005425136618, -0.00047876324546219224`}, {-0.0005540507151041467, 
      0.9000007266774315, -0.00055405014125534}, {-0.0006411774876608856, 
      0.9000009733154916, -0.0006411759794642606}, {-0.0007420052114676562, 
      0.9000013036207218, -0.000742002339281995}, {-0.0008586883773109723, 
      0.9000017459748407, -0.0008586834638416047}, {-0.0009937202544731398, 
      0.9000023383866713, -0.000993712240167018}, {-0.0011499861520105335`, 
      0.9000031317571955, -0.0011499733862325614`}, {-0.0013308250483773448`, 
      0.9000041942515874, -0.0013308049656080999`}, {-0.001540100901399345, 
      0.9000056171532406, -0.0015400695192741615`}, {-0.001782285154734713, 
      0.9000075227016112, -0.0017822362960301507`}, {-0.0020625521920063826`, 
      0.9000100745852097, -0.002062476278897225}, {-0.002386889759947074, 
      0.900013491987496, -0.0023867719455445305`}, {-0.002762226691656061, 
      0.9000180683856399, -0.0027620439648329016`}, {-0.0031965806150993283`, 
      0.9000241967049589, -0.003196297314861797}, {-0.003699228734783367, 
      0.900032402968037, -0.0036987896013242626`}, {-0.004280905230008388, 
      0.9000433912896321, -0.004280224641368071}, {-0.004954029323672025, 
      0.9000581040114911, -0.004952974627654946}, {-0.00573296864086906, 
      0.9000778020150245, -0.0057313343499476}, {-0.00663434309111738, 
      0.9001041718815416, -0.006631810946242317}, {-0.007677375158079984, 
      0.9001394686944053, -0.0076734523532692046`}, {-0.008884293138378897, 
      0.9001867060151131, -0.008878216825658966}, {-0.010280794486388502`, 
      0.9002499080407276, -0.01027138428445006}, {-0.011896576909226648`, 
      0.9003344432676268, -0.01188200737040854}, {-0.013765945074690636`, 
      0.9004474641778494, -0.013743395220974033`}, {-0.015928500518401417`, 
      0.9005984833881584, -0.01589361515606632}, {-0.018429921208707768`, 
      0.9008001228639454, -0.01837598524163044}, {-0.021322834697999567`, 
      0.9010690780456014, -0.021239512232852205`}, {-0.02466778402078236, 
      0.9014273407580807, -0.02453920239952535}, {-0.02853427725206294, 
      0.9019037193970307, -0.02833613483352653}, {-0.03300189813296203, 
      0.9025356751375196, -0.03269713648503844}, {-0.03816143396725662, 
      0.9033714481770784, -0.03769383663094056}, {-0.044115945024829795`, 
      0.9044723640308479, -0.043400813475674704`}, {-0.050981653680620624`, 
      0.9059150712763276, -0.04989249697342}, {-0.05888846931131413, 
      0.9077932604842719, -0.05723849829510074}, {-0.06797988850307982, 
      0.9102181647022204, -0.06549715790273677}, {-0.07841193074024518, 
      0.9133169092275373, -0.07470741216267938}, {-0.09035071524048378, 
      0.917227698317479, -0.08487961632050624}, {-0.10396830366156465`, 
      0.922091093586123, -0.09598667321707381}, {-0.11943658755509501`, 
      0.9280374165592626, -0.10795747213590348`}, {-0.13691933113123209`, 
      0.9351715556332953, -0.12067484664279797`}, {-0.15656295981693966`, 
      0.9435577807490064, -0.1339796438067071}, {-0.17848717485139987`, 
      0.9532078936703905, -0.1476810353190579}, {-0.20277676037689074`, 
      0.9640756101950395, -0.16157140773259085`}, {-0.22947586218018515`, 
      0.9760585060813644, -0.17544287504230816`}, {-0.25858555295149754`, 
      0.9890068434545266, -0.18910225896367977`}, {-0.2900648357396278, 
      1.0027370226280237`, -0.20238224451827572`}, {-0.32383462257929163`, 
      1.0170468057408006`, -0.2151477803131333}, {-0.35978383591155944`, 
      1.0317297869486466`, -0.22729801740044914`}, {-0.39777666064060113`, 
      1.0465874275988705`, -0.2387648121558621}, {-0.4376600655845333, 
      1.061437893770102, -0.24950903642904193`}, {-0.4792709182512726, 
      1.076121656874798, -0.2595158092630929}, {-0.5224422520570962, 
      1.0905042623490506`, -0.26878948238627004`}, {-0.5670084572510616, 
      1.1044768703134067`, -0.2773489134659866}, {-0.6128093320139911, 
      1.1179552014762626`, -0.2852233148668189}, {-0.6596930441290106, 
      1.1308774552152234`, -0.292448790396325}, {-0.7075181222568138, 
      1.1432016592313916`, -0.29906556185700206`}, {-0.7561546291428581, 
      1.1549027954047972`, -0.3051158257936424}, {-0.8054846773397217, 
      1.165969942530749, -0.3106421529274213}, {-0.8554024401895737, 
      1.1764035910283397`, -0.3156863356907166}, {-0.9058137938697337, 
      1.1862132188928423`, -0.32028859391631787`}, {-0.9566357052966055, 
      1.195415170380532, -0.3244870590934945}, {-1.0077954589681972`, 
      1.2040308461384672`, -0.328317470001516}, {-1.0592297954446077`, 
      1.2120851924383398`, -0.3318130248781381}, {-1.1108840162008304`, 
      1.219605464827354, -0.3350043465096148}, {-1.1627110944642247`, 
      1.2266202353410531`, -0.3379195262971232}, {-1.2146708193830538`, 
      1.2331586104355627`, -0.3405842213765883}, {-1.2667289912378465`, 
      1.2392496274835398`, -0.3430217853474096}, {-1.318856678063257, 
      1.2449217999476523`, -0.3452534182884984}, {-1.3710295386168845`, 
      1.2502027844364596`, -0.3472983257213497}, {-1.423227212745956, 
      1.2551191462507127`, -0.3491738792276168}, {-1.4754327775316058`, 
      1.2596962034189954`, -0.35089577372947606`}, {-1.527632265849533, 
      1.2639579324075316`, -0.3524781781544887}, {-1.5798142429400102`, 
      1.267926921567634, -0.35393387746464006`}, {-1.6319694360407797`, 
      1.2716243609133713`, -0.3552744049383825}, {-1.684090411955331, 
      1.2750700589973472`, -0.35651016423943627`}, {-1.7361712974929326`, 
      1.278282479492327, -0.35765054125302603`}, {-1.7882075379403666`, 
      1.2812787916213346`, -0.3587040059703496}, {-1.8401956890458868`, 
      1.2840749298445386`, -0.3596782048945873}, {-1.8921332383683744`, 
      1.2866856592444689`, -0.3605800445564112}, {-1.9440184522373691`, 
      1.2891246438869055`, -0.3614157667861095}, {-1.9958502449611324`, 
      1.2914045161052272`, -0.3621910164097926}, {-2.0476280672961544`, 
      1.2935369451894363`, -0.36291090203103693`}, {-2.099351811544038, 
      1.295532704382095, -0.3635800505357856}, {-2.1510217309658364`, 
      1.2974017354129261`, -0.36420265592392004`}, {-2.2026383714977418`, 
      1.2991532100594188`, -0.3647825230303222}, {-2.254202514015423, 
      1.3007955884170563`, -0.3653231066547757}, {-2.305715125628342, 
      1.3023366737117612`, -0.36582754657597333`}, {-2.357177318691856, 
      1.3037836635986522`, -0.36629869888174615`}, {-2.408590316406007, 
      1.3051431979732133`, -0.3667391640063784}, {-2.4599554240279806`, 
      1.3064214033799055`, -0.36715131182712607`}, {-2.5112740048626665`, 
      1.307623934144267, -0.36753730413612273`}, {-2.5625474603148524`, 
      1.3087560103817746`, -0.3678991147708593}, {-2.6137772133895205`, 
      1.3098224530534333`, -0.368238547656358}, {-2.6649646951154646`, 
      1.310827716246816, -0.368557252984926}, {-2.7161113334438145`, 
      1.3117759168641185`, -0.36885674173482497`}, {-2.7672185442386636`, 
      1.3126708618973133`, -0.36913839870714826`}, {-2.8182877240332926`, 
      1.313516073465918, -0.3694034942404596}, {-2.8693202442737054`, 
      1.3143148117861874`, -0.3696531947451235}, {-2.9203174468125033`, 
      1.3150700962324273`, -0.3698885721835448}, {-2.971280640451431, 
      1.3157847246421643`, -0.3701106126085528}, {-3, 
       1.3161874401860187`, -0.37023573935875814`}}], 
    Line3DBox[{{0., 0.75, -1.*^-6}, {-9.63963064743451*^-8, 
      0.75, -1.0046354071927043`*^-6}, {-1.9368661135595524`*^-7, 
      0.75, -1.0185845398707027`*^-6}, {-2.9277219354065394`*^-7, 
      0.75, -1.0419768208726156`*^-6}, {-3.945722579769716*^-7, 
      0.75, -1.075028998784386*^-6}, {-5.000304178869435*^-7, 
      0.75, -1.118047491888238*^-6}, {-6.101244585261265*^-7, 
      0.75, -1.171431096447165*^-6}, {-7.25874418968571*^-7, 
      0.75, -1.2356750053097076`*^-6}, {-8.483536795257067*^-7, 
      0.75, -1.3113746753845724`*^-6}, {-9.786979083421743*^-7, 
      0.75, -1.3992317865490546`*^-6}, {-1.1181156443379474`*^-6, 
      0.75, -1.5000607458398724`*^-6}, {-1.2678991738375305`*^-6, 
      0.75, -1.614796472853357*^-6}, {-1.4294373446889662`*^-6, 
      0.75, -1.7445024769575526`*^-6}, {-1.6042270872713448`*^-6, 
      0.75, -1.8903817652468372`*^-6}, {-1.7938893749448946`*^-6, 
      0.75, -2.053786316291479*^-6}, {-2.000182426303128*^-6, 
      0.75, -2.2362311052043297`*^-6}, {-2.225018646927855*^-6, 
      0.75, -2.4394076219655577`*^-6}, {-2.4704828192016027`*^-6, 
      0.75, -2.665199139810544*^-6}, {-2.7388502928594414`*^-6, 
      0.75, -2.9156991936871426`*^-6}, {-3.032609198143228*^-6, 
      0.75, -3.1932299776221868`*^-6}, {-3.354482637941926*^-6, 
      0.75, -3.5003646809847865`*^-6}, {-3.7074547512577334`*^-6, 
      0.75, -3.839950575259027*^-6}, {-4.094797965599732*^-6, 
      0.75, -4.215135797456632*^-6}, {-4.5201032298130855`*^-6, 
      0.75, -4.629398640437455*^-6}, {-4.987313430624421*^-6, 
      0.75, -5.086579678426582*^-6}, {-5.500759892968026*^-6, 
      0.75, -5.590917423877726*^-6}, {-6.0652028434297415`*^-6, 
      0.75, -6.147087319231559*^-6}, {-6.685875017895697*^-6, 
      0.75, -6.760245596022907*^-6}, {-7.368530476186218*^-6, 
      0.75, -7.4360767796588286`*^-6}, {-8.119498050856585*^-6, 
      0.75, -8.18084628580741*^-6}, {-8.945739826372636*^-6, 
      0.75, -9.001458697990456*^-6}, {-9.854915676788622*^-6, 
      0.75, -9.90552178490242*^-6}, {-0.000010855454435045279`, 
      0.75, -0.000010901416875420529`}, {-0.000011956631857642982`, 
      0.75, -0.000011998376736394562`}, {-0.000013168656749468971`, 
      0.75, -0.000013206571037077934`}, {-0.000014502765521255142`, 
      0.75, -0.000014537200715991115`}, {-0.00001597132640164618, 
      0.75, -0.000016002601780958107`}, {-0.000017587954126325297`, 
      0.75, -0.0000176163596478643}, {-0.000019367636143653748`, 
      0.75, -0.00001939343510190799}, {-0.00002132687148216251, 
      0.75, -0.00002135030307379744}, {-0.00002348382381144244, 
      0.75, -0.000023505105273719663`}, {-0.000025858489793059814`, 
      0.7500000001004329, -0.000025877818420070944`}, \
{-0.000028472884473670578`, 
      0.7500000002221848, -0.000028490439431753182`}, \
{-0.00003135124533353748, 
      0.7500000003697812, -0.00003136718940426131}, \
{-0.000034520257080197857`, 
      0.750000000548708, -0.00003453473806586776}, {-0.00003800929896617459, 
      0.7500000007656158, -0.000038022451098092504`}, \
{-0.000041850717164656715`, 
      0.7500000010285669, -0.000041862662371352015`}, \
{-0.000046080124665008025`, 
      0.7500000013473349, -0.00004609097368412919}, \
{-0.000050736731420752723`, 
      0.7500000017337681, -0.000050746584833175586`}, {-0.0000558637078752209,
       0.75000000220223, -0.00005587265700766191}, {-0.00006150858516042804, 
      0.7500000027701328, -0.00006151671295246705}, {-0.00006772369576068202, 
      0.750000003458585, -0.00006773107752871205}, {-0.00007456665867598787, 
      0.7500000042931757, -0.00007457336280604881}, {-0.00008210091359232288, 
      0.750000005304926, -0.00008210700217460718}, {-0.00009039630902298428, 
      0.7500000065314417, -0.0000904018384161286}, {-0.0000995297498489209, 
      0.7500000080183113, -0.000099534771210673}, {-0.00010958591031167732`, 
      0.7500000098208005, -0.00010959047003122244`}, \
{-0.00012065801897156642`, 
      0.750000012005906, -0.00012066215913244997`}, {-0.00013284872305687224`,
       0.7500000146548464, -0.0001328524817622209}, {-0.00014627104004820567`,
       0.7500000178660805, -0.00014627445177643565`}, {-0.0001610494054488071,
       0.7500000217589667, -0.0001610525013500728}, {-0.00017732082640882735`,
       0.7500000264782004, -0.0001773236345424802}, {-0.0001952361518861213, 
      0.750000032199191, -0.0001952386974229335}, {-0.00021496147112664204`, 
      0.7500000391345826, -0.0002149637765226108}, {-0.00023667965345885886`, 
      0.7500000475421572, -0.0002366817385466974}, {-0.0002605920436155512, 
      0.7500000577344168, -0.0002605939256805411}, {-0.00028692032837301375`, 
      0.750000070090198, -0.0002869220221307047}, {-0.0003159085917569124, 
      0.7500000850687535, -0.00031591010925730956`}, {-0.0003478255778841421, 
      0.7500001032268219, -0.0003478269283291974}, {-0.0003829671824402782, 
      0.7500001252393207, -0.0003829683718512321}, {-0.0004216591958571126, 
      0.7500001519244327, -0.00042166022658451105`}, \
{-0.00046426032363953653`, 
      0.7500001842740164, -0.0004642611936592275}, {-0.0005111655118405442, 
      0.7500002234904717, -0.0005111662137645295}, {-0.0005628096085141138, 
      0.7500002710314319, -0.0005628101282204665}, {-0.0006196713950802501, 
      0.7500003286639407, -0.0006196717098538723}, {-0.0006822780249882714, 
      0.7500003985301308, -0.0006822781009961197}, {-0.0007512099108136968, 
      0.7500004832268417, -0.0007512096997085619}, {-0.0008271061051054208, 
      0.7500005859021386, -0.0008271055394553264}, {-0.0009106702248499194, 
      0.7500007103723176, -0.0009106692120217102}, {-0.0010026769744906204`, 
      0.7500008612637462, -0.0010026753884498055`}, {-0.0011039793279505976`, 
      0.750001044184809, -0.001103976998304328}, {-0.0012155164362508324`, 
      0.7500012659343489, -0.0012155131335944826`}, {-0.0013383223340088977`, 
      0.750001534754349, -0.0013383177503556002`}, {-0.0014735355255291029`, 
      0.7500018606362416, -0.0014735292481699192`}, {-0.0016224095393325179`, 
      0.7500022556922253, -0.0016224010159295427`}, {-0.0017863245489481143`, 
      0.7500027346053835, -0.0017863130409307899`}, {-0.0019668001676661174`, 
      0.7500033151753216, -0.001966784688016003}, {-0.0021655095358248657`, 
      0.7500040189795867, -0.0021654887660241253`}, {-0.0023842948311694925`, 
      0.7500048721754271, -0.002384267010340591}, {-0.002625184345994646, 
      0.7500059064716538, -0.0026251471229227674`}, {-0.002890411289276908, 
      0.7500071603066699, -0.002890361524898331}, {-0.0031824344879655252`, 
      0.7500086802763714, -0.003182367991739322}, {-0.003503961179148294, 
      0.7500105228648676, -0.003503872357190696}, {-0.0038579721041339388`, 
      0.7500127565421729, -0.0038578534895886835`}, {-0.0042477491367420095`, 
      0.75001546430657, -0.004247590762983943}, {-0.004676905701468897, 
      0.7500187467657526, -0.004676694265556576}, {-0.0051494202629016935`, 
      0.7500227258706972, -0.00514913800911397}, {-0.0056696731960151825`, 
      0.7500275494402027, -0.005669296425844902}, {-0.006242487378043925, 
      0.7500333966430339, -0.006241984461728737}, {-0.006873172876742989, 
      0.7500404846396117, -0.006872501599668853}, {-0.0075675761473108305`, 
      0.7500490766274404, -0.007566680168957824}, {-0.00833213419135701, 
      0.7500594915853853, -0.008330938320225495}, {-0.009173934176362667, 
      0.7500721160732124, -0.009172338065364995}, {-0.010100779063443728`, 
      0.7500874185164935, -0.010098648798361042`}, {-0.011121259845216346`, 
      0.7501059664953875, -0.011118416723104848`}, {-0.012244835054518004`, 
      0.7501284476616378, -0.012241040614927725`}, {-0.013481918268973082`, 
      0.7501556950344352, -0.0134768543293085}, {-0.014843974406175998`, 
      0.7501887175760314, -0.014837216438049083`}, {-0.0163436256797885, 
      0.7502287371258615, -0.0163346073121532}, {-0.01799476816816048, 
      0.7502772329813829, -0.017982733870976344`}, {-0.01981270003399946, 
      0.7503359956586814, -0.019796642064716263`}, {-0.021814262525592296`, 
      0.7504071916495109, -0.02179283693317667}, {-0.02401799498600248, 
      0.7504934413160275, -0.023989409763278347`}, {-0.026444305194528686`, 
      0.7505979124300121, -0.0264061714188148}, {-0.02911565646114702, 
      0.7507244322659823, -0.029064790296817997`}, {-0.03205677298420537, 
      0.7508776215870693, -0.03198893252229461}, {-0.03529486505561157, 
      0.7510630542987815, -0.035204400859581535`}, {-0.0388598757425548, 
      0.7512874469536169, -0.038739267310217325`}, {-0.042784750669318874`, 
      0.7515588826113462, -0.04262399238175343}, {-0.047105732434497775`, 
      0.7518870737056411, -0.04689152142830114}, {-0.05186268097824308, 
      0.752283668401595, -0.05157734514459536}, {-0.057099420785712125`, 
      0.7527626042512567, -0.056719507095563976`}, {-0.06286411506335955, 
      0.7533405114817178, -0.06235853594668643}, {-0.06920966578574239, 
      0.7540371655903517, -0.06853727373256951}, {-0.07619413653555909, 
      0.7548759845515436, -0.07530056406593515}, {-0.0838811919949762, 
      0.7558845591919603, -0.08269475583878663}, {-0.09234054329816309, 
      0.7570951953690911, -0.09076696921977051}, {-0.10164838156044727`, 
      0.7585454326257897, -0.09956406264580067}, {-0.11188777191824967`, 
      0.7602784852201728, -0.10913123385914449`}, {-0.1231489663745037, 
      0.7623435274806347, -0.1195101877476301}, {-0.13552957470387525`, 
      0.764795716891003, -0.13073681305063126`}, {-0.14913450807920045`, 
      0.7676958175193715, -0.14283833459224166`}, {-0.16407558045163753`, 
      0.7711092585701727, -0.15582995438986358`}, {-0.1804706207207978, 
      0.7751044471813606, -0.16971107043325034`}, {-0.19844192064666258`, 
      0.7797501650300689, -0.18446127008798627`}, {-0.21811383064896728`, 
      0.7851119326698094, -0.20003643286024547`}, {-0.23960933513142887`, 
      0.7912473417344731, -0.21636542884099644`}, {-0.2630455114456545, 
      0.7982005431487837, -0.23334803073640312`}, {-0.2885279199424485, 
      0.8059963289722204, -0.2508547164639715}, {-0.31614418996749916`, 
      0.8146345133455176, -0.2687289638684537}, {-0.3459573322700006, 
      0.8240855241501497, -0.2867923810380007}, {-0.37799955832478116`, 
      0.8342881600501544, -0.30485257447158054`}, {-0.41226752849786213`, 
      0.8451502653351495, -0.3227131085091921}, {-0.44871989469631524`, 
      0.8565526175283019, -0.34018440294732893`}, {-0.4872777123490606, 
      0.8683557064675193, -0.35709412798986767`}, {-0.527827822619431, 
      0.8804084922688028, -0.37329570842600507`}, {-0.570228781303068, 
      0.892557858288323, -0.38867394122269094`}, {-0.6143184951363705, 
      0.9046574372925326, -0.4031473316884553}, {-0.659922532853628, 
      0.9165747656703259, -0.4166673653176926}, {-0.7068621303666218, 
      0.9281961829527052, -0.42921538341476356`}, {-0.7549611451298458, 
      0.939429376974665, -0.4407979390689591}, {-0.8040515309970246, 
      0.9502038504934983, -0.4514414922917693}, {-0.853977206144806, 
      0.9604697969742446, -0.4611871362023605}, {-0.904596414082483, 
      0.9701959309970627, -0.470085819716601}, {-0.9557828131921808, 
      0.97936676810116, -0.47819431528493866`}, {-1.007425584236075, 
      0.9879797427227013, -0.48557201011925333`}, {-1.0594288414664417`, 
      0.9960424333490002, -0.49227848621474796`}, {-1.111710596085203, 
      1.0035700568264905`, -0.4983717919571943}, {-1.1642014703744423`, 
      1.0105833102000292`, -0.5039072831230246}, {-1.2168433096213938`, 
      1.0171065801378647`, -0.5089369101502219}, {-1.269587793841656, 
      1.0231665034784754`, -0.5135088407872775}, {-1.3223951149390305`, 
      1.028790842519112, -0.5176673250425503}, {-1.3752327575031198`, 
      1.0340076302346608`, -0.5214527281139778}, {-1.4280744018607807`, 
      1.038844539456191, -0.5249016742003114}, {-1.4808989547397315`, 
      1.0433284330370245`, -0.5280472587165381}, {-1.5336897044415962`, 
      1.0474850570682146`, -0.5309192982261958}, {-1.5864335924268929`, 
      1.0513388449309364`, -0.5335445965618761}, {-1.63912059062087, 
      1.0549128056049748`, -0.5359472125158095}, {-1.6917431727503394`, 
      1.058228474779078, -0.5381487195715767}, {-1.7442958680324683`, 
      1.0613059117555028`, -0.5401684518144342}, {-1.796774886146825, 
      1.0641637288722436`, -0.5420237327428111}, {-1.8491778033537654`, 
      1.066819143222706, -0.5437300854842706}, {-1.901503300693319, 
      1.069288042910251, -0.5453014241124867}, {-1.9537509462944418`, 
      1.0715850620223855`, -0.5467502265330099}, {-2.005921014876523, 
      1.0737236600334956`, -0.5480876898784803}, {-2.058014338496012, 
      1.0757162025250782`, -0.5493238696195406}, {-2.1100321834636824`, 
      1.077574041017101, -0.5504678037220748}, {-2.1619761491277116`, 
      1.0793075903909959`, -0.5515276232119367}, {-2.213848084887295, 
      1.0809264029011416`, -0.5525106504785657}, {-2.265650022377944, 
      1.0824392381556878`, -0.553423486582273}, {-2.317384120262009, 
      1.0838541287295775`, -0.5542720887426624}, {-2.369052619476023, 
      1.0851784412766603`, -0.5550618390885546}, {-2.420657807139703, 
      1.0864189331525624`, -0.5557976056501318}, {-2.4722019876288757`, 
      1.0875818046601204`, -0.556483796476435}, {-2.52368745956425, 
      1.0886727470959032`, -0.5571244076686325}, {-2.575116497677092, 
      1.089696986818328, -0.5577230660332301}, {-2.6264913386877073`, 
      1.0906593255816914`, -0.5582830669803348}, {-2.6778141704786385`, 
      1.0915641773911442`, -0.5588074082204258}, {-2.7290871239662597`, 
      1.0924156021349962`, -0.5592988197486642}, {-2.7803122671759493`, 
      1.0932173362456339`, -0.5597597905482261}, {-2.8314916011105464`, 
      1.093972820630863, -0.560192592392981}, {-2.882627057072179, 
      1.0946852261052578`, -0.5605993010845253}, {-2.9337204951561024`, 
      1.0953574765372365`, -0.5609818154185535}, {-2.984773703683918, 
      1.0959922699129396`, -0.5613418741402819}, {-3, 
       1.0961815930194918`, -0.5614492593751441}}], 
    Line3DBox[{{0., 0.6, -1.*^-6}, {-7.966242453778674*^-8, 
      0.6, -1.0031679677782165`*^-6}, {-1.5982874414332617`*^-7, 
      0.6, -1.0126919673296451`*^-6}, {-2.410073221102551*^-7, 
      0.6, -1.0286323527130694`*^-6}, {-3.237132307610731*^-7, 
      0.6, -1.0510899848905436`*^-6}, {-4.0846995616895115`*^-7, 
      0.6, -1.080207299467184*^-6}, {-4.958149581260597*^-7, 
      0.6, -1.116168630338855*^-6}, {-5.863010754289038*^-7, 
      0.6, -1.1592020536019024`*^-6}, {-6.805020352713257*^-7, 
      0.6, -1.20958003494637*^-6}, {-7.790149181763504*^-7, 
      0.6, -1.267621622797299*^-6}, {-8.824632254363677*^-7, 
      0.6, -1.3336949654079318`*^-6}, {-9.915028243836363*^-7, 
      0.6, -1.4082184290545567`*^-6}, {-1.1068246678865269`*^-6, 
      0.6, -1.4916641232990753`*^-6}, {-1.2291589335113028`*^-6, 
      0.6, -1.5845611109612272`*^-6}, {-1.3592812055953326`*^-6, 
      0.6, -1.6874976144333035`*^-6}, {-1.4980159522565942`*^-6, 
      0.6, -1.8011257962263185`*^-6}, {-1.6462419260524005`*^-6, 
      0.6, -1.926165814609562*^-6}, {-1.804898670825312*^-6, 
      0.6, -2.063409573997201*^-6}, {-1.974990957363396*^-6, 
      0.6, -2.213727037357415*^-6}, {-2.1575962683231646`*^-6, 
      0.6, -2.3780707891250872`*^-6}, {-2.3538718605922823`*^-6, 
      0.6, -2.5574818423286764`*^-6}, {-2.5650616342511726`*^-6, 
      0.6, -2.753096643228282*^-6}, {-2.792503484396626*^-6, 
      0.6, -2.9661547559689366`*^-6}, {-3.0376385326281363`*^-6, 
      0.6, -3.1980060349018836`*^-6}, {-3.302019446134877*^-6, 
      0.6, -3.4501199288394305`*^-6}, {-3.5873218737898955`*^-6, 
      0.6, -3.7240932826499644`*^-6}, {-3.895353140830065*^-6, 
      0.6, -4.02166227898114*^-6}, {-4.228064755489368*^-6, 
      0.6, -4.34471243638805*^-6}, {-4.587565198103897*^-6, 
      0.6, -4.6952901370201686`*^-6}, {-4.9761320536841974`*^-6, 
      0.6, -5.075616783760655*^-6}, {-5.396227312367623*^-6, 
      0.6, -5.488102029929633*^-6}, {-5.850512505358708*^-6, 
      0.6, -5.935359498737442*^-6}, {-6.341866025042803*^-6, 
      0.6, -6.4202228945442*^-6}, {-6.873401130316037*^-6, 
      0.6, -6.945764184519457*^-6}, {-7.448485518631518*^-6, 
      0.6, -7.515313213897554*^-6}, {-8.070762831428064*^-6, 
      0.6, -8.132478638142032*^-6}, {-8.744175736375208*^-6, 
      0.6, -8.801170790085483*^-6}, {-9.472991033730625*^-6, 
      0.6, -9.525626330472663*^-6}, {-0.000010261826378629162`, 
      0.6, -0.00001031043540070326}, {-0.00001111567971522896, 
      0.6, -0.000011160570529700403`}, {-0.000012039961043251015`, 
      0.6, -0.00001208141803981509}, {-0.00001304052654496819, 
      0.6, -0.000013078812323689824`}, {-0.0000141237157257236, 
      0.6, -0.000014159072774364945`}, {-0.000015296391483507826`, 
      0.6, -0.00001532904392112678}, {-0.000016565983816266942`, 
      0.6, -0.00001659613857188567}, {-0.000017940536793788674`, 
      0.6, -0.00001796838488365336}, {-0.00001942875942691038, 
      0.6, -0.000019454477325420624`}, {-0.000021040080996614087`, 
      0.6, -0.00002106383161622855}, {-0.000022784710682482025`, 
      0.6, -0.0000228066444968091}, {-0.000024673702280973754`, 
      0.6, -0.000024693958301481556`}, {-0.000026719024302568726`, 
      0.6, -0.00002673773086020153}, {-0.000028933635736675955`, 
      0.6, -0.000028950911328779123`}, {-0.00003133156813753918, 
      0.6, -0.00003134752225468653}, {-0.00003392801460466383, 
      0.6, -0.000033942748344997835`}, {-0.00003673942601308858, 
      0.6, -0.000036753032707190084`}, {-0.000039783615203098854`, 
      0.6000000001091956, -0.00003979618107288167}, {-0.00004307986990793968, 
      0.6000000002372297, -0.00004309147454667639}, {-0.00004664907490048348, 
      0.6000000003873521, -0.00004665979182735772}, {-0.00005051384434162842, 
      0.6000000005633737, -0.000050523741469545095`}, \
{-0.00005469866509203078, 
      0.6000000007697623, -0.00005470780509935663}, \
{-0.000059230051794284675`, 
      0.6000000010117571, -0.00005923849259176804}, {-0.00006413671490969004, 
      0.6000000012955007, -0.00006414450999225902}, {-0.00006944974265579308, 
      0.6000000016281956, -0.00006945694136569936}, {-0.00007520279789342707, 
      0.6000000020182868, -0.00007520944582704246}, {-0.0000814323314920522, 
      0.6000000024756765, -0.00008143847072194383}, {-0.00008817781320316944, 
      0.6000000030119749, -0.0000881834826297993}, {-0.00009548198184281131, 
      0.6000000036407951, -0.00009548721731462756}, {-0.00010339111596788464`,
       0.6000000043780991, -0.0001033959506077712}, {-0.00011195532716171946`,
       0.6000000052426024, -0.00011195979153834072`}, \
{-0.00012122887751200564`, 
      0.6000000062562495, -0.00012123299984364999`}, {-0.000131270523425155, 
      0.6000000074447704, -0.00013127432973880797`}, \
{-0.00014214388789933322`, 
      0.6000000088383345, -0.00014214740217964277`}, \
{-0.00015391786362658585`, 
      0.6000000104723155, -0.00015392110796578882`}, {-0.0001666670494863301, 
      0.6000000123881903, -0.00016667004422963406`}, \
{-0.00018047222321229429`, 
      0.600000014634591, -0.0001804749870600886}, {-0.0001954208531826299, 
      0.6000000172685395, -0.00019542340330060305`}, \
{-0.00021160765260653234`, 
      0.6000000203568956, -0.00021161000473330916`}, {-0.0002291351796399001, 
      0.6000000239780534, -0.0002291373481390928}, {-0.0002481144871769335, 
      0.6000000282239316, -0.0002481164850906514}, {-0.00026866582646344745`, 
      0.6000000332023065, -0.00026866766556649444`}, \
{-0.00029091940900029435`, 
      0.6000000390395483, -0.00029092109983314953`}, {-0.0003150162315661229, 
      0.600000045883828, -0.0003150177834204011}, {-0.0003411089695466271, 
      0.6000000539088794, -0.00034111039045598926`}, {-0.0003693629442849313, 
      0.6000000633184085, -0.00036936424096443125`}, \
{-0.00039995717053814127`, 
      0.6000000743512643, -0.00039995834830163906`}, {-0.0004330854907048535, 
      0.6000000872875024, -0.000433086553332235}, {-0.00046895780300066075`, 
      0.6000001024554928, -0.00046895875254322777`}, {-0.0005078013913550303, 
      0.6000001202402561, -0.0005078022278813244}, {-0.0005498623654646476, 
      0.6000001410932356, -0.0005498630867278635}, {-0.0005954072201321105, 
      0.6000001655437578, -0.0005954078211265788}, {-0.0006447245237663512, 
      0.6000001942124674, -0.0006447249961423188}, {-0.0006981267467378309, 
      0.6000002278270823, -0.0006981270780475018}, {-0.0007559522411712853, 
      0.6000002672408649, -0.0007559524139138662}, {-0.0008185673847389719, 
      0.6000003134542811, -0.0008185673751237488}, {-0.0008863689020205878, 
      0.6000003676403952, -0.0008863686783871242}, {-0.0009597863781408396, 
      0.6000004311746461, -0.000959785898952402}, {-0.0010392849806192088`, 
      0.6000005056697599, -0.0010392841919074293`}, {-0.0011253684066843876`, 
      0.6000005930166858, -0.0011253672387818334`}, {-0.0012185820747090397`, 
      0.6000006954325934, -0.001218580438108279}, {-0.0013195165800089933`, 
      0.60000081551715, -0.0013195143600960673`}, {-0.0014288114369022456`, 
      0.6000009563185068, -0.0014288084872573087`}, {-0.0015471591307337615`, 
      0.6000011214106667, -0.0015471552646276945`}, {-0.001675309505559245, 
      0.6000013149841996, -0.0016753044851455625`}, {-0.001814074515285831, 
      0.6000015419526045, -0.0018140680378773205`}, {-0.001964333368390137, 
      0.6000018080770199, -0.0019643250490298113`}, {-0.002127038098822196, 
      0.6000021201124445, -0.002127027448150441}, {-0.0023032195984105355`, 
      0.6000024859791795, -0.0023032059945602068`}, {-0.002493994149010176, 
      0.600002914963841, -0.0024939768019234484`}, {-0.0027005704958149254`, 
      0.6000034179550413, -0.0027005484019314266`}, {-0.0029242575066792194`, 
      0.6000040077197176, -0.002924229391409132}, {-0.0031664724660345972`, 
      0.6000046992271143, -0.0031664367107121227`}, {-0.0034287500559997525`, 
      0.6000055100286346, -0.003428704605144422}, {-0.003712752081670872, 
      0.6000064607031901, -0.0037126943252414526`}, {-0.004020278002303554, 
      0.6000075753793362, -0.00402020462620424}, {-0.004353276335232484, 
      0.6000088823474224, -0.004353183131514129}, {-0.004713857004939682, 
      0.6000104147772627, -0.004713738630827498}, {-0.0051043047157049454`, 
      0.6000122115594995, -0.005104154387665155}, {-0.0055270934328219, 
      0.6000143182919532, -0.00552690253814807}, {-0.00598490206443786, 
      0.6000167884359109, -0.005984659668135527}, {-0.006480631443783328, 
      0.6000196846715852, -0.0064803236625259365`}, {-0.00701742271988955, 
      0.6000230804869885, -0.007017031927226803}, {-0.007598677273958814, 
      0.6000270620403302, -0.007598181091305535}, {-0.008228078288389862, 
      0.6000317303429052, -0.008227448304072604}, {-0.008909614106143132, 
      0.6000372038174611, -0.008908814249245101}, {-0.009647603529752547, 
      0.6000436212964042, -0.009646588005769173}, {-0.010446723221920928`, 
      0.6000511455351548, -0.010445433892214535`}, {-0.011312037383389062`, 
      0.6000599673287352, -0.011310400438675917`}, {-0.01224902989874062, 
      0.6000703103345806, -0.012246951636567695`}, {-0.013263639157135671`, 
      0.6000824367219221, -0.013261000622205813`}, {-0.014362295772771424`, 
      0.6000966537883013, -0.014358945954186738`}, {-0.015551963449328257`, 
      0.600113321707257, -0.015547710646661751`}, {-0.016840183253927613`, 
      0.600132862598479, -0.016834784119891557`}, {-0.018235121589417494`, 
      0.6001557711432843, -0.018228267224911523`}, {-0.019745622179319765`, 
      0.6001826270047381, -0.019736920489437374`}, {-0.02138126240778037, 
      0.600214109353765, -0.0213702157155964}, {-0.023152414387624182`, 
      0.6002510138508576, -0.02313839103453761}, {-0.02507031116343909, 
      0.6002942724881886, -0.025052509485710167`}, {-0.027147118493818456`, 
      0.6003449767597551, -0.027124521136136108`}, {-0.02939601269782262, 
      0.6004044046982475, -0.029367328682943394`}, {-0.031831265095709126`, 
      0.6004740523970931, -0.03179485638524201}, {-0.03446833362333235, 
      0.6005556707247809, -0.03442212204216916}, {-0.03732396225354338, 
      0.600651308035878, -0.0372653115639089}, {-0.04041628891647032, 
      0.6007633597881673, -0.04034185546089107}, {-0.04376496267346856, 
      0.6008946260861298, -0.043670506289790016`}, {-0.04739127096602093, 
      0.6010483782840924, -0.047271415726877715`}, {-0.05131827782931711, 
      0.6012284358921806, -0.05116620946958702}, {-0.05557097402771401, 
      0.6014392551260955, -0.055378057571407596`}, {-0.06017644013076547, 
      0.6016860305148295, -0.059931737064297455`}, {-0.06516402359588774, 
      0.6019748110100481, -0.06485368278227155}, {-0.07056553094415034, 
      0.6023126320004834, -0.07017202113007259}, {-0.07641543608932834, 
      0.6027076644872136, -0.07591658009737927}, {-0.08275110577717393, 
      0.6031693823702786, -0.08211886705408904}, {-0.08961304286704455, 
      0.6037087482649277, -0.08881200372790038}, {-0.09704514777573463, 
      0.6043384174156738, -0.09603060521940675}, {-0.10509499770839423`, 
      0.6050729579895004, -0.10381058692535289`}, {-0.11381414218837126`, 
      0.6059290841552637, -0.11218887982206785`}, {-0.12325841167773036`, 
      0.6069258957089894, -0.12120303076879287`}, {-0.13348823349541145`, 
      0.6080851143656708, -0.13089066047787917`}, {-0.1445689454492063, 
      0.6094313019659493, -0.14128874786489976`}, {-0.15657109216627507`, 
      0.6109920395028737, -0.15243270615569432`}, {-0.16957068151147064`, 
      0.6127980378782543, -0.16435521422516058`}, {-0.18364936814730592`, 
      0.614883141618563, -0.17708476744487353`}, {-0.19889451767969563`, 
      0.6172841756893741, -0.19064391765426422`}, {-0.2153990876496707, 
      0.6200405738534199, -0.20504718423236676`}, {-0.23326124114977265`, 
      0.6231937163843726, -0.22029864077996847`}, {-0.2525835864609278, 
      0.6267858982813025, -0.2363892181980594}, {-0.2734719150977387, 
      0.6308588509355388, -0.2532938183109917}, {-0.29603329706851034`, 
      0.6354517567239398, -0.2709684044103037}, {-0.32037339555734184`, 
      0.6405987347323949, -0.28934732416754794`}, {-0.3465928966060371, 
      0.6463258438486587, -0.30834121736228204`}, {-0.3747830272159649, 
      0.6526477501544622, -0.3278359466849235}, {-0.40502026868875546`, 
      0.6595643333574629, -0.3476930335070702}, {-0.4373605602047099, 
      0.6670576417947188, -0.3677520420213608}, {-0.4718335077139699, 
      0.6750897095367769, -0.3878351965829792}, {-0.5084373134554776, 
      0.6836017716170274, -0.40775422230466674`}, {-0.5471352463929651, 
      0.6925153073235991, -0.4273189968746196}, {-0.5878544080926286, 
      0.701735089816238, -0.44634717883850966`}, {-0.63048727517951, 
      0.7111540602598394, -0.4646736639694408}, {-0.6748960549239186, 
      0.7206594703177467, -0.48215864185008084`}, {-0.7209193885804647, 
      0.7301394685345591, -0.4986932369604885}, {-0.7683805290914458, 
      0.7394892362624055, -0.5142021730981294}, {-0.8170959272007016, 
      0.7486159258766312, -0.5286434556075843}, {-0.8668832207082563, 
      0.7574419554163094, -0.5420055540664233}, {-0.9175678815468312, 
      0.765906560870763, -0.5543028669578466}, {-0.9689881263760023, 
      0.7739657981361806, -0.5655703245027869}, {-1.0209980299922854`, 
      0.7815913634017235, -0.5758578793355794}, {-1.0734690267482794`, 
      0.7887686571532998, -0.5852254287169598}, {-1.1262901211038938`, 
      0.7954944822264072, -0.5937384856661192}, {-1.179367168207111, 
      0.8017746816873899, -0.6014647228922463}, {-1.232621559555233, 
      0.8076219238503443, -0.6084713757029057}, {-1.2859885888138909`, 
      0.8130537527810111, -0.6148234086727768}, {-1.3394157029048794`, 
      0.8180909539066501, -0.620582314499002}, {-1.3928607782892777`, 
      0.82275623759773, -0.6258054076036081}, {-1.4462905088862856`, 
      0.8270732157481214, -0.630545486707117}, {-1.4996789519571603`, 
      0.8310656326786542, -0.6348507602450599}, {-1.5530062503718065`, 
      0.8347568074469986, -0.6387649500409164}, {-1.6062575316212748`, 
      0.8381692460798011, -0.6423275087240843}, {-1.659421973225369, 
      0.8413243866317371, -0.6455739034847675}, {-1.7124920185959582`, 
      0.844242445542328, -0.6485359325016973}, {-1.765462725204141, 
      0.8469423394433714, -0.6512420509667386}, {-1.8183312267771385`, 
      0.849441661801446, -0.6537176915222284}, {-1.8710962923240113`, 
      0.8517566983115319, -0.6559855696467635}, {-1.9237579664645994`, 
      0.8539024687270406, -0.6580659685653056}, {-1.9763172774383662`, 
      0.8558927858571518, -0.6599770010394751}, {-2.028776001074845, 
      0.8577403248699039, -0.6617348472513002}, {-2.0811364707911064`, 
      0.859456697909826, -0.6633539691895789}, {-2.133401425284152, 
      0.861052530470936, -0.6648473026787796}, {-2.1855738869866808`, 
      0.8625375370484167, -0.6662264286005392}, {-2.2376570655554078`, 
      0.8639205944007712, -0.6675017250517394}, {-2.2896542816763032`, 
      0.8652098113508918, -0.6686825022351343}, {-2.3415689073207466`, 
      0.8664125944891388, -0.6697771218406421}, {-2.393404319292194, 
      0.8675357094535592, -0.6707931025836458}, {-2.4451638634856314`, 
      0.8685853376823988, -0.6717372134453601}, {-2.4968508277611483`, 
      0.8695671286856322, -0.6726155560257564}, {-2.548468421725533, 
      0.8704862479833461, -0.6734336372821901}, {-2.6000197620367302`, 
      0.8713474209230663, -0.6741964337933063}, {-2.6515078621078425`, 
      0.8721549726257796, -0.6749084485618756}, {-2.702935625300727, 
      0.8729128643291023, -0.6755737612539717}, {-2.754305840872904, 
      0.8736247264014989, -0.6761960726662108}, {-2.8056211820827617`, 
      0.8742938882978287, -0.6767787441177217}, {-2.856884205972839, 
      0.8749234057168868, -0.6773248323787283}, {-2.9080973544442874`, 
      0.8755160852082168, -0.6778371206724633}, {-2.9592629563113437`, 
      0.876074506459929, -0.6783181462207956}, {-3, 
       0.8765191104535806, -0.6787011292809516}}], 
    Line3DBox[{{0., 0.44999999999999996`, -1.*^-6}, {-7.134723414501347*^-8, 
      0.44999999999999996`, -1.002542063741177*^-6}, \
{-1.4305837688518765`*^-7, 
      0.44999999999999996`, -1.0101810105623227`*^-6}, \
{-2.154967734152932*^-7, 
      0.44999999999999996`, -1.0229558643313247`*^-6}, \
{-2.890307745408398*^-7, 
      0.44999999999999996`, -1.0409314566069097`*^-6}, \
{-3.640341036395112*^-7, 
      0.44999999999999996`, -1.064199334435632*^-6}, \
{-4.4088804002153466`*^-7, 
      0.44999999999999996`, -1.0928777431872995`*^-6}, \
{-5.199836035066605*^-7, 
      0.44999999999999996`, -1.1271124025440586`*^-6}, \
{-6.017236607023236*^-7, 
      0.44999999999999996`, -1.1670770179160928`*^-6}, \
{-6.865217775678005*^-7, 
      0.44999999999999996`, -1.21297574013234*^-6}, {-7.748099131855509*^-7, 
      0.44999999999999996`, -1.265041541940066*^-6}, {-8.670378183571346*^-7, 
      0.44999999999999996`, -1.3235385759616437`*^-6}, {-9.6367354829077*^-7, 
      0.44999999999999996`, -1.3887647722497255`*^-6}, \
{-1.0652085561463318`*^-6, 
      0.44999999999999996`, -1.461051658050996*^-6}, \
{-1.1721596345192777`*^-6, 
      0.44999999999999996`, -1.5407663385801718`*^-6}, \
{-1.285070111620071*^-6, 
      0.44999999999999996`, -1.6283143916790711`*^-6}, \
{-1.4045138632817459`*^-6, 
      0.44999999999999996`, -1.7241410520422314`*^-6}, \
{-1.5310981915573519`*^-6, 
      0.44999999999999996`, -1.8287334743582048`*^-6}, \
{-1.6654670801943373`*^-6, 
      0.44999999999999996`, -1.9426230827057118`*^-6}, \
{-1.8083033922776558`*^-6, 
      0.44999999999999996`, -2.0663891291609994`*^-6}, \
{-1.9603334524247734`*^-6, 
      0.44999999999999996`, -2.2006607406434344`*^-6}, \
{-2.122329607354318*^-6, 
      0.44999999999999996`, -2.3461210774190357`*^-6}, {-2.29511596518892*^-6,
       0.44999999999999996`, -2.503509232443332*^-6}, \
{-2.4795705080124257`*^-6, 
      0.44999999999999996`, -2.673625815426528*^-6}, {-2.676631910984807*^-6, 
      0.44999999999999996`, -2.857334891403352*^-6}, {-2.887301540214653*^-6, 
      0.44999999999999996`, -3.055570929247529*^-6}, {-3.112650182286899*^-6, 
      0.44999999999999996`, -3.269342042412968*^-6}, \
{-3.3538238237944027`*^-6, 
      0.44999999999999996`, -3.4997347832486412`*^-6}, \
{-3.6120489408216634`*^-6, 
      0.44999999999999996`, -3.747920175204181*^-6}, {-3.888637958257981*^-6, 
      0.44999999999999996`, -4.015160415276889*^-6}, {-4.184997189944022*^-6, 
      0.44999999999999996`, -4.302814069690691*^-6}, {-4.502633338245304*^-6, 
      0.44999999999999996`, -4.612343609884963*^-6}, {-4.843161439475326*^-6, 
      0.44999999999999996`, -4.945322571021944*^-6}, {-5.208312188759989*^-6, 
      0.44999999999999996`, -5.303444415856724*^-6}, {-5.599942458101949*^-6, 
      0.44999999999999996`, -5.688529464798932*^-6}, {-6.020043757360849*^-6, 
      0.44999999999999996`, -6.102535105637641*^-6}, {-6.470751292042781*^-6, 
      0.44999999999999996`, -6.547566799171606*^-6}, {-6.954356739842578*^-6, 
      0.44999999999999996`, -7.025886890073013*^-6}, {-7.473318681215185*^-6, 
      0.44999999999999996`, -7.539927313395222*^-6}, {-8.03027572549071*^-6, 
      0.44999999999999996`, -8.092301339177262*^-6}, {-8.628059431525398*^-6, 
      0.44999999999999996`, -8.685817347708354*^-6}, {-9.269708933152438*^-6, 
      0.44999999999999996`, -9.323492880685393*^-6}, {-9.958486438784107*^-6, 
      0.44999999999999996`, -0.000010008569934267623`}, \
{-0.00001069789384721814, 
      0.44999999999999996`, -0.000010744531411366596`}, \
{-0.000011491690361231996`, 
      0.44999999999999996`, -0.000011535119018371788`}, \
{-0.000012343911716900317`, 
      0.44999999999999996`, -0.000012384352171810618`}, \
{-0.000013258890686692433`, 
      0.44999999999999996`, -0.000013296548448239219`}, \
{-0.000014241278921281758`, 
      0.44999999999999996`, -0.000014276345721189373`}, \
{-0.000015296071206466793`, 
      0.44999999999999996`, -0.000015328725134568974`}, \
{-0.000016428630063719618`, 
      0.44999999999999996`, -0.000016459037218669332`}, \
{-0.000017644713524115053`, 
      0.44999999999999996`, -0.0000176730285835542}, \
{-0.000018950504366774897`, 
      0.44999999999999996`, -0.000018976871171115328`}, \
{-0.00002035264130409333, 
      0.44999999999999996`, -0.000020377193881954313`}, \
{-0.000021858252921625866`, 
      0.44999999999999996`, -0.000021881116089563407`}, \
{-0.000023474993835572113`, 
      0.44999999999999996`, -0.000023496283920627453`}, \
{-0.000025211083801706954`, 
      0.44999999999999996`, -0.00002523090893666175}, \
{-0.00002707534915203755, 
      0.44999999999999996`, -0.00002709381023531901}, \
{-0.000029077268072715166`, 
      0.44999999999999996`, -0.00002909445888378475}, \
{-0.00003122701845449571, 
      0.44999999999999996`, -0.00003124302640777641}, {-0.0000335355298459224,
       0.44999999999999996`, -0.000033550436296778154`}, \
{-0.00003601453888371683, 
      0.44999999999999996`, -0.00003602841967638939}, \
{-0.000038676649086372284`, 
      0.44999999999999996`, -0.00003868957482701747}, \
{-0.00004153539488308933, 
      0.44999999999999996`, -0.000041547431283133285`}, \
{-0.00004460531043319484, 
      0.44999999999999996`, -0.000044616518609488505`}, \
{-0.000047902003423066026`, 
      0.44999999999999996`, -0.000047912440366753464`}, \
{-0.00005144223452298444, 
      0.44999999999999996`, -0.00005145195333548419}, \
{-0.00005524400264978194, 
      0.4500000001144316, -0.00005525305265930006}, {-0.00005932663625072962, 
      0.45000000024639875`, -0.0000593350635583017}, {-0.00006371089186736032,
       0.4500000003985885, -0.00006371873928333221}, {-0.00006841905943403426,
       0.4500000005740999, -0.00006842636685719879}, {-0.00007347507571674198,
       0.45000000077650665`, -0.00007348188026932538}, \
{-0.00007890464595649392, 
      0.4500000010099302, -0.0000789109822112461}, {-0.00008473537456994377, 
      0.4500000012791236, -0.00008474127473836306}, {-0.0000909969055243023, 
      0.4500000015895682, -0.00009100239957006011}, {-0.00009772107299872647, 
      0.4500000019475854, -0.00009772618884181891}, {-0.00010494206328769456`,
       0.4500000023604651, -0.00010494682688700984`}, \
{-0.00011269658854432877`, 
      0.45000000283661457`, -0.00011270102409584594`}, {-0.000121024073489525,
       0.45000000338572915`, -0.00012102820349288676`}, \
{-0.0001299668558188694, 
      0.4500000040189901, -0.0001299707011989128}, {-0.0001395704014408362, 
      0.450000004749292, -0.00013957398168172215`}, {-0.00014988353565243242`,
       0.45000000559150544`, -0.00014988686887831127`}, \
{-0.00016095869137068116`, 
      0.45000000656277966`, -0.00016096179442038952`}, \
{-0.0001728521756997754, 
      0.45000000768289206`, -0.0001728550642074028}, {-0.0001856244561933367, 
      0.4500000089746505, -0.00018562714467813246`}, {-0.0001993404682976118, 
      0.45000001046435806`, -0.00019934297020581177`}, \
{-0.0002140699454583209, 
      0.4500000121823485, -0.00021407227325988856`}, \
{-0.00022988777369645474`, 
      0.45000001416360386`, -0.00022988993888594376`}, \
{-0.00024687437228847675`, 
      0.4500000164484669, -0.00024687638547313435`}, \
{-0.00026511610265612717`, 
      0.45000001908346243`, -0.0002651179735751421}, {-0.000284705707430874, 
      0.4500000221222448, -0.00028470744497678023`}, {-0.0003057427819649852, 
      0.45000002562669034`, -0.0003057443941986388}, {-0.0003283342806727297, 
      0.45000002966815716`, -0.0003283357748504603}, {-0.0003525950608180716, 
      0.4500000343289385, -0.0003525964433652916}, {-0.0003786484664476143, 
      0.45000003970393804`, -0.000378649742944441}, {-0.00040662695549228744`,
       0.45000004590260256`, -0.00040662813062700804`}, \
{-0.00043667277319004604`, 
      0.4500000530511505, -0.0004366738507076153}, {-0.00046893867527488106`, 
      0.45000006129514186`, -0.0004689396579039847}, {-0.0005035887046206662, 
      0.4500000708024424, -0.0005035895939385976}, {-0.0005407990252356432, 
      0.45000008176664147`, -0.0005407998215345792}, {-0.0005807588179098019, 
      0.4500000944109939, -0.0005807595200027806}, {-0.0006236712420348896, 
      0.4500001089929663, -0.000623671847005898}, {-0.0006697544684918599, 
      0.45000012580947896`, -0.0006697549713829874}, {-0.0007192427888586797, 
      0.45000014520295245`, -0.0007192431822818432}, {-0.000772387806591622, 
      0.45000016756827954`, -0.0007723880802220415}, {-0.0008294597162035784, 
      0.45000019336086605`, -0.0008294598561737848}, {-0.0008907486769837668, 
      0.45000022310590393`, -0.0008907486651110251}, {-0.0009565662882200244, 
      0.4500002574090649, -0.0009565661010406529}, {-0.001027247173423457, 
      0.45000029696883337`, -0.0010272467810018705`}, \
{-0.0011031506816229135`, 
      0.4500003425907285, -0.0011031500460690583`}, {-0.001184662714373776, 
      0.4500003952037061, -0.0011846617880028607`}, {-0.001272197687775233, 
      0.4500004558790736, -0.0012721964108204978`}, {-0.0013662006394634767`, 
      0.4500005258523035, -0.0013661989372528928`}, {-0.0014671494913179638`, 
      0.45000060654818935`, -0.0014671472707571433`}, \
{-0.0015755574793625807`, 
      0.45000069960985634`, -0.00157555462458688}, {-0.0016919757632381295`, 
      0.4500008069322173, -0.0016919721302231616`}, {-0.0018169962285139436`, 
      0.45000093070055475`, -0.0018169916383961844`}, {-0.00195125449609164, 
      0.45000107343501533`, -0.0019512487268952532`}, \
{-0.0020954331540118873`, 
      0.45000123804192116`, -0.00209542593040186}, {-0.0022502652281093903`, 
      0.4500014278729435, -0.0022502562086948678`}, {-0.002416537909168609, 
      0.4500016467933431, -0.0024165266707820163`}, {-0.0025950965555548607`, 
      0.45000189926066547`, -0.0025950825737781234`}, \
{-0.0027868489916898194`, 
      0.4500021904154936, -0.0027868316167323844`}, {-0.002992770124247682, 
      0.4500025261861045, -0.0029927485510775793`}, {-0.0032139068995856225`, 
      0.45000291340915893`, -0.0032138801309295065`}, \
{-0.0034513836276418314`, 
      0.4500033599688808, -0.0034513504281681305`}, {-0.003706407699430694, 
      0.45000387495755684`, -0.0037063665390040406`}, \
{-0.0039802757272633105`, 
      0.4500044688606219, -0.003980224710665457}, {-0.004274380138988578, 
      0.45000515377009426`, -0.004274316918883395}, {-0.004590216259880932, 
      0.4500059436307007, -0.004590137929028119}, {-0.004929389918304029, 
      0.45000685452369543`, -0.004929292876068856}, {-0.005293625613964022, 
      0.45000790499414217`, -0.005293505401001193}, {-0.005684775290472045, 
      0.45000911642830876`, -0.005684626383991867}, {-0.006104827757043486, 
      0.4500105134888415, -0.0061046433172681795`}, {-0.006555918807525755, 
      0.4500121246165558, -0.006555690363694642}, {-0.007040342088549708, 
      0.45001398260902786`, -0.007040059150068968}, {-0.007560560772502126, 
      0.4500161252877265, -0.007560210347392086}, {-0.008119220095205354, 
      0.45001859626721136`, -0.00811878609375178}, {-0.008719160822718808, 
      0.4500214458419846, -0.00871862331896814}, {-0.009363433716558966, 
      0.4500247320089527, -0.00936276803377898}, {-0.010055315071906426`, 
      0.45002852164618323`, -0.010054490650064822`}, {-0.010798323409067502`, 
      0.45003289187177986`, -0.010797302402389304`}, {-0.011596237404619859`, 
      0.4500379316103071, -0.0115949729449178}, {-0.012453115155346216`, 
      0.4500437433983439, -0.012451549201506158`}, {-0.013373314875290207`, 
      0.45005044546551, -0.013371375550346388`}, {-0.014361517134119525`, 
      0.45005817413277904`, -0.014359115427899477`}, {-0.015422748753511212`, 
      0.4500670865761697, -0.015419774439804043`}, {-0.016562408487556475`, 
      0.4500773640110982, -0.016558725068843205`}, {-0.017786294623303056`, 
      0.45008921536091745`, -0.01778173307165151}, {-0.019100634648607184`, 
      0.45010288148259026`, -0.01909498565636066}, {-0.020512117146559216`, 
      0.45011864003321495`, -0.02050512153245881}, {-0.022027926089007832`, 
      0.4501368110734011, -0.022019262921310942`}, {-0.023655777716277224`, 
      0.45015776351747916`, -0.023645049610489244`}, {-0.025403960206215638`, 
      0.4501819225564167, -0.025390675126577205`}, {-0.027281376353418776`, 
      0.45020977819731883`, -0.02726492508854931}, {-0.029297589499053155`, 
      0.45024189508373574`, -0.029277217786082128`}, {-0.03146287297340444, 
      0.45027892378390094`, -0.031437647002847235`}, {-0.033788263337363976`, 
      0.45032161375969293`, -0.033757027072271545`}, {-0.036285617735844156`, 
      0.4503708282577289, -0.036246940110320695`}, {-0.03896767570590119, 
      0.4504275613956927, -0.038919785313974546`}, {-0.041848125815482584`, 
      0.45049295775181625`, -0.04178883014202646}, {-0.04494167754553951, 
      0.4505683348032877, -0.04486826310273652}, {-0.04826413886905844, 
      0.4506552085999699, -0.048173247755905535`}, {-0.05183250002559246, 
      0.4507553231026214, -0.05171997738926786}, {-0.055665024039183345`, 
      0.4508706836588478, -0.0555257296436145}, {-0.05978134458095752, 
      0.45100359513376054`, -0.05960892012915257}, {-0.06420257183450723, 
      0.4511567052534814, -0.0639891537869246}, {-0.06895140708108614, 
      0.45133305375485794`, -0.06868727239125808}, {-0.07405226678023039, 
      0.45153612795927234`, -0.07372539614748454}, {-0.07953141697561147, 
      0.4517699253955514, -0.07912695679627298}, {-0.08541711889928695, 
      0.4520390240775005, -0.08491671897181279}, {-0.09173978667007363, 
      0.4523486609829398, -0.09112078575290061}, {-0.09853215796851605, 
      0.45270481916642463`, -0.09776658336828517}, {-0.1058294784996445, 
      0.4531143237446152, -0.10488281884305331`}, {-0.11366970089308887`, 
      0.45358494669196625`, -0.11249940297354362`}, {-0.12209369839177477`, 
      0.4541255199366672, -0.12064732936847486`}, {-0.1311454931798312, 
      0.4547460556034822, -0.129358498374327}, {-0.14087249840618427`, 
      0.45545787134962845`, -0.1386654725076329}, {-0.15132577174745973`, 
      0.4562737175063308, -0.14860114756430237`}, {-0.1625602765539604, 
      0.4572079010820347, -0.15919832092609043`}, {-0.1746351440143949, 
      0.45827639950091736`, -0.17048913586221348`}, {-0.18761392607644656`, 
      0.459496954133834, -0.18250437805624045`}, {-0.20156482372541507`, 
      0.4608891301279015, -0.1952725985509017}, {-0.2165608682532808, 
      0.4624743246900506, -0.20881903638721672`}, {-0.2326800239297402, 
      0.46427570084420633`, -0.22316431530561917`}, {-0.2500051686624986, 
      0.46631801793078026`, -0.23832289324781425`}, {-0.2686238946701353, 
      0.4686273241854619, -0.2543012527892107}, {-0.28862805422785176`, 
      0.4712304714751459, -0.2710958372840861}, {-0.31011295740569256`, 
      0.47415440914471996`, -0.2886907640684576}, {-0.33317611206378184`, 
      0.4774252152050386, -0.3070553852516054}, {-0.3579153859748663, 
      0.4810668319504134, -0.3261418204360292}, {-0.3844264742877353, 
      0.48509949349192005`, -0.34588265401462864`}, {-0.4127995828915463, 
      0.4895378687179724, -0.3661890681003685}, {-0.4431153015043757, 
      0.494388997583015, -0.3869497592621829}, {-0.4754397497456075, 
      0.49965017025721475`, -0.4080310423381771}, {-0.5098192375073186, 
      0.5053069793045469, -0.429278547467032}, {-0.5462748738331242, 
      0.5113318465746661, -0.4505208323594112}, {-0.5847977487198462, 
      0.5176833611173884, -0.4715750337965651}, {-0.6253454381736265, 
      0.5243067309253444, -0.4922543703862227}, {-0.6678405727767385, 
      0.5311355284075906, -0.5123769281697266}, {-0.7121720123811004, 
      0.5380947027251946, -0.5317748067997683}, {-0.758198789037639, 
      0.5451045841802189, -0.5503024978838081}, {-0.8057564973673192, 
      0.5520853891885587, -0.5678434057930838}, {-0.8546653640542451, 
      0.5589616232289157, -0.5843137239706673}, {-0.9047389550650915, 
      0.5656658139128187, -0.5996633661495959}, {-0.9557924570376255, 
      0.5721411723748936, -0.6138741726907447}, {-1.0076496798819856`, 
      0.5783430171015941, -0.6269560170983418}, {-1.0601482764473626`, 
      0.5842390233109569, -0.6389416379949394}, {-1.1131430429863505`, 
      0.5898085247531323, -0.6498810134678641}, {-1.1665074580250125`, 
      0.5950411708461768, -0.65983593787517}, {-1.220133794485893, 
      0.5999352405107148, -0.6688752388167131}, {-1.2739322040740615`, 
      0.6044958624717002, -0.6770708542496059}, {-1.3278291541882346`, 
      0.6087333195671607, -0.6844948178383264}, {-1.3817655326163276`, 
      0.6126615436657086, -0.691217087648379}, {-1.4356946544519769`, 
      0.6162968500887942, -0.6973040937038562}, {-1.489580328691785, 
      0.6196569196993753, -0.7028178599805246}, {-1.5433950785360637`, 
      0.6227600117778664, -0.7078155613991507}, {-1.5971185622060116`, 
      0.6256243779873463, -0.7123493943354989}, {-1.6507362088525976`, 
      0.6282678433075959, -0.7164666618195137}, {-1.704238063951198, 
      0.6307075205273239, -0.7202099970402936}, {-1.7576178272512126`, 
      0.632959628312852, -0.7236176685425003}, {-1.810872061069212, 
      0.635039387416202, -0.7267239267021028}, {-1.8639995452820783`, 
      0.6369609742810345, -0.7295593636990338}, {-1.9170007562100675`, 
      0.6387375156351482, -0.7321512686803618}, {-1.9698774486063286`, 
      0.6403811113958473, -0.73452396669664}, {-2.022632322502849, 
      0.6419028763026765, -0.7366991348620426}, {-2.075268759289558, 
      0.6433129931653846, -0.738696092532971}, {-2.127790613893053, 
      0.6446207725497152, -0.7405320645264447}, {-2.1802020521609298`, 
      0.6458347152088117, -0.7422224178258925}, {-2.232507424505209, 
      0.646962574690142, -0.7437808730872139}, {-2.284711168513279, 
      0.6480114183836806, -0.7452196927383499}, {-2.3368177346180783`, 
      0.6489876858912549, -0.7465498476880894}, {-2.3888315300617435`, 
      0.6498972440419524, -0.7477811647144693}, {-2.4407568773222525`, 
      0.6507454381959518, -0.7489224565526508}, {-2.4925979839331625`, 
      0.6515371397014658, -0.7499816365895804}, {-2.5443589212419697`, 
      0.6522767895215656, -0.7509658199270336}, {-2.596043610148722, 
      0.6529684381483777, -0.7518814124148399}, {-2.6476558122652687`, 
      0.6536157819857107, -0.7527341890943859}, {-2.6991991252553604`, 
      0.6542221964181983, -0.7535293633363633}, {-2.7506769813719036`, 
      0.6547907658033605, -0.7542716478104464}, {-2.802092648412453, 
      0.6553243106283887, -0.7549653082903398}, {-2.853449232477612, 
      0.6558254120701414, -0.7556142111762171}, {-2.9047496820475702`, 
      0.6562964341878511, -0.7562218655079271}, {-2.955996792996107, 
      0.6567395439655705, -0.7567914601458919}, {-3, 
       0.6571200190970178, -0.7572805411945357}}], 
    Line3DBox[{{0., 0.3, -1.*^-6}, {-6.678493655910459*^-8, 
      0.3, -1.0022276892765741`*^-6}, {-1.3386750780970206`*^-7, 
      0.3, -1.0089205765157686`*^-6}, {-2.0154668554143494`*^-7, 
      0.3, -1.0201085142764823`*^-6}, {-2.701232041229943*^-7, 
      0.3, -1.0358415123796642`*^-6}, {-3.39903381347727*^-7, 
      0.3, -1.056189472766338*^-6}, {-4.111980071596534*^-7, 
      0.3, -1.081243107963027*^-6}, {-4.843259766391138*^-7, 
      0.3, -1.1111135414402855`*^-6}, {-5.596112651760028*^-7, 
      0.3, -1.1459345694892541`*^-6}, {-6.373887272375092*^-7, 
      0.3, -1.1858616454994782`*^-6}, {-7.180067961183765*^-7, 
      0.3, -1.231071681772395*^-6}, {-8.018240914112324*^-7, 
      0.3, -1.2817663892485147`*^-6}, {-8.892134632574111*^-7, 
      0.3, -1.338171984247668*^-6}, {-9.805641367002497*^-7, 
      0.3, -1.4005398677556818`*^-6}, {-1.0762841695417155`*^-6, 
      0.3, -1.4691471786795621`*^-6}, {-1.1767998167441179`*^-6, 
      0.3, -1.5442997167648015`*^-6}, {-1.2825578682226035`*^-6, 
      0.3, -1.6263331082461823`*^-6}, {-1.394029652934908*^-6, 
      0.3, -1.71561273300299*^-6}, {-1.51171325322889*^-6, 
      0.3, -1.8125352049856501`*^-6}, {-1.6361317098260666`*^-6, 
      0.3, -1.9175333877777697`*^-6}, {-1.7678395422205298`*^-6, 
      0.3, -2.0310749283534105`*^-6}, {-1.907423618607151*^-6, 
      0.3, -2.1536656344594187`*^-6}, {-2.055506008429541*^-6, 
      0.3, -2.2858515333959365`*^-6}, {-2.2127462975506236`*^-6, 
      0.3, -2.4282217077867856`*^-6}, {-2.3798454781386005`*^-6, 
      0.3, -2.581410069592885*^-6}, {-2.557547540632761*^-6, 
      0.3, -2.746099571689989*^-6}, {-2.746644283435241*^-6, 
      0.3, -2.9230238905022468`*^-6}, {-2.9479783992742266`*^-6, 
      0.3, -3.1129710894528917`*^-6}, {-3.162446532496442*^-6, 
      0.3, -3.3167877917054726`*^-6}, {-3.3910043609394717`*^-6, 
      0.3, -3.535381924919711*^-6}, {-3.634670374988702*^-6, 
      0.3, -3.7697272163383716`*^-6}, {-3.894530061252142*^-6, 
      0.3, -4.020867872323033*^-6}, {-4.1717410638260034`*^-6, 
      0.3, -4.289922920032549*^-6}, {-4.467538506486905*^-6, 
      0.3, -4.578091033763461*^-6}, {-4.783240401492533*^-6, 
      0.3, -4.886655963661626*^-6}, {-5.120253227446524*^-6, 
      0.3, -5.216992544158132*^-6}, {-5.480078473757281*^-6, 
      0.3, -5.570572547299763*^-6}, {-5.864319346194713*^-6, 
      0.3, -5.948971224642474*^-6}, {-6.274687484623632*^-6, 
      0.3, -6.35387474309596*^-6}, {-6.7130116297313*^-6, 
      0.3, -6.7870866719558956`*^-6}, {-7.181244425828174*^-6, 
      0.3, -7.250537344915815*^-6}, {-7.681471934867809*^-6, 
      0.3, -7.746291657043595*^-6}, {-8.21592302779506*^-6, 
      0.3, -8.27655816692727*^-6}, {-8.786978760963714*^-6, 
      0.3, -8.84369948590293*^-6}, {-9.397183397558899*^-6, 
      0.3, -9.45024239462441*^-6}, {-0.000010049255584683492`, 
      0.3, -0.000010098889257900972`}, {-0.000010746100503259545`, 
      0.3, -0.000010792530027594574`}, {-0.000011490822888526703`, 
      0.3, -0.00001153425504164126}, {-0.000012286740657069303`, 
      0.3, -0.000012327368997168232`}, {-0.00001313739991711532, 
      0.3, -0.000013175405447032781`}, {-0.000014046590610532026`, 
      0.3, -0.000014082142699571559`}, {-0.0000150183635220846, 
      0.3, -0.000015051620528723258`}, {-0.00001605704822243643, 
      0.3, -0.000016088158276858134`}, {-0.00001716727242061475, 
      0.3, -0.000017196374036197515`}, {-0.000018353982436232473`, 
      0.3, -0.000018381205369457523`}, {-0.000019622465483006438`, 
      0.3, -0.000019647931062734855`}, {-0.000020978373130716244`, 
      0.3, -0.000021002194738343354`}, {-0.00002242774636934795, 
      0.3, -0.000022450030114352384`}, {-0.000023977042582054545`, 
      0.3, -0.000023997887828529208`}, {-0.000025633164454551888`, 
      0.3, -0.000025652664038571083`}, {-0.000027403490561375354`, 
      0.3, -0.000027421731314077117`}, {-0.0000292959082653284, 
      0.3, -0.000029312971458357415`}, {-0.000031318848873378776`, 
      0.3, -0.000031334810609387646`}, {-0.00003348132534850715, 
      0.3, -0.000033496256633521026`}, {-0.000035792972158988854`, 
      0.3, -0.000035806939564783}, {-0.000038264088488607336`, 
      0.3, -0.00003827715422451536}, {-0.00004090568397544407, 
      0.3, -0.00004091790623560334}, {-0.00004372952780693092, 
      0.3, -0.00004374096101269307}, {-0.00004674820111162362, 
      0.3, -0.00004675889622481993}, {-0.000049975153088467726`, 
      0.3, -0.0000499851577569037}, {-0.00005342476085129323, 
      0.3, -0.00005343411969170071}, {-0.000057112393595193064`, 
      0.3, -0.00005712114823950704}, {-0.00006105448091275595, 
      0.3, -0.00006106267035825647}, {-0.00006526858609391412, 
      0.3, -0.00006527624684045025}, {-0.00006977348439662157, 
      0.3000000001002776, -0.00006978065053188749}, {-0.00007458924661465522, 
      0.3000000002148738, -0.00007459595005321001}, {-0.00007973732856008432, 
      0.300000000345833, -0.0000797435991513294}, {-0.00008524066661767659, 
      0.3000000004954918, -0.00008524653232142091}, {-0.00009112377999846065, 
      0.3000000006665202, -0.000091129266923227}, {-0.00009741287992662876, 
      0.3000000008619696, -0.00009741801246819544}, {-0.0001041359863976564, 
      0.30000000108532704`, -0.0001041407874132914}, \
{-0.00011132305307885435`, 
      0.3000000013405774, -0.00011132754392926088`}, \
{-0.00011900610072265799`, 
      0.30000000163227475`, -0.00011901030138832464`}, \
{-0.00012721935984334127`, 
      0.30000000196562326`, -0.00012722328900696182`}, \
{-0.00013599942322620426`, 
      0.30000000234657026`, -0.00013600309834724245`}, \
{-0.00014538540895911082`, 
      0.3000000027819123, -0.0001453888463454958}, {-0.0001554191347082767, 
      0.3000000032794164, -0.00015542234959911117`}, {-0.0001661453040401259, 
      0.30000000384795855`, -0.00016614831066260393`}, \
{-0.0001776117055793287, 
      0.30000000449768227`, -0.00017761451722295485`}, \
{-0.00018986942593492845`, 
      0.3000000052401794, -0.0001898720549970068}, {-0.00020297307731271624`, 
      0.30000000608869687`, -0.00020297553532992293`}, \
{-0.00021698104080191468`, 
      0.3000000070583733, -0.00021698333853473526`}, {-0.0002319557265172252, 
      0.30000000816650885`, -0.00023195787395998015`}, \
{-0.00024796385163889794`, 
      0.3000000094328739, -0.0002479658580604297}, {-0.00026507673766399813`, 
      0.30000001088006195`, -0.0002650786116353576}, {-0.0002833706281601616, 
      0.30000001253389247`, -0.0002833723775916395}, {-0.0003029270284733349, 
      0.3000000144238717, -0.0003029286606115613}, {-0.0003238330688411456, 
      0.3000000165837191, -0.00032383459030045116`}, {-0.0003461818926075196, 
      0.3000000190519689, -0.0003461833093541502}, {-0.00037007307119617824`, 
      0.30000002187265745`, -0.00037007438854760416`}, \
{-0.00039561304773806834`, 
      0.3000000250961092, -0.00039561427034712877`}, \
{-0.00042291561130662923`, 
      0.30000002877983417`, -0.0004229167431452081}, \
{-0.00045210240390118264`, 
      0.30000003298955435`, -0.00045210344820306215`}, \
{-0.0004833034623926922, 
      0.30000003780037593`, -0.00048330442160383956`}, \
{-0.0005166577978904463, 
      0.30000004329812957`, -0.000516658673586675}, {-0.0005523140150832487, 
      0.3000000495809015, -0.0005523148078700134}, {-0.0005904309743276877, 
      0.3000000567607835, -0.0005904316837097919}, {-0.0006311784994258328, 
      0.30000006496587295`, -0.00063117912364903}, {-0.000674738134260248, 
      0.300000074342558, -0.0006747386700968372}, {-0.0007213039516352518, 
      0.30000008505812925`, -0.0007213043941288693}, {-0.0007710834179417777, 
      0.30000009730376465`, -0.0007710837600978929}, {-0.0008242983175084023, 
      0.30000011129794, -0.0008242985498950338}, {-0.0008811857407324859, 
      0.3000001272903271, -0.0008811858510022799}, {-0.0009419991404183611, 
      0.3000001455662477, -0.0009419991127118349}, {-0.0010070094610130503`, 
      0.3000001664517644, -0.001007009275231507}, {-0.00107650634578046, 
      0.3000001903194975, -0.0010765059766938226`}, {-0.0011507994272908625`, 
      0.30000021759527296`, -0.0011507988434443434`}, \
{-0.0012302197069769044`, 
      0.3000002487657197, -0.0012302188693516635`}, {-0.0013151210299046294`, 
      0.300000284386951, -0.0013151198902767423`}, {-0.0014058816613267988`, 
      0.30000032509448626`, -0.0014058801602674098`}, \
{-0.0015029059720567627`, 
      0.30000037161458903`, -0.0015029040364780975`}, \
{-0.0016066262401614735`, 
      0.3000004247772238, -0.001606623780321936}, {-0.0017175045770139482`, 
      0.3000004855308628, -0.0017175014828545102`}, {-0.0018360349862832602`, 
      0.3000005549594074, -0.0018360311229556245`}, {-0.0019627455650519975`, 
      0.30000063430152496`, -0.0019627407674441904`}, \
{-0.0020982008568583314`, 
      0.30000072497274655`, -0.002098194922915674}, {-0.0022430043671724798`, 
      0.30000082859072014`, -0.0022429970497267813`}, {-0.00239780125250794, 
      0.30000094700406876`, -0.0023977922493015366`}, \
{-0.0025632811951723598`, 
      0.3000010823253693, -0.002563270136666823}, {-0.0027401814764751843`, 
      0.3000012369688391, -0.0027401679109564756`}, {-0.002929290262103052, 
      0.3000014136934033, -0.002929273637484363}, {-0.0031314501143230346`, 
      0.3000016156519103, -0.0031314297559121534`}, {-0.0033475617466864893`, 
      0.3000018464473736, -0.0033475368300262226`}, {-0.003578588037997289, 
      0.3000021101972418, -0.003578557555683911}, {-0.0038255583234666646`, 
      0.3000024116068439, -0.0038255210446115832`}, {-0.004089572982219352, 
      0.3000027560533173, -0.004089527402928417}, {-0.004371808341655212, 
      0.300003149681517, -0.004371752624527085}, {-0.00467352192058243, 
      0.3000035995136125, -0.0046734538208001815`}, {-0.004996058034577381, 
      0.3000041135743275, -0.004995974809615338}, {-0.005340853788648212, 
      0.30000470103405236`, -0.005340752087967455}, {-0.005709445484036219, 
      0.300005372372379, -0.005709321214332599}, {-0.006103475467860875, 
      0.30000613956497046`, -0.006103323628446886}, {-0.006524699456323306, 
      0.30000701629709164`, -0.006524513938024497}, {-0.006974994364334822, 
      0.3000080182076023, -0.006974767703818182}, {-0.007456366676750825, 
      0.30000916316775256`, -0.0074560897564061685`}, {-0.007970961398864078, 
      0.30001047159973976`, -0.00797062308017506}, {-0.008521071626473854, 
      0.30001196684068937`, -0.008520658302141453}, {-0.009109148778704546, 
      0.3000136755585268, -0.009108643825520594}, {-0.009737813539817574, 
      0.30001562822712485`, -0.009737196650299144}, {-0.010409867559563387`, 
      0.3000178596691579, -0.010409113925489264`}, {-0.011128305965176409`, 
      0.30002040967628824`, -0.011127385280217946`}, {-0.01189633074194574, 
      0.30002332371767126`, -0.011895205983320157`}, {-0.012717365043424684`, 
      0.30002665374931803`, -0.012715990983629086`}, {-0.013595068496803983`, 
      0.3000304591386215, -0.01359338988565323}, {-0.014533353573793735`, 
      0.3000348077203672, -0.014531302917757671`}, {-0.015536403102579196`, 
      0.3000397770028418, -0.015533897952261478`}, {-0.016608689002072616`, 
      0.30004545554525963`, -0.01660562863895439}, {-0.017754992325830336`, 
      0.3000519445306965, -0.01775125371532304}, {-0.01898042470968629, 
      0.3000593595620851, -0.018975857558149956`}, {-0.02029045132444037, 
      0.30006783271265514`, -0.020284872041950338`}, {-0.02169091544289653, 
      0.30007751486653583`, -0.021684099769763085`}, {-0.02318806473925757, 
      0.30008857839015346`, -0.023179738740879578`}, {-0.02478857944843795, 
      0.3001012201806114, -0.02477840851789721}, {-0.02649960252336704, 
      0.30011566514351806`, -0.026487177951666656`}, {-0.02832877193993959, 
      0.30013217015980026`, -0.02831359451683554}, {-0.030284255312075535`, 
      0.3001510286089982, -0.03026571530223716}, {-0.03237478699353109, 
      0.30017257552546367`, -0.03235213968868502}, {-0.03460970785885192, 
      0.3001971934738677, -0.034582043730999594`}, {-0.036999007973375755`, 
      0.3002253192415513, -0.036965216240340215`}, {-0.03955337238171724, 
      0.3002574514575978, -0.03951209653593558}, {-0.04228423026595588, 
      0.3002941592621327, -0.042233813800639605`}, {-0.04520380774908359, 
      0.3003360921643009, -0.045142227930600444`}, {-0.0483251846464476, 
      0.30038399124362886`, -0.048249971713548064`}, {-0.05166235549825047, 
      0.30043870186698907`, -0.05157049410014941}, {-0.05523029524993295, 
      0.30050118811200355`, -0.055118104245355334`}, {-0.05904502998470661, 
      0.3005725491071835, -0.05890801588781925}, {-0.06312371315377599, 
      0.30065403751898007`, -0.06295639150065316}, {-0.06748470779487076, 
      0.3007470804355627, -0.06728038548042173}, {-0.0721476752783006, 
      0.3008533029155852, -0.07189818543667753}, {-0.07713367117111376, 
      0.30097455448607985`, -0.07682905039354627}, {-0.08246524886267029, 
      0.30111293888501756`, -0.08209334440844993}, {-0.0881665716466235, 
      0.3012708473483421, -0.08771256373990557}, {-0.0942635340010443, 
      0.30145099573483136`, -0.09370935524351869}, {-0.10078389284419922`, 
      0.3016564657601081, -0.10010752312788083`}, {-0.10775740955923041`, 
      0.3018907505670492, -0.10693202054315319`}, {-0.11521600356329816`, 
      0.3021578047851741, -0.11420892168585822`}, {-0.12319391812623297`, 
      0.3024620991151235, -0.12196536916355255`}, {-0.13172789899268278`, 
      0.3028086793015312, -0.1302294902518051}, {-0.1408573860910586, 
      0.30320322910976033`, -0.13903027437354845`}, {-0.1506247181679111, 
      0.3036521365754355, -0.1483974026216071}, {-0.16107534949306637`, 
      0.3041625623208501, -0.1583610184216881}, {-0.17225807673791116`, 
      0.30474250809289494`, -0.16895142650359207`}, {-0.18422527260224805`, 
      0.3054008828298687, -0.18019870524759446`}, {-0.19703312057890637`, 
      0.30614756245969166`, -0.19213221527830465`}, {-0.21074184217715586`, 
      0.3069934382158226, -0.20477998503360811`}, {-0.2254159037028243, 
      0.30795044647700814`, -0.21816795218499851`}, {-0.2411241839964256, 
      0.30903157095199507`, -0.23231903861647235`}, {-0.25794007701821803`, 
      0.3102508054298101, -0.24725203677564145`}, {-0.2759414935252364, 
      0.3116230623500524, -0.26298028746315394`}, {-0.295210714119739, 
      0.31316400927352156`, -0.2795101347497447}, {-0.31583403176931957`, 
      0.3148898122852154, -0.29683915434710784`}, {-0.3379011061896317, 
      0.31681676304031803`, -0.314954169478147}, {-0.3615039369052394, 
      0.31896076554426306`, -0.3338290954659602}, {-0.3867353495351432, 
      0.32133666128603067`, -0.3534226931893527}, {-0.41368688613914556`, 
      0.32395737896424814`, -0.3736763636711084}, {-0.44244600302881926`, 
      0.32683291005506543`, -0.3945121805578173}, {-0.4730925182305451, 
      0.32996913603691014`, -0.4158314289969063}, {-0.5056943263482147, 
      0.33336656826049843`, -0.4375139865310714}, {-0.5403025183313295, 
      0.3370191055983919, -0.4594189235068815}, {-0.5769462055781716, 
      0.34091296191782233`, -0.4813866882329358}, {-0.6156275325864738, 
      0.34502595296086047`, -0.5032431439417595}, {-0.6563175277198465, 
      0.3493273430738574, -0.5248055182700354}, {-0.6989535249913433, 
      0.35377841842736363`, -0.5458900169217267}, {-0.7434388252851661, 
      0.3583338648901891, -0.5663204909085279}, {-0.7896450154164585, 
      0.3629438933553869, -0.5859372260974094}, {-0.8374169510219144, 
      0.367556903399873, -0.6046047595236947}, {-0.8865799302492232, 
      0.3721223538166144, -0.6222177044808056}, {-0.936948180895877, 
      0.37659345908121306`, -0.6387038924702999}, {-0.9883335812519436, 
      0.38092937329487647`, -0.6540246268059791}, {-1.0405535882958867`, 
      0.38509664204801297`, -0.6681723419865085}, {-1.093437615165644, 
      0.3890698557918118, -0.6811663334297628}, {-1.1468314752982347`, 
      0.39283157783002937`, -0.6930473869541509}, {-1.2005998741214876`, 
      0.39637171269640115`, -0.703872101927513}, {-1.2546271972636585`, 
      0.39968651661534166`, -0.7137075305293694}, {-1.308816987094755, 
      0.40277744064192456`, -0.7226265301134435}, {-1.3630905311120634`, 
      0.4056499578691693, -0.7307040127673007}, {-1.4173849422709395`, 
      0.40831247735611165`, -0.7380141128794442}, {-1.4716510310355502`, 
      0.4107754021710105, -0.7446281896989364}, {-1.5258511809041928`, 
      0.4130503536401865, -0.7506135301377144}, {-1.5799573607829678`, 
      0.4151495600044983, -0.7560326029636338}, {-1.6339493461865136`, 
      0.41708539379941934`, -0.7609427243895414}, {-1.6878131776843661`, 
      0.4188700358717764, -0.7653960152654676}, {-1.741539856816664, 
      0.4205152424853373, -0.7694395538280221}, {-1.79512426327494, 
      0.42203219338183945`, -0.7731156507449787}, {-1.8485642689762722`, 
      0.4234314014821381, -0.7764621928638084}, {-1.90186002186454, 
      0.42472266819182214`, -0.7795130179549405}, {-1.9550133727026615`, 
      0.4259150714753128, -0.7822982949647412}, {-2.0080274202907025`, 
      0.4270169767124536, -0.7848448933577121}, {-2.0609061534951594`, 
      0.4280360627510862, -0.7871767316397609}, {-2.1136541716203365`, 
      0.4289793575127929, -0.7893150996976371}, {-2.166276467665484, 
      0.42985327903941634`, -0.7912789526645609}, {-2.2187782617279996`, 
      0.4306636790466899, -0.7930851760316731}, {-2.2711648741709087`, 
      0.4314158869428034, -0.7947488229796923}, {-2.3234416301671934`, 
      0.4321147529333527, -0.7962833256369191}, {-2.375613788889898, 
      0.4327646893208488, -0.7977006823474269}, {-2.4276864919744323`, 
      0.4333697094586514, -0.7990116231776239}, {-2.4796647269812504`, 
      0.43393346406922123`, -0.800225755885013}, {-2.531553302474667, 
      0.43445927481099916`, -0.8013516944783234}, {-2.5833568320447307`, 
      0.43495016509699586`, -0.8023971723527776}, {-2.63507972516641, 
      0.4354088882464671, -0.8033691418143113}, {-2.6867261832414977`, 
      0.43583795310020584`, -0.8042738616290355}, {-2.7383001995265017`, 
      0.43623964725843917`, -0.805116974059668}, {-2.789805561933056, 
      0.4366160581142979, -0.8059035726853067}, {-2.8412458579112463`, 
      0.43696909185986643`, -0.8066382621481172}, {-2.892624480802896, 
      0.4373004906392209, -0.8073252108317279}, {-2.9439446371910845`, 
      0.4376118480159883, -0.8079681973516353}, {-2.995209354881731, 
      0.43790462291349525`, -0.808570651627272}, {-3, 
       0.4379319824835207, -0.8086269504769404}}], 
    Line3DBox[{{0., 0.15, -1.*^-6}, {-6.443433194933083*^-8, 
      0.15, -1.0020737743277588`*^-6}, {-1.29135996939957*^-7, 
      0.15, -1.0083037360470293`*^-6}, {-1.9437392017844482`*^-7, 
      0.15, -1.0187155694847545`*^-6}, {-2.604175827966277*^-7, 
      0.15, -1.0333527257001537`*^-6}, {-3.275412657362031*^-7, 
      0.15, -1.052275781813812*^-6}, {-3.960227023744951*^-7, 
      0.15, -1.075563453436069*^-6}, {-4.661470125392186*^-7, 
      0.15, -1.1033119718036767`*^-6}, {-5.3820530100713*^-7, 
      0.15, -1.1356362908537015`*^-6}, {-6.124959603125292*^-7, 
      0.15, -1.1726706735639933`*^-6}, {-6.89326260907065*^-7, 
      0.15, -1.2145691776717817`*^-6}, {-7.690150142080328*^-7, 
      0.15, -1.2615055204808035`*^-6}, {-8.518946330387656*^-7, 
      0.15, -1.3136732448486927`*^-6}, {-9.383079665149491*^-7, 
      0.15, -1.3712892191755178`*^-6}, {-1.0286122308558473`*^-6, 
      0.15, -1.4345932356634524`*^-6}, {-1.1231827602023882`*^-6, 
      0.15, -1.5038472988356013`*^-6}, {-1.2224118457091072`*^-6, 
      0.15, -1.5793386165067243`*^-6}, {-1.3267109036521641`*^-6, 
      0.15, -1.6613804031386458`*^-6}, {-1.436512528480057*^-6, 
      0.15, -1.7503129200260717`*^-6}, {-1.5522727854556216`*^-6, 
      0.15, -1.8465044763969238`*^-6}, {-1.6744712289355113`*^-6, 
      0.15, -1.9503545104569073`*^-6}, {-1.8036147966794545`*^-6, 
      0.15, -2.062293646635765*^-6}, {-1.940238758439581*^-6, 
      0.15, -2.182786478150043*^-6}, {-2.0849097320306366`*^-6, 
      0.15, -2.312332789943245*^-6}, {-2.2382283525434406`*^-6, 
      0.15, -2.4514693465684016`*^-6}, {-2.4008302492228466`*^-6, 
      0.15, -2.600773470202083*^-6}, {-2.573389767630285*^-6, 
      0.15, -2.7608644608034433`*^-6}, {-2.7566225858631495`*^-6, 
      0.15, -2.932406325796533*^-6}, {-2.951288820511898*^-6, 
      0.15, -3.1161104132683897`*^-6}, {-3.1581952939892454`*^-6, 
      0.15, -3.312739182704914*^-6}, {-3.378200836005567*^-6, 
      0.15, -3.5231075295948152`*^-6}, {-3.61221755113906*^-6, 
      0.15, -3.748088336917419*^-6}, {-3.86121620556135*^-6, 
      0.15, -3.988614567270195*^-6}, {-4.126229739409668*^-6, 
      0.15, -4.2456836246881784`*^-6}, {-4.4083570627826935`*^-6, 
      0.15, -4.520361963377964*^-6}, {-4.708768507941547*^-6, 
      0.15, -4.813788644970639*^-6}, {-5.0287098457947836`*^-6, 
      0.15, -5.127180876835195*^-6}, {-5.369507999659964*^-6, 
      0.15, -5.461838527973099*^-6}, {-5.732576472376144*^-6, 
      0.15, -5.81914959442285*^-6}, {-6.119421361992568*^-6, 
      0.15, -6.2005958041765445`*^-6}, {-6.531646939786244*^-6, 
      0.15, -6.607759422182722*^-6}, {-6.9709629130371766`*^-6, 
      0.15, -7.042329212391981*^-6}, {-7.439191562162873*^-6, 
      0.15, -7.506107396114734*^-6}, {-7.938274724274568*^-6, 
      0.15, -8.001017695340337*^-6}, {-8.470282461155048*^-6, 
      0.15, -8.529112703386299*^-6}, {-9.037421109141385*^-6, 
      0.15, -9.092582929666342*^-6}, {-9.642043200808865*^-6, 
      0.15, -9.693765119550882*^-6}, {-0.000010286656185943047`, 
      0.15, -0.000010335152975760652`}, {-0.000010973933850575575`, 
      0.15, -0.000011019406488005315`}, {-0.000011706726697223026`, 
      0.15, -0.000011749363671065353`}, {-0.000012488073957163347`, 
      0.15, -0.000012528052147107163`}, {-0.000013321216344263034`, 
      0.15, -0.000013358701555071304`}, {-0.000014209609413835587`, 
      0.15, -0.000014244757027707254`}, {-0.000015156937802206634`, 
      0.15, -0.000015189893572783509`}, {-0.000016167130549057407`, 
      0.15, -0.000016198031275580866`}, {-0.000017244377535889845`, 
      0.15, -0.00001727335141544887}, {-0.000018393146794283704`, 
      0.15, -0.00001842031387730081}, {-0.000019618202898414915`, 
      0.15, -0.000019643675788025543`}, {-0.000020924626777148146`, 
      0.15, -0.00002094851119640539}, {-0.000022317836993089275`, 
      0.15, -0.000022340231912757613`}, {-0.000023803611876170983`, 
      0.15, -0.000023824610294650588`}, {-0.000025388113839235068`, 
      0.15, -0.00002540780283894287}, {-0.000027077914751994338`, 
      0.15, -0.000027096375901118768`}, {-0.00002888002311751658, 
      0.15, -0.000028897333010437952`}, {-0.00003080191328527931, 
      0.15, -0.000030818143772824316`}, {-0.000032851556489941735`, 
      0.15, -0.00003286677481316332}, {-0.000035037453682239424`, 
      0.15, -0.00003505172304761742}, {-0.000037368671085706535`, 
      0.15, -0.000037382050626844624`}, {-0.000039854877581892736`, 
      0.15, -0.00003986742273932176}, {-0.000042506384834936774`, 
      0.15, -0.00004251814767613534}, {-0.00004533419016956659, 
      0.15, -0.000045345219475656264`}, {-0.00004835002208155722, 
      0.15, -0.000048360363623697136`}, {-0.00005156638896614365, 
      0.15, -0.00005157608560207229}, {-0.00005499663090103541, 
      0.15, -0.00005500572285228446}, {-0.000058654975048496585`, 
      0.15, -0.0000586635000202469}, {-0.00006255659466489486, 
      0.15, -0.00006256458795250105}, {-0.00006671767193484964, 
      0.15, -0.00006672516671623809}, {-0.0000711554652159935, 
      0.15, -0.00007116249257914385}, {-0.00007588838055895836, 
      0.15, -0.00007589496964110088}, {-0.00008093604803883369, 
      0.15, -0.00008094222617526713}, {-0.0000863194032180542, 
      0.15, -0.00008632519599178665}, {-0.0000920607739040593, 
      0.15, -0.00009206620533611016}, {-0.00009818397282551279, 
      0.15, -0.00009818906541840536}, {-0.00010471439636318739`, 
      0.15000000010166337`, -0.00010471917120611992`}, \
{-0.00011167912986716826`, 
      0.15000000021729945`, -0.00011168360676735046`}, \
{-0.00011910706005278342`, 
      0.15000000034882868`, -0.00011911125754583032`}, \
{-0.0001270289947580574, 
      0.1500000004984354, -0.0001270329302174018}, {-0.00013547779073460855`, 
      0.15000000066860422`, -0.00013548148044931316`}, \
{-0.00014448848994706118`, 
      0.1500000008621612, -0.00014449194914730864`}, \
{-0.00015409846486912917`, 
      0.15000000108232084`, -0.00015410170783296793`}, \
{-0.00016434757350156033`, 
      0.15000000133273944`, -0.00016435061363066813`}, \
{-0.0001752783247297733, 
      0.1500000016175758, -0.00017528117453402943`}, \
{-0.00018693605458168586`, 
      0.15000000194156032`, -0.00018693872576077777`}, \
{-0.00019936911426552607`, 
      0.1500000023100736, -0.00019937161777958416`}, \
{-0.00021262907073702056`, 
      0.1500000027292357, -0.0002126314168190564}, {-0.00022677092056696738`, 
      0.15000000320600784`, -0.00022677311875134596`}, \
{-0.00024185331803494074`, 
      0.150000003748308, -0.0002418553771987277}, {-0.0002579388184017046, 
      0.15000000436514238`, -0.00025794074680266806`}, \
{-0.0002750941373723053, 
      0.1500000050667551, -0.00027509594266134226`}, \
{-0.00029339042778768113`, 
      0.1500000058647981, -0.00029339211704989567`}, {-0.0003129035747692219, 
      0.15000000677252492`, -0.00031290515449428037`}, \
{-0.00033371451041796965`, 
      0.15000000780501055`, -0.00033371598654488533`}, \
{-0.0003559095495145768, 
      0.15000000897940197`, -0.0003559109274145519}, \
{-0.00037958074750004745`, 
      0.15000001031520283`, -0.00037958203198528004`}, \
{-0.0004048262822948104, 
      0.15000001183459738`, -0.00040482747759557395`}, \
{-0.00043175086149300606`, 
      0.15000001356281895`, -0.0004317519712385253}, {-0.0004604661566489217, 
      0.15000001552856887`, -0.0004604671838312866}, {-0.0004910912664466505, 
      0.15000001776449326`, -0.0004910922133670627}, {-0.0005237532106676704, 
      0.15000002030772513`, -0.000523754078876672}, {-0.0005585874570155575, 
      0.15000002320050107`, -0.000558588247237684}, {-0.0005957384829933214, 
      0.15000002649086272`, -0.0005957391950053186}, {-0.0006353603751225251, 
      0.1500000302334546, -0.0006353610076361863}, {-0.0006776174680419281, 
      0.1500000344904316, -0.0006776180185372486}, {-0.000722685026104194, 
      0.15000003933249118`, -0.0007226854906220482}, {-0.0007707499703007866, 
      0.15000004484004753`, -0.0007707503431971136}, {-0.0008220116535442863, 
      0.15000005110456704`, -0.0008220119271781843}, {-0.0008766826875044734, 
      0.15000005823008725`, -0.0008766828518696191}, {-0.0009349898244485253, 
      0.15000006633494464`, -0.0009349898667137958}, {-0.0009971748977322388, 
      0.15000007555373995`, -0.0009971748016765931}, {-0.0010634958248365986`,
       0.15000008603957343`, -0.0010634955701737479`}, \
{-0.0011342276771294855`, 
      0.15000009796658748`, -0.0011342272386757981`}, \
{-0.0012096638207727435`, 
      0.1500001115328586, -0.0012096631674416948`}, {-0.0012901171335199827`, 
      0.15000012696368697`, -0.0012901162270954835`}, \
{-0.0013759213024425404`, 
      0.15000014451533789`, -0.0013759200960970041`}, \
{-0.0014674322079849794`, 
      0.15000016447929768`, -0.0014674306444638647`}, \
{-0.0015650294000656966`, 
      0.1500001871871144, -0.001565027409502451}, {-0.0016691176723780932`, 
      0.15000021301590374`, -0.001669115169627918}, {-0.0017801287414018832`, 
      0.15000024239461188`, -0.00178012562281149}, {-0.001898523037104124, 
      0.15000027581113867`, -0.001898519176589697}, {-0.00202479161275562, 
      0.15000031382044016`, -0.0020247868570476947`}, \
{-0.0021594581817988403`, 
      0.15000035705374443`, -0.0021594523446629454`}, \
{-0.0023030812902049918`, 
      0.15000040622903402`, -0.0023030741454436914`}, \
{-0.0024562566333622016`, 
      0.1500004621629689, -0.002456247906311213}, {-0.0026196195270925884`, 
      0.150000525784448, -0.00261960888431164}, {-0.0027938475430727963`, 
      0.15000059815003441`, -0.0027938345798373615`}, \
{-0.0029796633196000582`, 
      0.15000068046150025`, -0.002979647544725193}, {-0.003177837559378945, 
      0.15000077408578258`, -0.0031778183768087884`}, \
{-0.0033891922267851576`, 
      0.15000088057768163`, -0.003389168913259548}, {-0.0036146039578949566`, 
      0.15000100170567787`, -0.0036145756358564205`}, \
{-0.0038550076974563255`, 
      0.15000113948129667`, -0.0038549733021826503`}, {-0.004111400577925834, 
      0.15000129619250765`, -0.004111358817658188}, {-0.004384846056707881, 
      0.1500014744417131, -0.004384795364282659}, {-0.004676478328814595, 
      0.15000167718895566`, -0.0046764168029886964`}, {-0.004987507033319107, 
      0.15000190780106207`, -0.0049874323675929005`}, {-0.005319222273209401, 
      0.15000217010753816`, -0.005319131669482276}, {-0.005672999969566956, 
      0.15000246846414209`, -0.005672890033393703}, {-0.006050307572401779, 
      0.15000280782518977`, -0.006050174185933462}, {-0.006452710151987363, 
      0.15000319382579144`, -0.006452548319837668}, {-0.006881876896143611, 
      0.15000363287538193`, -0.006881680558413765}, {-0.007339588040640932, 
      0.15000413226409456`, -0.007339349846108982}, {-0.007827742261746474, 
      0.15000470028374047`, -0.00782745329273111}, {-0.008348364561902846, 
      0.15000534636539634`, -0.008348014000510193}, {-0.008903614681652058, 
      0.15000608123587789`, -0.00890318940491419}, {-0.009495796073177248, 
      0.15000691709568723`, -0.009495280161941403}, {-0.010127365473277174`, 
      0.15000786782137635`, -0.010126739616469864`}, {-0.010800943116192997`, 
      0.15000894919567037`, -0.010800183888176334`}, {-0.011519323629515547`, 
      0.15001017916915022`, -0.011518402613508246`}, {-0.01228548765941902, 
      0.15001157815781196`, -0.012284370384199298`}, {-0.013102614274714113`, 
      0.15001316938140774`, -0.013101258924844272`}, {-0.013974094202713613`, 
      0.15001497924813914`, -0.013972450054064918`}, {-0.014903543953680976`, 
      0.15001703779203016`, -0.014901549475775483`}, {-0.015894820894712967`, 
      0.1500193791701633, -0.015892401448956126`}, {-0.016952039338321317`, 
      0.1500220422279329, -0.01694910438611642}, {-0.018079587715767835`, 
      0.15002507114156913`, -0.018076027432209738`}, {-0.019282146910401185`, 
      0.15002851614843024`, -0.019277828077076398`}, {-0.02056470983189875, 
      0.1500324343769666, -0.020559470855440732`}, {-0.02193260231847937, 
      0.1500368907898502, -0.021926247188951486`}, {-0.02339150546088701, 
      0.15004195925555708`, -0.023383796424583495`}, {-0.024947479449316516`, 
      0.15004772376571324`, -0.024938128122732817`}, {-0.02660698905254722, 
      0.15005427981779237`, -0.02659564564630615}, {-0.028376930847452, 
      0.15006173598531608`, -0.028363171098760673`}, {-0.03026466232687209, 
      0.15007021570058116`, -0.030247971654047252`}, {-0.03227803302470779, 
      0.1500798592781605, -0.03225778731434082}, {-0.03442541780911164, 
      0.15009082621102213`, -0.034400860121803156`}, {-0.036715752508045145`, 
      0.15010329777512202`, -0.03668596483779953}, {-0.039158572046346984`, 
      0.15011747998278072`, -0.039122441086241196`}, {-0.041764051290066766`, 
      0.15013360693008088`, -0.04172022693614029}, {-0.04454304881236432, 
      0.15015194458894787`, -0.04448989387094822}, {-0.04750715381600893, 
      0.15017279510051387`, -0.047442683057468724`}, {-0.05066873647069969, 
      0.15019650163281867`, -0.05059054278348447}, {-0.0540410019493424, 
      0.15022345387285277`, -0.05394616687876581}, {-0.05763804847633713, 
      0.15025409423035216`, -0.057523033866494024`}, {-0.06147492973310574, 
      0.15028892483852752`, -0.06133544650850682}, {-0.06556772200172194, 
      0.15032851544491177`, -0.06539857130476517}, {-0.06993359646669764, 
      0.15037351229352758`, -0.06972847738098034}, {-0.07459089713765445, 
      0.15042464810729492`, -0.07434217404356663}, {-0.0795592249014139, 
      0.15048275328657168`, -0.07925764609220813}, {-0.08485952826019535, 
      0.1505487684453193, -0.08449388575047545}, {-0.09051420136168123, 
      0.15062375840974834`, -0.09007091979599768}, {-0.09654718997431638, 
      0.15070892780425202`, -0.09600983013417645}, {-0.10298410610358663`, 
      0.15080563834440217`, -0.10233276565227037`}, {-0.10985235197643387`, 
      0.15091542794465634`, -0.10906294270115936`}, {-0.11718125413288587`, 
      0.15104003172642827`, -0.11622463096579198`}, {-0.12500220834398296`, 
      0.15118140497665705`, -0.12384312078618148`}, {-0.13334883600534825`, 
      0.1513417480532275, -0.13194466716150252`}, {-0.14225715251106233`, 
      0.15152353315541683`, -0.14055640469239078`}, {-0.15176574785764263`, 
      0.15172953276714218`, -0.14970622657365618`}, {-0.1619159793142802, 
      0.15196284942825458`, -0.15942261942680902`}, {-0.17275217535679377`, 
      0.15222694628212277`, -0.16973444425095818`}, {-0.1843218491099252, 
      0.15252567757114557`, -0.18067065207561597`}, {-0.19667591815767965`, 
      0.15286331788753452`, -0.19225992104410217`}, {-0.20986892561116577`, 
      0.1532445885138003, -0.20453019969931407`}, {-0.2239592545734383, 
      0.15367467858291056`, -0.2175081392945353}, {-0.2390093243723742, 
      0.15415925802899708`, -0.2312183961996611}, {-0.25508575186536453`, 
      0.15470447836645165`, -0.24568278422295764`}, {-0.2722594544473976, 
      0.15531695621957542`, -0.26091925639126695`}, {-0.2906056628230839, 
      0.15600373324013792`, -0.2769406971264046}, {-0.3102038009280888, 
      0.15677220465015695`, -0.2937535098204518}, {-0.33113717762542755`, 
      0.15763000725316634`, -0.311355992912666}, {-0.35349242042208373`, 
      0.15858485659487215`, -0.3297365114739202}, {-0.37735856669431417`, 
      0.15964432239944906`, -0.34887149313246624`}, {-0.40282571524710775`, 
      0.1608155320344643, -0.36872330917404217`}, {-0.42998313469017824`, 
      0.16210479436597222`, -0.38923814564677306`}, {-0.4589167315213375, 
      0.16351714195547337`, -0.41034402567409217`}, {-0.48970580865303803`, 
      0.16505579917480884`, -0.4319492102048548}, {-0.5224191044098748, 
      0.16672159823362526`, -0.4539412720756311}, {-0.5571102014409604, 
      0.16851238418642894`, -0.476187191929774}, {-0.5938125368646712, 
      0.17042247183635845`, -0.49853484009502547`}, {-0.6325344182002504, 
      0.17244223766194677`, -0.5208161557999001}, {-0.6732546228422812, 
      0.1745579413005065, -0.5428521863743206}, {-0.7159192786130639, 
      0.1767518650447023, -0.5644598941989858}, {-0.7604407238676623, 
      0.17900282924596678`, -0.5854603035573203}, {-0.806698875207146, 
      0.18128708579467967`, -0.6056872145325876}, {-0.8545452829875259, 
      0.1835795204298407, -0.6249954633156904}, {-0.9038095934078743, 
      0.18585502679436267`, -0.6432676620726151}, {-0.9543076866004959, 
      0.1880898735658995, -0.6604185568761428}, {-1.0058504632141398`, 
      0.19026288636947847`, -0.6763965588376816}, {-1.0582521987602855`, 
      0.1923563089803877, -0.6911825091454874}, {-1.1113375756140589`, 
      0.1943562782370392, -0.7047861821207487}, {-1.1649468523002031`, 
      0.196252920773735, -0.7172412984194413}, {-1.218939016252352, 
      0.1980401366592855, -0.7285998779291487}, {-1.2731930850868427`, 
      0.19971516500346453`, -0.7389266475314771}, {-1.3276079185417253`, 
      0.20127803036979966`, -0.7482940103510689}, {-1.3821009763253804`, 
      0.2027309542898003, -0.7567778574404037}, {-1.4366064366689915`, 
      0.20407779303616852`, -0.7644543123570463}, {-1.4910730169020427`, 
      0.2053235389572142, -0.7713973662330796}, {-1.545461745756528, 
      0.2064739027439195, -0.7776772855094934}, {-1.5997438502768229`, 
      0.20753497970769316`, -0.7833596443848247}, {-1.6538988494715476`, 
      0.20851299428551015`, -0.7885048339089584}, {-1.7079128951801765`, 
      0.20941411244493016`, -0.7931679160922848}, {-1.761777366347437, 
      0.2102443101115075, -0.7973987146629556}, {-1.8154877023850418`, 
      0.2110092860242332, -0.8012420581416861}, {-1.8690424506750911`, 
      0.21171440867217778`, -0.8047381125266603}, {-1.9224424991916655`, 
      0.21236468859859367`, -0.8079227588072062}, {-1.9756904651346354`, 
      0.21296476903071754`, -0.8108279845814952}, {-2.0287902125894246`, 
      0.2135189293215866, -0.813482269624273}, {-2.0817464753720505`, 
      0.21403109699658535`, -0.815910952932403}, {-2.134564564668265, 
      0.21450486526587004`, -0.8181365741899288}, {-2.1872501444191768`, 
      0.21494351371017367`, -0.8201791862961479}, {-2.2398090604359426`, 
      0.21535003050176268`, -0.8220566380479881}, {-2.292247211859861, 
      0.2157271350181876, -0.8237848276204253}, {-2.3445704558099862`, 
      0.2160773000759574, -0.8253779284165474}, {-2.3967845379047183`, 
      0.21640277328231297`, -0.826848589361025}, {-2.44889504285039, 
      0.2167055971990585, -0.828208111930126}, {-2.500907360507634, 
      0.21698762815151051`, -0.8294666062487817}, {-2.552826663822848, 
      0.21725055361258008`, -0.830633128510361}, {-2.60465789579051, 
      0.21749590815799014`, -0.8317158018352258}, {-2.656405763229734, 
      0.2177250880321114, -0.8327219225114595}, {-2.7080747356467656`, 
      0.21793936439121975`, -0.8336580533759702}, {-2.7596690478401307`, 
      0.21813989530684103`, -0.8345301059094136}, {-2.811192705207923, 
      0.2183277366197175, -0.8353434124418281}, {-2.862649490954469, 
      0.21850385173732406`, -0.8361027897018259}, {-2.9140429745798704`, 
      0.21866912046661063`, -0.8368125947926579}, {-2.9653765211816854`, 
      0.2188243469700538, -0.8374767745440482}, {-3, 
       0.21892904422769105`, -0.8379247508690076}}], 
    Line3DBox[{{0., 0., -1.*^-6}, {-6.370570949530546*^-8, 
      0., -1.0020271471471906`*^-6}, {-1.2766949314973133`*^-7, 
      0., -1.008116712313137*^-6}, {-1.9215039346977472`*^-7, 
      0., -1.018293443298604*^-6}, {-2.574119273573999*^-7, 
      0., -1.0325982691908846`*^-6}, {-3.237159257678373*^-7, 
      0., -1.0510897323683285`*^-6}, {-3.913323642857668*^-7, 
      0., -1.073842593057055*^-6}, {-4.6053396927621666`*^-7, 
      0., -1.1009494994785982`*^-6}, {-5.316029386896399*^-7, 
      0., -1.1325197881286103`*^-6}, {-6.048280203995727*^-7, 
      0., -1.1686811283144092`*^-6}, {-6.805044994289269*^-7, 
      0., -1.2095809336683228`*^-6}, {-7.589398623888822*^-7, 
      0., -1.2553846428787307`*^-6}, {-8.404526996086839*^-7, 
      0., -1.306277615626886*^-6}, {-9.253730839245148*^-7, 
      0., -1.3624664151541747`*^-6}, {-1.0140443910186734`*^-6, 
      0., -1.4241794462859855`*^-6}, {-1.1068263330131951`*^-6, 
      0., -1.4916667779835079`*^-6}, {-1.204096986435562*^-6, 
      0., -1.565200606243104*^-6}, {-1.3062488023446434`*^-6, 
      0., -1.6450804809149077`*^-6}, {-1.41369662752848*^-6, 
      0., -1.731629708897658*^-6}, {-1.526876060309171*^-6, 
      0., -1.8251991882130806`*^-6}, {-1.646246324695826*^-6, 
      0., -1.9261679667974624`*^-6}, {-1.772289809260034*^-6, 
      0., -2.0349467142921883`*^-6}, {-1.9055184178294034`*^-6, 
      0., -2.1519756783114053`*^-6}, {-2.046472538548036*^-6, 
      0., -2.277729096980033*^-6}, {-2.1957234407586725`*^-6, 
      0., -2.4127169762248326`*^-6}, {-2.353876291126301*^-6, 
      0., -2.557486512012702*^-6}, {-2.5215730408469382`*^-6, 
      0., -2.7126239361807853`*^-6}, {-2.699491988035451*^-6, 
      0., -2.878759668865763*^-6}, {-2.8883552106819446`*^-6, 
      0., -3.0565665552967677`*^-6}, {-3.0889287178365595`*^-6, 
      0., -3.246765163967338*^-6}, {-3.3020257728801466`*^-6, 
      0., -3.4501265102775185`*^-6}, {-3.5285095906670486`*^-6, 
      0., -3.6674757571514466`*^-6}, {-3.7692991463216986`*^-6, 
      0., -3.899693354442991*^-6}, {-4.025369978996115*^-6, 
      0., -4.147721412599827*^-6}, {-4.297760564872197*^-6, 
      0., -4.412565190385922*^-6}, {-4.587574786434154*^-6, 
      0., -4.695298857640522*^-6}, {-4.895988017524022*^-6, 
      0., -4.997068283807054*^-6}, {-5.22425075046226*^-6, 
      0., -5.319096790099253*^-6}, {-5.573693720630051*^-6, 
      0., -5.662690059703035*^-6}, {-5.945734037475158*^-6, 
      0., -6.029240707549391*^-6}, {-6.34187932882573*^-6, 
      0., -6.42023550209111*^-6}, {-6.763735989734456*^-6, 
      0., -6.8372592882445*^-6}, {-7.213014246430832*^-6, 
      0., -7.282002840973516*^-6}, {-7.691535849319845*^-6, 
      0., -7.756268969404608*^-6}, {-8.201240426241533*^-6, 
      0., -8.261980848623406*^-6}, {-8.744194629117247*^-6, 
      0., -8.801188545256455*^-6}, {-9.322599720875472*^-6, 
      0., -9.376078113785154*^-6}, {-9.938800466752343*^-6, 
      0., -9.988980492510754*^-6}, {-0.000010595295536518429`, 
      0., -0.000010642380062753007`}, {-0.000011294745963812862`, 
      0., -0.000011338926383146745`}, {-0.000012039987692753574`, 
      0., -0.000012081443181924556`}, {-0.00001283404197536879, 
      0., -0.000012872940900052246`}, {-0.000013680128482458443`, 
      0., -0.00001371662803708792}, {-0.000014581677172532375`, 
      0., -0.000014615925339892738`}, {-0.000015542343036773027`, 
      0., -0.000015574478834414658`}, {-0.00001656602084819016, 
      0., -0.000016596174676151885`}, {-0.000017656860979855006`, 
      0., -0.00001768515487742834}, {-0.000018819285768109436`, 
      0., -0.00001884583456250822}, {-0.0000200580080567377, 
      0., -0.00002008291925342596}, {-0.00002137804974849208, 
      0., -0.000021401424501696904`}, {-0.00002278476266792347, 
      0., -0.000022806695720172822`}, {-0.000024283849877083003`, 
      0., -0.000024304430235771942`}, {-0.00002588138908276963, 
      0., -0.000025900700102155986`}, {-0.00002758385703129966, 
      0., -0.000027601976962488676`}, {-0.00002939815588964253, 
      0., -0.00002941515816394895}, {-0.00003133164114865747, 
      0., -0.00003134759480065776}, {-0.00003339215165128943, 
      0., -0.00003340712130926175}, {-0.00003558804109159966, 
      0., -0.00003560208751258564}, {-0.0000379282121713939, 
      0., -0.00003794139218279746}, {-0.0000404221523881134, 
      0., -0.0000404345194243975}, {-0.00004307997267749099, 
      0., -0.000043091576946585245`}, {-0.000045912448450443775`, 
      0., -0.000045923336997115354`}, {-0.0000489310631737936, 
      0., -0.00004894128014038095}, {-0.00005214805497267523, 
      0., -0.000052157641756141564`}, {-0.000055576466207939764`, 
      0., -0.000055585461682961186`}, {-0.00005923019641247561, 
      0., -0.000059238637024738146`}, {-0.00006312405858306502, 
      0., -0.0000631319785523779}, {-0.00006727383927737234, 
      0., -0.00006728127070792752}, {-0.00007169636258486122, 
      0., -0.00007170333562926643}, {-0.00007640955838932872, 
      0., -0.00007641610129660628}, {-0.00008143253500072704, 
      0., -0.00008143867427613696}, {-0.00008678565664652367, 
      0., -0.0000867914171599732}, {-0.00009249062602549807, 
      0., -0.00009249603112761401}, {-0.00009857057232404, 
      0., -0.00009857564389826741}, {-0.0001050501449298675, 
      0., -0.00010505490355252779`}, {-0.00011195561345420578`, 
      0., -0.00011196007837268469`}, {-0.00011931497413350634`, 
      0., -0.00011931916344084923`}, {-0.00012715806340772828`, 
      0., -0.0001271619940614384}, {-0.0001355166788626906, 
      0., -0.00013552036674080206`}, {-0.00014442470811499512`, 
      0., -0.00014442816812629738`}, {-0.00015391826624504604`, 
      0., -0.00015392151234455497`}, {-0.0001640358421617701, 
      0., -0.0001640388874693042}, {-0.00017481845471571276`, 
      0., -0.00017482131148928594`}, {-0.0001863098189375721, 
      0., -0.00018631249866441987`}, {-0.0001985565232988516, 
      0., -0.00019855903672194933`}, {-0.0002116082185800688, 
      0., -0.00021161057574415468`}, {-0.00022551781917273589`, 
      0., -0.00022552002945290745`}, {-0.00024034171760636556`, 
      0., -0.00024034378973196495`}, {-0.00025614001315684093`, 
      0., -0.0002561419552701}, {-0.00027297675552655334`, 
      0., -0.00027297857518843004`}, {-0.00029092020450802424`, 
      0., -0.00029092190871584327`}, {-0.00031004310673492057`, 
      0., -0.0003100447019140819}, {-0.0003304229905767459, 
      0., -0.00033042448264006084`}, {-0.00035214248050225095`, 
      0., -0.00035214387481172303`}, {-0.00037528963203162333`, 
      0., -0.00037529093340589513`}, {-0.000399958288734953, 
      0., -0.0003999595014466769}, {-0.0004262484626933278, 
      0., -0.0004262495904625569}, {-0.00045426674000000197`, 
      0., -0.0004542677859196042}, {-0.0004841267128484365, 
      0., -0.0004841276793714781}, {-0.0005159494400690705, 
      0., -0.0005159503289680087}, {-0.0005498639379500883, 
      0., -0.0005498647502209627}, {-0.0005860077032828311, 
      0., -0.0005860084390656226}, {-0.0006245272708178767, 
      0., -0.0006245279292729525}, {-0.0006655788073415159, 
      0., -0.0006655793865221173}, {-0.0007093287448332595, 
      0., -0.0007093292414892262}, {-0.0007559544552113638, 
      0., -0.0007559548645783319}, {-0.0008056449694454072, 
      0., -0.0008056452849859785}, {-0.0008586017439453855, 
      0., -0.000858601957019608}, {-0.0009150394773262925, 
      0., -0.0009150395767836952}, {-0.0009751869808479588, 
      0., -0.0009751869525548798}, {-0.0010392881060966182`, 
      0., -0.0010392879323356669`}, {-0.0011076027336251214`, 
      0., -0.001107602392389366}, {-0.0011804078265998167`, 
      0., -0.0011804072907218037`}, {-0.0012579985537053506`, 
      0., -0.0012579977897984715`}, {-0.0013406894858586087`, 
      0., -0.0013406884530467033`}, {-0.0014288158716055086`, 
      0., -0.001428814519967623}, {-0.001522734996346622, 
      0., -0.0015227332650471818`}, {-0.0016228276309276223`, 
      0., -0.001622825445944109}, {-0.0017294995754594759`, 
      0., -0.001729496846826668}, {-0.0018431833046249997`, 
      0., -0.0018431799231086784`}, {-0.001964339721162633, 
      0., -0.0019643355542217087`}, {-0.0020934600246263818`, 
      0., -0.002093454911526549}, {-0.002231067703009457, 
      0., -0.0022310614489099013`}, {-0.002377720655315125, 
      0., -0.0023777130241084206`}, {-0.002534013453684485, 
      0., -0.0025340041593329013`}, {-0.0027005797542715626`, 
      0., -0.0027005684503103975`}, {-0.0028780948666408917`, 
      0., -0.002878081133476159}, {-0.0030672784921261815`, 
      0., -0.003067261821660561}, {-0.003268897642270744, 
      0., -0.0032688774192935915`}, {-0.0034837697492081775`, 
      0., -0.0034837452288590844`}, {-0.003712765980603997, 
      0., -0.0037127362611095514`}, {-0.003956814772656058, 
      0., -0.003956778762315402}, {-0.004216905595495566, 
      0., -0.004216861972723809}, {-0.004494092966315168, 
      0., -0.00449404013127486}, {-0.004789500726544754, 
      0., -0.004789436742604064}, {-0.005104326600497025, 
      0., -0.0051042491233597685`}, {-0.005439847054035673, 
      0., -0.005439753245966964}, {-0.005797422473082819, 
      0., -0.005797308899079193}, {-0.006178502683075071, 
      0., -0.006178365185189732}, {-0.006584632831904535, 
      0., -0.0065844663771248224`}, {-0.007017459660374487, 
      0., -0.007017258156491302}, {-0.007478738185816904, 
      0., -0.007478494258549573}, {-0.007970338826235946, 
      0., -0.007970043549463205}, {-0.008494254994189036, 
      0., -0.008493897563416055}, {-0.009052611191582006, 
      0., -0.009052178528707848}, {-0.009647671638678598, 
      0., -0.009647147913606022}, {-0.010281849472880189`, 
      0., -0.010281215524479519`}, {-0.010957716555270416`, 
      0., -0.010956949190523996`}, {-0.011678013925523681`, 
      0., -0.01167708507123073}, {-0.012445662948585307`, 
      0., -0.012444538624617321`}, {-0.013263777199547825`, 
      0., -0.013262416276125594`}, {-0.014135675136396565`, 
      0., -0.014134027829974891`}, {-0.015064893613806083`, 
      0., -0.015062899666604712`}, {-0.01605520229495167, 
      0., -0.01605278877162498}, {-0.017110619022395537`, 
      0., -0.01710769764336117}, {-0.01823542621354067, 
      0., -0.018231890127587178`}, {-0.019434188350960967`, 
      0., -0.019429908229304647`}, {-0.020711770643145593`, 
      0., -0.020706589952379048`}, {-0.022073358936900045`, 
      0., -0.02206708821836072}, {-0.023524480968870103`, 
      0., -0.023516890915784485`}, {-0.025071029050467916`, 
      0., -0.025061842130487316`}, {-0.02671928428795319, 
      0., -0.026708164605814773`}, {-0.02847594244764043, 
      0., -0.02846248347876303}, {-0.030348141585262747`, 
      0., -0.030331851333829627`}, {-0.032343491568534465`, 
      0., -0.03232377461026333}, {-0.03447010563304706, 
      0., -0.03444624139007358}, {-0.036736634123947454`, 
      0., -0.03670775058305437}, {-0.03915230058955419, 
      0., -0.03911734251054484}, {-0.041726940408345854`, 
      0., -0.04168463087091187}, {-0.04447104214781987, 
      0., -0.04441983604584404}, {-0.047395791872793955`, 
      0., -0.047333819676347144`}, {-0.050513120642057666`, 
      0., -0.050438120399438915`}, {-0.05383575545614194, 
      0., -0.05374499058927952}, {-0.05737727394562454, 
      0., -0.05726743388783013}, {-0.06115216311909485, 
      0., -0.061019243237670245`}, {-0.06517588252287992, 
      0., -0.06501503904041643}, {-0.06946493220104302, 
      0., -0.069270306954771}, {-0.07403692588402805, 
      0., -0.0738014347144153}, {-0.0789106698774539, 
      0., -0.07862574718276794}, {-0.08410624816844482, 
      0., -0.08376153866314129}, {-0.08964511431449892, 
      0., -0.08922810124205734}, {-0.09555019072749035, 
      0., -0.09504574765219928}, {-0.10184597601012477`, 
      0., -0.10123582679007558`}, {-0.10855866103963503`, 
      0., -0.10782072960082965`}, {-0.1157162545171173, 
      0., -0.11482388253601364`}, {-0.12334871870098899`, 
      0., -0.12226972518521492`}, {-0.13148811600563548`, 
      0., -0.13018366796337186`}, {-0.14016876705154985`, 
      0., -0.13859202488556696`}, {-0.14942742057329822`, 
      0., -0.1475219154629108}, {-0.15930343528782656`, 
      0., -0.15700112859089205`}, {-0.16983897334502437`, 
      0., -0.16705793996295812`}, {-0.18107920425344495`, 
      0., -0.1777208730223463}, {-0.19307251710105758`, 
      0., -0.18901839177321758`}, {-0.2058707373483689, 
      0., -0.2009785119398627}, {-0.21952934229768017`, 
      0., -0.21362831505893334`}, {-0.23410766633508537`, 
      0., -0.2269933482401624}, {-0.2496690829558733, 
      0., -0.24109689074740964`}, {-0.26628114513750983`, 
      0., -0.25595906757059267`}, {-0.28401565851976796`, 
      0., -0.27159579029312203`}, {-0.3029486528221144, 
      0., -0.28801750756186884`}, {-0.32316020582730187`, 
      0., -0.3052277524007397}, {-0.34473406121398376`, 
      0., -0.3232214829100857}, {-0.36775696717467676`, 
      0., -0.3419832283908503}, {-0.3923176486275418, 
      0., -0.3614850767641271}, {-0.41850531478116615`, 
      0., -0.3816845734886717}, {-0.4464076005544783, 
      0., -0.402522648566795}, {-0.4761078518298296, 
      0., -0.4239217464701436}, {-0.507681699746306, 
      0., -0.4457844001793372}, {-0.54119293803655, 
      0., -0.4679925554986294}, {-0.576688827206599, 
      0., -0.4904079980042102}, {-0.6141950996702691, 
      0., -0.5128742367962313}, {-0.6537111151438071, 
      0., -0.5352201264323727}, {-0.6952057788595222, 
      0., -0.5572653361371804}, {-0.7386149291063455, 
      0., -0.5788275002332691}, {-0.7838408608423746, 
      0., -0.5997305410172946}, {-0.8307544350559398, 
      0., -0.6198133256006522}, {-0.8791998392921822, 
      0., -0.6389376108931609}, {-0.929001594544534, 
      0., -0.6569942416464578}, {-0.9799729818689518, 
      0., -0.6739068264063106}, {-1.0319248222493083`, 
      0., -0.6896325642042247}, {-1.0846735562916359`, 
      0., -0.7041603969141388}, {-1.1380478127636227`, 
      0., -0.7175070711716138}, {-1.1918930272322013`, 
      0., -0.7297119124984776}, {-1.2460740511474957`, 
      0., -0.7408311262947508}, {-1.3004759835439699`, 
      0., -0.7509322968066706}, {-1.355003621769078, 
      0., -0.7600895365141304}, {-1.4095799725876628`, 
      0., -0.7683795173172209}, {-1.4641442259919129`, 
      0., -0.7758784367505253}, {-1.518649511679431, 
      0., -0.7826598535824683}, {-1.5730606648848973`, 
      0., -0.7887932636677998}, {-1.6273521439837662`, 
      0., -0.7943432652812347}, {-1.6815061758769887`, 
      0., -0.7993691681504054}, {-1.7355111580251779`, 
      0., -0.8039249193326853}, {-1.7893603156334295`, 
      0., -0.8080592430904346}, {-1.8430505950017824`, 
      0., -0.8118159157064077}, {-1.8965817655917117`, 
      0., -0.8152341170832211}, {-1.949955700721395, 
      0., -0.8183488180306322}, {-2.003175807616762, 
      0., -0.821191175366958}, {-2.0562465801794407`, 
      0., -0.823788916810554}, {-2.109173251238575, 
      0., -0.8261667047345842}, {-2.1619615246033184`, 
      0., -0.8283464728189985}, {-2.21461737058201, 
      0., -0.830347732995137}, {-2.267146871618272, 
      0., -0.8321878522771629}, {-2.3195561072576547`, 
      0., -0.8338823004486654}, {-2.3718510698059054`, 
      0., -0.8354448703754518}, {-2.424037603807252, 
      0., -0.8368878731315573}, {-2.4761213639067696`, 
      0., -0.838222310286866}, {-2.528107786815976, 
      0., -0.839458025704046}, {-2.580002074023359, 
      0., -0.8406038390935522}, {-2.6318091826243295`, 
      0., -0.841667663421355}, {-2.6835338222245975`, 
      0., -0.8426566080833644}, {-2.7351804563277775`, 
      0., -0.8435770695716229}, {-2.7867533069770922`, 
      0., -0.8444348111716733}, {-2.8382563617026584`, 
      0., -0.8452350330547691}, {-2.8896933820462825`, 
      0., -0.8459824339663924}, {-2.9410679131079327`, 
      0., -0.846681265565405}, {-2.9923832936923827`, 
      0., -0.8473353803363568}, {-3, 0., -0.8474324701376029}}], 
    Line3DBox[{{
      0., -0.15, -1.*^-6}, {-6.443433194933083*^-8, -0.15, \
-1.0020737743277588`*^-6}, {-1.29135996939957*^-7, -0.15, \
-1.0083037360470293`*^-6}, {-1.9437392017844482`*^-7, -0.15, \
-1.0187155694847545`*^-6}, {-2.604175827966277*^-7, -0.15, \
-1.0333527257001537`*^-6}, {-3.275412657362031*^-7, -0.15, \
-1.052275781813812*^-6}, {-3.960227023744951*^-7, -0.15, \
-1.075563453436069*^-6}, {-4.661470125392186*^-7, -0.15, \
-1.1033119718036767`*^-6}, {-5.3820530100713*^-7, -0.15, \
-1.1356362908537015`*^-6}, {-6.124959603125292*^-7, -0.15, \
-1.1726706735639933`*^-6}, {-6.89326260907065*^-7, -0.15, \
-1.2145691776717817`*^-6}, {-7.690150142080328*^-7, -0.15, \
-1.2615055204808035`*^-6}, {-8.518946330387656*^-7, -0.15, \
-1.3136732448486927`*^-6}, {-9.383079665149491*^-7, -0.15, \
-1.3712892191755178`*^-6}, {-1.0286122308558473`*^-6, -0.15, \
-1.4345932356634524`*^-6}, {-1.1231827602023882`*^-6, -0.15, \
-1.5038472988356013`*^-6}, {-1.2224118457091072`*^-6, -0.15, \
-1.5793386165067243`*^-6}, {-1.3267109036521641`*^-6, -0.15, \
-1.6613804031386458`*^-6}, {-1.436512528480057*^-6, -0.15, \
-1.7503129200260717`*^-6}, {-1.5522727854556216`*^-6, -0.15, \
-1.8465044763969238`*^-6}, {-1.6744712289355113`*^-6, -0.15, \
-1.9503545104569073`*^-6}, {-1.8036147966794545`*^-6, -0.15, \
-2.062293646635765*^-6}, {-1.940238758439581*^-6, -0.15, \
-2.182786478150043*^-6}, {-2.0849097320306366`*^-6, -0.15, \
-2.312332789943245*^-6}, {-2.2382283525434406`*^-6, -0.15, \
-2.4514693465684016`*^-6}, {-2.4008302492228466`*^-6, -0.15, \
-2.600773470202083*^-6}, {-2.573389767630285*^-6, -0.15, \
-2.7608644608034433`*^-6}, {-2.7566225858631495`*^-6, -0.15, \
-2.932406325796533*^-6}, {-2.951288820511898*^-6, -0.15, \
-3.1161104132683897`*^-6}, {-3.1581952939892454`*^-6, -0.15, \
-3.312739182704914*^-6}, {-3.378200836005567*^-6, -0.15, \
-3.5231075295948152`*^-6}, {-3.61221755113906*^-6, -0.15, \
-3.748088336917419*^-6}, {-3.86121620556135*^-6, -0.15, \
-3.988614567270195*^-6}, {-4.126229739409668*^-6, -0.15, \
-4.2456836246881784`*^-6}, {-4.4083570627826935`*^-6, -0.15, \
-4.520361963377964*^-6}, {-4.708768507941547*^-6, -0.15, \
-4.813788644970639*^-6}, {-5.0287098457947836`*^-6, -0.15, \
-5.127180876835195*^-6}, {-5.369507999659964*^-6, -0.15, \
-5.461838527973099*^-6}, {-5.732576472376144*^-6, -0.15, \
-5.81914959442285*^-6}, {-6.119421361992568*^-6, -0.15, \
-6.2005958041765445`*^-6}, {-6.531646939786244*^-6, -0.15, \
-6.607759422182722*^-6}, {-6.9709629130371766`*^-6, -0.15, \
-7.042329212391981*^-6}, {-7.439191562162873*^-6, -0.15, \
-7.506107396114734*^-6}, {-7.938274724274568*^-6, -0.15, \
-8.001017695340337*^-6}, {-8.470282461155048*^-6, -0.15, \
-8.529112703386299*^-6}, {-9.037421109141385*^-6, -0.15, \
-9.092582929666342*^-6}, {-9.642043200808865*^-6, -0.15, \
-9.693765119550882*^-6}, {-0.000010286656185943047`, -0.15, \
-0.000010335152975760652`}, {-0.000010973933850575575`, -0.15, \
-0.000011019406488005315`}, {-0.000011706726697223026`, -0.15, \
-0.000011749363671065353`}, {-0.000012488073957163347`, -0.15, \
-0.000012528052147107163`}, {-0.000013321216344263034`, -0.15, \
-0.000013358701555071304`}, {-0.000014209609413835587`, -0.15, \
-0.000014244757027707254`}, {-0.000015156937802206634`, -0.15, \
-0.000015189893572783509`}, {-0.000016167130549057407`, -0.15, \
-0.000016198031275580866`}, {-0.000017244377535889845`, -0.15, \
-0.00001727335141544887}, {-0.000018393146794283704`, -0.15, \
-0.00001842031387730081}, {-0.000019618202898414915`, -0.15, \
-0.000019643675788025543`}, {-0.000020924626777148146`, -0.15, \
-0.00002094851119640539}, {-0.000022317836993089275`, -0.15, \
-0.000022340231912757613`}, {-0.000023803611876170983`, -0.15, \
-0.000023824610294650588`}, {-0.000025388113839235068`, -0.15, \
-0.00002540780283894287}, {-0.000027077914751994338`, -0.15, \
-0.000027096375901118768`}, {-0.00002888002311751658, -0.15, \
-0.000028897333010437952`}, {-0.00003080191328527931, -0.15, \
-0.000030818143772824316`}, {-0.000032851556489941735`, -0.15, \
-0.00003286677481316332}, {-0.000035037453682239424`, -0.15, \
-0.00003505172304761742}, {-0.000037368671085706535`, -0.15, \
-0.000037382050626844624`}, {-0.000039854877581892736`, -0.15, \
-0.00003986742273932176}, {-0.000042506384834936774`, -0.15, \
-0.00004251814767613534}, {-0.00004533419016956659, -0.15, \
-0.000045345219475656264`}, {-0.00004835002208155722, -0.15, \
-0.000048360363623697136`}, {-0.00005156638896614365, -0.15, \
-0.00005157608560207229}, {-0.00005499663090103541, -0.15, \
-0.00005500572285228446}, {-0.000058654975048496585`, -0.15, \
-0.0000586635000202469}, {-0.00006255659466489486, -0.15, \
-0.00006256458795250105}, {-0.00006671767193484964, -0.15, \
-0.00006672516671623809}, {-0.0000711554652159935, -0.15, \
-0.00007116249257914385}, {-0.00007588838055895836, -0.15, \
-0.00007589496964110088}, {-0.00008093604803883369, -0.15, \
-0.00008094222617526713}, {-0.0000863194032180542, -0.15, \
-0.00008632519599178665}, {-0.0000920607739040593, -0.15, \
-0.00009206620533611016}, {-0.00009818397282551279, -0.15, \
-0.00009818906541840536}, {-0.00010471439636318739`, -0.15000000010166337`, \
-0.00010471917120611992`}, {-0.00011167912986716826`, -0.15000000021729945`, \
-0.00011168360676735046`}, {-0.00011910706005278342`, -0.15000000034882868`, \
-0.00011911125754583032`}, {-0.0001270289947580574, -0.1500000004984354, \
-0.0001270329302174018}, {-0.00013547779073460855`, -0.15000000066860422`, \
-0.00013548148044931316`}, {-0.00014448848994706118`, -0.1500000008621612, \
-0.00014449194914730864`}, {-0.00015409846486912917`, -0.15000000108232084`, \
-0.00015410170783296793`}, {-0.00016434757350156033`, -0.15000000133273944`, \
-0.00016435061363066813`}, {-0.0001752783247297733, -0.1500000016175758, \
-0.00017528117453402943`}, {-0.00018693605458168586`, -0.15000000194156032`, \
-0.00018693872576077777`}, {-0.00019936911426552607`, -0.1500000023100736, \
-0.00019937161777958416`}, {-0.00021262907073702056`, -0.1500000027292357, \
-0.0002126314168190564}, {-0.00022677092056696738`, -0.15000000320600784`, \
-0.00022677311875134596`}, {-0.00024185331803494074`, -0.150000003748308, \
-0.0002418553771987277}, {-0.0002579388184017046, -0.15000000436514238`, \
-0.00025794074680266806`}, {-0.0002750941373723053, -0.1500000050667551, \
-0.00027509594266134226`}, {-0.00029339042778768113`, -0.1500000058647981, \
-0.00029339211704989567`}, {-0.0003129035747692219, -0.15000000677252492`, \
-0.00031290515449428037`}, {-0.00033371451041796965`, -0.15000000780501055`, \
-0.00033371598654488533`}, {-0.0003559095495145768, -0.15000000897940197`, \
-0.0003559109274145519}, {-0.00037958074750004745`, -0.15000001031520283`, \
-0.00037958203198528004`}, {-0.0004048262822948104, -0.15000001183459738`, \
-0.00040482747759557395`}, {-0.00043175086149300606`, -0.15000001356281895`, \
-0.0004317519712385253}, {-0.0004604661566489217, -0.15000001552856887`, \
-0.0004604671838312866}, {-0.0004910912664466505, -0.15000001776449326`, \
-0.0004910922133670627}, {-0.0005237532106676704, -0.15000002030772513`, \
-0.000523754078876672}, {-0.0005585874570155575, -0.15000002320050107`, \
-0.000558588247237684}, {-0.0005957384829933214, -0.15000002649086272`, \
-0.0005957391950053186}, {-0.0006353603751225251, -0.1500000302334546, \
-0.0006353610076361863}, {-0.0006776174680419281, -0.1500000344904316, \
-0.0006776180185372486}, {-0.000722685026104194, -0.15000003933249118`, \
-0.0007226854906220482}, {-0.0007707499703007866, -0.15000004484004753`, \
-0.0007707503431971136}, {-0.0008220116535442863, -0.15000005110456704`, \
-0.0008220119271781843}, {-0.0008766826875044734, -0.15000005823008725`, \
-0.0008766828518696191}, {-0.0009349898244485253, -0.15000006633494464`, \
-0.0009349898667137958}, {-0.0009971748977322388, -0.15000007555373995`, \
-0.0009971748016765931}, {-0.0010634958248365986`, -0.15000008603957343`, \
-0.0010634955701737479`}, {-0.0011342276771294855`, -0.15000009796658748`, \
-0.0011342272386757981`}, {-0.0012096638207727435`, -0.1500001115328586, \
-0.0012096631674416948`}, {-0.0012901171335199827`, -0.15000012696368697`, \
-0.0012901162270954835`}, {-0.0013759213024425404`, -0.15000014451533789`, \
-0.0013759200960970041`}, {-0.0014674322079849794`, -0.15000016447929768`, \
-0.0014674306444638647`}, {-0.0015650294000656966`, -0.1500001871871144, \
-0.001565027409502451}, {-0.0016691176723780932`, -0.15000021301590374`, \
-0.001669115169627918}, {-0.0017801287414018832`, -0.15000024239461188`, \
-0.00178012562281149}, {-0.001898523037104124, -0.15000027581113867`, \
-0.001898519176589697}, {-0.00202479161275562, -0.15000031382044016`, \
-0.0020247868570476947`}, {-0.0021594581817988403`, -0.15000035705374443`, \
-0.0021594523446629454`}, {-0.0023030812902049918`, -0.15000040622903402`, \
-0.0023030741454436914`}, {-0.0024562566333622016`, -0.1500004621629689, \
-0.002456247906311213}, {-0.0026196195270925884`, -0.150000525784448, \
-0.00261960888431164}, {-0.0027938475430727963`, -0.15000059815003441`, \
-0.0027938345798373615`}, {-0.0029796633196000582`, -0.15000068046150025`, \
-0.002979647544725193}, {-0.003177837559378945, -0.15000077408578258`, \
-0.0031778183768087884`}, {-0.0033891922267851576`, -0.15000088057768163`, \
-0.003389168913259548}, {-0.0036146039578949566`, -0.15000100170567787`, \
-0.0036145756358564205`}, {-0.0038550076974563255`, -0.15000113948129667`, \
-0.0038549733021826503`}, {-0.004111400577925834, -0.15000129619250765`, \
-0.004111358817658188}, {-0.004384846056707881, -0.1500014744417131, \
-0.004384795364282659}, {-0.004676478328814595, -0.15000167718895566`, \
-0.0046764168029886964`}, {-0.004987507033319107, -0.15000190780106207`, \
-0.0049874323675929005`}, {-0.005319222273209401, -0.15000217010753816`, \
-0.005319131669482276}, {-0.005672999969566956, -0.15000246846414209`, \
-0.005672890033393703}, {-0.006050307572401779, -0.15000280782518977`, \
-0.006050174185933462}, {-0.006452710151987363, -0.15000319382579144`, \
-0.006452548319837668}, {-0.006881876896143611, -0.15000363287538193`, \
-0.006881680558413765}, {-0.007339588040640932, -0.15000413226409456`, \
-0.007339349846108982}, {-0.007827742261746474, -0.15000470028374047`, \
-0.00782745329273111}, {-0.008348364561902846, -0.15000534636539634`, \
-0.008348014000510193}, {-0.008903614681652058, -0.15000608123587789`, \
-0.00890318940491419}, {-0.009495796073177248, -0.15000691709568723`, \
-0.009495280161941403}, {-0.010127365473277174`, -0.15000786782137635`, \
-0.010126739616469864`}, {-0.010800943116192997`, -0.15000894919567037`, \
-0.010800183888176334`}, {-0.011519323629515547`, -0.15001017916915022`, \
-0.011518402613508246`}, {-0.01228548765941902, -0.15001157815781196`, \
-0.012284370384199298`}, {-0.013102614274714113`, -0.15001316938140774`, \
-0.013101258924844272`}, {-0.013974094202713613`, -0.15001497924813914`, \
-0.013972450054064918`}, {-0.014903543953680976`, -0.15001703779203016`, \
-0.014901549475775483`}, {-0.015894820894712967`, -0.1500193791701633, \
-0.015892401448956126`}, {-0.016952039338321317`, -0.1500220422279329, \
-0.01694910438611642}, {-0.018079587715767835`, -0.15002507114156913`, \
-0.018076027432209738`}, {-0.019282146910401185`, -0.15002851614843024`, \
-0.019277828077076398`}, {-0.02056470983189875, -0.1500324343769666, \
-0.020559470855440732`}, {-0.02193260231847937, -0.1500368907898502, \
-0.021926247188951486`}, {-0.02339150546088701, -0.15004195925555708`, \
-0.023383796424583495`}, {-0.024947479449316516`, -0.15004772376571324`, \
-0.024938128122732817`}, {-0.02660698905254722, -0.15005427981779237`, \
-0.02659564564630615}, {-0.028376930847452, -0.15006173598531608`, \
-0.028363171098760673`}, {-0.03026466232687209, -0.15007021570058116`, \
-0.030247971654047252`}, {-0.03227803302470779, -0.1500798592781605, \
-0.03225778731434082}, {-0.03442541780911164, -0.15009082621102213`, \
-0.034400860121803156`}, {-0.036715752508045145`, -0.15010329777512202`, \
-0.03668596483779953}, {-0.039158572046346984`, -0.15011747998278072`, \
-0.039122441086241196`}, {-0.041764051290066766`, -0.15013360693008088`, \
-0.04172022693614029}, {-0.04454304881236432, -0.15015194458894787`, \
-0.04448989387094822}, {-0.04750715381600893, -0.15017279510051387`, \
-0.047442683057468724`}, {-0.05066873647069969, -0.15019650163281867`, \
-0.05059054278348447}, {-0.0540410019493424, -0.15022345387285277`, \
-0.05394616687876581}, {-0.05763804847633713, -0.15025409423035216`, \
-0.057523033866494024`}, {-0.06147492973310574, -0.15028892483852752`, \
-0.06133544650850682}, {-0.06556772200172194, -0.15032851544491177`, \
-0.06539857130476517}, {-0.06993359646669764, -0.15037351229352758`, \
-0.06972847738098034}, {-0.07459089713765445, -0.15042464810729492`, \
-0.07434217404356663}, {-0.0795592249014139, -0.15048275328657168`, \
-0.07925764609220813}, {-0.08485952826019535, -0.1505487684453193, \
-0.08449388575047545}, {-0.09051420136168123, -0.15062375840974834`, \
-0.09007091979599768}, {-0.09654718997431638, -0.15070892780425202`, \
-0.09600983013417645}, {-0.10298410610358663`, -0.15080563834440217`, \
-0.10233276565227037`}, {-0.10985235197643387`, -0.15091542794465634`, \
-0.10906294270115936`}, {-0.11718125413288587`, -0.15104003172642827`, \
-0.11622463096579198`}, {-0.12500220834398296`, -0.15118140497665705`, \
-0.12384312078618148`}, {-0.13334883600534825`, -0.1513417480532275, \
-0.13194466716150252`}, {-0.14225715251106233`, -0.15152353315541683`, \
-0.14055640469239078`}, {-0.15176574785764263`, -0.15172953276714218`, \
-0.14970622657365618`}, {-0.1619159793142802, -0.15196284942825458`, \
-0.15942261942680902`}, {-0.17275217535679377`, -0.15222694628212277`, \
-0.16973444425095818`}, {-0.1843218491099252, -0.15252567757114557`, \
-0.18067065207561597`}, {-0.19667591815767965`, -0.15286331788753452`, \
-0.19225992104410217`}, {-0.20986892561116577`, -0.1532445885138003, \
-0.20453019969931407`}, {-0.2239592545734383, -0.15367467858291056`, \
-0.2175081392945353}, {-0.2390093243723742, -0.15415925802899708`, \
-0.2312183961996611}, {-0.25508575186536453`, -0.15470447836645165`, \
-0.24568278422295764`}, {-0.2722594544473976, -0.15531695621957542`, \
-0.26091925639126695`}, {-0.2906056628230839, -0.15600373324013792`, \
-0.2769406971264046}, {-0.3102038009280888, -0.15677220465015695`, \
-0.2937535098204518}, {-0.33113717762542755`, -0.15763000725316634`, \
-0.311355992912666}, {-0.35349242042208373`, -0.15858485659487215`, \
-0.3297365114739202}, {-0.37735856669431417`, -0.15964432239944906`, \
-0.34887149313246624`}, {-0.40282571524710775`, -0.1608155320344643, \
-0.36872330917404217`}, {-0.42998313469017824`, -0.16210479436597222`, \
-0.38923814564677306`}, {-0.4589167315213375, -0.16351714195547337`, \
-0.41034402567409217`}, {-0.48970580865303803`, -0.16505579917480884`, \
-0.4319492102048548}, {-0.5224191044098748, -0.16672159823362526`, \
-0.4539412720756311}, {-0.5571102014409604, -0.16851238418642894`, \
-0.476187191929774}, {-0.5938125368646712, -0.17042247183635845`, \
-0.49853484009502547`}, {-0.6325344182002504, -0.17244223766194677`, \
-0.5208161557999001}, {-0.6732546228422812, -0.1745579413005065, \
-0.5428521863743206}, {-0.7159192786130639, -0.1767518650447023, \
-0.5644598941989858}, {-0.7604407238676623, -0.17900282924596678`, \
-0.5854603035573203}, {-0.806698875207146, -0.18128708579467967`, \
-0.6056872145325876}, {-0.8545452829875259, -0.1835795204298407, \
-0.6249954633156904}, {-0.9038095934078743, -0.18585502679436267`, \
-0.6432676620726151}, {-0.9543076866004959, -0.1880898735658995, \
-0.6604185568761428}, {-1.0058504632141398`, -0.19026288636947847`, \
-0.6763965588376816}, {-1.0582521987602855`, -0.1923563089803877, \
-0.6911825091454874}, {-1.1113375756140589`, -0.1943562782370392, \
-0.7047861821207487}, {-1.1649468523002031`, -0.196252920773735, \
-0.7172412984194413}, {-1.218939016252352, -0.1980401366592855, \
-0.7285998779291487}, {-1.2731930850868427`, -0.19971516500346453`, \
-0.7389266475314771}, {-1.3276079185417253`, -0.20127803036979966`, \
-0.7482940103510689}, {-1.3821009763253804`, -0.2027309542898003, \
-0.7567778574404037}, {-1.4366064366689915`, -0.20407779303616852`, \
-0.7644543123570463}, {-1.4910730169020427`, -0.2053235389572142, \
-0.7713973662330796}, {-1.545461745756528, -0.2064739027439195, \
-0.7776772855094934}, {-1.5997438502768229`, -0.20753497970769316`, \
-0.7833596443848247}, {-1.6538988494715476`, -0.20851299428551015`, \
-0.7885048339089584}, {-1.7079128951801765`, -0.20941411244493016`, \
-0.7931679160922848}, {-1.761777366347437, -0.2102443101115075, \
-0.7973987146629556}, {-1.8154877023850418`, -0.2110092860242332, \
-0.8012420581416861}, {-1.8690424506750911`, -0.21171440867217778`, \
-0.8047381125266603}, {-1.9224424991916655`, -0.21236468859859367`, \
-0.8079227588072062}, {-1.9756904651346354`, -0.21296476903071754`, \
-0.8108279845814952}, {-2.0287902125894246`, -0.2135189293215866, \
-0.813482269624273}, {-2.0817464753720505`, -0.21403109699658535`, \
-0.815910952932403}, {-2.134564564668265, -0.21450486526587004`, \
-0.8181365741899288}, {-2.1872501444191768`, -0.21494351371017367`, \
-0.8201791862961479}, {-2.2398090604359426`, -0.21535003050176268`, \
-0.8220566380479881}, {-2.292247211859861, -0.2157271350181876, \
-0.8237848276204253}, {-2.3445704558099862`, -0.2160773000759574, \
-0.8253779284165474}, {-2.3967845379047183`, -0.21640277328231297`, \
-0.826848589361025}, {-2.44889504285039, -0.2167055971990585, \
-0.828208111930126}, {-2.500907360507634, -0.21698762815151051`, \
-0.8294666062487817}, {-2.552826663822848, -0.21725055361258008`, \
-0.830633128510361}, {-2.60465789579051, -0.21749590815799014`, \
-0.8317158018352258}, {-2.656405763229734, -0.2177250880321114, \
-0.8327219225114595}, {-2.7080747356467656`, -0.21793936439121975`, \
-0.8336580533759702}, {-2.7596690478401307`, -0.21813989530684103`, \
-0.8345301059094136}, {-2.811192705207923, -0.2183277366197175, \
-0.8353434124418281}, {-2.862649490954469, -0.21850385173732406`, \
-0.8361027897018259}, {-2.9140429745798704`, -0.21866912046661063`, \
-0.8368125947926579}, {-2.9653765211816854`, -0.2188243469700538, \
-0.8374767745440482}, {-3, -0.21892904422769105`, -0.8379247508690076}}], 
    Line3DBox[{{
      0., -0.3, -1.*^-6}, {-6.678493655910459*^-8, -0.3, \
-1.0022276892765741`*^-6}, {-1.3386750780970206`*^-7, -0.3, \
-1.0089205765157686`*^-6}, {-2.0154668554143494`*^-7, -0.3, \
-1.0201085142764823`*^-6}, {-2.701232041229943*^-7, -0.3, \
-1.0358415123796642`*^-6}, {-3.39903381347727*^-7, -0.3, \
-1.056189472766338*^-6}, {-4.111980071596534*^-7, -0.3, \
-1.081243107963027*^-6}, {-4.843259766391138*^-7, -0.3, \
-1.1111135414402855`*^-6}, {-5.596112651760028*^-7, -0.3, \
-1.1459345694892541`*^-6}, {-6.373887272375092*^-7, -0.3, \
-1.1858616454994782`*^-6}, {-7.180067961183765*^-7, -0.3, \
-1.231071681772395*^-6}, {-8.018240914112324*^-7, -0.3, \
-1.2817663892485147`*^-6}, {-8.892134632574111*^-7, -0.3, \
-1.338171984247668*^-6}, {-9.805641367002497*^-7, -0.3, \
-1.4005398677556818`*^-6}, {-1.0762841695417155`*^-6, -0.3, \
-1.4691471786795621`*^-6}, {-1.1767998167441179`*^-6, -0.3, \
-1.5442997167648015`*^-6}, {-1.2825578682226035`*^-6, -0.3, \
-1.6263331082461823`*^-6}, {-1.394029652934908*^-6, -0.3, \
-1.71561273300299*^-6}, {-1.51171325322889*^-6, -0.3, \
-1.8125352049856501`*^-6}, {-1.6361317098260666`*^-6, -0.3, \
-1.9175333877777697`*^-6}, {-1.7678395422205298`*^-6, -0.3, \
-2.0310749283534105`*^-6}, {-1.907423618607151*^-6, -0.3, \
-2.1536656344594187`*^-6}, {-2.055506008429541*^-6, -0.3, \
-2.2858515333959365`*^-6}, {-2.2127462975506236`*^-6, -0.3, \
-2.4282217077867856`*^-6}, {-2.3798454781386005`*^-6, -0.3, \
-2.581410069592885*^-6}, {-2.557547540632761*^-6, -0.3, \
-2.746099571689989*^-6}, {-2.746644283435241*^-6, -0.3, \
-2.9230238905022468`*^-6}, {-2.9479783992742266`*^-6, -0.3, \
-3.1129710894528917`*^-6}, {-3.162446532496442*^-6, -0.3, \
-3.3167877917054726`*^-6}, {-3.3910043609394717`*^-6, -0.3, \
-3.535381924919711*^-6}, {-3.634670374988702*^-6, -0.3, \
-3.7697272163383716`*^-6}, {-3.894530061252142*^-6, -0.3, \
-4.020867872323033*^-6}, {-4.1717410638260034`*^-6, -0.3, \
-4.289922920032549*^-6}, {-4.467538506486905*^-6, -0.3, \
-4.578091033763461*^-6}, {-4.783240401492533*^-6, -0.3, \
-4.886655963661626*^-6}, {-5.120253227446524*^-6, -0.3, \
-5.216992544158132*^-6}, {-5.480078473757281*^-6, -0.3, \
-5.570572547299763*^-6}, {-5.864319346194713*^-6, -0.3, \
-5.948971224642474*^-6}, {-6.274687484623632*^-6, -0.3, \
-6.35387474309596*^-6}, {-6.7130116297313*^-6, -0.3, \
-6.7870866719558956`*^-6}, {-7.181244425828174*^-6, -0.3, \
-7.250537344915815*^-6}, {-7.681471934867809*^-6, -0.3, \
-7.746291657043595*^-6}, {-8.21592302779506*^-6, -0.3, \
-8.27655816692727*^-6}, {-8.786978760963714*^-6, -0.3, \
-8.84369948590293*^-6}, {-9.397183397558899*^-6, -0.3, \
-9.45024239462441*^-6}, {-0.000010049255584683492`, -0.3, \
-0.000010098889257900972`}, {-0.000010746100503259545`, -0.3, \
-0.000010792530027594574`}, {-0.000011490822888526703`, -0.3, \
-0.00001153425504164126}, {-0.000012286740657069303`, -0.3, \
-0.000012327368997168232`}, {-0.00001313739991711532, -0.3, \
-0.000013175405447032781`}, {-0.000014046590610532026`, -0.3, \
-0.000014082142699571559`}, {-0.0000150183635220846, -0.3, \
-0.000015051620528723258`}, {-0.00001605704822243643, -0.3, \
-0.000016088158276858134`}, {-0.00001716727242061475, -0.3, \
-0.000017196374036197515`}, {-0.000018353982436232473`, -0.3, \
-0.000018381205369457523`}, {-0.000019622465483006438`, -0.3, \
-0.000019647931062734855`}, {-0.000020978373130716244`, -0.3, \
-0.000021002194738343354`}, {-0.00002242774636934795, -0.3, \
-0.000022450030114352384`}, {-0.000023977042582054545`, -0.3, \
-0.000023997887828529208`}, {-0.000025633164454551888`, -0.3, \
-0.000025652664038571083`}, {-0.000027403490561375354`, -0.3, \
-0.000027421731314077117`}, {-0.0000292959082653284, -0.3, \
-0.000029312971458357415`}, {-0.000031318848873378776`, -0.3, \
-0.000031334810609387646`}, {-0.00003348132534850715, -0.3, \
-0.000033496256633521026`}, {-0.000035792972158988854`, -0.3, \
-0.000035806939564783}, {-0.000038264088488607336`, -0.3, \
-0.00003827715422451536}, {-0.00004090568397544407, -0.3, \
-0.00004091790623560334}, {-0.00004372952780693092, -0.3, \
-0.00004374096101269307}, {-0.00004674820111162362, -0.3, \
-0.00004675889622481993}, {-0.000049975153088467726`, -0.3, \
-0.0000499851577569037}, {-0.00005342476085129323, -0.3, \
-0.00005343411969170071}, {-0.000057112393595193064`, -0.3, \
-0.00005712114823950704}, {-0.00006105448091275595, -0.3, \
-0.00006106267035825647}, {-0.00006526858609391412, -0.3, \
-0.00006527624684045025}, {-0.00006977348439662157, -0.3000000001002776, \
-0.00006978065053188749}, {-0.00007458924661465522, -0.3000000002148738, \
-0.00007459595005321001}, {-0.00007973732856008432, -0.300000000345833, \
-0.0000797435991513294}, {-0.00008524066661767659, -0.3000000004954918, \
-0.00008524653232142091}, {-0.00009112377999846065, -0.3000000006665202, \
-0.000091129266923227}, {-0.00009741287992662876, -0.3000000008619696, \
-0.00009741801246819544}, {-0.0001041359863976564, -0.30000000108532704`, \
-0.0001041407874132914}, {-0.00011132305307885435`, -0.3000000013405774, \
-0.00011132754392926088`}, {-0.00011900610072265799`, -0.30000000163227475`, \
-0.00011901030138832464`}, {-0.00012721935984334127`, -0.30000000196562326`, \
-0.00012722328900696182`}, {-0.00013599942322620426`, -0.30000000234657026`, \
-0.00013600309834724245`}, {-0.00014538540895911082`, -0.3000000027819123, \
-0.0001453888463454958}, {-0.0001554191347082767, -0.3000000032794164, \
-0.00015542234959911117`}, {-0.0001661453040401259, -0.30000000384795855`, \
-0.00016614831066260393`}, {-0.0001776117055793287, -0.30000000449768227`, \
-0.00017761451722295485`}, {-0.00018986942593492845`, -0.3000000052401794, \
-0.0001898720549970068}, {-0.00020297307731271624`, -0.30000000608869687`, \
-0.00020297553532992293`}, {-0.00021698104080191468`, -0.3000000070583733, \
-0.00021698333853473526`}, {-0.0002319557265172252, -0.30000000816650885`, \
-0.00023195787395998015`}, {-0.00024796385163889794`, -0.3000000094328739, \
-0.0002479658580604297}, {-0.00026507673766399813`, -0.30000001088006195`, \
-0.0002650786116353576}, {-0.0002833706281601616, -0.30000001253389247`, \
-0.0002833723775916395}, {-0.0003029270284733349, -0.3000000144238717, \
-0.0003029286606115613}, {-0.0003238330688411456, -0.3000000165837191, \
-0.00032383459030045116`}, {-0.0003461818926075196, -0.3000000190519689, \
-0.0003461833093541502}, {-0.00037007307119617824`, -0.30000002187265745`, \
-0.00037007438854760416`}, {-0.00039561304773806834`, -0.3000000250961092, \
-0.00039561427034712877`}, {-0.00042291561130662923`, -0.30000002877983417`, \
-0.0004229167431452081}, {-0.00045210240390118264`, -0.30000003298955435`, \
-0.00045210344820306215`}, {-0.0004833034623926922, -0.30000003780037593`, \
-0.00048330442160383956`}, {-0.0005166577978904463, -0.30000004329812957`, \
-0.000516658673586675}, {-0.0005523140150832487, -0.3000000495809015, \
-0.0005523148078700134}, {-0.0005904309743276877, -0.3000000567607835, \
-0.0005904316837097919}, {-0.0006311784994258328, -0.30000006496587295`, \
-0.00063117912364903}, {-0.000674738134260248, -0.300000074342558, \
-0.0006747386700968372}, {-0.0007213039516352518, -0.30000008505812925`, \
-0.0007213043941288693}, {-0.0007710834179417777, -0.30000009730376465`, \
-0.0007710837600978929}, {-0.0008242983175084023, -0.30000011129794, \
-0.0008242985498950338}, {-0.0008811857407324859, -0.3000001272903271, \
-0.0008811858510022799}, {-0.0009419991404183611, -0.3000001455662477, \
-0.0009419991127118349}, {-0.0010070094610130503`, -0.3000001664517644, \
-0.001007009275231507}, {-0.00107650634578046, -0.3000001903194975, \
-0.0010765059766938226`}, {-0.0011507994272908625`, -0.30000021759527296`, \
-0.0011507988434443434`}, {-0.0012302197069769044`, -0.3000002487657197, \
-0.0012302188693516635`}, {-0.0013151210299046294`, -0.300000284386951, \
-0.0013151198902767423`}, {-0.0014058816613267988`, -0.30000032509448626`, \
-0.0014058801602674098`}, {-0.0015029059720567627`, -0.30000037161458903`, \
-0.0015029040364780975`}, {-0.0016066262401614735`, -0.3000004247772238, \
-0.001606623780321936}, {-0.0017175045770139482`, -0.3000004855308628, \
-0.0017175014828545102`}, {-0.0018360349862832602`, -0.3000005549594074, \
-0.0018360311229556245`}, {-0.0019627455650519975`, -0.30000063430152496`, \
-0.0019627407674441904`}, {-0.0020982008568583314`, -0.30000072497274655`, \
-0.002098194922915674}, {-0.0022430043671724798`, -0.30000082859072014`, \
-0.0022429970497267813`}, {-0.00239780125250794, -0.30000094700406876`, \
-0.0023977922493015366`}, {-0.0025632811951723598`, -0.3000010823253693, \
-0.002563270136666823}, {-0.0027401814764751843`, -0.3000012369688391, \
-0.0027401679109564756`}, {-0.002929290262103052, -0.3000014136934033, \
-0.002929273637484363}, {-0.0031314501143230346`, -0.3000016156519103, \
-0.0031314297559121534`}, {-0.0033475617466864893`, -0.3000018464473736, \
-0.0033475368300262226`}, {-0.003578588037997289, -0.3000021101972418, \
-0.003578557555683911}, {-0.0038255583234666646`, -0.3000024116068439, \
-0.0038255210446115832`}, {-0.004089572982219352, -0.3000027560533173, \
-0.004089527402928417}, {-0.004371808341655212, -0.300003149681517, \
-0.004371752624527085}, {-0.00467352192058243, -0.3000035995136125, \
-0.0046734538208001815`}, {-0.004996058034577381, -0.3000041135743275, \
-0.004995974809615338}, {-0.005340853788648212, -0.30000470103405236`, \
-0.005340752087967455}, {-0.005709445484036219, -0.300005372372379, \
-0.005709321214332599}, {-0.006103475467860875, -0.30000613956497046`, \
-0.006103323628446886}, {-0.006524699456323306, -0.30000701629709164`, \
-0.006524513938024497}, {-0.006974994364334822, -0.3000080182076023, \
-0.006974767703818182}, {-0.007456366676750825, -0.30000916316775256`, \
-0.0074560897564061685`}, {-0.007970961398864078, -0.30001047159973976`, \
-0.00797062308017506}, {-0.008521071626473854, -0.30001196684068937`, \
-0.008520658302141453}, {-0.009109148778704546, -0.3000136755585268, \
-0.009108643825520594}, {-0.009737813539817574, -0.30001562822712485`, \
-0.009737196650299144}, {-0.010409867559563387`, -0.3000178596691579, \
-0.010409113925489264`}, {-0.011128305965176409`, -0.30002040967628824`, \
-0.011127385280217946`}, {-0.01189633074194574, -0.30002332371767126`, \
-0.011895205983320157`}, {-0.012717365043424684`, -0.30002665374931803`, \
-0.012715990983629086`}, {-0.013595068496803983`, -0.3000304591386215, \
-0.01359338988565323}, {-0.014533353573793735`, -0.3000348077203672, \
-0.014531302917757671`}, {-0.015536403102579196`, -0.3000397770028418, \
-0.015533897952261478`}, {-0.016608689002072616`, -0.30004545554525963`, \
-0.01660562863895439}, {-0.017754992325830336`, -0.3000519445306965, \
-0.01775125371532304}, {-0.01898042470968629, -0.3000593595620851, \
-0.018975857558149956`}, {-0.02029045132444037, -0.30006783271265514`, \
-0.020284872041950338`}, {-0.02169091544289653, -0.30007751486653583`, \
-0.021684099769763085`}, {-0.02318806473925757, -0.30008857839015346`, \
-0.023179738740879578`}, {-0.02478857944843795, -0.3001012201806114, \
-0.02477840851789721}, {-0.02649960252336704, -0.30011566514351806`, \
-0.026487177951666656`}, {-0.02832877193993959, -0.30013217015980026`, \
-0.02831359451683554}, {-0.030284255312075535`, -0.3001510286089982, \
-0.03026571530223716}, {-0.03237478699353109, -0.30017257552546367`, \
-0.03235213968868502}, {-0.03460970785885192, -0.3001971934738677, \
-0.034582043730999594`}, {-0.036999007973375755`, -0.3002253192415513, \
-0.036965216240340215`}, {-0.03955337238171724, -0.3002574514575978, \
-0.03951209653593558}, {-0.04228423026595588, -0.3002941592621327, \
-0.042233813800639605`}, {-0.04520380774908359, -0.3003360921643009, \
-0.045142227930600444`}, {-0.0483251846464476, -0.30038399124362886`, \
-0.048249971713548064`}, {-0.05166235549825047, -0.30043870186698907`, \
-0.05157049410014941}, {-0.05523029524993295, -0.30050118811200355`, \
-0.055118104245355334`}, {-0.05904502998470661, -0.3005725491071835, \
-0.05890801588781925}, {-0.06312371315377599, -0.30065403751898007`, \
-0.06295639150065316}, {-0.06748470779487076, -0.3007470804355627, \
-0.06728038548042173}, {-0.0721476752783006, -0.3008533029155852, \
-0.07189818543667753}, {-0.07713367117111376, -0.30097455448607985`, \
-0.07682905039354627}, {-0.08246524886267029, -0.30111293888501756`, \
-0.08209334440844993}, {-0.0881665716466235, -0.3012708473483421, \
-0.08771256373990557}, {-0.0942635340010443, -0.30145099573483136`, \
-0.09370935524351869}, {-0.10078389284419922`, -0.3016564657601081, \
-0.10010752312788083`}, {-0.10775740955923041`, -0.3018907505670492, \
-0.10693202054315319`}, {-0.11521600356329816`, -0.3021578047851741, \
-0.11420892168585822`}, {-0.12319391812623297`, -0.3024620991151235, \
-0.12196536916355255`}, {-0.13172789899268278`, -0.3028086793015312, \
-0.1302294902518051}, {-0.1408573860910586, -0.30320322910976033`, \
-0.13903027437354845`}, {-0.1506247181679111, -0.3036521365754355, \
-0.1483974026216071}, {-0.16107534949306637`, -0.3041625623208501, \
-0.1583610184216881}, {-0.17225807673791116`, -0.30474250809289494`, \
-0.16895142650359207`}, {-0.18422527260224805`, -0.3054008828298687, \
-0.18019870524759446`}, {-0.19703312057890637`, -0.30614756245969166`, \
-0.19213221527830465`}, {-0.21074184217715586`, -0.3069934382158226, \
-0.20477998503360811`}, {-0.2254159037028243, -0.30795044647700814`, \
-0.21816795218499851`}, {-0.2411241839964256, -0.30903157095199507`, \
-0.23231903861647235`}, {-0.25794007701821803`, -0.3102508054298101, \
-0.24725203677564145`}, {-0.2759414935252364, -0.3116230623500524, \
-0.26298028746315394`}, {-0.295210714119739, -0.31316400927352156`, \
-0.2795101347497447}, {-0.31583403176931957`, -0.3148898122852154, \
-0.29683915434710784`}, {-0.3379011061896317, -0.31681676304031803`, \
-0.314954169478147}, {-0.3615039369052394, -0.31896076554426306`, \
-0.3338290954659602}, {-0.3867353495351432, -0.32133666128603067`, \
-0.3534226931893527}, {-0.41368688613914556`, -0.32395737896424814`, \
-0.3736763636711084}, {-0.44244600302881926`, -0.32683291005506543`, \
-0.3945121805578173}, {-0.4730925182305451, -0.32996913603691014`, \
-0.4158314289969063}, {-0.5056943263482147, -0.33336656826049843`, \
-0.4375139865310714}, {-0.5403025183313295, -0.3370191055983919, \
-0.4594189235068815}, {-0.5769462055781716, -0.34091296191782233`, \
-0.4813866882329358}, {-0.6156275325864738, -0.34502595296086047`, \
-0.5032431439417595}, {-0.6563175277198465, -0.3493273430738574, \
-0.5248055182700354}, {-0.6989535249913433, -0.35377841842736363`, \
-0.5458900169217267}, {-0.7434388252851661, -0.3583338648901891, \
-0.5663204909085279}, {-0.7896450154164585, -0.3629438933553869, \
-0.5859372260974094}, {-0.8374169510219144, -0.367556903399873, \
-0.6046047595236947}, {-0.8865799302492232, -0.3721223538166144, \
-0.6222177044808056}, {-0.936948180895877, -0.37659345908121306`, \
-0.6387038924702999}, {-0.9883335812519436, -0.38092937329487647`, \
-0.6540246268059791}, {-1.0405535882958867`, -0.38509664204801297`, \
-0.6681723419865085}, {-1.093437615165644, -0.3890698557918118, \
-0.6811663334297628}, {-1.1468314752982347`, -0.39283157783002937`, \
-0.6930473869541509}, {-1.2005998741214876`, -0.39637171269640115`, \
-0.703872101927513}, {-1.2546271972636585`, -0.39968651661534166`, \
-0.7137075305293694}, {-1.308816987094755, -0.40277744064192456`, \
-0.7226265301134435}, {-1.3630905311120634`, -0.4056499578691693, \
-0.7307040127673007}, {-1.4173849422709395`, -0.40831247735611165`, \
-0.7380141128794442}, {-1.4716510310355502`, -0.4107754021710105, \
-0.7446281896989364}, {-1.5258511809041928`, -0.4130503536401865, \
-0.7506135301377144}, {-1.5799573607829678`, -0.4151495600044983, \
-0.7560326029636338}, {-1.6339493461865136`, -0.41708539379941934`, \
-0.7609427243895414}, {-1.6878131776843661`, -0.4188700358717764, \
-0.7653960152654676}, {-1.741539856816664, -0.4205152424853373, \
-0.7694395538280221}, {-1.79512426327494, -0.42203219338183945`, \
-0.7731156507449787}, {-1.8485642689762722`, -0.4234314014821381, \
-0.7764621928638084}, {-1.90186002186454, -0.42472266819182214`, \
-0.7795130179549405}, {-1.9550133727026615`, -0.4259150714753128, \
-0.7822982949647412}, {-2.0080274202907025`, -0.4270169767124536, \
-0.7848448933577121}, {-2.0609061534951594`, -0.4280360627510862, \
-0.7871767316397609}, {-2.1136541716203365`, -0.4289793575127929, \
-0.7893150996976371}, {-2.166276467665484, -0.42985327903941634`, \
-0.7912789526645609}, {-2.2187782617279996`, -0.4306636790466899, \
-0.7930851760316731}, {-2.2711648741709087`, -0.4314158869428034, \
-0.7947488229796923}, {-2.3234416301671934`, -0.4321147529333527, \
-0.7962833256369191}, {-2.375613788889898, -0.4327646893208488, \
-0.7977006823474269}, {-2.4276864919744323`, -0.4333697094586514, \
-0.7990116231776239}, {-2.4796647269812504`, -0.43393346406922123`, \
-0.800225755885013}, {-2.531553302474667, -0.43445927481099916`, \
-0.8013516944783234}, {-2.5833568320447307`, -0.43495016509699586`, \
-0.8023971723527776}, {-2.63507972516641, -0.4354088882464671, \
-0.8033691418143113}, {-2.6867261832414977`, -0.43583795310020584`, \
-0.8042738616290355}, {-2.7383001995265017`, -0.43623964725843917`, \
-0.805116974059668}, {-2.789805561933056, -0.4366160581142979, \
-0.8059035726853067}, {-2.8412458579112463`, -0.43696909185986643`, \
-0.8066382621481172}, {-2.892624480802896, -0.4373004906392209, \
-0.8073252108317279}, {-2.9439446371910845`, -0.4376118480159883, \
-0.8079681973516353}, {-2.995209354881731, -0.43790462291349525`, \
-0.808570651627272}, {-3, -0.4379319824835207, -0.8086269504769404}}], 
    Line3DBox[{{
      0., -0.44999999999999996`, -1.*^-6}, {-7.134723414501347*^-8, \
-0.44999999999999996`, -1.002542063741177*^-6}, {-1.4305837688518765`*^-7, \
-0.44999999999999996`, -1.0101810105623227`*^-6}, {-2.154967734152932*^-7, \
-0.44999999999999996`, -1.0229558643313247`*^-6}, {-2.890307745408398*^-7, \
-0.44999999999999996`, -1.0409314566069097`*^-6}, {-3.640341036395112*^-7, \
-0.44999999999999996`, -1.064199334435632*^-6}, {-4.4088804002153466`*^-7, \
-0.44999999999999996`, -1.0928777431872995`*^-6}, {-5.199836035066605*^-7, \
-0.44999999999999996`, -1.1271124025440586`*^-6}, {-6.017236607023236*^-7, \
-0.44999999999999996`, -1.1670770179160928`*^-6}, {-6.865217775678005*^-7, \
-0.44999999999999996`, -1.21297574013234*^-6}, {-7.748099131855509*^-7, \
-0.44999999999999996`, -1.265041541940066*^-6}, {-8.670378183571346*^-7, \
-0.44999999999999996`, -1.3235385759616437`*^-6}, {-9.6367354829077*^-7, \
-0.44999999999999996`, -1.3887647722497255`*^-6}, {-1.0652085561463318`*^-6, \
-0.44999999999999996`, -1.461051658050996*^-6}, {-1.1721596345192777`*^-6, \
-0.44999999999999996`, -1.5407663385801718`*^-6}, {-1.285070111620071*^-6, \
-0.44999999999999996`, -1.6283143916790711`*^-6}, {-1.4045138632817459`*^-6, \
-0.44999999999999996`, -1.7241410520422314`*^-6}, {-1.5310981915573519`*^-6, \
-0.44999999999999996`, -1.8287334743582048`*^-6}, {-1.6654670801943373`*^-6, \
-0.44999999999999996`, -1.9426230827057118`*^-6}, {-1.8083033922776558`*^-6, \
-0.44999999999999996`, -2.0663891291609994`*^-6}, {-1.9603334524247734`*^-6, \
-0.44999999999999996`, -2.2006607406434344`*^-6}, {-2.122329607354318*^-6, \
-0.44999999999999996`, -2.3461210774190357`*^-6}, {-2.29511596518892*^-6, \
-0.44999999999999996`, -2.503509232443332*^-6}, {-2.4795705080124257`*^-6, \
-0.44999999999999996`, -2.673625815426528*^-6}, {-2.676631910984807*^-6, \
-0.44999999999999996`, -2.857334891403352*^-6}, {-2.887301540214653*^-6, \
-0.44999999999999996`, -3.055570929247529*^-6}, {-3.112650182286899*^-6, \
-0.44999999999999996`, -3.269342042412968*^-6}, {-3.3538238237944027`*^-6, \
-0.44999999999999996`, -3.4997347832486412`*^-6}, {-3.6120489408216634`*^-6, \
-0.44999999999999996`, -3.747920175204181*^-6}, {-3.888637958257981*^-6, \
-0.44999999999999996`, -4.015160415276889*^-6}, {-4.184997189944022*^-6, \
-0.44999999999999996`, -4.302814069690691*^-6}, {-4.502633338245304*^-6, \
-0.44999999999999996`, -4.612343609884963*^-6}, {-4.843161439475326*^-6, \
-0.44999999999999996`, -4.945322571021944*^-6}, {-5.208312188759989*^-6, \
-0.44999999999999996`, -5.303444415856724*^-6}, {-5.599942458101949*^-6, \
-0.44999999999999996`, -5.688529464798932*^-6}, {-6.020043757360849*^-6, \
-0.44999999999999996`, -6.102535105637641*^-6}, {-6.470751292042781*^-6, \
-0.44999999999999996`, -6.547566799171606*^-6}, {-6.954356739842578*^-6, \
-0.44999999999999996`, -7.025886890073013*^-6}, {-7.473318681215185*^-6, \
-0.44999999999999996`, -7.539927313395222*^-6}, {-8.03027572549071*^-6, \
-0.44999999999999996`, -8.092301339177262*^-6}, {-8.628059431525398*^-6, \
-0.44999999999999996`, -8.685817347708354*^-6}, {-9.269708933152438*^-6, \
-0.44999999999999996`, -9.323492880685393*^-6}, {-9.958486438784107*^-6, \
-0.44999999999999996`, -0.000010008569934267623`}, {-0.00001069789384721814,
       -0.44999999999999996`, -0.000010744531411366596`}, \
{-0.000011491690361231996`, -0.44999999999999996`, \
-0.000011535119018371788`}, {-0.000012343911716900317`, \
-0.44999999999999996`, -0.000012384352171810618`}, \
{-0.000013258890686692433`, -0.44999999999999996`, \
-0.000013296548448239219`}, {-0.000014241278921281758`, \
-0.44999999999999996`, -0.000014276345721189373`}, \
{-0.000015296071206466793`, -0.44999999999999996`, \
-0.000015328725134568974`}, {-0.000016428630063719618`, \
-0.44999999999999996`, -0.000016459037218669332`}, \
{-0.000017644713524115053`, -0.44999999999999996`, -0.0000176730285835542}, \
{-0.000018950504366774897`, -0.44999999999999996`, \
-0.000018976871171115328`}, {-0.00002035264130409333, -0.44999999999999996`, \
-0.000020377193881954313`}, {-0.000021858252921625866`, \
-0.44999999999999996`, -0.000021881116089563407`}, \
{-0.000023474993835572113`, -0.44999999999999996`, \
-0.000023496283920627453`}, {-0.000025211083801706954`, \
-0.44999999999999996`, -0.00002523090893666175}, {-0.00002707534915203755, \
-0.44999999999999996`, -0.00002709381023531901}, {-0.000029077268072715166`, \
-0.44999999999999996`, -0.00002909445888378475}, {-0.00003122701845449571, \
-0.44999999999999996`, -0.00003124302640777641}, {-0.0000335355298459224, \
-0.44999999999999996`, -0.000033550436296778154`}, {-0.00003601453888371683, \
-0.44999999999999996`, -0.00003602841967638939}, {-0.000038676649086372284`, \
-0.44999999999999996`, -0.00003868957482701747}, {-0.00004153539488308933, \
-0.44999999999999996`, -0.000041547431283133285`}, {-0.00004460531043319484, \
-0.44999999999999996`, -0.000044616518609488505`}, \
{-0.000047902003423066026`, -0.44999999999999996`, \
-0.000047912440366753464`}, {-0.00005144223452298444, -0.44999999999999996`, \
-0.00005145195333548419}, {-0.00005524400264978194, -0.4500000001144316, \
-0.00005525305265930006}, {-0.00005932663625072962, -0.45000000024639875`, \
-0.0000593350635583017}, {-0.00006371089186736032, -0.4500000003985885, \
-0.00006371873928333221}, {-0.00006841905943403426, -0.4500000005740999, \
-0.00006842636685719879}, {-0.00007347507571674198, -0.45000000077650665`, \
-0.00007348188026932538}, {-0.00007890464595649392, -0.4500000010099302, \
-0.0000789109822112461}, {-0.00008473537456994377, -0.4500000012791236, \
-0.00008474127473836306}, {-0.0000909969055243023, -0.4500000015895682, \
-0.00009100239957006011}, {-0.00009772107299872647, -0.4500000019475854, \
-0.00009772618884181891}, {-0.00010494206328769456`, -0.4500000023604651, \
-0.00010494682688700984`}, {-0.00011269658854432877`, -0.45000000283661457`, \
-0.00011270102409584594`}, {-0.000121024073489525, -0.45000000338572915`, \
-0.00012102820349288676`}, {-0.0001299668558188694, -0.4500000040189901, \
-0.0001299707011989128}, {-0.0001395704014408362, -0.450000004749292, \
-0.00013957398168172215`}, {-0.00014988353565243242`, -0.45000000559150544`, \
-0.00014988686887831127`}, {-0.00016095869137068116`, -0.45000000656277966`, \
-0.00016096179442038952`}, {-0.0001728521756997754, -0.45000000768289206`, \
-0.0001728550642074028}, {-0.0001856244561933367, -0.4500000089746505, \
-0.00018562714467813246`}, {-0.0001993404682976118, -0.45000001046435806`, \
-0.00019934297020581177`}, {-0.0002140699454583209, -0.4500000121823485, \
-0.00021407227325988856`}, {-0.00022988777369645474`, -0.45000001416360386`, \
-0.00022988993888594376`}, {-0.00024687437228847675`, -0.4500000164484669, \
-0.00024687638547313435`}, {-0.00026511610265612717`, -0.45000001908346243`, \
-0.0002651179735751421}, {-0.000284705707430874, -0.4500000221222448, \
-0.00028470744497678023`}, {-0.0003057427819649852, -0.45000002562669034`, \
-0.0003057443941986388}, {-0.0003283342806727297, -0.45000002966815716`, \
-0.0003283357748504603}, {-0.0003525950608180716, -0.4500000343289385, \
-0.0003525964433652916}, {-0.0003786484664476143, -0.45000003970393804`, \
-0.000378649742944441}, {-0.00040662695549228744`, -0.45000004590260256`, \
-0.00040662813062700804`}, {-0.00043667277319004604`, -0.4500000530511505, \
-0.0004366738507076153}, {-0.00046893867527488106`, -0.45000006129514186`, \
-0.0004689396579039847}, {-0.0005035887046206662, -0.4500000708024424, \
-0.0005035895939385976}, {-0.0005407990252356432, -0.45000008176664147`, \
-0.0005407998215345792}, {-0.0005807588179098019, -0.4500000944109939, \
-0.0005807595200027806}, {-0.0006236712420348896, -0.4500001089929663, \
-0.000623671847005898}, {-0.0006697544684918599, -0.45000012580947896`, \
-0.0006697549713829874}, {-0.0007192427888586797, -0.45000014520295245`, \
-0.0007192431822818432}, {-0.000772387806591622, -0.45000016756827954`, \
-0.0007723880802220415}, {-0.0008294597162035784, -0.45000019336086605`, \
-0.0008294598561737848}, {-0.0008907486769837668, -0.45000022310590393`, \
-0.0008907486651110251}, {-0.0009565662882200244, -0.4500002574090649, \
-0.0009565661010406529}, {-0.001027247173423457, -0.45000029696883337`, \
-0.0010272467810018705`}, {-0.0011031506816229135`, -0.4500003425907285, \
-0.0011031500460690583`}, {-0.001184662714373776, -0.4500003952037061, \
-0.0011846617880028607`}, {-0.001272197687775233, -0.4500004558790736, \
-0.0012721964108204978`}, {-0.0013662006394634767`, -0.4500005258523035, \
-0.0013661989372528928`}, {-0.0014671494913179638`, -0.45000060654818935`, \
-0.0014671472707571433`}, {-0.0015755574793625807`, -0.45000069960985634`, \
-0.00157555462458688}, {-0.0016919757632381295`, -0.4500008069322173, \
-0.0016919721302231616`}, {-0.0018169962285139436`, -0.45000093070055475`, \
-0.0018169916383961844`}, {-0.00195125449609164, -0.45000107343501533`, \
-0.0019512487268952532`}, {-0.0020954331540118873`, -0.45000123804192116`, \
-0.00209542593040186}, {-0.0022502652281093903`, -0.4500014278729435, \
-0.0022502562086948678`}, {-0.002416537909168609, -0.4500016467933431, \
-0.0024165266707820163`}, {-0.0025950965555548607`, -0.45000189926066547`, \
-0.0025950825737781234`}, {-0.0027868489916898194`, -0.4500021904154936, \
-0.0027868316167323844`}, {-0.002992770124247682, -0.4500025261861045, \
-0.0029927485510775793`}, {-0.0032139068995856225`, -0.45000291340915893`, \
-0.0032138801309295065`}, {-0.0034513836276418314`, -0.4500033599688808, \
-0.0034513504281681305`}, {-0.003706407699430694, -0.45000387495755684`, \
-0.0037063665390040406`}, {-0.0039802757272633105`, -0.4500044688606219, \
-0.003980224710665457}, {-0.004274380138988578, -0.45000515377009426`, \
-0.004274316918883395}, {-0.004590216259880932, -0.4500059436307007, \
-0.004590137929028119}, {-0.004929389918304029, -0.45000685452369543`, \
-0.004929292876068856}, {-0.005293625613964022, -0.45000790499414217`, \
-0.005293505401001193}, {-0.005684775290472045, -0.45000911642830876`, \
-0.005684626383991867}, {-0.006104827757043486, -0.4500105134888415, \
-0.0061046433172681795`}, {-0.006555918807525755, -0.4500121246165558, \
-0.006555690363694642}, {-0.007040342088549708, -0.45001398260902786`, \
-0.007040059150068968}, {-0.007560560772502126, -0.4500161252877265, \
-0.007560210347392086}, {-0.008119220095205354, -0.45001859626721136`, \
-0.00811878609375178}, {-0.008719160822718808, -0.4500214458419846, \
-0.00871862331896814}, {-0.009363433716558966, -0.4500247320089527, \
-0.00936276803377898}, {-0.010055315071906426`, -0.45002852164618323`, \
-0.010054490650064822`}, {-0.010798323409067502`, -0.45003289187177986`, \
-0.010797302402389304`}, {-0.011596237404619859`, -0.4500379316103071, \
-0.0115949729449178}, {-0.012453115155346216`, -0.4500437433983439, \
-0.012451549201506158`}, {-0.013373314875290207`, -0.45005044546551, \
-0.013371375550346388`}, {-0.014361517134119525`, -0.45005817413277904`, \
-0.014359115427899477`}, {-0.015422748753511212`, -0.4500670865761697, \
-0.015419774439804043`}, {-0.016562408487556475`, -0.4500773640110982, \
-0.016558725068843205`}, {-0.017786294623303056`, -0.45008921536091745`, \
-0.01778173307165151}, {-0.019100634648607184`, -0.45010288148259026`, \
-0.01909498565636066}, {-0.020512117146559216`, -0.45011864003321495`, \
-0.02050512153245881}, {-0.022027926089007832`, -0.4501368110734011, \
-0.022019262921310942`}, {-0.023655777716277224`, -0.45015776351747916`, \
-0.023645049610489244`}, {-0.025403960206215638`, -0.4501819225564167, \
-0.025390675126577205`}, {-0.027281376353418776`, -0.45020977819731883`, \
-0.02726492508854931}, {-0.029297589499053155`, -0.45024189508373574`, \
-0.029277217786082128`}, {-0.03146287297340444, -0.45027892378390094`, \
-0.031437647002847235`}, {-0.033788263337363976`, -0.45032161375969293`, \
-0.033757027072271545`}, {-0.036285617735844156`, -0.4503708282577289, \
-0.036246940110320695`}, {-0.03896767570590119, -0.4504275613956927, \
-0.038919785313974546`}, {-0.041848125815482584`, -0.45049295775181625`, \
-0.04178883014202646}, {-0.04494167754553951, -0.4505683348032877, \
-0.04486826310273652}, {-0.04826413886905844, -0.4506552085999699, \
-0.048173247755905535`}, {-0.05183250002559246, -0.4507553231026214, \
-0.05171997738926786}, {-0.055665024039183345`, -0.4508706836588478, \
-0.0555257296436145}, {-0.05978134458095752, -0.45100359513376054`, \
-0.05960892012915257}, {-0.06420257183450723, -0.4511567052534814, \
-0.0639891537869246}, {-0.06895140708108614, -0.45133305375485794`, \
-0.06868727239125808}, {-0.07405226678023039, -0.45153612795927234`, \
-0.07372539614748454}, {-0.07953141697561147, -0.4517699253955514, \
-0.07912695679627298}, {-0.08541711889928695, -0.4520390240775005, \
-0.08491671897181279}, {-0.09173978667007363, -0.4523486609829398, \
-0.09112078575290061}, {-0.09853215796851605, -0.45270481916642463`, \
-0.09776658336828517}, {-0.1058294784996445, -0.4531143237446152, \
-0.10488281884305331`}, {-0.11366970089308887`, -0.45358494669196625`, \
-0.11249940297354362`}, {-0.12209369839177477`, -0.4541255199366672, \
-0.12064732936847486`}, {-0.1311454931798312, -0.4547460556034822, \
-0.129358498374327}, {-0.14087249840618427`, -0.45545787134962845`, \
-0.1386654725076329}, {-0.15132577174745973`, -0.4562737175063308, \
-0.14860114756430237`}, {-0.1625602765539604, -0.4572079010820347, \
-0.15919832092609043`}, {-0.1746351440143949, -0.45827639950091736`, \
-0.17048913586221348`}, {-0.18761392607644656`, -0.459496954133834, \
-0.18250437805624045`}, {-0.20156482372541507`, -0.4608891301279015, \
-0.1952725985509017}, {-0.2165608682532808, -0.4624743246900506, \
-0.20881903638721672`}, {-0.2326800239297402, -0.46427570084420633`, \
-0.22316431530561917`}, {-0.2500051686624986, -0.46631801793078026`, \
-0.23832289324781425`}, {-0.2686238946701353, -0.4686273241854619, \
-0.2543012527892107}, {-0.28862805422785176`, -0.4712304714751459, \
-0.2710958372840861}, {-0.31011295740569256`, -0.47415440914471996`, \
-0.2886907640684576}, {-0.33317611206378184`, -0.4774252152050386, \
-0.3070553852516054}, {-0.3579153859748663, -0.4810668319504134, \
-0.3261418204360292}, {-0.3844264742877353, -0.48509949349192005`, \
-0.34588265401462864`}, {-0.4127995828915463, -0.4895378687179724, \
-0.3661890681003685}, {-0.4431153015043757, -0.494388997583015, \
-0.3869497592621829}, {-0.4754397497456075, -0.49965017025721475`, \
-0.4080310423381771}, {-0.5098192375073186, -0.5053069793045469, \
-0.429278547467032}, {-0.5462748738331242, -0.5113318465746661, \
-0.4505208323594112}, {-0.5847977487198462, -0.5176833611173884, \
-0.4715750337965651}, {-0.6253454381736265, -0.5243067309253444, \
-0.4922543703862227}, {-0.6678405727767385, -0.5311355284075906, \
-0.5123769281697266}, {-0.7121720123811004, -0.5380947027251946, \
-0.5317748067997683}, {-0.758198789037639, -0.5451045841802189, \
-0.5503024978838081}, {-0.8057564973673192, -0.5520853891885587, \
-0.5678434057930838}, {-0.8546653640542451, -0.5589616232289157, \
-0.5843137239706673}, {-0.9047389550650915, -0.5656658139128187, \
-0.5996633661495959}, {-0.9557924570376255, -0.5721411723748936, \
-0.6138741726907447}, {-1.0076496798819856`, -0.5783430171015941, \
-0.6269560170983418}, {-1.0601482764473626`, -0.5842390233109569, \
-0.6389416379949394}, {-1.1131430429863505`, -0.5898085247531323, \
-0.6498810134678641}, {-1.1665074580250125`, -0.5950411708461768, \
-0.65983593787517}, {-1.220133794485893, -0.5999352405107148, \
-0.6688752388167131}, {-1.2739322040740615`, -0.6044958624717002, \
-0.6770708542496059}, {-1.3278291541882346`, -0.6087333195671607, \
-0.6844948178383264}, {-1.3817655326163276`, -0.6126615436657086, \
-0.691217087648379}, {-1.4356946544519769`, -0.6162968500887942, \
-0.6973040937038562}, {-1.489580328691785, -0.6196569196993753, \
-0.7028178599805246}, {-1.5433950785360637`, -0.6227600117778664, \
-0.7078155613991507}, {-1.5971185622060116`, -0.6256243779873463, \
-0.7123493943354989}, {-1.6507362088525976`, -0.6282678433075959, \
-0.7164666618195137}, {-1.704238063951198, -0.6307075205273239, \
-0.7202099970402936}, {-1.7576178272512126`, -0.632959628312852, \
-0.7236176685425003}, {-1.810872061069212, -0.635039387416202, \
-0.7267239267021028}, {-1.8639995452820783`, -0.6369609742810345, \
-0.7295593636990338}, {-1.9170007562100675`, -0.6387375156351482, \
-0.7321512686803618}, {-1.9698774486063286`, -0.6403811113958473, \
-0.73452396669664}, {-2.022632322502849, -0.6419028763026765, \
-0.7366991348620426}, {-2.075268759289558, -0.6433129931653846, \
-0.738696092532971}, {-2.127790613893053, -0.6446207725497152, \
-0.7405320645264447}, {-2.1802020521609298`, -0.6458347152088117, \
-0.7422224178258925}, {-2.232507424505209, -0.646962574690142, \
-0.7437808730872139}, {-2.284711168513279, -0.6480114183836806, \
-0.7452196927383499}, {-2.3368177346180783`, -0.6489876858912549, \
-0.7465498476880894}, {-2.3888315300617435`, -0.6498972440419524, \
-0.7477811647144693}, {-2.4407568773222525`, -0.6507454381959518, \
-0.7489224565526508}, {-2.4925979839331625`, -0.6515371397014658, \
-0.7499816365895804}, {-2.5443589212419697`, -0.6522767895215656, \
-0.7509658199270336}, {-2.596043610148722, -0.6529684381483777, \
-0.7518814124148399}, {-2.6476558122652687`, -0.6536157819857107, \
-0.7527341890943859}, {-2.6991991252553604`, -0.6542221964181983, \
-0.7535293633363633}, {-2.7506769813719036`, -0.6547907658033605, \
-0.7542716478104464}, {-2.802092648412453, -0.6553243106283887, \
-0.7549653082903398}, {-2.853449232477612, -0.6558254120701414, \
-0.7556142111762171}, {-2.9047496820475702`, -0.6562964341878511, \
-0.7562218655079271}, {-2.955996792996107, -0.6567395439655705, \
-0.7567914601458919}, {-3, -0.6571200190970178, -0.7572805411945357}}], 
    Line3DBox[{{
      0., -0.6, -1.*^-6}, {-7.966242453778674*^-8, -0.6, \
-1.0031679677782165`*^-6}, {-1.5982874414332617`*^-7, -0.6, \
-1.0126919673296451`*^-6}, {-2.410073221102551*^-7, -0.6, \
-1.0286323527130694`*^-6}, {-3.237132307610731*^-7, -0.6, \
-1.0510899848905436`*^-6}, {-4.0846995616895115`*^-7, -0.6, \
-1.080207299467184*^-6}, {-4.958149581260597*^-7, -0.6, \
-1.116168630338855*^-6}, {-5.863010754289038*^-7, -0.6, \
-1.1592020536019024`*^-6}, {-6.805020352713257*^-7, -0.6, \
-1.20958003494637*^-6}, {-7.790149181763504*^-7, -0.6, \
-1.267621622797299*^-6}, {-8.824632254363677*^-7, -0.6, \
-1.3336949654079318`*^-6}, {-9.915028243836363*^-7, -0.6, \
-1.4082184290545567`*^-6}, {-1.1068246678865269`*^-6, -0.6, \
-1.4916641232990753`*^-6}, {-1.2291589335113028`*^-6, -0.6, \
-1.5845611109612272`*^-6}, {-1.3592812055953326`*^-6, -0.6, \
-1.6874976144333035`*^-6}, {-1.4980159522565942`*^-6, -0.6, \
-1.8011257962263185`*^-6}, {-1.6462419260524005`*^-6, -0.6, \
-1.926165814609562*^-6}, {-1.804898670825312*^-6, -0.6, \
-2.063409573997201*^-6}, {-1.974990957363396*^-6, -0.6, \
-2.213727037357415*^-6}, {-2.1575962683231646`*^-6, -0.6, \
-2.3780707891250872`*^-6}, {-2.3538718605922823`*^-6, -0.6, \
-2.5574818423286764`*^-6}, {-2.5650616342511726`*^-6, -0.6, \
-2.753096643228282*^-6}, {-2.792503484396626*^-6, -0.6, \
-2.9661547559689366`*^-6}, {-3.0376385326281363`*^-6, -0.6, \
-3.1980060349018836`*^-6}, {-3.302019446134877*^-6, -0.6, \
-3.4501199288394305`*^-6}, {-3.5873218737898955`*^-6, -0.6, \
-3.7240932826499644`*^-6}, {-3.895353140830065*^-6, -0.6, \
-4.02166227898114*^-6}, {-4.228064755489368*^-6, -0.6, \
-4.34471243638805*^-6}, {-4.587565198103897*^-6, -0.6, \
-4.6952901370201686`*^-6}, {-4.9761320536841974`*^-6, -0.6, \
-5.075616783760655*^-6}, {-5.396227312367623*^-6, -0.6, \
-5.488102029929633*^-6}, {-5.850512505358708*^-6, -0.6, \
-5.935359498737442*^-6}, {-6.341866025042803*^-6, -0.6, \
-6.4202228945442*^-6}, {-6.873401130316037*^-6, -0.6, \
-6.945764184519457*^-6}, {-7.448485518631518*^-6, -0.6, \
-7.515313213897554*^-6}, {-8.070762831428064*^-6, -0.6, \
-8.132478638142032*^-6}, {-8.744175736375208*^-6, -0.6, \
-8.801170790085483*^-6}, {-9.472991033730625*^-6, -0.6, \
-9.525626330472663*^-6}, {-0.000010261826378629162`, -0.6, \
-0.00001031043540070326}, {-0.00001111567971522896, -0.6, \
-0.000011160570529700403`}, {-0.000012039961043251015`, -0.6, \
-0.00001208141803981509}, {-0.00001304052654496819, -0.6, \
-0.000013078812323689824`}, {-0.0000141237157257236, -0.6, \
-0.000014159072774364945`}, {-0.000015296391483507826`, -0.6, \
-0.00001532904392112678}, {-0.000016565983816266942`, -0.6, \
-0.00001659613857188567}, {-0.000017940536793788674`, -0.6, \
-0.00001796838488365336}, {-0.00001942875942691038, -0.6, \
-0.000019454477325420624`}, {-0.000021040080996614087`, -0.6, \
-0.00002106383161622855}, {-0.000022784710682482025`, -0.6, \
-0.0000228066444968091}, {-0.000024673702280973754`, -0.6, \
-0.000024693958301481556`}, {-0.000026719024302568726`, -0.6, \
-0.00002673773086020153}, {-0.000028933635736675955`, -0.6, \
-0.000028950911328779123`}, {-0.00003133156813753918, -0.6, \
-0.00003134752225468653}, {-0.00003392801460466383, -0.6, \
-0.000033942748344997835`}, {-0.00003673942601308858, -0.6, \
-0.000036753032707190084`}, {-0.000039783615203098854`, -0.6000000001091956, \
-0.00003979618107288167}, {-0.00004307986990793968, -0.6000000002372297, \
-0.00004309147454667639}, {-0.00004664907490048348, -0.6000000003873521, \
-0.00004665979182735772}, {-0.00005051384434162842, -0.6000000005633737, \
-0.000050523741469545095`}, {-0.00005469866509203078, -0.6000000007697623, \
-0.00005470780509935663}, {-0.000059230051794284675`, -0.6000000010117571, \
-0.00005923849259176804}, {-0.00006413671490969004, -0.6000000012955007, \
-0.00006414450999225902}, {-0.00006944974265579308, -0.6000000016281956, \
-0.00006945694136569936}, {-0.00007520279789342707, -0.6000000020182868, \
-0.00007520944582704246}, {-0.0000814323314920522, -0.6000000024756765, \
-0.00008143847072194383}, {-0.00008817781320316944, -0.6000000030119749, \
-0.0000881834826297993}, {-0.00009548198184281131, -0.6000000036407951, \
-0.00009548721731462756}, {-0.00010339111596788464`, -0.6000000043780991, \
-0.0001033959506077712}, {-0.00011195532716171946`, -0.6000000052426024, \
-0.00011195979153834072`}, {-0.00012122887751200564`, -0.6000000062562495, \
-0.00012123299984364999`}, {-0.000131270523425155, -0.6000000074447704, \
-0.00013127432973880797`}, {-0.00014214388789933322`, -0.6000000088383345, \
-0.00014214740217964277`}, {-0.00015391786362658585`, -0.6000000104723155, \
-0.00015392110796578882`}, {-0.0001666670494863301, -0.6000000123881903, \
-0.00016667004422963406`}, {-0.00018047222321229429`, -0.600000014634591, \
-0.0001804749870600886}, {-0.0001954208531826299, -0.6000000172685395, \
-0.00019542340330060305`}, {-0.00021160765260653234`, -0.6000000203568956, \
-0.00021161000473330916`}, {-0.0002291351796399001, -0.6000000239780534, \
-0.0002291373481390928}, {-0.0002481144871769335, -0.6000000282239316, \
-0.0002481164850906514}, {-0.00026866582646344745`, -0.6000000332023065, \
-0.00026866766556649444`}, {-0.00029091940900029435`, -0.6000000390395483, \
-0.00029092109983314953`}, {-0.0003150162315661229, -0.600000045883828, \
-0.0003150177834204011}, {-0.0003411089695466271, -0.6000000539088794, \
-0.00034111039045598926`}, {-0.0003693629442849313, -0.6000000633184085, \
-0.00036936424096443125`}, {-0.00039995717053814127`, -0.6000000743512643, \
-0.00039995834830163906`}, {-0.0004330854907048535, -0.6000000872875024, \
-0.000433086553332235}, {-0.00046895780300066075`, -0.6000001024554928, \
-0.00046895875254322777`}, {-0.0005078013913550303, -0.6000001202402561, \
-0.0005078022278813244}, {-0.0005498623654646476, -0.6000001410932356, \
-0.0005498630867278635}, {-0.0005954072201321105, -0.6000001655437578, \
-0.0005954078211265788}, {-0.0006447245237663512, -0.6000001942124674, \
-0.0006447249961423188}, {-0.0006981267467378309, -0.6000002278270823, \
-0.0006981270780475018}, {-0.0007559522411712853, -0.6000002672408649, \
-0.0007559524139138662}, {-0.0008185673847389719, -0.6000003134542811, \
-0.0008185673751237488}, {-0.0008863689020205878, -0.6000003676403952, \
-0.0008863686783871242}, {-0.0009597863781408396, -0.6000004311746461, \
-0.000959785898952402}, {-0.0010392849806192088`, -0.6000005056697599, \
-0.0010392841919074293`}, {-0.0011253684066843876`, -0.6000005930166858, \
-0.0011253672387818334`}, {-0.0012185820747090397`, -0.6000006954325934, \
-0.001218580438108279}, {-0.0013195165800089933`, -0.60000081551715, \
-0.0013195143600960673`}, {-0.0014288114369022456`, -0.6000009563185068, \
-0.0014288084872573087`}, {-0.0015471591307337615`, -0.6000011214106667, \
-0.0015471552646276945`}, {-0.001675309505559245, -0.6000013149841996, \
-0.0016753044851455625`}, {-0.001814074515285831, -0.6000015419526045, \
-0.0018140680378773205`}, {-0.001964333368390137, -0.6000018080770199, \
-0.0019643250490298113`}, {-0.002127038098822196, -0.6000021201124445, \
-0.002127027448150441}, {-0.0023032195984105355`, -0.6000024859791795, \
-0.0023032059945602068`}, {-0.002493994149010176, -0.600002914963841, \
-0.0024939768019234484`}, {-0.0027005704958149254`, -0.6000034179550413, \
-0.0027005484019314266`}, {-0.0029242575066792194`, -0.6000040077197176, \
-0.002924229391409132}, {-0.0031664724660345972`, -0.6000046992271143, \
-0.0031664367107121227`}, {-0.0034287500559997525`, -0.6000055100286346, \
-0.003428704605144422}, {-0.003712752081670872, -0.6000064607031901, \
-0.0037126943252414526`}, {-0.004020278002303554, -0.6000075753793362, \
-0.00402020462620424}, {-0.004353276335232484, -0.6000088823474224, \
-0.004353183131514129}, {-0.004713857004939682, -0.6000104147772627, \
-0.004713738630827498}, {-0.0051043047157049454`, -0.6000122115594995, \
-0.005104154387665155}, {-0.0055270934328219, -0.6000143182919532, \
-0.00552690253814807}, {-0.00598490206443786, -0.6000167884359109, \
-0.005984659668135527}, {-0.006480631443783328, -0.6000196846715852, \
-0.0064803236625259365`}, {-0.00701742271988955, -0.6000230804869885, \
-0.007017031927226803}, {-0.007598677273958814, -0.6000270620403302, \
-0.007598181091305535}, {-0.008228078288389862, -0.6000317303429052, \
-0.008227448304072604}, {-0.008909614106143132, -0.6000372038174611, \
-0.008908814249245101}, {-0.009647603529752547, -0.6000436212964042, \
-0.009646588005769173}, {-0.010446723221920928`, -0.6000511455351548, \
-0.010445433892214535`}, {-0.011312037383389062`, -0.6000599673287352, \
-0.011310400438675917`}, {-0.01224902989874062, -0.6000703103345806, \
-0.012246951636567695`}, {-0.013263639157135671`, -0.6000824367219221, \
-0.013261000622205813`}, {-0.014362295772771424`, -0.6000966537883013, \
-0.014358945954186738`}, {-0.015551963449328257`, -0.600113321707257, \
-0.015547710646661751`}, {-0.016840183253927613`, -0.600132862598479, \
-0.016834784119891557`}, {-0.018235121589417494`, -0.6001557711432843, \
-0.018228267224911523`}, {-0.019745622179319765`, -0.6001826270047381, \
-0.019736920489437374`}, {-0.02138126240778037, -0.600214109353765, \
-0.0213702157155964}, {-0.023152414387624182`, -0.6002510138508576, \
-0.02313839103453761}, {-0.02507031116343909, -0.6002942724881886, \
-0.025052509485710167`}, {-0.027147118493818456`, -0.6003449767597551, \
-0.027124521136136108`}, {-0.02939601269782262, -0.6004044046982475, \
-0.029367328682943394`}, {-0.031831265095709126`, -0.6004740523970931, \
-0.03179485638524201}, {-0.03446833362333235, -0.6005556707247809, \
-0.03442212204216916}, {-0.03732396225354338, -0.600651308035878, \
-0.0372653115639089}, {-0.04041628891647032, -0.6007633597881673, \
-0.04034185546089107}, {-0.04376496267346856, -0.6008946260861298, \
-0.043670506289790016`}, {-0.04739127096602093, -0.6010483782840924, \
-0.047271415726877715`}, {-0.05131827782931711, -0.6012284358921806, \
-0.05116620946958702}, {-0.05557097402771401, -0.6014392551260955, \
-0.055378057571407596`}, {-0.06017644013076547, -0.6016860305148295, \
-0.059931737064297455`}, {-0.06516402359588774, -0.6019748110100481, \
-0.06485368278227155}, {-0.07056553094415034, -0.6023126320004834, \
-0.07017202113007259}, {-0.07641543608932834, -0.6027076644872136, \
-0.07591658009737927}, {-0.08275110577717393, -0.6031693823702786, \
-0.08211886705408904}, {-0.08961304286704455, -0.6037087482649277, \
-0.08881200372790038}, {-0.09704514777573463, -0.6043384174156738, \
-0.09603060521940675}, {-0.10509499770839423`, -0.6050729579895004, \
-0.10381058692535289`}, {-0.11381414218837126`, -0.6059290841552637, \
-0.11218887982206785`}, {-0.12325841167773036`, -0.6069258957089894, \
-0.12120303076879287`}, {-0.13348823349541145`, -0.6080851143656708, \
-0.13089066047787917`}, {-0.1445689454492063, -0.6094313019659493, \
-0.14128874786489976`}, {-0.15657109216627507`, -0.6109920395028737, \
-0.15243270615569432`}, {-0.16957068151147064`, -0.6127980378782543, \
-0.16435521422516058`}, {-0.18364936814730592`, -0.614883141618563, \
-0.17708476744487353`}, {-0.19889451767969563`, -0.6172841756893741, \
-0.19064391765426422`}, {-0.2153990876496707, -0.6200405738534199, \
-0.20504718423236676`}, {-0.23326124114977265`, -0.6231937163843726, \
-0.22029864077996847`}, {-0.2525835864609278, -0.6267858982813025, \
-0.2363892181980594}, {-0.2734719150977387, -0.6308588509355388, \
-0.2532938183109917}, {-0.29603329706851034`, -0.6354517567239398, \
-0.2709684044103037}, {-0.32037339555734184`, -0.6405987347323949, \
-0.28934732416754794`}, {-0.3465928966060371, -0.6463258438486587, \
-0.30834121736228204`}, {-0.3747830272159649, -0.6526477501544622, \
-0.3278359466849235}, {-0.40502026868875546`, -0.6595643333574629, \
-0.3476930335070702}, {-0.4373605602047099, -0.6670576417947188, \
-0.3677520420213608}, {-0.4718335077139699, -0.6750897095367769, \
-0.3878351965829792}, {-0.5084373134554776, -0.6836017716170274, \
-0.40775422230466674`}, {-0.5471352463929651, -0.6925153073235991, \
-0.4273189968746196}, {-0.5878544080926286, -0.701735089816238, \
-0.44634717883850966`}, {-0.63048727517951, -0.7111540602598394, \
-0.4646736639694408}, {-0.6748960549239186, -0.7206594703177467, \
-0.48215864185008084`}, {-0.7209193885804647, -0.7301394685345591, \
-0.4986932369604885}, {-0.7683805290914458, -0.7394892362624055, \
-0.5142021730981294}, {-0.8170959272007016, -0.7486159258766312, \
-0.5286434556075843}, {-0.8668832207082563, -0.7574419554163094, \
-0.5420055540664233}, {-0.9175678815468312, -0.765906560870763, \
-0.5543028669578466}, {-0.9689881263760023, -0.7739657981361806, \
-0.5655703245027869}, {-1.0209980299922854`, -0.7815913634017235, \
-0.5758578793355794}, {-1.0734690267482794`, -0.7887686571532998, \
-0.5852254287169598}, {-1.1262901211038938`, -0.7954944822264072, \
-0.5937384856661192}, {-1.179367168207111, -0.8017746816873899, \
-0.6014647228922463}, {-1.232621559555233, -0.8076219238503443, \
-0.6084713757029057}, {-1.2859885888138909`, -0.8130537527810111, \
-0.6148234086727768}, {-1.3394157029048794`, -0.8180909539066501, \
-0.620582314499002}, {-1.3928607782892777`, -0.82275623759773, \
-0.6258054076036081}, {-1.4462905088862856`, -0.8270732157481214, \
-0.630545486707117}, {-1.4996789519571603`, -0.8310656326786542, \
-0.6348507602450599}, {-1.5530062503718065`, -0.8347568074469986, \
-0.6387649500409164}, {-1.6062575316212748`, -0.8381692460798011, \
-0.6423275087240843}, {-1.659421973225369, -0.8413243866317371, \
-0.6455739034847675}, {-1.7124920185959582`, -0.844242445542328, \
-0.6485359325016973}, {-1.765462725204141, -0.8469423394433714, \
-0.6512420509667386}, {-1.8183312267771385`, -0.849441661801446, \
-0.6537176915222284}, {-1.8710962923240113`, -0.8517566983115319, \
-0.6559855696467635}, {-1.9237579664645994`, -0.8539024687270406, \
-0.6580659685653056}, {-1.9763172774383662`, -0.8558927858571518, \
-0.6599770010394751}, {-2.028776001074845, -0.8577403248699039, \
-0.6617348472513002}, {-2.0811364707911064`, -0.859456697909826, \
-0.6633539691895789}, {-2.133401425284152, -0.861052530470936, \
-0.6648473026787796}, {-2.1855738869866808`, -0.8625375370484167, \
-0.6662264286005392}, {-2.2376570655554078`, -0.8639205944007712, \
-0.6675017250517394}, {-2.2896542816763032`, -0.8652098113508918, \
-0.6686825022351343}, {-2.3415689073207466`, -0.8664125944891388, \
-0.6697771218406421}, {-2.393404319292194, -0.8675357094535592, \
-0.6707931025836458}, {-2.4451638634856314`, -0.8685853376823988, \
-0.6717372134453601}, {-2.4968508277611483`, -0.8695671286856322, \
-0.6726155560257564}, {-2.548468421725533, -0.8704862479833461, \
-0.6734336372821901}, {-2.6000197620367302`, -0.8713474209230663, \
-0.6741964337933063}, {-2.6515078621078425`, -0.8721549726257796, \
-0.6749084485618756}, {-2.702935625300727, -0.8729128643291023, \
-0.6755737612539717}, {-2.754305840872904, -0.8736247264014989, \
-0.6761960726662108}, {-2.8056211820827617`, -0.8742938882978287, \
-0.6767787441177217}, {-2.856884205972839, -0.8749234057168868, \
-0.6773248323787283}, {-2.9080973544442874`, -0.8755160852082168, \
-0.6778371206724633}, {-2.9592629563113437`, -0.876074506459929, \
-0.6783181462207956}, {-3, -0.8765191104535806, -0.6787011292809516}}], 
    Line3DBox[{{
      0., -0.75, -1.*^-6}, {-9.63963064743451*^-8, -0.75, \
-1.0046354071927043`*^-6}, {-1.9368661135595524`*^-7, -0.75, \
-1.0185845398707027`*^-6}, {-2.9277219354065394`*^-7, -0.75, \
-1.0419768208726156`*^-6}, {-3.945722579769716*^-7, -0.75, \
-1.075028998784386*^-6}, {-5.000304178869435*^-7, -0.75, \
-1.118047491888238*^-6}, {-6.101244585261265*^-7, -0.75, \
-1.171431096447165*^-6}, {-7.25874418968571*^-7, -0.75, \
-1.2356750053097076`*^-6}, {-8.483536795257067*^-7, -0.75, \
-1.3113746753845724`*^-6}, {-9.786979083421743*^-7, -0.75, \
-1.3992317865490546`*^-6}, {-1.1181156443379474`*^-6, -0.75, \
-1.5000607458398724`*^-6}, {-1.2678991738375305`*^-6, -0.75, \
-1.614796472853357*^-6}, {-1.4294373446889662`*^-6, -0.75, \
-1.7445024769575526`*^-6}, {-1.6042270872713448`*^-6, -0.75, \
-1.8903817652468372`*^-6}, {-1.7938893749448946`*^-6, -0.75, \
-2.053786316291479*^-6}, {-2.000182426303128*^-6, -0.75, \
-2.2362311052043297`*^-6}, {-2.225018646927855*^-6, -0.75, \
-2.4394076219655577`*^-6}, {-2.4704828192016027`*^-6, -0.75, \
-2.665199139810544*^-6}, {-2.7388502928594414`*^-6, -0.75, \
-2.9156991936871426`*^-6}, {-3.032609198143228*^-6, -0.75, \
-3.1932299776221868`*^-6}, {-3.354482637941926*^-6, -0.75, \
-3.5003646809847865`*^-6}, {-3.7074547512577334`*^-6, -0.75, \
-3.839950575259027*^-6}, {-4.094797965599732*^-6, -0.75, \
-4.215135797456632*^-6}, {-4.5201032298130855`*^-6, -0.75, \
-4.629398640437455*^-6}, {-4.987313430624421*^-6, -0.75, \
-5.086579678426582*^-6}, {-5.500759892968026*^-6, -0.75, \
-5.590917423877726*^-6}, {-6.0652028434297415`*^-6, -0.75, \
-6.147087319231559*^-6}, {-6.685875017895697*^-6, -0.75, \
-6.760245596022907*^-6}, {-7.368530476186218*^-6, -0.75, \
-7.4360767796588286`*^-6}, {-8.119498050856585*^-6, -0.75, \
-8.18084628580741*^-6}, {-8.945739826372636*^-6, -0.75, \
-9.001458697990456*^-6}, {-9.854915676788622*^-6, -0.75, \
-9.90552178490242*^-6}, {-0.000010855454435045279`, -0.75, \
-0.000010901416875420529`}, {-0.000011956631857642982`, -0.75, \
-0.000011998376736394562`}, {-0.000013168656749468971`, -0.75, \
-0.000013206571037077934`}, {-0.000014502765521255142`, -0.75, \
-0.000014537200715991115`}, {-0.00001597132640164618, -0.75, \
-0.000016002601780958107`}, {-0.000017587954126325297`, -0.75, \
-0.0000176163596478643}, {-0.000019367636143653748`, -0.75, \
-0.00001939343510190799}, {-0.00002132687148216251, -0.75, \
-0.00002135030307379744}, {-0.00002348382381144244, -0.75, \
-0.000023505105273719663`}, {-0.000025858489793059814`, -0.7500000001004329, \
-0.000025877818420070944`}, {-0.000028472884473670578`, -0.7500000002221848, \
-0.000028490439431753182`}, {-0.00003135124533353748, -0.7500000003697812, \
-0.00003136718940426131}, {-0.000034520257080197857`, -0.750000000548708, \
-0.00003453473806586776}, {-0.00003800929896617459, -0.7500000007656158, \
-0.000038022451098092504`}, {-0.000041850717164656715`, -0.7500000010285669, \
-0.000041862662371352015`}, {-0.000046080124665008025`, -0.7500000013473349, \
-0.00004609097368412919}, {-0.000050736731420752723`, -0.7500000017337681, \
-0.000050746584833175586`}, {-0.0000558637078752209, -0.75000000220223, \
-0.00005587265700766191}, {-0.00006150858516042804, -0.7500000027701328, \
-0.00006151671295246705}, {-0.00006772369576068202, -0.750000003458585, \
-0.00006773107752871205}, {-0.00007456665867598787, -0.7500000042931757, \
-0.00007457336280604881}, {-0.00008210091359232288, -0.750000005304926, \
-0.00008210700217460718}, {-0.00009039630902298428, -0.7500000065314417, \
-0.0000904018384161286}, {-0.0000995297498489209, -0.7500000080183113, \
-0.000099534771210673}, {-0.00010958591031167732`, -0.7500000098208005, \
-0.00010959047003122244`}, {-0.00012065801897156642`, -0.750000012005906, \
-0.00012066215913244997`}, {-0.00013284872305687224`, -0.7500000146548464, \
-0.0001328524817622209}, {-0.00014627104004820567`, -0.7500000178660805, \
-0.00014627445177643565`}, {-0.0001610494054488071, -0.7500000217589667, \
-0.0001610525013500728}, {-0.00017732082640882735`, -0.7500000264782004, \
-0.0001773236345424802}, {-0.0001952361518861213, -0.750000032199191, \
-0.0001952386974229335}, {-0.00021496147112664204`, -0.7500000391345826, \
-0.0002149637765226108}, {-0.00023667965345885886`, -0.7500000475421572, \
-0.0002366817385466974}, {-0.0002605920436155512, -0.7500000577344168, \
-0.0002605939256805411}, {-0.00028692032837301375`, -0.750000070090198, \
-0.0002869220221307047}, {-0.0003159085917569124, -0.7500000850687535, \
-0.00031591010925730956`}, {-0.0003478255778841421, -0.7500001032268219, \
-0.0003478269283291974}, {-0.0003829671824402782, -0.7500001252393207, \
-0.0003829683718512321}, {-0.0004216591958571126, -0.7500001519244327, \
-0.00042166022658451105`}, {-0.00046426032363953653`, -0.7500001842740164, \
-0.0004642611936592275}, {-0.0005111655118405442, -0.7500002234904717, \
-0.0005111662137645295}, {-0.0005628096085141138, -0.7500002710314319, \
-0.0005628101282204665}, {-0.0006196713950802501, -0.7500003286639407, \
-0.0006196717098538723}, {-0.0006822780249882714, -0.7500003985301308, \
-0.0006822781009961197}, {-0.0007512099108136968, -0.7500004832268417, \
-0.0007512096997085619}, {-0.0008271061051054208, -0.7500005859021386, \
-0.0008271055394553264}, {-0.0009106702248499194, -0.7500007103723176, \
-0.0009106692120217102}, {-0.0010026769744906204`, -0.7500008612637462, \
-0.0010026753884498055`}, {-0.0011039793279505976`, -0.750001044184809, \
-0.001103976998304328}, {-0.0012155164362508324`, -0.7500012659343489, \
-0.0012155131335944826`}, {-0.0013383223340088977`, -0.750001534754349, \
-0.0013383177503556002`}, {-0.0014735355255291029`, -0.7500018606362416, \
-0.0014735292481699192`}, {-0.0016224095393325179`, -0.7500022556922253, \
-0.0016224010159295427`}, {-0.0017863245489481143`, -0.7500027346053835, \
-0.0017863130409307899`}, {-0.0019668001676661174`, -0.7500033151753216, \
-0.001966784688016003}, {-0.0021655095358248657`, -0.7500040189795867, \
-0.0021654887660241253`}, {-0.0023842948311694925`, -0.7500048721754271, \
-0.002384267010340591}, {-0.002625184345994646, -0.7500059064716538, \
-0.0026251471229227674`}, {-0.002890411289276908, -0.7500071603066699, \
-0.002890361524898331}, {-0.0031824344879655252`, -0.7500086802763714, \
-0.003182367991739322}, {-0.003503961179148294, -0.7500105228648676, \
-0.003503872357190696}, {-0.0038579721041339388`, -0.7500127565421729, \
-0.0038578534895886835`}, {-0.0042477491367420095`, -0.75001546430657, \
-0.004247590762983943}, {-0.004676905701468897, -0.7500187467657526, \
-0.004676694265556576}, {-0.0051494202629016935`, -0.7500227258706972, \
-0.00514913800911397}, {-0.0056696731960151825`, -0.7500275494402027, \
-0.005669296425844902}, {-0.006242487378043925, -0.7500333966430339, \
-0.006241984461728737}, {-0.006873172876742989, -0.7500404846396117, \
-0.006872501599668853}, {-0.0075675761473108305`, -0.7500490766274404, \
-0.007566680168957824}, {-0.00833213419135701, -0.7500594915853853, \
-0.008330938320225495}, {-0.009173934176362667, -0.7500721160732124, \
-0.009172338065364995}, {-0.010100779063443728`, -0.7500874185164935, \
-0.010098648798361042`}, {-0.011121259845216346`, -0.7501059664953875, \
-0.011118416723104848`}, {-0.012244835054518004`, -0.7501284476616378, \
-0.012241040614927725`}, {-0.013481918268973082`, -0.7501556950344352, \
-0.0134768543293085}, {-0.014843974406175998`, -0.7501887175760314, \
-0.014837216438049083`}, {-0.0163436256797885, -0.7502287371258615, \
-0.0163346073121532}, {-0.01799476816816048, -0.7502772329813829, \
-0.017982733870976344`}, {-0.01981270003399946, -0.7503359956586814, \
-0.019796642064716263`}, {-0.021814262525592296`, -0.7504071916495109, \
-0.02179283693317667}, {-0.02401799498600248, -0.7504934413160275, \
-0.023989409763278347`}, {-0.026444305194528686`, -0.7505979124300121, \
-0.0264061714188148}, {-0.02911565646114702, -0.7507244322659823, \
-0.029064790296817997`}, {-0.03205677298420537, -0.7508776215870693, \
-0.03198893252229461}, {-0.03529486505561157, -0.7510630542987815, \
-0.035204400859581535`}, {-0.0388598757425548, -0.7512874469536169, \
-0.038739267310217325`}, {-0.042784750669318874`, -0.7515588826113462, \
-0.04262399238175343}, {-0.047105732434497775`, -0.7518870737056411, \
-0.04689152142830114}, {-0.05186268097824308, -0.752283668401595, \
-0.05157734514459536}, {-0.057099420785712125`, -0.7527626042512567, \
-0.056719507095563976`}, {-0.06286411506335955, -0.7533405114817178, \
-0.06235853594668643}, {-0.06920966578574239, -0.7540371655903517, \
-0.06853727373256951}, {-0.07619413653555909, -0.7548759845515436, \
-0.07530056406593515}, {-0.0838811919949762, -0.7558845591919603, \
-0.08269475583878663}, {-0.09234054329816309, -0.7570951953690911, \
-0.09076696921977051}, {-0.10164838156044727`, -0.7585454326257897, \
-0.09956406264580067}, {-0.11188777191824967`, -0.7602784852201728, \
-0.10913123385914449`}, {-0.1231489663745037, -0.7623435274806347, \
-0.1195101877476301}, {-0.13552957470387525`, -0.764795716891003, \
-0.13073681305063126`}, {-0.14913450807920045`, -0.7676958175193715, \
-0.14283833459224166`}, {-0.16407558045163753`, -0.7711092585701727, \
-0.15582995438986358`}, {-0.1804706207207978, -0.7751044471813606, \
-0.16971107043325034`}, {-0.19844192064666258`, -0.7797501650300689, \
-0.18446127008798627`}, {-0.21811383064896728`, -0.7851119326698094, \
-0.20003643286024547`}, {-0.23960933513142887`, -0.7912473417344731, \
-0.21636542884099644`}, {-0.2630455114456545, -0.7982005431487837, \
-0.23334803073640312`}, {-0.2885279199424485, -0.8059963289722204, \
-0.2508547164639715}, {-0.31614418996749916`, -0.8146345133455176, \
-0.2687289638684537}, {-0.3459573322700006, -0.8240855241501497, \
-0.2867923810380007}, {-0.37799955832478116`, -0.8342881600501544, \
-0.30485257447158054`}, {-0.41226752849786213`, -0.8451502653351495, \
-0.3227131085091921}, {-0.44871989469631524`, -0.8565526175283019, \
-0.34018440294732893`}, {-0.4872777123490606, -0.8683557064675193, \
-0.35709412798986767`}, {-0.527827822619431, -0.8804084922688028, \
-0.37329570842600507`}, {-0.570228781303068, -0.892557858288323, \
-0.38867394122269094`}, {-0.6143184951363705, -0.9046574372925326, \
-0.4031473316884553}, {-0.659922532853628, -0.9165747656703259, \
-0.4166673653176926}, {-0.7068621303666218, -0.9281961829527052, \
-0.42921538341476356`}, {-0.7549611451298458, -0.939429376974665, \
-0.4407979390689591}, {-0.8040515309970246, -0.9502038504934983, \
-0.4514414922917693}, {-0.853977206144806, -0.9604697969742446, \
-0.4611871362023605}, {-0.904596414082483, -0.9701959309970627, \
-0.470085819716601}, {-0.9557828131921808, -0.97936676810116, \
-0.47819431528493866`}, {-1.007425584236075, -0.9879797427227013, \
-0.48557201011925333`}, {-1.0594288414664417`, -0.9960424333490002, \
-0.49227848621474796`}, {-1.111710596085203, -1.0035700568264905`, \
-0.4983717919571943}, {-1.1642014703744423`, -1.0105833102000292`, \
-0.5039072831230246}, {-1.2168433096213938`, -1.0171065801378647`, \
-0.5089369101502219}, {-1.269587793841656, -1.0231665034784754`, \
-0.5135088407872775}, {-1.3223951149390305`, -1.028790842519112, \
-0.5176673250425503}, {-1.3752327575031198`, -1.0340076302346608`, \
-0.5214527281139778}, {-1.4280744018607807`, -1.038844539456191, \
-0.5249016742003114}, {-1.4808989547397315`, -1.0433284330370245`, \
-0.5280472587165381}, {-1.5336897044415962`, -1.0474850570682146`, \
-0.5309192982261958}, {-1.5864335924268929`, -1.0513388449309364`, \
-0.5335445965618761}, {-1.63912059062087, -1.0549128056049748`, \
-0.5359472125158095}, {-1.6917431727503394`, -1.058228474779078, \
-0.5381487195715767}, {-1.7442958680324683`, -1.0613059117555028`, \
-0.5401684518144342}, {-1.796774886146825, -1.0641637288722436`, \
-0.5420237327428111}, {-1.8491778033537654`, -1.066819143222706, \
-0.5437300854842706}, {-1.901503300693319, -1.069288042910251, \
-0.5453014241124867}, {-1.9537509462944418`, -1.0715850620223855`, \
-0.5467502265330099}, {-2.005921014876523, -1.0737236600334956`, \
-0.5480876898784803}, {-2.058014338496012, -1.0757162025250782`, \
-0.5493238696195406}, {-2.1100321834636824`, -1.077574041017101, \
-0.5504678037220748}, {-2.1619761491277116`, -1.0793075903909959`, \
-0.5515276232119367}, {-2.213848084887295, -1.0809264029011416`, \
-0.5525106504785657}, {-2.265650022377944, -1.0824392381556878`, \
-0.553423486582273}, {-2.317384120262009, -1.0838541287295775`, \
-0.5542720887426624}, {-2.369052619476023, -1.0851784412766603`, \
-0.5550618390885546}, {-2.420657807139703, -1.0864189331525624`, \
-0.5557976056501318}, {-2.4722019876288757`, -1.0875818046601204`, \
-0.556483796476435}, {-2.52368745956425, -1.0886727470959032`, \
-0.5571244076686325}, {-2.575116497677092, -1.089696986818328, \
-0.5577230660332301}, {-2.6264913386877073`, -1.0906593255816914`, \
-0.5582830669803348}, {-2.6778141704786385`, -1.0915641773911442`, \
-0.5588074082204258}, {-2.7290871239662597`, -1.0924156021349962`, \
-0.5592988197486642}, {-2.7803122671759493`, -1.0932173362456339`, \
-0.5597597905482261}, {-2.8314916011105464`, -1.093972820630863, \
-0.560192592392981}, {-2.882627057072179, -1.0946852261052578`, \
-0.5605993010845253}, {-2.9337204951561024`, -1.0953574765372365`, \
-0.5609818154185535}, {-2.984773703683918, -1.0959922699129396`, \
-0.5613418741402819}, {-3, -1.0961815930194918`, -0.5614492593751441}}], 
    Line3DBox[{{
      0., -0.8999999999999999, -1.*^-6}, {-1.465698823428751*^-7, \
-0.8999999999999999, -1.0106843457002216`*^-6}, {-2.962716132545117*^-7, \
-0.8999999999999999, -1.0429655740649054`*^-6}, {-4.523043253880178*^-7, \
-0.8999999999999999, -1.0975334615932973`*^-6}, {-6.180022658837846*^-7, \
-0.8999999999999999, -1.1755540173520624`*^-6}, {-7.969059631159191*^-7, \
-0.8999999999999999, -1.2786945199104919`*^-6}, {-9.928385247413383*^-7, \
-0.8999999999999999, -1.4091588268505606`*^-6}, {-1.2099864386585537`*^-6, \
-0.8999999999999999, -1.5697349821063224`*^-6}, {-1.452990187185515*^-6, \
-0.8999999999999999, -1.7638540249057294`*^-6}, {-1.7270421258603356`*^-6, \
-0.8999999999999999, -1.995664229217233*^-6}, {-2.0379985252006594`*^-6, \
-0.8999999999999999, -2.27011890837035*^-6}, {-2.3925040374707387`*^-6, \
-0.8999999999999999, -2.5930828060027324`*^-6}, {-2.7981340704073425`*^-6, \
-0.8999999999999999, -2.971457080427524*^-6}, {-3.263556290598541*^-6, \
-0.8999999999999999, -3.4133271140037162`*^-6}, {-3.798716013221317*^-6, \
-0.8999999999999999, -3.928135130751879*^-6}, {-4.415048904742475*^-6, \
-0.8999999999999999, -4.52688178142071*^-6}, {-5.12572507030871*^-6, \
-0.8999999999999999, -5.222361478178697*^-6}, {-5.945930650766179*^-6, \
-0.8999999999999999, -6.02943562787205*^-6}, {-6.893192316764313*^-6, \
-0.8999999999999999, -6.9653502103332345`*^-6}, {-7.987751676693452*^-6, \
-0.8999999999999999, -8.050104410339301*^-6}, {-9.252997952341795*^-6, \
-0.8999999999999999, -9.306877832068441*^-6}, {-0.000010715967605819572`, \
-0.8999999999999999, -0.000010762525980325966`}, {-0.000012407922199866816`, \
-0.8999999999999999, -0.00001244815399544828}, {-0.000014365016435613169`, \
-0.9000000001240995, -0.00001439978130316071}, {-0.000016629070618201228`, \
-0.9000000002902985, -0.00001665911140813307}, {-0.000019248464347268406`, \
-0.9000000005128784, -0.000019274422986232753`}, {-0.000022279170328160028`, \
-0.9000000008109659, -0.00002230160152237324}, {-0.00002578595044016695, \
-0.9000000012101756, -0.000025805333490166334`}, {-0.00002984373956993924, \
-0.9000000017448123, -0.000029860488645684583`}, {-0.00003453924689364828, \
-0.9000000024608177, -0.00003455371985372336}, {-0.00003997280869814209, \
-0.9000000034197188, -0.00003998531476233666}, {-0.00004626053246898117, \
-0.9000000047039146, -0.000046271338756084996`}, {-0.000053536777880838855`, \
-0.9000000064237575, -0.000053546115159145205`}, {-0.00006195702791390615, \
-0.9000000087270351, -0.000061965095476414}, {-0.00007170121128199128, \
-0.90000001181167, -0.00007170818116847847}, {-0.00008297754725960348, \
-0.9000000159427275, -0.00008298356784567422}, {-0.00009602699500270876, \
-0.900000021475193, -0.00009603219408272723}, {-0.00011112840250803374`, \
-0.9000000288844757, -0.00011113288983837191`}, {-0.00012860446515882792`, \
-0.9000000388072614, -0.00012860833455496663`}, {-0.00014882862123586239`, \
-0.9000000520962226, -0.00014883195217412997`}, {-0.00017223303170731967`, \
-0.9000000698932891, -0.00017223589039690017`}, {-0.00019931781480918477`, \
-0.9000000937277741, -0.0001993202546342679}, {-0.00023066173272786548`, \
-0.9000001256477881, -0.00023066379388226772`}, {-0.00026693455871396824`, \
-0.900000168396231, -0.0002669362667383926}, {-0.00030891138887053645`, \
-0.9000002256464872, -0.0003089127515869075}, {-0.000357489204361981, \
-0.9000003023180722, -0.00035749020644431707`}, {-0.0004137060378612305, \
-0.9000004049993533, -0.00041370663184000893`}, {-0.0004787631536514389, \
-0.9000005425136618, -0.00047876324546219224`}, {-0.0005540507151041467, \
-0.9000007266774315, -0.00055405014125534}, {-0.0006411774876608856, \
-0.9000009733154916, -0.0006411759794642606}, {-0.0007420052114676562, \
-0.9000013036207218, -0.000742002339281995}, {-0.0008586883773109723, \
-0.9000017459748407, -0.0008586834638416047}, {-0.0009937202544731398, \
-0.9000023383866713, -0.000993712240167018}, {-0.0011499861520105335`, \
-0.9000031317571955, -0.0011499733862325614`}, {-0.0013308250483773448`, \
-0.9000041942515874, -0.0013308049656080999`}, {-0.001540100901399345, \
-0.9000056171532406, -0.0015400695192741615`}, {-0.001782285154734713, \
-0.9000075227016112, -0.0017822362960301507`}, {-0.0020625521920063826`, \
-0.9000100745852097, -0.002062476278897225}, {-0.002386889759947074, \
-0.900013491987496, -0.0023867719455445305`}, {-0.002762226691656061, \
-0.9000180683856399, -0.0027620439648329016`}, {-0.0031965806150993283`, \
-0.9000241967049589, -0.003196297314861797}, {-0.003699228734783367, \
-0.900032402968037, -0.0036987896013242626`}, {-0.004280905230008388, \
-0.9000433912896321, -0.004280224641368071}, {-0.004954029323672025, \
-0.9000581040114911, -0.004952974627654946}, {-0.00573296864086906, \
-0.9000778020150245, -0.0057313343499476}, {-0.00663434309111738, \
-0.9001041718815416, -0.006631810946242317}, {-0.007677375158079984, \
-0.9001394686944053, -0.0076734523532692046`}, {-0.008884293138378897, \
-0.9001867060151131, -0.008878216825658966}, {-0.010280794486388502`, \
-0.9002499080407276, -0.01027138428445006}, {-0.011896576909226648`, \
-0.9003344432676268, -0.01188200737040854}, {-0.013765945074690636`, \
-0.9004474641778494, -0.013743395220974033`}, {-0.015928500518401417`, \
-0.9005984833881584, -0.01589361515606632}, {-0.018429921208707768`, \
-0.9008001228639454, -0.01837598524163044}, {-0.021322834697999567`, \
-0.9010690780456014, -0.021239512232852205`}, {-0.02466778402078236, \
-0.9014273407580807, -0.02453920239952535}, {-0.02853427725206294, \
-0.9019037193970307, -0.02833613483352653}, {-0.03300189813296203, \
-0.9025356751375196, -0.03269713648503844}, {-0.03816143396725662, \
-0.9033714481770784, -0.03769383663094056}, {-0.044115945024829795`, \
-0.9044723640308479, -0.043400813475674704`}, {-0.050981653680620624`, \
-0.9059150712763276, -0.04989249697342}, {-0.05888846931131413, \
-0.9077932604842719, -0.05723849829510074}, {-0.06797988850307982, \
-0.9102181647022204, -0.06549715790273677}, {-0.07841193074024518, \
-0.9133169092275373, -0.07470741216267938}, {-0.09035071524048378, \
-0.917227698317479, -0.08487961632050624}, {-0.10396830366156465`, \
-0.922091093586123, -0.09598667321707381}, {-0.11943658755509501`, \
-0.9280374165592626, -0.10795747213590348`}, {-0.13691933113123209`, \
-0.9351715556332953, -0.12067484664279797`}, {-0.15656295981693966`, \
-0.9435577807490064, -0.1339796438067071}, {-0.17848717485139987`, \
-0.9532078936703905, -0.1476810353190579}, {-0.20277676037689074`, \
-0.9640756101950395, -0.16157140773259085`}, {-0.22947586218018515`, \
-0.9760585060813644, -0.17544287504230816`}, {-0.25858555295149754`, \
-0.9890068434545266, -0.18910225896367977`}, {-0.2900648357396278, \
-1.0027370226280237`, -0.20238224451827572`}, {-0.32383462257929163`, \
-1.0170468057408006`, -0.2151477803131333}, {-0.35978383591155944`, \
-1.0317297869486466`, -0.22729801740044914`}, {-0.39777666064060113`, \
-1.0465874275988705`, -0.2387648121558621}, {-0.4376600655845333, \
-1.061437893770102, -0.24950903642904193`}, {-0.4792709182512726, \
-1.076121656874798, -0.2595158092630929}, {-0.5224422520570962, \
-1.0905042623490506`, -0.26878948238627004`}, {-0.5670084572510616, \
-1.1044768703134067`, -0.2773489134659866}, {-0.6128093320139911, \
-1.1179552014762626`, -0.2852233148668189}, {-0.6596930441290106, \
-1.1308774552152234`, -0.292448790396325}, {-0.7075181222568138, \
-1.1432016592313916`, -0.29906556185700206`}, {-0.7561546291428581, \
-1.1549027954047972`, -0.3051158257936424}, {-0.8054846773397217, \
-1.165969942530749, -0.3106421529274213}, {-0.8554024401895737, \
-1.1764035910283397`, -0.3156863356907166}, {-0.9058137938697337, \
-1.1862132188928423`, -0.32028859391631787`}, {-0.9566357052966055, \
-1.195415170380532, -0.3244870590934945}, {-1.0077954589681972`, \
-1.2040308461384672`, -0.328317470001516}, {-1.0592297954446077`, \
-1.2120851924383398`, -0.3318130248781381}, {-1.1108840162008304`, \
-1.219605464827354, -0.3350043465096148}, {-1.1627110944642247`, \
-1.2266202353410531`, -0.3379195262971232}, {-1.2146708193830538`, \
-1.2331586104355627`, -0.3405842213765883}, {-1.2667289912378465`, \
-1.2392496274835398`, -0.3430217853474096}, {-1.318856678063257, \
-1.2449217999476523`, -0.3452534182884984}, {-1.3710295386168845`, \
-1.2502027844364596`, -0.3472983257213497}, {-1.423227212745956, \
-1.2551191462507127`, -0.3491738792276168}, {-1.4754327775316058`, \
-1.2596962034189954`, -0.35089577372947606`}, {-1.527632265849533, \
-1.2639579324075316`, -0.3524781781544887}, {-1.5798142429400102`, \
-1.267926921567634, -0.35393387746464006`}, {-1.6319694360407797`, \
-1.2716243609133713`, -0.3552744049383825}, {-1.684090411955331, \
-1.2750700589973472`, -0.35651016423943627`}, {-1.7361712974929326`, \
-1.278282479492327, -0.35765054125302603`}, {-1.7882075379403666`, \
-1.2812787916213346`, -0.3587040059703496}, {-1.8401956890458868`, \
-1.2840749298445386`, -0.3596782048945873}, {-1.8921332383683744`, \
-1.2866856592444689`, -0.3605800445564112}, {-1.9440184522373691`, \
-1.2891246438869055`, -0.3614157667861095}, {-1.9958502449611324`, \
-1.2914045161052272`, -0.3621910164097926}, {-2.0476280672961544`, \
-1.2935369451894363`, -0.36291090203103693`}, {-2.099351811544038, \
-1.295532704382095, -0.3635800505357856}, {-2.1510217309658364`, \
-1.2974017354129261`, -0.36420265592392004`}, {-2.2026383714977418`, \
-1.2991532100594188`, -0.3647825230303222}, {-2.254202514015423, \
-1.3007955884170563`, -0.3653231066547757}, {-2.305715125628342, \
-1.3023366737117612`, -0.36582754657597333`}, {-2.357177318691856, \
-1.3037836635986522`, -0.36629869888174615`}, {-2.408590316406007, \
-1.3051431979732133`, -0.3667391640063784}, {-2.4599554240279806`, \
-1.3064214033799055`, -0.36715131182712607`}, {-2.5112740048626665`, \
-1.307623934144267, -0.36753730413612273`}, {-2.5625474603148524`, \
-1.3087560103817746`, -0.3678991147708593}, {-2.6137772133895205`, \
-1.3098224530534333`, -0.368238547656358}, {-2.6649646951154646`, \
-1.310827716246816, -0.368557252984926}, {-2.7161113334438145`, \
-1.3117759168641185`, -0.36885674173482497`}, {-2.7672185442386636`, \
-1.3126708618973133`, -0.36913839870714826`}, {-2.8182877240332926`, \
-1.313516073465918, -0.3694034942404596}, {-2.8693202442737054`, \
-1.3143148117861874`, -0.3696531947451235}, {-2.9203174468125033`, \
-1.3150700962324273`, -0.3698885721835448}, {-2.971280640451431, \
-1.3157847246421643`, -0.3701106126085528}, {-3, -1.3161874401860187`, \
-0.37023573935875814`}}], 
    Line3DBox[{{0., -1.000001, 
      0.}, {-0.0011312323423716627`, -1.0032898250994993`, 
      0.}, {-0.0070020263912524815`, -1.0058736690197863`, 
      0.}, {-0.01516856240356814, -1.011046050957896, 
      0.}, {-0.026025492597341653`, -1.0182304014537078`, 
      0.}, {-0.03963470155667449, -1.0271707885512913`, 
      0.}, {-0.05598296480284253, -1.037672389672608, 
      0.}, {-0.07502843801875392, -1.0495442357249523`, 
      0.}, {-0.09671088599000162, -1.0625898168231476`, 
      0.}, {-0.12095454840421604`, -1.0766085187990855`, 
      0.}, {-0.1476694336193151, -1.0913997852710215`, 
      0.}, {-0.1767525082673613, -1.1067677334295511`, 
      0.}, {-0.20808918496792728`, -1.1225254102317272`, 
      0.}, {-0.24155517228390255`, -1.1384983478641602`, 
      0.}, {-0.2770186214205868, -1.1545272796254027`, 
      0.}, {-0.31434245274734324`, -1.1704699883125536`, 
      0.}, {-0.3533867317507632, -1.186202329278039, 
      0.}, {-0.39401097210064256`, -1.2016185156582764`, 
      0.}, {-0.4360762639452556, -1.2166307802246765`, 
      0.}, {-0.4794471520017683, -1.2311685405832273`, 
      0.}, {-0.5239932158160809, -1.2451771951713921`, 
      0.}, {-0.5695903304691667, -1.258616669658633, 
      0.}, {-0.6161216079709821, -1.2714598197743088`, 
      0.}, {-0.6634780366182957, -1.2836907797777175`, 
      0.}, {-0.7115588475200119, -1.295303327827025, 
      0.}, {-0.7602716446973695, -1.3062993219763022`, 
      0.}, {-0.8095323383668719, -1.3166872445179647`, 
      0.}, {-0.8592649210781389, -1.3264808785344986`, 
      0.}, {-0.909401124182561, -1.3356981291099805`, 
      0.}, {-0.9598799884452605, -1.3443599926896337`, 
      0.}, {-1.0106473781455716`, -1.3524896713923698`, 
      0.}, {-1.0616554632558046`, -1.3601118243967103`, 
      0.}, {-1.1128621896174355`, -1.3672519455054861`, 
      0.}, {-1.1642307526954905`, -1.3739358543138813`, 
      0.}, {-1.2157290866306674`, -1.3801892877450368`, 
      0.}, {-1.2673293769911262`, -1.3860375788015873`, 
      0.}, {-1.3190076028621371`, -1.3915054099788293`, 
      0.}, {-1.3707431116747844`, -1.396616629709743, 
      0.}, {-1.422518228415169, -1.4013941213200645`, 
      0.}, {-1.4743178995123336`, -1.4058597151562395`, 
      0.}, {-1.5261293707124612`, -1.4100341357344917`, 
      0.}, {-1.5779418975467678`, -1.4139369768942782`, 
      0.}, {-1.6297464865339826`, -1.4175866989922494`, 
      0.}, {-1.6815356649751894`, -1.4210006431259425`, 
      0.}, {-1.733303277056194, -1.424195058222766, 
      0.}, {-1.7850443039347397`, -1.4271851375694267`, 
      0.}, {-1.836754705527748, -1.4299850619946273`, 
      0.}, {-1.8884312818041131`, -1.4326080474612573`, 
      0.}, {-1.9400715515133227`, -1.4350663952825506`, 
      0.}, {-1.9916736464254339`, -1.4373715435594916`, 
      0.}, {-2.0432362193133344`, -1.4395341187537096`, 
      0.}, {-2.094758364066164, -1.441563986570333, 
      0.}, {-2.1462395464779127`, -1.4434703015371315`, 
      0.}, {-2.1976795444038957`, -1.4452615548373213`, 
      0.}, {-2.2490783961176892`, -1.4469456200902573`, 
      0.}, {-2.3004363558308767`, -1.4485297968826982`, 
      0.}, {-2.3517538554569435`, -1.450020851938372, 
      0.}, {-2.4030314718087946`, -1.4514250578794132`, 
      0.}, {-2.454269898516879, -1.4527482295834973`, 
      0.}, {-2.505469922042308, -1.4539957581781113`, 
      0.}, {-2.5566324012372594`, -1.4551726427409093`, 
      0.}, {-2.607758249974119, -1.456283519794529, 
      0.}, {-2.6588484224259448`, -1.457332690697312, 
      0.}, {-2.709903900634728, -1.4583241470394408`, 
      0.}, {-2.7609256840512937`, -1.459261594158208, 
      0.}, {-2.8119147807721965`, -1.4601484728873975`, 
      0.}, {-2.8628722002353113`, -1.4609879796547678`, 
      0.}, {-2.913798947167554, -1.4617830850390348`, 
      0.}, {-2.964696016605837, -1.4625365508939467`, 
      0.}, {-3, -1.4630591811027869`, 0.}}]}, {
    Line3DBox[{{0., 1.000001, 0.}, {0.0011312323423716627`, 
      1.0032898250994993`, 0.}, {0.0070020263912524815`, 1.0058736690197863`, 
      0.}, {0.01516856240356814, 1.011046050957896, 0.}, {
      0.026025492597341653`, 1.0182304014537078`, 0.}, {0.03963470155667449, 
      1.0271707885512913`, 0.}, {0.05598296480284253, 1.037672389672608, 
      0.}, {0.07502843801875392, 1.0495442357249523`, 0.}, {
      0.09671088599000162, 1.0625898168231476`, 0.}, {0.12095454840421604`, 
      1.0766085187990855`, 0.}, {0.1476694336193151, 1.0913997852710215`, 
      0.}, {0.1767525082673613, 1.1067677334295511`, 0.}, {
      0.20808918496792728`, 1.1225254102317272`, 0.}, {0.24155517228390255`, 
      1.1384983478641602`, 0.}, {0.2770186214205868, 1.1545272796254027`, 
      0.}, {0.31434245274734324`, 1.1704699883125536`, 0.}, {
      0.3533867317507632, 1.186202329278039, 0.}, {0.39401097210064256`, 
      1.2016185156582764`, 0.}, {0.4360762639452556, 1.2166307802246765`, 
      0.}, {0.4794471520017683, 1.2311685405832273`, 0.}, {0.5239932158160809,
       1.2451771951713921`, 0.}, {0.5695903304691667, 1.258616669658633, 
      0.}, {0.6161216079709821, 1.2714598197743088`, 0.}, {0.6634780366182957,
       1.2836907797777175`, 0.}, {0.7115588475200119, 1.295303327827025, 
      0.}, {0.7602716446973695, 1.3062993219763022`, 0.}, {0.8095323383668719,
       1.3166872445179647`, 0.}, {0.8592649210781389, 1.3264808785344986`, 
      0.}, {0.909401124182561, 1.3356981291099805`, 0.}, {0.9598799884452605, 
      1.3443599926896337`, 0.}, {1.0106473781455716`, 1.3524896713923698`, 
      0.}, {1.0616554632558046`, 1.3601118243967103`, 0.}, {
      1.1128621896174355`, 1.3672519455054861`, 0.}, {1.1642307526954905`, 
      1.3739358543138813`, 0.}, {1.2157290866306674`, 1.3801892877450368`, 
      0.}, {1.2673293769911262`, 1.3860375788015873`, 0.}, {
      1.3190076028621371`, 1.3915054099788293`, 0.}, {1.3707431116747844`, 
      1.396616629709743, 0.}, {1.422518228415169, 1.4013941213200645`, 0.}, {
      1.4743178995123336`, 1.4058597151562395`, 0.}, {1.5261293707124612`, 
      1.4100341357344917`, 0.}, {1.5779418975467678`, 1.4139369768942782`, 
      0.}, {1.6297464865339826`, 1.4175866989922494`, 0.}, {
      1.6815356649751894`, 1.4210006431259425`, 0.}, {1.733303277056194, 
      1.424195058222766, 0.}, {1.7850443039347397`, 1.4271851375694267`, 
      0.}, {1.836754705527748, 1.4299850619946273`, 0.}, {1.8884312818041131`,
       1.4326080474612573`, 0.}, {1.9400715515133227`, 1.4350663952825506`, 
      0.}, {1.9916736464254339`, 1.4373715435594916`, 0.}, {
      2.0432362193133344`, 1.4395341187537096`, 0.}, {2.094758364066164, 
      1.441563986570333, 0.}, {2.1462395464779127`, 1.4434703015371315`, 
      0.}, {2.1976795444038957`, 1.4452615548373213`, 0.}, {
      2.2490783961176892`, 1.4469456200902573`, 0.}, {2.3004363558308767`, 
      1.4485297968826982`, 0.}, {2.3517538554569435`, 1.450020851938372, 
      0.}, {2.4030314718087946`, 1.4514250578794132`, 0.}, {2.454269898516879,
       1.4527482295834973`, 0.}, {2.505469922042308, 1.4539957581781113`, 
      0.}, {2.5566324012372594`, 1.4551726427409093`, 0.}, {2.607758249974119,
       1.456283519794529, 0.}, {2.6588484224259448`, 1.457332690697312, 0.}, {
      2.709903900634728, 1.4583241470394408`, 0.}, {2.7609256840512937`, 
      1.459261594158208, 0.}, {2.8119147807721965`, 1.4601484728873975`, 
      0.}, {2.8628722002353113`, 1.4609879796547678`, 0.}, {2.913798947167554,
       1.4617830850390348`, 0.}, {2.964696016605837, 1.4625365508939467`, 
      0.}, {3, 1.4630591811027869`, 0.}}], 
    Line3DBox[{{0., 0.8999999999999999, -1.*^-6}, {1.465698823428751*^-7, 
      0.8999999999999999, -1.0106843457002216`*^-6}, {2.962716132545117*^-7, 
      0.8999999999999999, -1.0429655740649054`*^-6}, {4.523043253880178*^-7, 
      0.8999999999999999, -1.0975334615932973`*^-6}, {6.180022658837846*^-7, 
      0.8999999999999999, -1.1755540173520624`*^-6}, {7.969059631159191*^-7, 
      0.8999999999999999, -1.2786945199104919`*^-6}, {9.928385247413383*^-7, 
      0.8999999999999999, -1.4091588268505606`*^-6}, {1.2099864386585537`*^-6,
       0.8999999999999999, -1.5697349821063224`*^-6}, {1.452990187185515*^-6, 
      0.8999999999999999, -1.7638540249057294`*^-6}, {1.7270421258603356`*^-6,
       0.8999999999999999, -1.995664229217233*^-6}, {2.0379985252006594`*^-6, 
      0.8999999999999999, -2.27011890837035*^-6}, {2.3925040374707387`*^-6, 
      0.8999999999999999, -2.5930828060027324`*^-6}, {2.7981340704073425`*^-6,
       0.8999999999999999, -2.971457080427524*^-6}, {3.263556290598541*^-6, 
      0.8999999999999999, -3.4133271140037162`*^-6}, {3.798716013221317*^-6, 
      0.8999999999999999, -3.928135130751879*^-6}, {4.415048904742475*^-6, 
      0.8999999999999999, -4.52688178142071*^-6}, {5.12572507030871*^-6, 
      0.8999999999999999, -5.222361478178697*^-6}, {5.945930650766179*^-6, 
      0.8999999999999999, -6.02943562787205*^-6}, {6.893192316764313*^-6, 
      0.8999999999999999, -6.9653502103332345`*^-6}, {7.987751676693452*^-6, 
      0.8999999999999999, -8.050104410339301*^-6}, {9.252997952341795*^-6, 
      0.8999999999999999, -9.306877832068441*^-6}, {0.000010715967605819572`, 
      0.8999999999999999, -0.000010762525980325966`}, {
      0.000012407922199866816`, 
      0.8999999999999999, -0.00001244815399544828}, {0.000014365016435613169`,
       0.9000000001240995, -0.00001439978130316071}, {
      0.000016629070618201228`, 
      0.9000000002902985, -0.00001665911140813307}, {0.000019248464347268406`,
       0.9000000005128784, -0.000019274422986232753`}, {
      0.000022279170328160028`, 
      0.9000000008109659, -0.00002230160152237324}, {0.00002578595044016695, 
      0.9000000012101756, -0.000025805333490166334`}, {0.00002984373956993924,
       0.9000000017448123, -0.000029860488645684583`}, {
      0.00003453924689364828, 0.9000000024608177, -0.00003455371985372336}, {
      0.00003997280869814209, 0.9000000034197188, -0.00003998531476233666}, {
      0.00004626053246898117, 
      0.9000000047039146, -0.000046271338756084996`}, {
      0.000053536777880838855`, 
      0.9000000064237575, -0.000053546115159145205`}, {0.00006195702791390615,
       0.9000000087270351, -0.000061965095476414}, {0.00007170121128199128, 
      0.90000001181167, -0.00007170818116847847}, {0.00008297754725960348, 
      0.9000000159427275, -0.00008298356784567422}, {0.00009602699500270876, 
      0.900000021475193, -0.00009603219408272723}, {0.00011112840250803374`, 
      0.9000000288844757, -0.00011113288983837191`}, {0.00012860446515882792`,
       0.9000000388072614, -0.00012860833455496663`}, {
      0.00014882862123586239`, 
      0.9000000520962226, -0.00014883195217412997`}, {0.00017223303170731967`,
       0.9000000698932891, -0.00017223589039690017`}, {
      0.00019931781480918477`, 0.9000000937277741, -0.0001993202546342679}, {
      0.00023066173272786548`, 
      0.9000001256477881, -0.00023066379388226772`}, {0.00026693455871396824`,
       0.900000168396231, -0.0002669362667383926}, {0.00030891138887053645`, 
      0.9000002256464872, -0.0003089127515869075}, {0.000357489204361981, 
      0.9000003023180722, -0.00035749020644431707`}, {0.0004137060378612305, 
      0.9000004049993533, -0.00041370663184000893`}, {0.0004787631536514389, 
      0.9000005425136618, -0.00047876324546219224`}, {0.0005540507151041467, 
      0.9000007266774315, -0.00055405014125534}, {0.0006411774876608856, 
      0.9000009733154916, -0.0006411759794642606}, {0.0007420052114676562, 
      0.9000013036207218, -0.000742002339281995}, {0.0008586883773109723, 
      0.9000017459748407, -0.0008586834638416047}, {0.0009937202544731398, 
      0.9000023383866713, -0.000993712240167018}, {0.0011499861520105335`, 
      0.9000031317571955, -0.0011499733862325614`}, {0.0013308250483773448`, 
      0.9000041942515874, -0.0013308049656080999`}, {0.001540100901399345, 
      0.9000056171532406, -0.0015400695192741615`}, {0.001782285154734713, 
      0.9000075227016112, -0.0017822362960301507`}, {0.0020625521920063826`, 
      0.9000100745852097, -0.002062476278897225}, {0.002386889759947074, 
      0.900013491987496, -0.0023867719455445305`}, {0.002762226691656061, 
      0.9000180683856399, -0.0027620439648329016`}, {0.0031965806150993283`, 
      0.9000241967049589, -0.003196297314861797}, {0.003699228734783367, 
      0.900032402968037, -0.0036987896013242626`}, {0.004280905230008388, 
      0.9000433912896321, -0.004280224641368071}, {0.004954029323672025, 
      0.9000581040114911, -0.004952974627654946}, {0.00573296864086906, 
      0.9000778020150245, -0.0057313343499476}, {0.00663434309111738, 
      0.9001041718815416, -0.006631810946242317}, {0.007677375158079984, 
      0.9001394686944053, -0.0076734523532692046`}, {0.008884293138378897, 
      0.9001867060151131, -0.008878216825658966}, {0.010280794486388502`, 
      0.9002499080407276, -0.01027138428445006}, {0.011896576909226648`, 
      0.9003344432676268, -0.01188200737040854}, {0.013765945074690636`, 
      0.9004474641778494, -0.013743395220974033`}, {0.015928500518401417`, 
      0.9005984833881584, -0.01589361515606632}, {0.018429921208707768`, 
      0.9008001228639454, -0.01837598524163044}, {0.021322834697999567`, 
      0.9010690780456014, -0.021239512232852205`}, {0.02466778402078236, 
      0.9014273407580807, -0.02453920239952535}, {0.02853427725206294, 
      0.9019037193970307, -0.02833613483352653}, {0.03300189813296203, 
      0.9025356751375196, -0.03269713648503844}, {0.03816143396725662, 
      0.9033714481770784, -0.03769383663094056}, {0.044115945024829795`, 
      0.9044723640308479, -0.043400813475674704`}, {0.050981653680620624`, 
      0.9059150712763276, -0.04989249697342}, {0.05888846931131413, 
      0.9077932604842719, -0.05723849829510074}, {0.06797988850307982, 
      0.9102181647022204, -0.06549715790273677}, {0.07841193074024518, 
      0.9133169092275373, -0.07470741216267938}, {0.09035071524048378, 
      0.917227698317479, -0.08487961632050624}, {0.10396830366156465`, 
      0.922091093586123, -0.09598667321707381}, {0.11943658755509501`, 
      0.9280374165592626, -0.10795747213590348`}, {0.13691933113123209`, 
      0.9351715556332953, -0.12067484664279797`}, {0.15656295981693966`, 
      0.9435577807490064, -0.1339796438067071}, {0.17848717485139987`, 
      0.9532078936703905, -0.1476810353190579}, {0.20277676037689074`, 
      0.9640756101950395, -0.16157140773259085`}, {0.22947586218018515`, 
      0.9760585060813644, -0.17544287504230816`}, {0.25858555295149754`, 
      0.9890068434545266, -0.18910225896367977`}, {0.2900648357396278, 
      1.0027370226280237`, -0.20238224451827572`}, {0.32383462257929163`, 
      1.0170468057408006`, -0.2151477803131333}, {0.35978383591155944`, 
      1.0317297869486466`, -0.22729801740044914`}, {0.39777666064060113`, 
      1.0465874275988705`, -0.2387648121558621}, {0.4376600655845333, 
      1.061437893770102, -0.24950903642904193`}, {0.4792709182512726, 
      1.076121656874798, -0.2595158092630929}, {0.5224422520570962, 
      1.0905042623490506`, -0.26878948238627004`}, {0.5670084572510616, 
      1.1044768703134067`, -0.2773489134659866}, {0.6128093320139911, 
      1.1179552014762626`, -0.2852233148668189}, {0.6596930441290106, 
      1.1308774552152234`, -0.292448790396325}, {0.7075181222568138, 
      1.1432016592313916`, -0.29906556185700206`}, {0.7561546291428581, 
      1.1549027954047972`, -0.3051158257936424}, {0.8054846773397217, 
      1.165969942530749, -0.3106421529274213}, {0.8554024401895737, 
      1.1764035910283397`, -0.3156863356907166}, {0.9058137938697337, 
      1.1862132188928423`, -0.32028859391631787`}, {0.9566357052966055, 
      1.195415170380532, -0.3244870590934945}, {1.0077954589681972`, 
      1.2040308461384672`, -0.328317470001516}, {1.0592297954446077`, 
      1.2120851924383398`, -0.3318130248781381}, {1.1108840162008304`, 
      1.219605464827354, -0.3350043465096148}, {1.1627110944642247`, 
      1.2266202353410531`, -0.3379195262971232}, {1.2146708193830538`, 
      1.2331586104355627`, -0.3405842213765883}, {1.2667289912378465`, 
      1.2392496274835398`, -0.3430217853474096}, {1.318856678063257, 
      1.2449217999476523`, -0.3452534182884984}, {1.3710295386168845`, 
      1.2502027844364596`, -0.3472983257213497}, {1.423227212745956, 
      1.2551191462507127`, -0.3491738792276168}, {1.4754327775316058`, 
      1.2596962034189954`, -0.35089577372947606`}, {1.527632265849533, 
      1.2639579324075316`, -0.3524781781544887}, {1.5798142429400102`, 
      1.267926921567634, -0.35393387746464006`}, {1.6319694360407797`, 
      1.2716243609133713`, -0.3552744049383825}, {1.684090411955331, 
      1.2750700589973472`, -0.35651016423943627`}, {1.7361712974929326`, 
      1.278282479492327, -0.35765054125302603`}, {1.7882075379403666`, 
      1.2812787916213346`, -0.3587040059703496}, {1.8401956890458868`, 
      1.2840749298445386`, -0.3596782048945873}, {1.8921332383683744`, 
      1.2866856592444689`, -0.3605800445564112}, {1.9440184522373691`, 
      1.2891246438869055`, -0.3614157667861095}, {1.9958502449611324`, 
      1.2914045161052272`, -0.3621910164097926}, {2.0476280672961544`, 
      1.2935369451894363`, -0.36291090203103693`}, {2.099351811544038, 
      1.295532704382095, -0.3635800505357856}, {2.1510217309658364`, 
      1.2974017354129261`, -0.36420265592392004`}, {2.2026383714977418`, 
      1.2991532100594188`, -0.3647825230303222}, {2.254202514015423, 
      1.3007955884170563`, -0.3653231066547757}, {2.305715125628342, 
      1.3023366737117612`, -0.36582754657597333`}, {2.357177318691856, 
      1.3037836635986522`, -0.36629869888174615`}, {2.408590316406007, 
      1.3051431979732133`, -0.3667391640063784}, {2.4599554240279806`, 
      1.3064214033799055`, -0.36715131182712607`}, {2.5112740048626665`, 
      1.307623934144267, -0.36753730413612273`}, {2.5625474603148524`, 
      1.3087560103817746`, -0.3678991147708593}, {2.6137772133895205`, 
      1.3098224530534333`, -0.368238547656358}, {2.6649646951154646`, 
      1.310827716246816, -0.368557252984926}, {2.7161113334438145`, 
      1.3117759168641185`, -0.36885674173482497`}, {2.7672185442386636`, 
      1.3126708618973133`, -0.36913839870714826`}, {2.8182877240332926`, 
      1.313516073465918, -0.3694034942404596}, {2.8693202442737054`, 
      1.3143148117861874`, -0.3696531947451235}, {2.9203174468125033`, 
      1.3150700962324273`, -0.3698885721835448}, {2.971280640451431, 
      1.3157847246421643`, -0.3701106126085528}, {
      3, 1.3161874401860187`, -0.37023573935875814`}}], 
    Line3DBox[{{0., 0.75, -1.*^-6}, {9.63963064743451*^-8, 
      0.75, -1.0046354071927043`*^-6}, {1.9368661135595524`*^-7, 
      0.75, -1.0185845398707027`*^-6}, {2.9277219354065394`*^-7, 
      0.75, -1.0419768208726156`*^-6}, {3.945722579769716*^-7, 
      0.75, -1.075028998784386*^-6}, {5.000304178869435*^-7, 
      0.75, -1.118047491888238*^-6}, {6.101244585261265*^-7, 
      0.75, -1.171431096447165*^-6}, {7.25874418968571*^-7, 
      0.75, -1.2356750053097076`*^-6}, {8.483536795257067*^-7, 
      0.75, -1.3113746753845724`*^-6}, {9.786979083421743*^-7, 
      0.75, -1.3992317865490546`*^-6}, {1.1181156443379474`*^-6, 
      0.75, -1.5000607458398724`*^-6}, {1.2678991738375305`*^-6, 
      0.75, -1.614796472853357*^-6}, {1.4294373446889662`*^-6, 
      0.75, -1.7445024769575526`*^-6}, {1.6042270872713448`*^-6, 
      0.75, -1.8903817652468372`*^-6}, {1.7938893749448946`*^-6, 
      0.75, -2.053786316291479*^-6}, {2.000182426303128*^-6, 
      0.75, -2.2362311052043297`*^-6}, {2.225018646927855*^-6, 
      0.75, -2.4394076219655577`*^-6}, {2.4704828192016027`*^-6, 
      0.75, -2.665199139810544*^-6}, {2.7388502928594414`*^-6, 
      0.75, -2.9156991936871426`*^-6}, {3.032609198143228*^-6, 
      0.75, -3.1932299776221868`*^-6}, {3.354482637941926*^-6, 
      0.75, -3.5003646809847865`*^-6}, {3.7074547512577334`*^-6, 
      0.75, -3.839950575259027*^-6}, {4.094797965599732*^-6, 
      0.75, -4.215135797456632*^-6}, {4.5201032298130855`*^-6, 
      0.75, -4.629398640437455*^-6}, {4.987313430624421*^-6, 
      0.75, -5.086579678426582*^-6}, {5.500759892968026*^-6, 
      0.75, -5.590917423877726*^-6}, {6.0652028434297415`*^-6, 
      0.75, -6.147087319231559*^-6}, {6.685875017895697*^-6, 
      0.75, -6.760245596022907*^-6}, {7.368530476186218*^-6, 
      0.75, -7.4360767796588286`*^-6}, {8.119498050856585*^-6, 
      0.75, -8.18084628580741*^-6}, {8.945739826372636*^-6, 
      0.75, -9.001458697990456*^-6}, {9.854915676788622*^-6, 
      0.75, -9.90552178490242*^-6}, {0.000010855454435045279`, 
      0.75, -0.000010901416875420529`}, {0.000011956631857642982`, 
      0.75, -0.000011998376736394562`}, {0.000013168656749468971`, 
      0.75, -0.000013206571037077934`}, {0.000014502765521255142`, 
      0.75, -0.000014537200715991115`}, {0.00001597132640164618, 
      0.75, -0.000016002601780958107`}, {0.000017587954126325297`, 
      0.75, -0.0000176163596478643}, {0.000019367636143653748`, 
      0.75, -0.00001939343510190799}, {0.00002132687148216251, 
      0.75, -0.00002135030307379744}, {0.00002348382381144244, 
      0.75, -0.000023505105273719663`}, {0.000025858489793059814`, 
      0.7500000001004329, -0.000025877818420070944`}, {
      0.000028472884473670578`, 
      0.7500000002221848, -0.000028490439431753182`}, {0.00003135124533353748,
       0.7500000003697812, -0.00003136718940426131}, {
      0.000034520257080197857`, 0.750000000548708, -0.00003453473806586776}, {
      0.00003800929896617459, 
      0.7500000007656158, -0.000038022451098092504`}, {
      0.000041850717164656715`, 
      0.7500000010285669, -0.000041862662371352015`}, {
      0.000046080124665008025`, 
      0.7500000013473349, -0.00004609097368412919}, {0.000050736731420752723`,
       0.7500000017337681, -0.000050746584833175586`}, {0.0000558637078752209,
       0.75000000220223, -0.00005587265700766191}, {0.00006150858516042804, 
      0.7500000027701328, -0.00006151671295246705}, {0.00006772369576068202, 
      0.750000003458585, -0.00006773107752871205}, {0.00007456665867598787, 
      0.7500000042931757, -0.00007457336280604881}, {0.00008210091359232288, 
      0.750000005304926, -0.00008210700217460718}, {0.00009039630902298428, 
      0.7500000065314417, -0.0000904018384161286}, {0.0000995297498489209, 
      0.7500000080183113, -0.000099534771210673}, {0.00010958591031167732`, 
      0.7500000098208005, -0.00010959047003122244`}, {0.00012065801897156642`,
       0.750000012005906, -0.00012066215913244997`}, {0.00013284872305687224`,
       0.7500000146548464, -0.0001328524817622209}, {0.00014627104004820567`, 
      0.7500000178660805, -0.00014627445177643565`}, {0.0001610494054488071, 
      0.7500000217589667, -0.0001610525013500728}, {0.00017732082640882735`, 
      0.7500000264782004, -0.0001773236345424802}, {0.0001952361518861213, 
      0.750000032199191, -0.0001952386974229335}, {0.00021496147112664204`, 
      0.7500000391345826, -0.0002149637765226108}, {0.00023667965345885886`, 
      0.7500000475421572, -0.0002366817385466974}, {0.0002605920436155512, 
      0.7500000577344168, -0.0002605939256805411}, {0.00028692032837301375`, 
      0.750000070090198, -0.0002869220221307047}, {0.0003159085917569124, 
      0.7500000850687535, -0.00031591010925730956`}, {0.0003478255778841421, 
      0.7500001032268219, -0.0003478269283291974}, {0.0003829671824402782, 
      0.7500001252393207, -0.0003829683718512321}, {0.0004216591958571126, 
      0.7500001519244327, -0.00042166022658451105`}, {0.00046426032363953653`,
       0.7500001842740164, -0.0004642611936592275}, {0.0005111655118405442, 
      0.7500002234904717, -0.0005111662137645295}, {0.0005628096085141138, 
      0.7500002710314319, -0.0005628101282204665}, {0.0006196713950802501, 
      0.7500003286639407, -0.0006196717098538723}, {0.0006822780249882714, 
      0.7500003985301308, -0.0006822781009961197}, {0.0007512099108136968, 
      0.7500004832268417, -0.0007512096997085619}, {0.0008271061051054208, 
      0.7500005859021386, -0.0008271055394553264}, {0.0009106702248499194, 
      0.7500007103723176, -0.0009106692120217102}, {0.0010026769744906204`, 
      0.7500008612637462, -0.0010026753884498055`}, {0.0011039793279505976`, 
      0.750001044184809, -0.001103976998304328}, {0.0012155164362508324`, 
      0.7500012659343489, -0.0012155131335944826`}, {0.0013383223340088977`, 
      0.750001534754349, -0.0013383177503556002`}, {0.0014735355255291029`, 
      0.7500018606362416, -0.0014735292481699192`}, {0.0016224095393325179`, 
      0.7500022556922253, -0.0016224010159295427`}, {0.0017863245489481143`, 
      0.7500027346053835, -0.0017863130409307899`}, {0.0019668001676661174`, 
      0.7500033151753216, -0.001966784688016003}, {0.0021655095358248657`, 
      0.7500040189795867, -0.0021654887660241253`}, {0.0023842948311694925`, 
      0.7500048721754271, -0.002384267010340591}, {0.002625184345994646, 
      0.7500059064716538, -0.0026251471229227674`}, {0.002890411289276908, 
      0.7500071603066699, -0.002890361524898331}, {0.0031824344879655252`, 
      0.7500086802763714, -0.003182367991739322}, {0.003503961179148294, 
      0.7500105228648676, -0.003503872357190696}, {0.0038579721041339388`, 
      0.7500127565421729, -0.0038578534895886835`}, {0.0042477491367420095`, 
      0.75001546430657, -0.004247590762983943}, {0.004676905701468897, 
      0.7500187467657526, -0.004676694265556576}, {0.0051494202629016935`, 
      0.7500227258706972, -0.00514913800911397}, {0.0056696731960151825`, 
      0.7500275494402027, -0.005669296425844902}, {0.006242487378043925, 
      0.7500333966430339, -0.006241984461728737}, {0.006873172876742989, 
      0.7500404846396117, -0.006872501599668853}, {0.0075675761473108305`, 
      0.7500490766274404, -0.007566680168957824}, {0.00833213419135701, 
      0.7500594915853853, -0.008330938320225495}, {0.009173934176362667, 
      0.7500721160732124, -0.009172338065364995}, {0.010100779063443728`, 
      0.7500874185164935, -0.010098648798361042`}, {0.011121259845216346`, 
      0.7501059664953875, -0.011118416723104848`}, {0.012244835054518004`, 
      0.7501284476616378, -0.012241040614927725`}, {0.013481918268973082`, 
      0.7501556950344352, -0.0134768543293085}, {0.014843974406175998`, 
      0.7501887175760314, -0.014837216438049083`}, {0.0163436256797885, 
      0.7502287371258615, -0.0163346073121532}, {0.01799476816816048, 
      0.7502772329813829, -0.017982733870976344`}, {0.01981270003399946, 
      0.7503359956586814, -0.019796642064716263`}, {0.021814262525592296`, 
      0.7504071916495109, -0.02179283693317667}, {0.02401799498600248, 
      0.7504934413160275, -0.023989409763278347`}, {0.026444305194528686`, 
      0.7505979124300121, -0.0264061714188148}, {0.02911565646114702, 
      0.7507244322659823, -0.029064790296817997`}, {0.03205677298420537, 
      0.7508776215870693, -0.03198893252229461}, {0.03529486505561157, 
      0.7510630542987815, -0.035204400859581535`}, {0.0388598757425548, 
      0.7512874469536169, -0.038739267310217325`}, {0.042784750669318874`, 
      0.7515588826113462, -0.04262399238175343}, {0.047105732434497775`, 
      0.7518870737056411, -0.04689152142830114}, {0.05186268097824308, 
      0.752283668401595, -0.05157734514459536}, {0.057099420785712125`, 
      0.7527626042512567, -0.056719507095563976`}, {0.06286411506335955, 
      0.7533405114817178, -0.06235853594668643}, {0.06920966578574239, 
      0.7540371655903517, -0.06853727373256951}, {0.07619413653555909, 
      0.7548759845515436, -0.07530056406593515}, {0.0838811919949762, 
      0.7558845591919603, -0.08269475583878663}, {0.09234054329816309, 
      0.7570951953690911, -0.09076696921977051}, {0.10164838156044727`, 
      0.7585454326257897, -0.09956406264580067}, {0.11188777191824967`, 
      0.7602784852201728, -0.10913123385914449`}, {0.1231489663745037, 
      0.7623435274806347, -0.1195101877476301}, {0.13552957470387525`, 
      0.764795716891003, -0.13073681305063126`}, {0.14913450807920045`, 
      0.7676958175193715, -0.14283833459224166`}, {0.16407558045163753`, 
      0.7711092585701727, -0.15582995438986358`}, {0.1804706207207978, 
      0.7751044471813606, -0.16971107043325034`}, {0.19844192064666258`, 
      0.7797501650300689, -0.18446127008798627`}, {0.21811383064896728`, 
      0.7851119326698094, -0.20003643286024547`}, {0.23960933513142887`, 
      0.7912473417344731, -0.21636542884099644`}, {0.2630455114456545, 
      0.7982005431487837, -0.23334803073640312`}, {0.2885279199424485, 
      0.8059963289722204, -0.2508547164639715}, {0.31614418996749916`, 
      0.8146345133455176, -0.2687289638684537}, {0.3459573322700006, 
      0.8240855241501497, -0.2867923810380007}, {0.37799955832478116`, 
      0.8342881600501544, -0.30485257447158054`}, {0.41226752849786213`, 
      0.8451502653351495, -0.3227131085091921}, {0.44871989469631524`, 
      0.8565526175283019, -0.34018440294732893`}, {0.4872777123490606, 
      0.8683557064675193, -0.35709412798986767`}, {0.527827822619431, 
      0.8804084922688028, -0.37329570842600507`}, {0.570228781303068, 
      0.892557858288323, -0.38867394122269094`}, {0.6143184951363705, 
      0.9046574372925326, -0.4031473316884553}, {0.659922532853628, 
      0.9165747656703259, -0.4166673653176926}, {0.7068621303666218, 
      0.9281961829527052, -0.42921538341476356`}, {0.7549611451298458, 
      0.939429376974665, -0.4407979390689591}, {0.8040515309970246, 
      0.9502038504934983, -0.4514414922917693}, {0.853977206144806, 
      0.9604697969742446, -0.4611871362023605}, {0.904596414082483, 
      0.9701959309970627, -0.470085819716601}, {0.9557828131921808, 
      0.97936676810116, -0.47819431528493866`}, {1.007425584236075, 
      0.9879797427227013, -0.48557201011925333`}, {1.0594288414664417`, 
      0.9960424333490002, -0.49227848621474796`}, {1.111710596085203, 
      1.0035700568264905`, -0.4983717919571943}, {1.1642014703744423`, 
      1.0105833102000292`, -0.5039072831230246}, {1.2168433096213938`, 
      1.0171065801378647`, -0.5089369101502219}, {1.269587793841656, 
      1.0231665034784754`, -0.5135088407872775}, {1.3223951149390305`, 
      1.028790842519112, -0.5176673250425503}, {1.3752327575031198`, 
      1.0340076302346608`, -0.5214527281139778}, {1.4280744018607807`, 
      1.038844539456191, -0.5249016742003114}, {1.4808989547397315`, 
      1.0433284330370245`, -0.5280472587165381}, {1.5336897044415962`, 
      1.0474850570682146`, -0.5309192982261958}, {1.5864335924268929`, 
      1.0513388449309364`, -0.5335445965618761}, {1.63912059062087, 
      1.0549128056049748`, -0.5359472125158095}, {1.6917431727503394`, 
      1.058228474779078, -0.5381487195715767}, {1.7442958680324683`, 
      1.0613059117555028`, -0.5401684518144342}, {1.796774886146825, 
      1.0641637288722436`, -0.5420237327428111}, {1.8491778033537654`, 
      1.066819143222706, -0.5437300854842706}, {1.901503300693319, 
      1.069288042910251, -0.5453014241124867}, {1.9537509462944418`, 
      1.0715850620223855`, -0.5467502265330099}, {2.005921014876523, 
      1.0737236600334956`, -0.5480876898784803}, {2.058014338496012, 
      1.0757162025250782`, -0.5493238696195406}, {2.1100321834636824`, 
      1.077574041017101, -0.5504678037220748}, {2.1619761491277116`, 
      1.0793075903909959`, -0.5515276232119367}, {2.213848084887295, 
      1.0809264029011416`, -0.5525106504785657}, {2.265650022377944, 
      1.0824392381556878`, -0.553423486582273}, {2.317384120262009, 
      1.0838541287295775`, -0.5542720887426624}, {2.369052619476023, 
      1.0851784412766603`, -0.5550618390885546}, {2.420657807139703, 
      1.0864189331525624`, -0.5557976056501318}, {2.4722019876288757`, 
      1.0875818046601204`, -0.556483796476435}, {2.52368745956425, 
      1.0886727470959032`, -0.5571244076686325}, {2.575116497677092, 
      1.089696986818328, -0.5577230660332301}, {2.6264913386877073`, 
      1.0906593255816914`, -0.5582830669803348}, {2.6778141704786385`, 
      1.0915641773911442`, -0.5588074082204258}, {2.7290871239662597`, 
      1.0924156021349962`, -0.5592988197486642}, {2.7803122671759493`, 
      1.0932173362456339`, -0.5597597905482261}, {2.8314916011105464`, 
      1.093972820630863, -0.560192592392981}, {2.882627057072179, 
      1.0946852261052578`, -0.5605993010845253}, {2.9337204951561024`, 
      1.0953574765372365`, -0.5609818154185535}, {2.984773703683918, 
      1.0959922699129396`, -0.5613418741402819}, {
      3, 1.0961815930194918`, -0.5614492593751441}}], 
    Line3DBox[{{0., 0.6, -1.*^-6}, {7.966242453778674*^-8, 
      0.6, -1.0031679677782165`*^-6}, {1.5982874414332617`*^-7, 
      0.6, -1.0126919673296451`*^-6}, {2.410073221102551*^-7, 
      0.6, -1.0286323527130694`*^-6}, {3.237132307610731*^-7, 
      0.6, -1.0510899848905436`*^-6}, {4.0846995616895115`*^-7, 
      0.6, -1.080207299467184*^-6}, {4.958149581260597*^-7, 
      0.6, -1.116168630338855*^-6}, {5.863010754289038*^-7, 
      0.6, -1.1592020536019024`*^-6}, {6.805020352713257*^-7, 
      0.6, -1.20958003494637*^-6}, {7.790149181763504*^-7, 
      0.6, -1.267621622797299*^-6}, {8.824632254363677*^-7, 
      0.6, -1.3336949654079318`*^-6}, {9.915028243836363*^-7, 
      0.6, -1.4082184290545567`*^-6}, {1.1068246678865269`*^-6, 
      0.6, -1.4916641232990753`*^-6}, {1.2291589335113028`*^-6, 
      0.6, -1.5845611109612272`*^-6}, {1.3592812055953326`*^-6, 
      0.6, -1.6874976144333035`*^-6}, {1.4980159522565942`*^-6, 
      0.6, -1.8011257962263185`*^-6}, {1.6462419260524005`*^-6, 
      0.6, -1.926165814609562*^-6}, {1.804898670825312*^-6, 
      0.6, -2.063409573997201*^-6}, {1.974990957363396*^-6, 
      0.6, -2.213727037357415*^-6}, {2.1575962683231646`*^-6, 
      0.6, -2.3780707891250872`*^-6}, {2.3538718605922823`*^-6, 
      0.6, -2.5574818423286764`*^-6}, {2.5650616342511726`*^-6, 
      0.6, -2.753096643228282*^-6}, {2.792503484396626*^-6, 
      0.6, -2.9661547559689366`*^-6}, {3.0376385326281363`*^-6, 
      0.6, -3.1980060349018836`*^-6}, {3.302019446134877*^-6, 
      0.6, -3.4501199288394305`*^-6}, {3.5873218737898955`*^-6, 
      0.6, -3.7240932826499644`*^-6}, {3.895353140830065*^-6, 
      0.6, -4.02166227898114*^-6}, {4.228064755489368*^-6, 
      0.6, -4.34471243638805*^-6}, {4.587565198103897*^-6, 
      0.6, -4.6952901370201686`*^-6}, {4.9761320536841974`*^-6, 
      0.6, -5.075616783760655*^-6}, {5.396227312367623*^-6, 
      0.6, -5.488102029929633*^-6}, {5.850512505358708*^-6, 
      0.6, -5.935359498737442*^-6}, {6.341866025042803*^-6, 
      0.6, -6.4202228945442*^-6}, {6.873401130316037*^-6, 
      0.6, -6.945764184519457*^-6}, {7.448485518631518*^-6, 
      0.6, -7.515313213897554*^-6}, {8.070762831428064*^-6, 
      0.6, -8.132478638142032*^-6}, {8.744175736375208*^-6, 
      0.6, -8.801170790085483*^-6}, {9.472991033730625*^-6, 
      0.6, -9.525626330472663*^-6}, {0.000010261826378629162`, 
      0.6, -0.00001031043540070326}, {0.00001111567971522896, 
      0.6, -0.000011160570529700403`}, {0.000012039961043251015`, 
      0.6, -0.00001208141803981509}, {0.00001304052654496819, 
      0.6, -0.000013078812323689824`}, {0.0000141237157257236, 
      0.6, -0.000014159072774364945`}, {0.000015296391483507826`, 
      0.6, -0.00001532904392112678}, {0.000016565983816266942`, 
      0.6, -0.00001659613857188567}, {0.000017940536793788674`, 
      0.6, -0.00001796838488365336}, {0.00001942875942691038, 
      0.6, -0.000019454477325420624`}, {0.000021040080996614087`, 
      0.6, -0.00002106383161622855}, {0.000022784710682482025`, 
      0.6, -0.0000228066444968091}, {0.000024673702280973754`, 
      0.6, -0.000024693958301481556`}, {0.000026719024302568726`, 
      0.6, -0.00002673773086020153}, {0.000028933635736675955`, 
      0.6, -0.000028950911328779123`}, {0.00003133156813753918, 
      0.6, -0.00003134752225468653}, {0.00003392801460466383, 
      0.6, -0.000033942748344997835`}, {0.00003673942601308858, 
      0.6, -0.000036753032707190084`}, {0.000039783615203098854`, 
      0.6000000001091956, -0.00003979618107288167}, {0.00004307986990793968, 
      0.6000000002372297, -0.00004309147454667639}, {0.00004664907490048348, 
      0.6000000003873521, -0.00004665979182735772}, {0.00005051384434162842, 
      0.6000000005633737, -0.000050523741469545095`}, {0.00005469866509203078,
       0.6000000007697623, -0.00005470780509935663}, {
      0.000059230051794284675`, 
      0.6000000010117571, -0.00005923849259176804}, {0.00006413671490969004, 
      0.6000000012955007, -0.00006414450999225902}, {0.00006944974265579308, 
      0.6000000016281956, -0.00006945694136569936}, {0.00007520279789342707, 
      0.6000000020182868, -0.00007520944582704246}, {0.0000814323314920522, 
      0.6000000024756765, -0.00008143847072194383}, {0.00008817781320316944, 
      0.6000000030119749, -0.0000881834826297993}, {0.00009548198184281131, 
      0.6000000036407951, -0.00009548721731462756}, {0.00010339111596788464`, 
      0.6000000043780991, -0.0001033959506077712}, {0.00011195532716171946`, 
      0.6000000052426024, -0.00011195979153834072`}, {0.00012122887751200564`,
       0.6000000062562495, -0.00012123299984364999`}, {0.000131270523425155, 
      0.6000000074447704, -0.00013127432973880797`}, {0.00014214388789933322`,
       0.6000000088383345, -0.00014214740217964277`}, {
      0.00015391786362658585`, 
      0.6000000104723155, -0.00015392110796578882`}, {0.0001666670494863301, 
      0.6000000123881903, -0.00016667004422963406`}, {0.00018047222321229429`,
       0.600000014634591, -0.0001804749870600886}, {0.0001954208531826299, 
      0.6000000172685395, -0.00019542340330060305`}, {0.00021160765260653234`,
       0.6000000203568956, -0.00021161000473330916`}, {0.0002291351796399001, 
      0.6000000239780534, -0.0002291373481390928}, {0.0002481144871769335, 
      0.6000000282239316, -0.0002481164850906514}, {0.00026866582646344745`, 
      0.6000000332023065, -0.00026866766556649444`}, {0.00029091940900029435`,
       0.6000000390395483, -0.00029092109983314953`}, {0.0003150162315661229, 
      0.600000045883828, -0.0003150177834204011}, {0.0003411089695466271, 
      0.6000000539088794, -0.00034111039045598926`}, {0.0003693629442849313, 
      0.6000000633184085, -0.00036936424096443125`}, {0.00039995717053814127`,
       0.6000000743512643, -0.00039995834830163906`}, {0.0004330854907048535, 
      0.6000000872875024, -0.000433086553332235}, {0.00046895780300066075`, 
      0.6000001024554928, -0.00046895875254322777`}, {0.0005078013913550303, 
      0.6000001202402561, -0.0005078022278813244}, {0.0005498623654646476, 
      0.6000001410932356, -0.0005498630867278635}, {0.0005954072201321105, 
      0.6000001655437578, -0.0005954078211265788}, {0.0006447245237663512, 
      0.6000001942124674, -0.0006447249961423188}, {0.0006981267467378309, 
      0.6000002278270823, -0.0006981270780475018}, {0.0007559522411712853, 
      0.6000002672408649, -0.0007559524139138662}, {0.0008185673847389719, 
      0.6000003134542811, -0.0008185673751237488}, {0.0008863689020205878, 
      0.6000003676403952, -0.0008863686783871242}, {0.0009597863781408396, 
      0.6000004311746461, -0.000959785898952402}, {0.0010392849806192088`, 
      0.6000005056697599, -0.0010392841919074293`}, {0.0011253684066843876`, 
      0.6000005930166858, -0.0011253672387818334`}, {0.0012185820747090397`, 
      0.6000006954325934, -0.001218580438108279}, {0.0013195165800089933`, 
      0.60000081551715, -0.0013195143600960673`}, {0.0014288114369022456`, 
      0.6000009563185068, -0.0014288084872573087`}, {0.0015471591307337615`, 
      0.6000011214106667, -0.0015471552646276945`}, {0.001675309505559245, 
      0.6000013149841996, -0.0016753044851455625`}, {0.001814074515285831, 
      0.6000015419526045, -0.0018140680378773205`}, {0.001964333368390137, 
      0.6000018080770199, -0.0019643250490298113`}, {0.002127038098822196, 
      0.6000021201124445, -0.002127027448150441}, {0.0023032195984105355`, 
      0.6000024859791795, -0.0023032059945602068`}, {0.002493994149010176, 
      0.600002914963841, -0.0024939768019234484`}, {0.0027005704958149254`, 
      0.6000034179550413, -0.0027005484019314266`}, {0.0029242575066792194`, 
      0.6000040077197176, -0.002924229391409132}, {0.0031664724660345972`, 
      0.6000046992271143, -0.0031664367107121227`}, {0.0034287500559997525`, 
      0.6000055100286346, -0.003428704605144422}, {0.003712752081670872, 
      0.6000064607031901, -0.0037126943252414526`}, {0.004020278002303554, 
      0.6000075753793362, -0.00402020462620424}, {0.004353276335232484, 
      0.6000088823474224, -0.004353183131514129}, {0.004713857004939682, 
      0.6000104147772627, -0.004713738630827498}, {0.0051043047157049454`, 
      0.6000122115594995, -0.005104154387665155}, {0.0055270934328219, 
      0.6000143182919532, -0.00552690253814807}, {0.00598490206443786, 
      0.6000167884359109, -0.005984659668135527}, {0.006480631443783328, 
      0.6000196846715852, -0.0064803236625259365`}, {0.00701742271988955, 
      0.6000230804869885, -0.007017031927226803}, {0.007598677273958814, 
      0.6000270620403302, -0.007598181091305535}, {0.008228078288389862, 
      0.6000317303429052, -0.008227448304072604}, {0.008909614106143132, 
      0.6000372038174611, -0.008908814249245101}, {0.009647603529752547, 
      0.6000436212964042, -0.009646588005769173}, {0.010446723221920928`, 
      0.6000511455351548, -0.010445433892214535`}, {0.011312037383389062`, 
      0.6000599673287352, -0.011310400438675917`}, {0.01224902989874062, 
      0.6000703103345806, -0.012246951636567695`}, {0.013263639157135671`, 
      0.6000824367219221, -0.013261000622205813`}, {0.014362295772771424`, 
      0.6000966537883013, -0.014358945954186738`}, {0.015551963449328257`, 
      0.600113321707257, -0.015547710646661751`}, {0.016840183253927613`, 
      0.600132862598479, -0.016834784119891557`}, {0.018235121589417494`, 
      0.6001557711432843, -0.018228267224911523`}, {0.019745622179319765`, 
      0.6001826270047381, -0.019736920489437374`}, {0.02138126240778037, 
      0.600214109353765, -0.0213702157155964}, {0.023152414387624182`, 
      0.6002510138508576, -0.02313839103453761}, {0.02507031116343909, 
      0.6002942724881886, -0.025052509485710167`}, {0.027147118493818456`, 
      0.6003449767597551, -0.027124521136136108`}, {0.02939601269782262, 
      0.6004044046982475, -0.029367328682943394`}, {0.031831265095709126`, 
      0.6004740523970931, -0.03179485638524201}, {0.03446833362333235, 
      0.6005556707247809, -0.03442212204216916}, {0.03732396225354338, 
      0.600651308035878, -0.0372653115639089}, {0.04041628891647032, 
      0.6007633597881673, -0.04034185546089107}, {0.04376496267346856, 
      0.6008946260861298, -0.043670506289790016`}, {0.04739127096602093, 
      0.6010483782840924, -0.047271415726877715`}, {0.05131827782931711, 
      0.6012284358921806, -0.05116620946958702}, {0.05557097402771401, 
      0.6014392551260955, -0.055378057571407596`}, {0.06017644013076547, 
      0.6016860305148295, -0.059931737064297455`}, {0.06516402359588774, 
      0.6019748110100481, -0.06485368278227155}, {0.07056553094415034, 
      0.6023126320004834, -0.07017202113007259}, {0.07641543608932834, 
      0.6027076644872136, -0.07591658009737927}, {0.08275110577717393, 
      0.6031693823702786, -0.08211886705408904}, {0.08961304286704455, 
      0.6037087482649277, -0.08881200372790038}, {0.09704514777573463, 
      0.6043384174156738, -0.09603060521940675}, {0.10509499770839423`, 
      0.6050729579895004, -0.10381058692535289`}, {0.11381414218837126`, 
      0.6059290841552637, -0.11218887982206785`}, {0.12325841167773036`, 
      0.6069258957089894, -0.12120303076879287`}, {0.13348823349541145`, 
      0.6080851143656708, -0.13089066047787917`}, {0.1445689454492063, 
      0.6094313019659493, -0.14128874786489976`}, {0.15657109216627507`, 
      0.6109920395028737, -0.15243270615569432`}, {0.16957068151147064`, 
      0.6127980378782543, -0.16435521422516058`}, {0.18364936814730592`, 
      0.614883141618563, -0.17708476744487353`}, {0.19889451767969563`, 
      0.6172841756893741, -0.19064391765426422`}, {0.2153990876496707, 
      0.6200405738534199, -0.20504718423236676`}, {0.23326124114977265`, 
      0.6231937163843726, -0.22029864077996847`}, {0.2525835864609278, 
      0.6267858982813025, -0.2363892181980594}, {0.2734719150977387, 
      0.6308588509355388, -0.2532938183109917}, {0.29603329706851034`, 
      0.6354517567239398, -0.2709684044103037}, {0.32037339555734184`, 
      0.6405987347323949, -0.28934732416754794`}, {0.3465928966060371, 
      0.6463258438486587, -0.30834121736228204`}, {0.3747830272159649, 
      0.6526477501544622, -0.3278359466849235}, {0.40502026868875546`, 
      0.6595643333574629, -0.3476930335070702}, {0.4373605602047099, 
      0.6670576417947188, -0.3677520420213608}, {0.4718335077139699, 
      0.6750897095367769, -0.3878351965829792}, {0.5084373134554776, 
      0.6836017716170274, -0.40775422230466674`}, {0.5471352463929651, 
      0.6925153073235991, -0.4273189968746196}, {0.5878544080926286, 
      0.701735089816238, -0.44634717883850966`}, {0.63048727517951, 
      0.7111540602598394, -0.4646736639694408}, {0.6748960549239186, 
      0.7206594703177467, -0.48215864185008084`}, {0.7209193885804647, 
      0.7301394685345591, -0.4986932369604885}, {0.7683805290914458, 
      0.7394892362624055, -0.5142021730981294}, {0.8170959272007016, 
      0.7486159258766312, -0.5286434556075843}, {0.8668832207082563, 
      0.7574419554163094, -0.5420055540664233}, {0.9175678815468312, 
      0.765906560870763, -0.5543028669578466}, {0.9689881263760023, 
      0.7739657981361806, -0.5655703245027869}, {1.0209980299922854`, 
      0.7815913634017235, -0.5758578793355794}, {1.0734690267482794`, 
      0.7887686571532998, -0.5852254287169598}, {1.1262901211038938`, 
      0.7954944822264072, -0.5937384856661192}, {1.179367168207111, 
      0.8017746816873899, -0.6014647228922463}, {1.232621559555233, 
      0.8076219238503443, -0.6084713757029057}, {1.2859885888138909`, 
      0.8130537527810111, -0.6148234086727768}, {1.3394157029048794`, 
      0.8180909539066501, -0.620582314499002}, {1.3928607782892777`, 
      0.82275623759773, -0.6258054076036081}, {1.4462905088862856`, 
      0.8270732157481214, -0.630545486707117}, {1.4996789519571603`, 
      0.8310656326786542, -0.6348507602450599}, {1.5530062503718065`, 
      0.8347568074469986, -0.6387649500409164}, {1.6062575316212748`, 
      0.8381692460798011, -0.6423275087240843}, {1.659421973225369, 
      0.8413243866317371, -0.6455739034847675}, {1.7124920185959582`, 
      0.844242445542328, -0.6485359325016973}, {1.765462725204141, 
      0.8469423394433714, -0.6512420509667386}, {1.8183312267771385`, 
      0.849441661801446, -0.6537176915222284}, {1.8710962923240113`, 
      0.8517566983115319, -0.6559855696467635}, {1.9237579664645994`, 
      0.8539024687270406, -0.6580659685653056}, {1.9763172774383662`, 
      0.8558927858571518, -0.6599770010394751}, {2.028776001074845, 
      0.8577403248699039, -0.6617348472513002}, {2.0811364707911064`, 
      0.859456697909826, -0.6633539691895789}, {2.133401425284152, 
      0.861052530470936, -0.6648473026787796}, {2.1855738869866808`, 
      0.8625375370484167, -0.6662264286005392}, {2.2376570655554078`, 
      0.8639205944007712, -0.6675017250517394}, {2.2896542816763032`, 
      0.8652098113508918, -0.6686825022351343}, {2.3415689073207466`, 
      0.8664125944891388, -0.6697771218406421}, {2.393404319292194, 
      0.8675357094535592, -0.6707931025836458}, {2.4451638634856314`, 
      0.8685853376823988, -0.6717372134453601}, {2.4968508277611483`, 
      0.8695671286856322, -0.6726155560257564}, {2.548468421725533, 
      0.8704862479833461, -0.6734336372821901}, {2.6000197620367302`, 
      0.8713474209230663, -0.6741964337933063}, {2.6515078621078425`, 
      0.8721549726257796, -0.6749084485618756}, {2.702935625300727, 
      0.8729128643291023, -0.6755737612539717}, {2.754305840872904, 
      0.8736247264014989, -0.6761960726662108}, {2.8056211820827617`, 
      0.8742938882978287, -0.6767787441177217}, {2.856884205972839, 
      0.8749234057168868, -0.6773248323787283}, {2.9080973544442874`, 
      0.8755160852082168, -0.6778371206724633}, {2.9592629563113437`, 
      0.876074506459929, -0.6783181462207956}, {
      3, 0.8765191104535806, -0.6787011292809516}}], 
    Line3DBox[{{0., 0.44999999999999996`, -1.*^-6}, {7.134723414501347*^-8, 
      0.44999999999999996`, -1.002542063741177*^-6}, {1.4305837688518765`*^-7,
       0.44999999999999996`, -1.0101810105623227`*^-6}, {
      2.154967734152932*^-7, 
      0.44999999999999996`, -1.0229558643313247`*^-6}, {2.890307745408398*^-7,
       0.44999999999999996`, -1.0409314566069097`*^-6}, {
      3.640341036395112*^-7, 0.44999999999999996`, -1.064199334435632*^-6}, {
      4.4088804002153466`*^-7, 
      0.44999999999999996`, -1.0928777431872995`*^-6}, {5.199836035066605*^-7,
       0.44999999999999996`, -1.1271124025440586`*^-6}, {
      6.017236607023236*^-7, 
      0.44999999999999996`, -1.1670770179160928`*^-6}, {6.865217775678005*^-7,
       0.44999999999999996`, -1.21297574013234*^-6}, {7.748099131855509*^-7, 
      0.44999999999999996`, -1.265041541940066*^-6}, {8.670378183571346*^-7, 
      0.44999999999999996`, -1.3235385759616437`*^-6}, {9.6367354829077*^-7, 
      0.44999999999999996`, -1.3887647722497255`*^-6}, {
      1.0652085561463318`*^-6, 
      0.44999999999999996`, -1.461051658050996*^-6}, {1.1721596345192777`*^-6,
       0.44999999999999996`, -1.5407663385801718`*^-6}, {
      1.285070111620071*^-6, 
      0.44999999999999996`, -1.6283143916790711`*^-6}, {
      1.4045138632817459`*^-6, 
      0.44999999999999996`, -1.7241410520422314`*^-6}, {
      1.5310981915573519`*^-6, 
      0.44999999999999996`, -1.8287334743582048`*^-6}, {
      1.6654670801943373`*^-6, 
      0.44999999999999996`, -1.9426230827057118`*^-6}, {
      1.8083033922776558`*^-6, 
      0.44999999999999996`, -2.0663891291609994`*^-6}, {
      1.9603334524247734`*^-6, 
      0.44999999999999996`, -2.2006607406434344`*^-6}, {2.122329607354318*^-6,
       0.44999999999999996`, -2.3461210774190357`*^-6}, {2.29511596518892*^-6,
       0.44999999999999996`, -2.503509232443332*^-6}, {
      2.4795705080124257`*^-6, 
      0.44999999999999996`, -2.673625815426528*^-6}, {2.676631910984807*^-6, 
      0.44999999999999996`, -2.857334891403352*^-6}, {2.887301540214653*^-6, 
      0.44999999999999996`, -3.055570929247529*^-6}, {3.112650182286899*^-6, 
      0.44999999999999996`, -3.269342042412968*^-6}, {3.3538238237944027`*^-6,
       0.44999999999999996`, -3.4997347832486412`*^-6}, {
      3.6120489408216634`*^-6, 
      0.44999999999999996`, -3.747920175204181*^-6}, {3.888637958257981*^-6, 
      0.44999999999999996`, -4.015160415276889*^-6}, {4.184997189944022*^-6, 
      0.44999999999999996`, -4.302814069690691*^-6}, {4.502633338245304*^-6, 
      0.44999999999999996`, -4.612343609884963*^-6}, {4.843161439475326*^-6, 
      0.44999999999999996`, -4.945322571021944*^-6}, {5.208312188759989*^-6, 
      0.44999999999999996`, -5.303444415856724*^-6}, {5.599942458101949*^-6, 
      0.44999999999999996`, -5.688529464798932*^-6}, {6.020043757360849*^-6, 
      0.44999999999999996`, -6.102535105637641*^-6}, {6.470751292042781*^-6, 
      0.44999999999999996`, -6.547566799171606*^-6}, {6.954356739842578*^-6, 
      0.44999999999999996`, -7.025886890073013*^-6}, {7.473318681215185*^-6, 
      0.44999999999999996`, -7.539927313395222*^-6}, {8.03027572549071*^-6, 
      0.44999999999999996`, -8.092301339177262*^-6}, {8.628059431525398*^-6, 
      0.44999999999999996`, -8.685817347708354*^-6}, {9.269708933152438*^-6, 
      0.44999999999999996`, -9.323492880685393*^-6}, {9.958486438784107*^-6, 
      0.44999999999999996`, -0.000010008569934267623`}, {
      0.00001069789384721814, 
      0.44999999999999996`, -0.000010744531411366596`}, {
      0.000011491690361231996`, 
      0.44999999999999996`, -0.000011535119018371788`}, {
      0.000012343911716900317`, 
      0.44999999999999996`, -0.000012384352171810618`}, {
      0.000013258890686692433`, 
      0.44999999999999996`, -0.000013296548448239219`}, {
      0.000014241278921281758`, 
      0.44999999999999996`, -0.000014276345721189373`}, {
      0.000015296071206466793`, 
      0.44999999999999996`, -0.000015328725134568974`}, {
      0.000016428630063719618`, 
      0.44999999999999996`, -0.000016459037218669332`}, {
      0.000017644713524115053`, 
      0.44999999999999996`, -0.0000176730285835542}, {
      0.000018950504366774897`, 
      0.44999999999999996`, -0.000018976871171115328`}, {
      0.00002035264130409333, 
      0.44999999999999996`, -0.000020377193881954313`}, {
      0.000021858252921625866`, 
      0.44999999999999996`, -0.000021881116089563407`}, {
      0.000023474993835572113`, 
      0.44999999999999996`, -0.000023496283920627453`}, {
      0.000025211083801706954`, 
      0.44999999999999996`, -0.00002523090893666175}, {0.00002707534915203755,
       0.44999999999999996`, -0.00002709381023531901}, {
      0.000029077268072715166`, 
      0.44999999999999996`, -0.00002909445888378475}, {0.00003122701845449571,
       0.44999999999999996`, -0.00003124302640777641}, {0.0000335355298459224,
       0.44999999999999996`, -0.000033550436296778154`}, {
      0.00003601453888371683, 
      0.44999999999999996`, -0.00003602841967638939}, {
      0.000038676649086372284`, 
      0.44999999999999996`, -0.00003868957482701747}, {0.00004153539488308933,
       0.44999999999999996`, -0.000041547431283133285`}, {
      0.00004460531043319484, 
      0.44999999999999996`, -0.000044616518609488505`}, {
      0.000047902003423066026`, 
      0.44999999999999996`, -0.000047912440366753464`}, {
      0.00005144223452298444, 
      0.44999999999999996`, -0.00005145195333548419}, {0.00005524400264978194,
       0.4500000001144316, -0.00005525305265930006}, {0.00005932663625072962, 
      0.45000000024639875`, -0.0000593350635583017}, {0.00006371089186736032, 
      0.4500000003985885, -0.00006371873928333221}, {0.00006841905943403426, 
      0.4500000005740999, -0.00006842636685719879}, {0.00007347507571674198, 
      0.45000000077650665`, -0.00007348188026932538}, {0.00007890464595649392,
       0.4500000010099302, -0.0000789109822112461}, {0.00008473537456994377, 
      0.4500000012791236, -0.00008474127473836306}, {0.0000909969055243023, 
      0.4500000015895682, -0.00009100239957006011}, {0.00009772107299872647, 
      0.4500000019475854, -0.00009772618884181891}, {0.00010494206328769456`, 
      0.4500000023604651, -0.00010494682688700984`}, {0.00011269658854432877`,
       0.45000000283661457`, -0.00011270102409584594`}, {0.000121024073489525,
       0.45000000338572915`, -0.00012102820349288676`}, {
      0.0001299668558188694, 0.4500000040189901, -0.0001299707011989128}, {
      0.0001395704014408362, 0.450000004749292, -0.00013957398168172215`}, {
      0.00014988353565243242`, 
      0.45000000559150544`, -0.00014988686887831127`}, {
      0.00016095869137068116`, 
      0.45000000656277966`, -0.00016096179442038952`}, {0.0001728521756997754,
       0.45000000768289206`, -0.0001728550642074028}, {0.0001856244561933367, 
      0.4500000089746505, -0.00018562714467813246`}, {0.0001993404682976118, 
      0.45000001046435806`, -0.00019934297020581177`}, {0.0002140699454583209,
       0.4500000121823485, -0.00021407227325988856`}, {
      0.00022988777369645474`, 
      0.45000001416360386`, -0.00022988993888594376`}, {
      0.00024687437228847675`, 
      0.4500000164484669, -0.00024687638547313435`}, {0.00026511610265612717`,
       0.45000001908346243`, -0.0002651179735751421}, {0.000284705707430874, 
      0.4500000221222448, -0.00028470744497678023`}, {0.0003057427819649852, 
      0.45000002562669034`, -0.0003057443941986388}, {0.0003283342806727297, 
      0.45000002966815716`, -0.0003283357748504603}, {0.0003525950608180716, 
      0.4500000343289385, -0.0003525964433652916}, {0.0003786484664476143, 
      0.45000003970393804`, -0.000378649742944441}, {0.00040662695549228744`, 
      0.45000004590260256`, -0.00040662813062700804`}, {
      0.00043667277319004604`, 0.4500000530511505, -0.0004366738507076153}, {
      0.00046893867527488106`, 
      0.45000006129514186`, -0.0004689396579039847}, {0.0005035887046206662, 
      0.4500000708024424, -0.0005035895939385976}, {0.0005407990252356432, 
      0.45000008176664147`, -0.0005407998215345792}, {0.0005807588179098019, 
      0.4500000944109939, -0.0005807595200027806}, {0.0006236712420348896, 
      0.4500001089929663, -0.000623671847005898}, {0.0006697544684918599, 
      0.45000012580947896`, -0.0006697549713829874}, {0.0007192427888586797, 
      0.45000014520295245`, -0.0007192431822818432}, {0.000772387806591622, 
      0.45000016756827954`, -0.0007723880802220415}, {0.0008294597162035784, 
      0.45000019336086605`, -0.0008294598561737848}, {0.0008907486769837668, 
      0.45000022310590393`, -0.0008907486651110251}, {0.0009565662882200244, 
      0.4500002574090649, -0.0009565661010406529}, {0.001027247173423457, 
      0.45000029696883337`, -0.0010272467810018705`}, {0.0011031506816229135`,
       0.4500003425907285, -0.0011031500460690583`}, {0.001184662714373776, 
      0.4500003952037061, -0.0011846617880028607`}, {0.001272197687775233, 
      0.4500004558790736, -0.0012721964108204978`}, {0.0013662006394634767`, 
      0.4500005258523035, -0.0013661989372528928`}, {0.0014671494913179638`, 
      0.45000060654818935`, -0.0014671472707571433`}, {0.0015755574793625807`,
       0.45000069960985634`, -0.00157555462458688}, {0.0016919757632381295`, 
      0.4500008069322173, -0.0016919721302231616`}, {0.0018169962285139436`, 
      0.45000093070055475`, -0.0018169916383961844`}, {0.00195125449609164, 
      0.45000107343501533`, -0.0019512487268952532`}, {0.0020954331540118873`,
       0.45000123804192116`, -0.00209542593040186}, {0.0022502652281093903`, 
      0.4500014278729435, -0.0022502562086948678`}, {0.002416537909168609, 
      0.4500016467933431, -0.0024165266707820163`}, {0.0025950965555548607`, 
      0.45000189926066547`, -0.0025950825737781234`}, {0.0027868489916898194`,
       0.4500021904154936, -0.0027868316167323844`}, {0.002992770124247682, 
      0.4500025261861045, -0.0029927485510775793`}, {0.0032139068995856225`, 
      0.45000291340915893`, -0.0032138801309295065`}, {0.0034513836276418314`,
       0.4500033599688808, -0.0034513504281681305`}, {0.003706407699430694, 
      0.45000387495755684`, -0.0037063665390040406`}, {0.0039802757272633105`,
       0.4500044688606219, -0.003980224710665457}, {0.004274380138988578, 
      0.45000515377009426`, -0.004274316918883395}, {0.004590216259880932, 
      0.4500059436307007, -0.004590137929028119}, {0.004929389918304029, 
      0.45000685452369543`, -0.004929292876068856}, {0.005293625613964022, 
      0.45000790499414217`, -0.005293505401001193}, {0.005684775290472045, 
      0.45000911642830876`, -0.005684626383991867}, {0.006104827757043486, 
      0.4500105134888415, -0.0061046433172681795`}, {0.006555918807525755, 
      0.4500121246165558, -0.006555690363694642}, {0.007040342088549708, 
      0.45001398260902786`, -0.007040059150068968}, {0.007560560772502126, 
      0.4500161252877265, -0.007560210347392086}, {0.008119220095205354, 
      0.45001859626721136`, -0.00811878609375178}, {0.008719160822718808, 
      0.4500214458419846, -0.00871862331896814}, {0.009363433716558966, 
      0.4500247320089527, -0.00936276803377898}, {0.010055315071906426`, 
      0.45002852164618323`, -0.010054490650064822`}, {0.010798323409067502`, 
      0.45003289187177986`, -0.010797302402389304`}, {0.011596237404619859`, 
      0.4500379316103071, -0.0115949729449178}, {0.012453115155346216`, 
      0.4500437433983439, -0.012451549201506158`}, {0.013373314875290207`, 
      0.45005044546551, -0.013371375550346388`}, {0.014361517134119525`, 
      0.45005817413277904`, -0.014359115427899477`}, {0.015422748753511212`, 
      0.4500670865761697, -0.015419774439804043`}, {0.016562408487556475`, 
      0.4500773640110982, -0.016558725068843205`}, {0.017786294623303056`, 
      0.45008921536091745`, -0.01778173307165151}, {0.019100634648607184`, 
      0.45010288148259026`, -0.01909498565636066}, {0.020512117146559216`, 
      0.45011864003321495`, -0.02050512153245881}, {0.022027926089007832`, 
      0.4501368110734011, -0.022019262921310942`}, {0.023655777716277224`, 
      0.45015776351747916`, -0.023645049610489244`}, {0.025403960206215638`, 
      0.4501819225564167, -0.025390675126577205`}, {0.027281376353418776`, 
      0.45020977819731883`, -0.02726492508854931}, {0.029297589499053155`, 
      0.45024189508373574`, -0.029277217786082128`}, {0.03146287297340444, 
      0.45027892378390094`, -0.031437647002847235`}, {0.033788263337363976`, 
      0.45032161375969293`, -0.033757027072271545`}, {0.036285617735844156`, 
      0.4503708282577289, -0.036246940110320695`}, {0.03896767570590119, 
      0.4504275613956927, -0.038919785313974546`}, {0.041848125815482584`, 
      0.45049295775181625`, -0.04178883014202646}, {0.04494167754553951, 
      0.4505683348032877, -0.04486826310273652}, {0.04826413886905844, 
      0.4506552085999699, -0.048173247755905535`}, {0.05183250002559246, 
      0.4507553231026214, -0.05171997738926786}, {0.055665024039183345`, 
      0.4508706836588478, -0.0555257296436145}, {0.05978134458095752, 
      0.45100359513376054`, -0.05960892012915257}, {0.06420257183450723, 
      0.4511567052534814, -0.0639891537869246}, {0.06895140708108614, 
      0.45133305375485794`, -0.06868727239125808}, {0.07405226678023039, 
      0.45153612795927234`, -0.07372539614748454}, {0.07953141697561147, 
      0.4517699253955514, -0.07912695679627298}, {0.08541711889928695, 
      0.4520390240775005, -0.08491671897181279}, {0.09173978667007363, 
      0.4523486609829398, -0.09112078575290061}, {0.09853215796851605, 
      0.45270481916642463`, -0.09776658336828517}, {0.1058294784996445, 
      0.4531143237446152, -0.10488281884305331`}, {0.11366970089308887`, 
      0.45358494669196625`, -0.11249940297354362`}, {0.12209369839177477`, 
      0.4541255199366672, -0.12064732936847486`}, {0.1311454931798312, 
      0.4547460556034822, -0.129358498374327}, {0.14087249840618427`, 
      0.45545787134962845`, -0.1386654725076329}, {0.15132577174745973`, 
      0.4562737175063308, -0.14860114756430237`}, {0.1625602765539604, 
      0.4572079010820347, -0.15919832092609043`}, {0.1746351440143949, 
      0.45827639950091736`, -0.17048913586221348`}, {0.18761392607644656`, 
      0.459496954133834, -0.18250437805624045`}, {0.20156482372541507`, 
      0.4608891301279015, -0.1952725985509017}, {0.2165608682532808, 
      0.4624743246900506, -0.20881903638721672`}, {0.2326800239297402, 
      0.46427570084420633`, -0.22316431530561917`}, {0.2500051686624986, 
      0.46631801793078026`, -0.23832289324781425`}, {0.2686238946701353, 
      0.4686273241854619, -0.2543012527892107}, {0.28862805422785176`, 
      0.4712304714751459, -0.2710958372840861}, {0.31011295740569256`, 
      0.47415440914471996`, -0.2886907640684576}, {0.33317611206378184`, 
      0.4774252152050386, -0.3070553852516054}, {0.3579153859748663, 
      0.4810668319504134, -0.3261418204360292}, {0.3844264742877353, 
      0.48509949349192005`, -0.34588265401462864`}, {0.4127995828915463, 
      0.4895378687179724, -0.3661890681003685}, {0.4431153015043757, 
      0.494388997583015, -0.3869497592621829}, {0.4754397497456075, 
      0.49965017025721475`, -0.4080310423381771}, {0.5098192375073186, 
      0.5053069793045469, -0.429278547467032}, {0.5462748738331242, 
      0.5113318465746661, -0.4505208323594112}, {0.5847977487198462, 
      0.5176833611173884, -0.4715750337965651}, {0.6253454381736265, 
      0.5243067309253444, -0.4922543703862227}, {0.6678405727767385, 
      0.5311355284075906, -0.5123769281697266}, {0.7121720123811004, 
      0.5380947027251946, -0.5317748067997683}, {0.758198789037639, 
      0.5451045841802189, -0.5503024978838081}, {0.8057564973673192, 
      0.5520853891885587, -0.5678434057930838}, {0.8546653640542451, 
      0.5589616232289157, -0.5843137239706673}, {0.9047389550650915, 
      0.5656658139128187, -0.5996633661495959}, {0.9557924570376255, 
      0.5721411723748936, -0.6138741726907447}, {1.0076496798819856`, 
      0.5783430171015941, -0.6269560170983418}, {1.0601482764473626`, 
      0.5842390233109569, -0.6389416379949394}, {1.1131430429863505`, 
      0.5898085247531323, -0.6498810134678641}, {1.1665074580250125`, 
      0.5950411708461768, -0.65983593787517}, {1.220133794485893, 
      0.5999352405107148, -0.6688752388167131}, {1.2739322040740615`, 
      0.6044958624717002, -0.6770708542496059}, {1.3278291541882346`, 
      0.6087333195671607, -0.6844948178383264}, {1.3817655326163276`, 
      0.6126615436657086, -0.691217087648379}, {1.4356946544519769`, 
      0.6162968500887942, -0.6973040937038562}, {1.489580328691785, 
      0.6196569196993753, -0.7028178599805246}, {1.5433950785360637`, 
      0.6227600117778664, -0.7078155613991507}, {1.5971185622060116`, 
      0.6256243779873463, -0.7123493943354989}, {1.6507362088525976`, 
      0.6282678433075959, -0.7164666618195137}, {1.704238063951198, 
      0.6307075205273239, -0.7202099970402936}, {1.7576178272512126`, 
      0.632959628312852, -0.7236176685425003}, {1.810872061069212, 
      0.635039387416202, -0.7267239267021028}, {1.8639995452820783`, 
      0.6369609742810345, -0.7295593636990338}, {1.9170007562100675`, 
      0.6387375156351482, -0.7321512686803618}, {1.9698774486063286`, 
      0.6403811113958473, -0.73452396669664}, {2.022632322502849, 
      0.6419028763026765, -0.7366991348620426}, {2.075268759289558, 
      0.6433129931653846, -0.738696092532971}, {2.127790613893053, 
      0.6446207725497152, -0.7405320645264447}, {2.1802020521609298`, 
      0.6458347152088117, -0.7422224178258925}, {2.232507424505209, 
      0.646962574690142, -0.7437808730872139}, {2.284711168513279, 
      0.6480114183836806, -0.7452196927383499}, {2.3368177346180783`, 
      0.6489876858912549, -0.7465498476880894}, {2.3888315300617435`, 
      0.6498972440419524, -0.7477811647144693}, {2.4407568773222525`, 
      0.6507454381959518, -0.7489224565526508}, {2.4925979839331625`, 
      0.6515371397014658, -0.7499816365895804}, {2.5443589212419697`, 
      0.6522767895215656, -0.7509658199270336}, {2.596043610148722, 
      0.6529684381483777, -0.7518814124148399}, {2.6476558122652687`, 
      0.6536157819857107, -0.7527341890943859}, {2.6991991252553604`, 
      0.6542221964181983, -0.7535293633363633}, {2.7506769813719036`, 
      0.6547907658033605, -0.7542716478104464}, {2.802092648412453, 
      0.6553243106283887, -0.7549653082903398}, {2.853449232477612, 
      0.6558254120701414, -0.7556142111762171}, {2.9047496820475702`, 
      0.6562964341878511, -0.7562218655079271}, {2.955996792996107, 
      0.6567395439655705, -0.7567914601458919}, {
      3, 0.6571200190970178, -0.7572805411945357}}], 
    Line3DBox[{{0., 0.3, -1.*^-6}, {6.678493655910459*^-8, 
      0.3, -1.0022276892765741`*^-6}, {1.3386750780970206`*^-7, 
      0.3, -1.0089205765157686`*^-6}, {2.0154668554143494`*^-7, 
      0.3, -1.0201085142764823`*^-6}, {2.701232041229943*^-7, 
      0.3, -1.0358415123796642`*^-6}, {3.39903381347727*^-7, 
      0.3, -1.056189472766338*^-6}, {4.111980071596534*^-7, 
      0.3, -1.081243107963027*^-6}, {4.843259766391138*^-7, 
      0.3, -1.1111135414402855`*^-6}, {5.596112651760028*^-7, 
      0.3, -1.1459345694892541`*^-6}, {6.373887272375092*^-7, 
      0.3, -1.1858616454994782`*^-6}, {7.180067961183765*^-7, 
      0.3, -1.231071681772395*^-6}, {8.018240914112324*^-7, 
      0.3, -1.2817663892485147`*^-6}, {8.892134632574111*^-7, 
      0.3, -1.338171984247668*^-6}, {9.805641367002497*^-7, 
      0.3, -1.4005398677556818`*^-6}, {1.0762841695417155`*^-6, 
      0.3, -1.4691471786795621`*^-6}, {1.1767998167441179`*^-6, 
      0.3, -1.5442997167648015`*^-6}, {1.2825578682226035`*^-6, 
      0.3, -1.6263331082461823`*^-6}, {1.394029652934908*^-6, 
      0.3, -1.71561273300299*^-6}, {1.51171325322889*^-6, 
      0.3, -1.8125352049856501`*^-6}, {1.6361317098260666`*^-6, 
      0.3, -1.9175333877777697`*^-6}, {1.7678395422205298`*^-6, 
      0.3, -2.0310749283534105`*^-6}, {1.907423618607151*^-6, 
      0.3, -2.1536656344594187`*^-6}, {2.055506008429541*^-6, 
      0.3, -2.2858515333959365`*^-6}, {2.2127462975506236`*^-6, 
      0.3, -2.4282217077867856`*^-6}, {2.3798454781386005`*^-6, 
      0.3, -2.581410069592885*^-6}, {2.557547540632761*^-6, 
      0.3, -2.746099571689989*^-6}, {2.746644283435241*^-6, 
      0.3, -2.9230238905022468`*^-6}, {2.9479783992742266`*^-6, 
      0.3, -3.1129710894528917`*^-6}, {3.162446532496442*^-6, 
      0.3, -3.3167877917054726`*^-6}, {3.3910043609394717`*^-6, 
      0.3, -3.535381924919711*^-6}, {3.634670374988702*^-6, 
      0.3, -3.7697272163383716`*^-6}, {3.894530061252142*^-6, 
      0.3, -4.020867872323033*^-6}, {4.1717410638260034`*^-6, 
      0.3, -4.289922920032549*^-6}, {4.467538506486905*^-6, 
      0.3, -4.578091033763461*^-6}, {4.783240401492533*^-6, 
      0.3, -4.886655963661626*^-6}, {5.120253227446524*^-6, 
      0.3, -5.216992544158132*^-6}, {5.480078473757281*^-6, 
      0.3, -5.570572547299763*^-6}, {5.864319346194713*^-6, 
      0.3, -5.948971224642474*^-6}, {6.274687484623632*^-6, 
      0.3, -6.35387474309596*^-6}, {6.7130116297313*^-6, 
      0.3, -6.7870866719558956`*^-6}, {7.181244425828174*^-6, 
      0.3, -7.250537344915815*^-6}, {7.681471934867809*^-6, 
      0.3, -7.746291657043595*^-6}, {8.21592302779506*^-6, 
      0.3, -8.27655816692727*^-6}, {8.786978760963714*^-6, 
      0.3, -8.84369948590293*^-6}, {9.397183397558899*^-6, 
      0.3, -9.45024239462441*^-6}, {0.000010049255584683492`, 
      0.3, -0.000010098889257900972`}, {0.000010746100503259545`, 
      0.3, -0.000010792530027594574`}, {0.000011490822888526703`, 
      0.3, -0.00001153425504164126}, {0.000012286740657069303`, 
      0.3, -0.000012327368997168232`}, {0.00001313739991711532, 
      0.3, -0.000013175405447032781`}, {0.000014046590610532026`, 
      0.3, -0.000014082142699571559`}, {0.0000150183635220846, 
      0.3, -0.000015051620528723258`}, {0.00001605704822243643, 
      0.3, -0.000016088158276858134`}, {0.00001716727242061475, 
      0.3, -0.000017196374036197515`}, {0.000018353982436232473`, 
      0.3, -0.000018381205369457523`}, {0.000019622465483006438`, 
      0.3, -0.000019647931062734855`}, {0.000020978373130716244`, 
      0.3, -0.000021002194738343354`}, {0.00002242774636934795, 
      0.3, -0.000022450030114352384`}, {0.000023977042582054545`, 
      0.3, -0.000023997887828529208`}, {0.000025633164454551888`, 
      0.3, -0.000025652664038571083`}, {0.000027403490561375354`, 
      0.3, -0.000027421731314077117`}, {0.0000292959082653284, 
      0.3, -0.000029312971458357415`}, {0.000031318848873378776`, 
      0.3, -0.000031334810609387646`}, {0.00003348132534850715, 
      0.3, -0.000033496256633521026`}, {0.000035792972158988854`, 
      0.3, -0.000035806939564783}, {0.000038264088488607336`, 
      0.3, -0.00003827715422451536}, {0.00004090568397544407, 
      0.3, -0.00004091790623560334}, {0.00004372952780693092, 
      0.3, -0.00004374096101269307}, {0.00004674820111162362, 
      0.3, -0.00004675889622481993}, {0.000049975153088467726`, 
      0.3, -0.0000499851577569037}, {0.00005342476085129323, 
      0.3, -0.00005343411969170071}, {0.000057112393595193064`, 
      0.3, -0.00005712114823950704}, {0.00006105448091275595, 
      0.3, -0.00006106267035825647}, {0.00006526858609391412, 
      0.3, -0.00006527624684045025}, {0.00006977348439662157, 
      0.3000000001002776, -0.00006978065053188749}, {0.00007458924661465522, 
      0.3000000002148738, -0.00007459595005321001}, {0.00007973732856008432, 
      0.300000000345833, -0.0000797435991513294}, {0.00008524066661767659, 
      0.3000000004954918, -0.00008524653232142091}, {0.00009112377999846065, 
      0.3000000006665202, -0.000091129266923227}, {0.00009741287992662876, 
      0.3000000008619696, -0.00009741801246819544}, {0.0001041359863976564, 
      0.30000000108532704`, -0.0001041407874132914}, {0.00011132305307885435`,
       0.3000000013405774, -0.00011132754392926088`}, {
      0.00011900610072265799`, 
      0.30000000163227475`, -0.00011901030138832464`}, {
      0.00012721935984334127`, 
      0.30000000196562326`, -0.00012722328900696182`}, {
      0.00013599942322620426`, 
      0.30000000234657026`, -0.00013600309834724245`}, {
      0.00014538540895911082`, 0.3000000027819123, -0.0001453888463454958}, {
      0.0001554191347082767, 0.3000000032794164, -0.00015542234959911117`}, {
      0.0001661453040401259, 
      0.30000000384795855`, -0.00016614831066260393`}, {0.0001776117055793287,
       0.30000000449768227`, -0.00017761451722295485`}, {
      0.00018986942593492845`, 0.3000000052401794, -0.0001898720549970068}, {
      0.00020297307731271624`, 
      0.30000000608869687`, -0.00020297553532992293`}, {
      0.00021698104080191468`, 
      0.3000000070583733, -0.00021698333853473526`}, {0.0002319557265172252, 
      0.30000000816650885`, -0.00023195787395998015`}, {
      0.00024796385163889794`, 0.3000000094328739, -0.0002479658580604297}, {
      0.00026507673766399813`, 
      0.30000001088006195`, -0.0002650786116353576}, {0.0002833706281601616, 
      0.30000001253389247`, -0.0002833723775916395}, {0.0003029270284733349, 
      0.3000000144238717, -0.0003029286606115613}, {0.0003238330688411456, 
      0.3000000165837191, -0.00032383459030045116`}, {0.0003461818926075196, 
      0.3000000190519689, -0.0003461833093541502}, {0.00037007307119617824`, 
      0.30000002187265745`, -0.00037007438854760416`}, {
      0.00039561304773806834`, 
      0.3000000250961092, -0.00039561427034712877`}, {0.00042291561130662923`,
       0.30000002877983417`, -0.0004229167431452081}, {
      0.00045210240390118264`, 
      0.30000003298955435`, -0.00045210344820306215`}, {0.0004833034623926922,
       0.30000003780037593`, -0.00048330442160383956`}, {
      0.0005166577978904463, 0.30000004329812957`, -0.000516658673586675}, {
      0.0005523140150832487, 0.3000000495809015, -0.0005523148078700134}, {
      0.0005904309743276877, 0.3000000567607835, -0.0005904316837097919}, {
      0.0006311784994258328, 0.30000006496587295`, -0.00063117912364903}, {
      0.000674738134260248, 0.300000074342558, -0.0006747386700968372}, {
      0.0007213039516352518, 0.30000008505812925`, -0.0007213043941288693}, {
      0.0007710834179417777, 0.30000009730376465`, -0.0007710837600978929}, {
      0.0008242983175084023, 0.30000011129794, -0.0008242985498950338}, {
      0.0008811857407324859, 0.3000001272903271, -0.0008811858510022799}, {
      0.0009419991404183611, 0.3000001455662477, -0.0009419991127118349}, {
      0.0010070094610130503`, 0.3000001664517644, -0.001007009275231507}, {
      0.00107650634578046, 0.3000001903194975, -0.0010765059766938226`}, {
      0.0011507994272908625`, 
      0.30000021759527296`, -0.0011507988434443434`}, {0.0012302197069769044`,
       0.3000002487657197, -0.0012302188693516635`}, {0.0013151210299046294`, 
      0.300000284386951, -0.0013151198902767423`}, {0.0014058816613267988`, 
      0.30000032509448626`, -0.0014058801602674098`}, {0.0015029059720567627`,
       0.30000037161458903`, -0.0015029040364780975`}, {
      0.0016066262401614735`, 0.3000004247772238, -0.001606623780321936}, {
      0.0017175045770139482`, 0.3000004855308628, -0.0017175014828545102`}, {
      0.0018360349862832602`, 0.3000005549594074, -0.0018360311229556245`}, {
      0.0019627455650519975`, 
      0.30000063430152496`, -0.0019627407674441904`}, {0.0020982008568583314`,
       0.30000072497274655`, -0.002098194922915674}, {0.0022430043671724798`, 
      0.30000082859072014`, -0.0022429970497267813`}, {0.00239780125250794, 
      0.30000094700406876`, -0.0023977922493015366`}, {0.0025632811951723598`,
       0.3000010823253693, -0.002563270136666823}, {0.0027401814764751843`, 
      0.3000012369688391, -0.0027401679109564756`}, {0.002929290262103052, 
      0.3000014136934033, -0.002929273637484363}, {0.0031314501143230346`, 
      0.3000016156519103, -0.0031314297559121534`}, {0.0033475617466864893`, 
      0.3000018464473736, -0.0033475368300262226`}, {0.003578588037997289, 
      0.3000021101972418, -0.003578557555683911}, {0.0038255583234666646`, 
      0.3000024116068439, -0.0038255210446115832`}, {0.004089572982219352, 
      0.3000027560533173, -0.004089527402928417}, {0.004371808341655212, 
      0.300003149681517, -0.004371752624527085}, {0.00467352192058243, 
      0.3000035995136125, -0.0046734538208001815`}, {0.004996058034577381, 
      0.3000041135743275, -0.004995974809615338}, {0.005340853788648212, 
      0.30000470103405236`, -0.005340752087967455}, {0.005709445484036219, 
      0.300005372372379, -0.005709321214332599}, {0.006103475467860875, 
      0.30000613956497046`, -0.006103323628446886}, {0.006524699456323306, 
      0.30000701629709164`, -0.006524513938024497}, {0.006974994364334822, 
      0.3000080182076023, -0.006974767703818182}, {0.007456366676750825, 
      0.30000916316775256`, -0.0074560897564061685`}, {0.007970961398864078, 
      0.30001047159973976`, -0.00797062308017506}, {0.008521071626473854, 
      0.30001196684068937`, -0.008520658302141453}, {0.009109148778704546, 
      0.3000136755585268, -0.009108643825520594}, {0.009737813539817574, 
      0.30001562822712485`, -0.009737196650299144}, {0.010409867559563387`, 
      0.3000178596691579, -0.010409113925489264`}, {0.011128305965176409`, 
      0.30002040967628824`, -0.011127385280217946`}, {0.01189633074194574, 
      0.30002332371767126`, -0.011895205983320157`}, {0.012717365043424684`, 
      0.30002665374931803`, -0.012715990983629086`}, {0.013595068496803983`, 
      0.3000304591386215, -0.01359338988565323}, {0.014533353573793735`, 
      0.3000348077203672, -0.014531302917757671`}, {0.015536403102579196`, 
      0.3000397770028418, -0.015533897952261478`}, {0.016608689002072616`, 
      0.30004545554525963`, -0.01660562863895439}, {0.017754992325830336`, 
      0.3000519445306965, -0.01775125371532304}, {0.01898042470968629, 
      0.3000593595620851, -0.018975857558149956`}, {0.02029045132444037, 
      0.30006783271265514`, -0.020284872041950338`}, {0.02169091544289653, 
      0.30007751486653583`, -0.021684099769763085`}, {0.02318806473925757, 
      0.30008857839015346`, -0.023179738740879578`}, {0.02478857944843795, 
      0.3001012201806114, -0.02477840851789721}, {0.02649960252336704, 
      0.30011566514351806`, -0.026487177951666656`}, {0.02832877193993959, 
      0.30013217015980026`, -0.02831359451683554}, {0.030284255312075535`, 
      0.3001510286089982, -0.03026571530223716}, {0.03237478699353109, 
      0.30017257552546367`, -0.03235213968868502}, {0.03460970785885192, 
      0.3001971934738677, -0.034582043730999594`}, {0.036999007973375755`, 
      0.3002253192415513, -0.036965216240340215`}, {0.03955337238171724, 
      0.3002574514575978, -0.03951209653593558}, {0.04228423026595588, 
      0.3002941592621327, -0.042233813800639605`}, {0.04520380774908359, 
      0.3003360921643009, -0.045142227930600444`}, {0.0483251846464476, 
      0.30038399124362886`, -0.048249971713548064`}, {0.05166235549825047, 
      0.30043870186698907`, -0.05157049410014941}, {0.05523029524993295, 
      0.30050118811200355`, -0.055118104245355334`}, {0.05904502998470661, 
      0.3005725491071835, -0.05890801588781925}, {0.06312371315377599, 
      0.30065403751898007`, -0.06295639150065316}, {0.06748470779487076, 
      0.3007470804355627, -0.06728038548042173}, {0.0721476752783006, 
      0.3008533029155852, -0.07189818543667753}, {0.07713367117111376, 
      0.30097455448607985`, -0.07682905039354627}, {0.08246524886267029, 
      0.30111293888501756`, -0.08209334440844993}, {0.0881665716466235, 
      0.3012708473483421, -0.08771256373990557}, {0.0942635340010443, 
      0.30145099573483136`, -0.09370935524351869}, {0.10078389284419922`, 
      0.3016564657601081, -0.10010752312788083`}, {0.10775740955923041`, 
      0.3018907505670492, -0.10693202054315319`}, {0.11521600356329816`, 
      0.3021578047851741, -0.11420892168585822`}, {0.12319391812623297`, 
      0.3024620991151235, -0.12196536916355255`}, {0.13172789899268278`, 
      0.3028086793015312, -0.1302294902518051}, {0.1408573860910586, 
      0.30320322910976033`, -0.13903027437354845`}, {0.1506247181679111, 
      0.3036521365754355, -0.1483974026216071}, {0.16107534949306637`, 
      0.3041625623208501, -0.1583610184216881}, {0.17225807673791116`, 
      0.30474250809289494`, -0.16895142650359207`}, {0.18422527260224805`, 
      0.3054008828298687, -0.18019870524759446`}, {0.19703312057890637`, 
      0.30614756245969166`, -0.19213221527830465`}, {0.21074184217715586`, 
      0.3069934382158226, -0.20477998503360811`}, {0.2254159037028243, 
      0.30795044647700814`, -0.21816795218499851`}, {0.2411241839964256, 
      0.30903157095199507`, -0.23231903861647235`}, {0.25794007701821803`, 
      0.3102508054298101, -0.24725203677564145`}, {0.2759414935252364, 
      0.3116230623500524, -0.26298028746315394`}, {0.295210714119739, 
      0.31316400927352156`, -0.2795101347497447}, {0.31583403176931957`, 
      0.3148898122852154, -0.29683915434710784`}, {0.3379011061896317, 
      0.31681676304031803`, -0.314954169478147}, {0.3615039369052394, 
      0.31896076554426306`, -0.3338290954659602}, {0.3867353495351432, 
      0.32133666128603067`, -0.3534226931893527}, {0.41368688613914556`, 
      0.32395737896424814`, -0.3736763636711084}, {0.44244600302881926`, 
      0.32683291005506543`, -0.3945121805578173}, {0.4730925182305451, 
      0.32996913603691014`, -0.4158314289969063}, {0.5056943263482147, 
      0.33336656826049843`, -0.4375139865310714}, {0.5403025183313295, 
      0.3370191055983919, -0.4594189235068815}, {0.5769462055781716, 
      0.34091296191782233`, -0.4813866882329358}, {0.6156275325864738, 
      0.34502595296086047`, -0.5032431439417595}, {0.6563175277198465, 
      0.3493273430738574, -0.5248055182700354}, {0.6989535249913433, 
      0.35377841842736363`, -0.5458900169217267}, {0.7434388252851661, 
      0.3583338648901891, -0.5663204909085279}, {0.7896450154164585, 
      0.3629438933553869, -0.5859372260974094}, {0.8374169510219144, 
      0.367556903399873, -0.6046047595236947}, {0.8865799302492232, 
      0.3721223538166144, -0.6222177044808056}, {0.936948180895877, 
      0.37659345908121306`, -0.6387038924702999}, {0.9883335812519436, 
      0.38092937329487647`, -0.6540246268059791}, {1.0405535882958867`, 
      0.38509664204801297`, -0.6681723419865085}, {1.093437615165644, 
      0.3890698557918118, -0.6811663334297628}, {1.1468314752982347`, 
      0.39283157783002937`, -0.6930473869541509}, {1.2005998741214876`, 
      0.39637171269640115`, -0.703872101927513}, {1.2546271972636585`, 
      0.39968651661534166`, -0.7137075305293694}, {1.308816987094755, 
      0.40277744064192456`, -0.7226265301134435}, {1.3630905311120634`, 
      0.4056499578691693, -0.7307040127673007}, {1.4173849422709395`, 
      0.40831247735611165`, -0.7380141128794442}, {1.4716510310355502`, 
      0.4107754021710105, -0.7446281896989364}, {1.5258511809041928`, 
      0.4130503536401865, -0.7506135301377144}, {1.5799573607829678`, 
      0.4151495600044983, -0.7560326029636338}, {1.6339493461865136`, 
      0.41708539379941934`, -0.7609427243895414}, {1.6878131776843661`, 
      0.4188700358717764, -0.7653960152654676}, {1.741539856816664, 
      0.4205152424853373, -0.7694395538280221}, {1.79512426327494, 
      0.42203219338183945`, -0.7731156507449787}, {1.8485642689762722`, 
      0.4234314014821381, -0.7764621928638084}, {1.90186002186454, 
      0.42472266819182214`, -0.7795130179549405}, {1.9550133727026615`, 
      0.4259150714753128, -0.7822982949647412}, {2.0080274202907025`, 
      0.4270169767124536, -0.7848448933577121}, {2.0609061534951594`, 
      0.4280360627510862, -0.7871767316397609}, {2.1136541716203365`, 
      0.4289793575127929, -0.7893150996976371}, {2.166276467665484, 
      0.42985327903941634`, -0.7912789526645609}, {2.2187782617279996`, 
      0.4306636790466899, -0.7930851760316731}, {2.2711648741709087`, 
      0.4314158869428034, -0.7947488229796923}, {2.3234416301671934`, 
      0.4321147529333527, -0.7962833256369191}, {2.375613788889898, 
      0.4327646893208488, -0.7977006823474269}, {2.4276864919744323`, 
      0.4333697094586514, -0.7990116231776239}, {2.4796647269812504`, 
      0.43393346406922123`, -0.800225755885013}, {2.531553302474667, 
      0.43445927481099916`, -0.8013516944783234}, {2.5833568320447307`, 
      0.43495016509699586`, -0.8023971723527776}, {2.63507972516641, 
      0.4354088882464671, -0.8033691418143113}, {2.6867261832414977`, 
      0.43583795310020584`, -0.8042738616290355}, {2.7383001995265017`, 
      0.43623964725843917`, -0.805116974059668}, {2.789805561933056, 
      0.4366160581142979, -0.8059035726853067}, {2.8412458579112463`, 
      0.43696909185986643`, -0.8066382621481172}, {2.892624480802896, 
      0.4373004906392209, -0.8073252108317279}, {2.9439446371910845`, 
      0.4376118480159883, -0.8079681973516353}, {2.995209354881731, 
      0.43790462291349525`, -0.808570651627272}, {
      3, 0.4379319824835207, -0.8086269504769404}}], 
    Line3DBox[{{0., 0.15, -1.*^-6}, {6.443433194933083*^-8, 
      0.15, -1.0020737743277588`*^-6}, {1.29135996939957*^-7, 
      0.15, -1.0083037360470293`*^-6}, {1.9437392017844482`*^-7, 
      0.15, -1.0187155694847545`*^-6}, {2.604175827966277*^-7, 
      0.15, -1.0333527257001537`*^-6}, {3.275412657362031*^-7, 
      0.15, -1.052275781813812*^-6}, {3.960227023744951*^-7, 
      0.15, -1.075563453436069*^-6}, {4.661470125392186*^-7, 
      0.15, -1.1033119718036767`*^-6}, {5.3820530100713*^-7, 
      0.15, -1.1356362908537015`*^-6}, {6.124959603125292*^-7, 
      0.15, -1.1726706735639933`*^-6}, {6.89326260907065*^-7, 
      0.15, -1.2145691776717817`*^-6}, {7.690150142080328*^-7, 
      0.15, -1.2615055204808035`*^-6}, {8.518946330387656*^-7, 
      0.15, -1.3136732448486927`*^-6}, {9.383079665149491*^-7, 
      0.15, -1.3712892191755178`*^-6}, {1.0286122308558473`*^-6, 
      0.15, -1.4345932356634524`*^-6}, {1.1231827602023882`*^-6, 
      0.15, -1.5038472988356013`*^-6}, {1.2224118457091072`*^-6, 
      0.15, -1.5793386165067243`*^-6}, {1.3267109036521641`*^-6, 
      0.15, -1.6613804031386458`*^-6}, {1.436512528480057*^-6, 
      0.15, -1.7503129200260717`*^-6}, {1.5522727854556216`*^-6, 
      0.15, -1.8465044763969238`*^-6}, {1.6744712289355113`*^-6, 
      0.15, -1.9503545104569073`*^-6}, {1.8036147966794545`*^-6, 
      0.15, -2.062293646635765*^-6}, {1.940238758439581*^-6, 
      0.15, -2.182786478150043*^-6}, {2.0849097320306366`*^-6, 
      0.15, -2.312332789943245*^-6}, {2.2382283525434406`*^-6, 
      0.15, -2.4514693465684016`*^-6}, {2.4008302492228466`*^-6, 
      0.15, -2.600773470202083*^-6}, {2.573389767630285*^-6, 
      0.15, -2.7608644608034433`*^-6}, {2.7566225858631495`*^-6, 
      0.15, -2.932406325796533*^-6}, {2.951288820511898*^-6, 
      0.15, -3.1161104132683897`*^-6}, {3.1581952939892454`*^-6, 
      0.15, -3.312739182704914*^-6}, {3.378200836005567*^-6, 
      0.15, -3.5231075295948152`*^-6}, {3.61221755113906*^-6, 
      0.15, -3.748088336917419*^-6}, {3.86121620556135*^-6, 
      0.15, -3.988614567270195*^-6}, {4.126229739409668*^-6, 
      0.15, -4.2456836246881784`*^-6}, {4.4083570627826935`*^-6, 
      0.15, -4.520361963377964*^-6}, {4.708768507941547*^-6, 
      0.15, -4.813788644970639*^-6}, {5.0287098457947836`*^-6, 
      0.15, -5.127180876835195*^-6}, {5.369507999659964*^-6, 
      0.15, -5.461838527973099*^-6}, {5.732576472376144*^-6, 
      0.15, -5.81914959442285*^-6}, {6.119421361992568*^-6, 
      0.15, -6.2005958041765445`*^-6}, {6.531646939786244*^-6, 
      0.15, -6.607759422182722*^-6}, {6.9709629130371766`*^-6, 
      0.15, -7.042329212391981*^-6}, {7.439191562162873*^-6, 
      0.15, -7.506107396114734*^-6}, {7.938274724274568*^-6, 
      0.15, -8.001017695340337*^-6}, {8.470282461155048*^-6, 
      0.15, -8.529112703386299*^-6}, {9.037421109141385*^-6, 
      0.15, -9.092582929666342*^-6}, {9.642043200808865*^-6, 
      0.15, -9.693765119550882*^-6}, {0.000010286656185943047`, 
      0.15, -0.000010335152975760652`}, {0.000010973933850575575`, 
      0.15, -0.000011019406488005315`}, {0.000011706726697223026`, 
      0.15, -0.000011749363671065353`}, {0.000012488073957163347`, 
      0.15, -0.000012528052147107163`}, {0.000013321216344263034`, 
      0.15, -0.000013358701555071304`}, {0.000014209609413835587`, 
      0.15, -0.000014244757027707254`}, {0.000015156937802206634`, 
      0.15, -0.000015189893572783509`}, {0.000016167130549057407`, 
      0.15, -0.000016198031275580866`}, {0.000017244377535889845`, 
      0.15, -0.00001727335141544887}, {0.000018393146794283704`, 
      0.15, -0.00001842031387730081}, {0.000019618202898414915`, 
      0.15, -0.000019643675788025543`}, {0.000020924626777148146`, 
      0.15, -0.00002094851119640539}, {0.000022317836993089275`, 
      0.15, -0.000022340231912757613`}, {0.000023803611876170983`, 
      0.15, -0.000023824610294650588`}, {0.000025388113839235068`, 
      0.15, -0.00002540780283894287}, {0.000027077914751994338`, 
      0.15, -0.000027096375901118768`}, {0.00002888002311751658, 
      0.15, -0.000028897333010437952`}, {0.00003080191328527931, 
      0.15, -0.000030818143772824316`}, {0.000032851556489941735`, 
      0.15, -0.00003286677481316332}, {0.000035037453682239424`, 
      0.15, -0.00003505172304761742}, {0.000037368671085706535`, 
      0.15, -0.000037382050626844624`}, {0.000039854877581892736`, 
      0.15, -0.00003986742273932176}, {0.000042506384834936774`, 
      0.15, -0.00004251814767613534}, {0.00004533419016956659, 
      0.15, -0.000045345219475656264`}, {0.00004835002208155722, 
      0.15, -0.000048360363623697136`}, {0.00005156638896614365, 
      0.15, -0.00005157608560207229}, {0.00005499663090103541, 
      0.15, -0.00005500572285228446}, {0.000058654975048496585`, 
      0.15, -0.0000586635000202469}, {0.00006255659466489486, 
      0.15, -0.00006256458795250105}, {0.00006671767193484964, 
      0.15, -0.00006672516671623809}, {0.0000711554652159935, 
      0.15, -0.00007116249257914385}, {0.00007588838055895836, 
      0.15, -0.00007589496964110088}, {0.00008093604803883369, 
      0.15, -0.00008094222617526713}, {0.0000863194032180542, 
      0.15, -0.00008632519599178665}, {0.0000920607739040593, 
      0.15, -0.00009206620533611016}, {0.00009818397282551279, 
      0.15, -0.00009818906541840536}, {0.00010471439636318739`, 
      0.15000000010166337`, -0.00010471917120611992`}, {
      0.00011167912986716826`, 
      0.15000000021729945`, -0.00011168360676735046`}, {
      0.00011910706005278342`, 
      0.15000000034882868`, -0.00011911125754583032`}, {0.0001270289947580574,
       0.1500000004984354, -0.0001270329302174018}, {0.00013547779073460855`, 
      0.15000000066860422`, -0.00013548148044931316`}, {
      0.00014448848994706118`, 
      0.1500000008621612, -0.00014449194914730864`}, {0.00015409846486912917`,
       0.15000000108232084`, -0.00015410170783296793`}, {
      0.00016434757350156033`, 
      0.15000000133273944`, -0.00016435061363066813`}, {0.0001752783247297733,
       0.1500000016175758, -0.00017528117453402943`}, {
      0.00018693605458168586`, 
      0.15000000194156032`, -0.00018693872576077777`}, {
      0.00019936911426552607`, 
      0.1500000023100736, -0.00019937161777958416`}, {0.00021262907073702056`,
       0.1500000027292357, -0.0002126314168190564}, {0.00022677092056696738`, 
      0.15000000320600784`, -0.00022677311875134596`}, {
      0.00024185331803494074`, 0.150000003748308, -0.0002418553771987277}, {
      0.0002579388184017046, 
      0.15000000436514238`, -0.00025794074680266806`}, {0.0002750941373723053,
       0.1500000050667551, -0.00027509594266134226`}, {
      0.00029339042778768113`, 
      0.1500000058647981, -0.00029339211704989567`}, {0.0003129035747692219, 
      0.15000000677252492`, -0.00031290515449428037`}, {
      0.00033371451041796965`, 
      0.15000000780501055`, -0.00033371598654488533`}, {0.0003559095495145768,
       0.15000000897940197`, -0.0003559109274145519}, {
      0.00037958074750004745`, 
      0.15000001031520283`, -0.00037958203198528004`}, {0.0004048262822948104,
       0.15000001183459738`, -0.00040482747759557395`}, {
      0.00043175086149300606`, 
      0.15000001356281895`, -0.0004317519712385253}, {0.0004604661566489217, 
      0.15000001552856887`, -0.0004604671838312866}, {0.0004910912664466505, 
      0.15000001776449326`, -0.0004910922133670627}, {0.0005237532106676704, 
      0.15000002030772513`, -0.000523754078876672}, {0.0005585874570155575, 
      0.15000002320050107`, -0.000558588247237684}, {0.0005957384829933214, 
      0.15000002649086272`, -0.0005957391950053186}, {0.0006353603751225251, 
      0.1500000302334546, -0.0006353610076361863}, {0.0006776174680419281, 
      0.1500000344904316, -0.0006776180185372486}, {0.000722685026104194, 
      0.15000003933249118`, -0.0007226854906220482}, {0.0007707499703007866, 
      0.15000004484004753`, -0.0007707503431971136}, {0.0008220116535442863, 
      0.15000005110456704`, -0.0008220119271781843}, {0.0008766826875044734, 
      0.15000005823008725`, -0.0008766828518696191}, {0.0009349898244485253, 
      0.15000006633494464`, -0.0009349898667137958}, {0.0009971748977322388, 
      0.15000007555373995`, -0.0009971748016765931}, {0.0010634958248365986`, 
      0.15000008603957343`, -0.0010634955701737479`}, {0.0011342276771294855`,
       0.15000009796658748`, -0.0011342272386757981`}, {
      0.0012096638207727435`, 0.1500001115328586, -0.0012096631674416948`}, {
      0.0012901171335199827`, 
      0.15000012696368697`, -0.0012901162270954835`}, {0.0013759213024425404`,
       0.15000014451533789`, -0.0013759200960970041`}, {
      0.0014674322079849794`, 
      0.15000016447929768`, -0.0014674306444638647`}, {0.0015650294000656966`,
       0.1500001871871144, -0.001565027409502451}, {0.0016691176723780932`, 
      0.15000021301590374`, -0.001669115169627918}, {0.0017801287414018832`, 
      0.15000024239461188`, -0.00178012562281149}, {0.001898523037104124, 
      0.15000027581113867`, -0.001898519176589697}, {0.00202479161275562, 
      0.15000031382044016`, -0.0020247868570476947`}, {0.0021594581817988403`,
       0.15000035705374443`, -0.0021594523446629454`}, {
      0.0023030812902049918`, 
      0.15000040622903402`, -0.0023030741454436914`}, {0.0024562566333622016`,
       0.1500004621629689, -0.002456247906311213}, {0.0026196195270925884`, 
      0.150000525784448, -0.00261960888431164}, {0.0027938475430727963`, 
      0.15000059815003441`, -0.0027938345798373615`}, {0.0029796633196000582`,
       0.15000068046150025`, -0.002979647544725193}, {0.003177837559378945, 
      0.15000077408578258`, -0.0031778183768087884`}, {0.0033891922267851576`,
       0.15000088057768163`, -0.003389168913259548}, {0.0036146039578949566`, 
      0.15000100170567787`, -0.0036145756358564205`}, {0.0038550076974563255`,
       0.15000113948129667`, -0.0038549733021826503`}, {0.004111400577925834, 
      0.15000129619250765`, -0.004111358817658188}, {0.004384846056707881, 
      0.1500014744417131, -0.004384795364282659}, {0.004676478328814595, 
      0.15000167718895566`, -0.0046764168029886964`}, {0.004987507033319107, 
      0.15000190780106207`, -0.0049874323675929005`}, {0.005319222273209401, 
      0.15000217010753816`, -0.005319131669482276}, {0.005672999969566956, 
      0.15000246846414209`, -0.005672890033393703}, {0.006050307572401779, 
      0.15000280782518977`, -0.006050174185933462}, {0.006452710151987363, 
      0.15000319382579144`, -0.006452548319837668}, {0.006881876896143611, 
      0.15000363287538193`, -0.006881680558413765}, {0.007339588040640932, 
      0.15000413226409456`, -0.007339349846108982}, {0.007827742261746474, 
      0.15000470028374047`, -0.00782745329273111}, {0.008348364561902846, 
      0.15000534636539634`, -0.008348014000510193}, {0.008903614681652058, 
      0.15000608123587789`, -0.00890318940491419}, {0.009495796073177248, 
      0.15000691709568723`, -0.009495280161941403}, {0.010127365473277174`, 
      0.15000786782137635`, -0.010126739616469864`}, {0.010800943116192997`, 
      0.15000894919567037`, -0.010800183888176334`}, {0.011519323629515547`, 
      0.15001017916915022`, -0.011518402613508246`}, {0.01228548765941902, 
      0.15001157815781196`, -0.012284370384199298`}, {0.013102614274714113`, 
      0.15001316938140774`, -0.013101258924844272`}, {0.013974094202713613`, 
      0.15001497924813914`, -0.013972450054064918`}, {0.014903543953680976`, 
      0.15001703779203016`, -0.014901549475775483`}, {0.015894820894712967`, 
      0.1500193791701633, -0.015892401448956126`}, {0.016952039338321317`, 
      0.1500220422279329, -0.01694910438611642}, {0.018079587715767835`, 
      0.15002507114156913`, -0.018076027432209738`}, {0.019282146910401185`, 
      0.15002851614843024`, -0.019277828077076398`}, {0.02056470983189875, 
      0.1500324343769666, -0.020559470855440732`}, {0.02193260231847937, 
      0.1500368907898502, -0.021926247188951486`}, {0.02339150546088701, 
      0.15004195925555708`, -0.023383796424583495`}, {0.024947479449316516`, 
      0.15004772376571324`, -0.024938128122732817`}, {0.02660698905254722, 
      0.15005427981779237`, -0.02659564564630615}, {0.028376930847452, 
      0.15006173598531608`, -0.028363171098760673`}, {0.03026466232687209, 
      0.15007021570058116`, -0.030247971654047252`}, {0.03227803302470779, 
      0.1500798592781605, -0.03225778731434082}, {0.03442541780911164, 
      0.15009082621102213`, -0.034400860121803156`}, {0.036715752508045145`, 
      0.15010329777512202`, -0.03668596483779953}, {0.039158572046346984`, 
      0.15011747998278072`, -0.039122441086241196`}, {0.041764051290066766`, 
      0.15013360693008088`, -0.04172022693614029}, {0.04454304881236432, 
      0.15015194458894787`, -0.04448989387094822}, {0.04750715381600893, 
      0.15017279510051387`, -0.047442683057468724`}, {0.05066873647069969, 
      0.15019650163281867`, -0.05059054278348447}, {0.0540410019493424, 
      0.15022345387285277`, -0.05394616687876581}, {0.05763804847633713, 
      0.15025409423035216`, -0.057523033866494024`}, {0.06147492973310574, 
      0.15028892483852752`, -0.06133544650850682}, {0.06556772200172194, 
      0.15032851544491177`, -0.06539857130476517}, {0.06993359646669764, 
      0.15037351229352758`, -0.06972847738098034}, {0.07459089713765445, 
      0.15042464810729492`, -0.07434217404356663}, {0.0795592249014139, 
      0.15048275328657168`, -0.07925764609220813}, {0.08485952826019535, 
      0.1505487684453193, -0.08449388575047545}, {0.09051420136168123, 
      0.15062375840974834`, -0.09007091979599768}, {0.09654718997431638, 
      0.15070892780425202`, -0.09600983013417645}, {0.10298410610358663`, 
      0.15080563834440217`, -0.10233276565227037`}, {0.10985235197643387`, 
      0.15091542794465634`, -0.10906294270115936`}, {0.11718125413288587`, 
      0.15104003172642827`, -0.11622463096579198`}, {0.12500220834398296`, 
      0.15118140497665705`, -0.12384312078618148`}, {0.13334883600534825`, 
      0.1513417480532275, -0.13194466716150252`}, {0.14225715251106233`, 
      0.15152353315541683`, -0.14055640469239078`}, {0.15176574785764263`, 
      0.15172953276714218`, -0.14970622657365618`}, {0.1619159793142802, 
      0.15196284942825458`, -0.15942261942680902`}, {0.17275217535679377`, 
      0.15222694628212277`, -0.16973444425095818`}, {0.1843218491099252, 
      0.15252567757114557`, -0.18067065207561597`}, {0.19667591815767965`, 
      0.15286331788753452`, -0.19225992104410217`}, {0.20986892561116577`, 
      0.1532445885138003, -0.20453019969931407`}, {0.2239592545734383, 
      0.15367467858291056`, -0.2175081392945353}, {0.2390093243723742, 
      0.15415925802899708`, -0.2312183961996611}, {0.25508575186536453`, 
      0.15470447836645165`, -0.24568278422295764`}, {0.2722594544473976, 
      0.15531695621957542`, -0.26091925639126695`}, {0.2906056628230839, 
      0.15600373324013792`, -0.2769406971264046}, {0.3102038009280888, 
      0.15677220465015695`, -0.2937535098204518}, {0.33113717762542755`, 
      0.15763000725316634`, -0.311355992912666}, {0.35349242042208373`, 
      0.15858485659487215`, -0.3297365114739202}, {0.37735856669431417`, 
      0.15964432239944906`, -0.34887149313246624`}, {0.40282571524710775`, 
      0.1608155320344643, -0.36872330917404217`}, {0.42998313469017824`, 
      0.16210479436597222`, -0.38923814564677306`}, {0.4589167315213375, 
      0.16351714195547337`, -0.41034402567409217`}, {0.48970580865303803`, 
      0.16505579917480884`, -0.4319492102048548}, {0.5224191044098748, 
      0.16672159823362526`, -0.4539412720756311}, {0.5571102014409604, 
      0.16851238418642894`, -0.476187191929774}, {0.5938125368646712, 
      0.17042247183635845`, -0.49853484009502547`}, {0.6325344182002504, 
      0.17244223766194677`, -0.5208161557999001}, {0.6732546228422812, 
      0.1745579413005065, -0.5428521863743206}, {0.7159192786130639, 
      0.1767518650447023, -0.5644598941989858}, {0.7604407238676623, 
      0.17900282924596678`, -0.5854603035573203}, {0.806698875207146, 
      0.18128708579467967`, -0.6056872145325876}, {0.8545452829875259, 
      0.1835795204298407, -0.6249954633156904}, {0.9038095934078743, 
      0.18585502679436267`, -0.6432676620726151}, {0.9543076866004959, 
      0.1880898735658995, -0.6604185568761428}, {1.0058504632141398`, 
      0.19026288636947847`, -0.6763965588376816}, {1.0582521987602855`, 
      0.1923563089803877, -0.6911825091454874}, {1.1113375756140589`, 
      0.1943562782370392, -0.7047861821207487}, {1.1649468523002031`, 
      0.196252920773735, -0.7172412984194413}, {1.218939016252352, 
      0.1980401366592855, -0.7285998779291487}, {1.2731930850868427`, 
      0.19971516500346453`, -0.7389266475314771}, {1.3276079185417253`, 
      0.20127803036979966`, -0.7482940103510689}, {1.3821009763253804`, 
      0.2027309542898003, -0.7567778574404037}, {1.4366064366689915`, 
      0.20407779303616852`, -0.7644543123570463}, {1.4910730169020427`, 
      0.2053235389572142, -0.7713973662330796}, {1.545461745756528, 
      0.2064739027439195, -0.7776772855094934}, {1.5997438502768229`, 
      0.20753497970769316`, -0.7833596443848247}, {1.6538988494715476`, 
      0.20851299428551015`, -0.7885048339089584}, {1.7079128951801765`, 
      0.20941411244493016`, -0.7931679160922848}, {1.761777366347437, 
      0.2102443101115075, -0.7973987146629556}, {1.8154877023850418`, 
      0.2110092860242332, -0.8012420581416861}, {1.8690424506750911`, 
      0.21171440867217778`, -0.8047381125266603}, {1.9224424991916655`, 
      0.21236468859859367`, -0.8079227588072062}, {1.9756904651346354`, 
      0.21296476903071754`, -0.8108279845814952}, {2.0287902125894246`, 
      0.2135189293215866, -0.813482269624273}, {2.0817464753720505`, 
      0.21403109699658535`, -0.815910952932403}, {2.134564564668265, 
      0.21450486526587004`, -0.8181365741899288}, {2.1872501444191768`, 
      0.21494351371017367`, -0.8201791862961479}, {2.2398090604359426`, 
      0.21535003050176268`, -0.8220566380479881}, {2.292247211859861, 
      0.2157271350181876, -0.8237848276204253}, {2.3445704558099862`, 
      0.2160773000759574, -0.8253779284165474}, {2.3967845379047183`, 
      0.21640277328231297`, -0.826848589361025}, {2.44889504285039, 
      0.2167055971990585, -0.828208111930126}, {2.500907360507634, 
      0.21698762815151051`, -0.8294666062487817}, {2.552826663822848, 
      0.21725055361258008`, -0.830633128510361}, {2.60465789579051, 
      0.21749590815799014`, -0.8317158018352258}, {2.656405763229734, 
      0.2177250880321114, -0.8327219225114595}, {2.7080747356467656`, 
      0.21793936439121975`, -0.8336580533759702}, {2.7596690478401307`, 
      0.21813989530684103`, -0.8345301059094136}, {2.811192705207923, 
      0.2183277366197175, -0.8353434124418281}, {2.862649490954469, 
      0.21850385173732406`, -0.8361027897018259}, {2.9140429745798704`, 
      0.21866912046661063`, -0.8368125947926579}, {2.9653765211816854`, 
      0.2188243469700538, -0.8374767745440482}, {
      3, 0.21892904422769105`, -0.8379247508690076}}], 
    Line3DBox[{{0., 0., -1.*^-6}, {6.370570949530546*^-8, 
      0., -1.0020271471471906`*^-6}, {1.2766949314973133`*^-7, 
      0., -1.008116712313137*^-6}, {1.9215039346977472`*^-7, 
      0., -1.018293443298604*^-6}, {2.574119273573999*^-7, 
      0., -1.0325982691908846`*^-6}, {3.237159257678373*^-7, 
      0., -1.0510897323683285`*^-6}, {3.913323642857668*^-7, 
      0., -1.073842593057055*^-6}, {4.6053396927621666`*^-7, 
      0., -1.1009494994785982`*^-6}, {5.316029386896399*^-7, 
      0., -1.1325197881286103`*^-6}, {6.048280203995727*^-7, 
      0., -1.1686811283144092`*^-6}, {6.805044994289269*^-7, 
      0., -1.2095809336683228`*^-6}, {7.589398623888822*^-7, 
      0., -1.2553846428787307`*^-6}, {8.404526996086839*^-7, 
      0., -1.306277615626886*^-6}, {9.253730839245148*^-7, 
      0., -1.3624664151541747`*^-6}, {1.0140443910186734`*^-6, 
      0., -1.4241794462859855`*^-6}, {1.1068263330131951`*^-6, 
      0., -1.4916667779835079`*^-6}, {1.204096986435562*^-6, 
      0., -1.565200606243104*^-6}, {1.3062488023446434`*^-6, 
      0., -1.6450804809149077`*^-6}, {1.41369662752848*^-6, 
      0., -1.731629708897658*^-6}, {1.526876060309171*^-6, 
      0., -1.8251991882130806`*^-6}, {1.646246324695826*^-6, 
      0., -1.9261679667974624`*^-6}, {1.772289809260034*^-6, 
      0., -2.0349467142921883`*^-6}, {1.9055184178294034`*^-6, 
      0., -2.1519756783114053`*^-6}, {2.046472538548036*^-6, 
      0., -2.277729096980033*^-6}, {2.1957234407586725`*^-6, 
      0., -2.4127169762248326`*^-6}, {2.353876291126301*^-6, 
      0., -2.557486512012702*^-6}, {2.5215730408469382`*^-6, 
      0., -2.7126239361807853`*^-6}, {2.699491988035451*^-6, 
      0., -2.878759668865763*^-6}, {2.8883552106819446`*^-6, 
      0., -3.0565665552967677`*^-6}, {3.0889287178365595`*^-6, 
      0., -3.246765163967338*^-6}, {3.3020257728801466`*^-6, 
      0., -3.4501265102775185`*^-6}, {3.5285095906670486`*^-6, 
      0., -3.6674757571514466`*^-6}, {3.7692991463216986`*^-6, 
      0., -3.899693354442991*^-6}, {4.025369978996115*^-6, 
      0., -4.147721412599827*^-6}, {4.297760564872197*^-6, 
      0., -4.412565190385922*^-6}, {4.587574786434154*^-6, 
      0., -4.695298857640522*^-6}, {4.895988017524022*^-6, 
      0., -4.997068283807054*^-6}, {5.22425075046226*^-6, 
      0., -5.319096790099253*^-6}, {5.573693720630051*^-6, 
      0., -5.662690059703035*^-6}, {5.945734037475158*^-6, 
      0., -6.029240707549391*^-6}, {6.34187932882573*^-6, 
      0., -6.42023550209111*^-6}, {6.763735989734456*^-6, 
      0., -6.8372592882445*^-6}, {7.213014246430832*^-6, 
      0., -7.282002840973516*^-6}, {7.691535849319845*^-6, 
      0., -7.756268969404608*^-6}, {8.201240426241533*^-6, 
      0., -8.261980848623406*^-6}, {8.744194629117247*^-6, 
      0., -8.801188545256455*^-6}, {9.322599720875472*^-6, 
      0., -9.376078113785154*^-6}, {9.938800466752343*^-6, 
      0., -9.988980492510754*^-6}, {0.000010595295536518429`, 
      0., -0.000010642380062753007`}, {0.000011294745963812862`, 
      0., -0.000011338926383146745`}, {0.000012039987692753574`, 
      0., -0.000012081443181924556`}, {0.00001283404197536879, 
      0., -0.000012872940900052246`}, {0.000013680128482458443`, 
      0., -0.00001371662803708792}, {0.000014581677172532375`, 
      0., -0.000014615925339892738`}, {0.000015542343036773027`, 
      0., -0.000015574478834414658`}, {0.00001656602084819016, 
      0., -0.000016596174676151885`}, {0.000017656860979855006`, 
      0., -0.00001768515487742834}, {0.000018819285768109436`, 
      0., -0.00001884583456250822}, {0.0000200580080567377, 
      0., -0.00002008291925342596}, {0.00002137804974849208, 
      0., -0.000021401424501696904`}, {0.00002278476266792347, 
      0., -0.000022806695720172822`}, {0.000024283849877083003`, 
      0., -0.000024304430235771942`}, {0.00002588138908276963, 
      0., -0.000025900700102155986`}, {0.00002758385703129966, 
      0., -0.000027601976962488676`}, {0.00002939815588964253, 
      0., -0.00002941515816394895}, {0.00003133164114865747, 
      0., -0.00003134759480065776}, {0.00003339215165128943, 
      0., -0.00003340712130926175}, {0.00003558804109159966, 
      0., -0.00003560208751258564}, {0.0000379282121713939, 
      0., -0.00003794139218279746}, {0.0000404221523881134, 
      0., -0.0000404345194243975}, {0.00004307997267749099, 
      0., -0.000043091576946585245`}, {0.000045912448450443775`, 
      0., -0.000045923336997115354`}, {0.0000489310631737936, 
      0., -0.00004894128014038095}, {0.00005214805497267523, 
      0., -0.000052157641756141564`}, {0.000055576466207939764`, 
      0., -0.000055585461682961186`}, {0.00005923019641247561, 
      0., -0.000059238637024738146`}, {0.00006312405858306502, 
      0., -0.0000631319785523779}, {0.00006727383927737234, 
      0., -0.00006728127070792752}, {0.00007169636258486122, 
      0., -0.00007170333562926643}, {0.00007640955838932872, 
      0., -0.00007641610129660628}, {0.00008143253500072704, 
      0., -0.00008143867427613696}, {0.00008678565664652367, 
      0., -0.0000867914171599732}, {0.00009249062602549807, 
      0., -0.00009249603112761401}, {0.00009857057232404, 
      0., -0.00009857564389826741}, {0.0001050501449298675, 
      0., -0.00010505490355252779`}, {0.00011195561345420578`, 
      0., -0.00011196007837268469`}, {0.00011931497413350634`, 
      0., -0.00011931916344084923`}, {0.00012715806340772828`, 
      0., -0.0001271619940614384}, {0.0001355166788626906, 
      0., -0.00013552036674080206`}, {0.00014442470811499512`, 
      0., -0.00014442816812629738`}, {0.00015391826624504604`, 
      0., -0.00015392151234455497`}, {0.0001640358421617701, 
      0., -0.0001640388874693042}, {0.00017481845471571276`, 
      0., -0.00017482131148928594`}, {0.0001863098189375721, 
      0., -0.00018631249866441987`}, {0.0001985565232988516, 
      0., -0.00019855903672194933`}, {0.0002116082185800688, 
      0., -0.00021161057574415468`}, {0.00022551781917273589`, 
      0., -0.00022552002945290745`}, {0.00024034171760636556`, 
      0., -0.00024034378973196495`}, {0.00025614001315684093`, 
      0., -0.0002561419552701}, {0.00027297675552655334`, 
      0., -0.00027297857518843004`}, {0.00029092020450802424`, 
      0., -0.00029092190871584327`}, {0.00031004310673492057`, 
      0., -0.0003100447019140819}, {0.0003304229905767459, 
      0., -0.00033042448264006084`}, {0.00035214248050225095`, 
      0., -0.00035214387481172303`}, {0.00037528963203162333`, 
      0., -0.00037529093340589513`}, {0.000399958288734953, 
      0., -0.0003999595014466769}, {0.0004262484626933278, 
      0., -0.0004262495904625569}, {0.00045426674000000197`, 
      0., -0.0004542677859196042}, {0.0004841267128484365, 
      0., -0.0004841276793714781}, {0.0005159494400690705, 
      0., -0.0005159503289680087}, {0.0005498639379500883, 
      0., -0.0005498647502209627}, {0.0005860077032828311, 
      0., -0.0005860084390656226}, {0.0006245272708178767, 
      0., -0.0006245279292729525}, {0.0006655788073415159, 
      0., -0.0006655793865221173}, {0.0007093287448332595, 
      0., -0.0007093292414892262}, {0.0007559544552113638, 
      0., -0.0007559548645783319}, {0.0008056449694454072, 
      0., -0.0008056452849859785}, {0.0008586017439453855, 
      0., -0.000858601957019608}, {0.0009150394773262925, 
      0., -0.0009150395767836952}, {0.0009751869808479588, 
      0., -0.0009751869525548798}, {0.0010392881060966182`, 
      0., -0.0010392879323356669`}, {0.0011076027336251214`, 
      0., -0.001107602392389366}, {0.0011804078265998167`, 
      0., -0.0011804072907218037`}, {0.0012579985537053506`, 
      0., -0.0012579977897984715`}, {0.0013406894858586087`, 
      0., -0.0013406884530467033`}, {0.0014288158716055086`, 
      0., -0.001428814519967623}, {0.001522734996346622, 
      0., -0.0015227332650471818`}, {0.0016228276309276223`, 
      0., -0.001622825445944109}, {0.0017294995754594759`, 
      0., -0.001729496846826668}, {0.0018431833046249997`, 
      0., -0.0018431799231086784`}, {0.001964339721162633, 
      0., -0.0019643355542217087`}, {0.0020934600246263818`, 
      0., -0.002093454911526549}, {0.002231067703009457, 
      0., -0.0022310614489099013`}, {0.002377720655315125, 
      0., -0.0023777130241084206`}, {0.002534013453684485, 
      0., -0.0025340041593329013`}, {0.0027005797542715626`, 
      0., -0.0027005684503103975`}, {0.0028780948666408917`, 
      0., -0.002878081133476159}, {0.0030672784921261815`, 
      0., -0.003067261821660561}, {0.003268897642270744, 
      0., -0.0032688774192935915`}, {0.0034837697492081775`, 
      0., -0.0034837452288590844`}, {0.003712765980603997, 
      0., -0.0037127362611095514`}, {0.003956814772656058, 
      0., -0.003956778762315402}, {0.004216905595495566, 
      0., -0.004216861972723809}, {0.004494092966315168, 
      0., -0.00449404013127486}, {0.004789500726544754, 
      0., -0.004789436742604064}, {0.005104326600497025, 
      0., -0.0051042491233597685`}, {0.005439847054035673, 
      0., -0.005439753245966964}, {0.005797422473082819, 
      0., -0.005797308899079193}, {0.006178502683075071, 
      0., -0.006178365185189732}, {0.006584632831904535, 
      0., -0.0065844663771248224`}, {0.007017459660374487, 
      0., -0.007017258156491302}, {0.007478738185816904, 
      0., -0.007478494258549573}, {0.007970338826235946, 
      0., -0.007970043549463205}, {0.008494254994189036, 
      0., -0.008493897563416055}, {0.009052611191582006, 
      0., -0.009052178528707848}, {0.009647671638678598, 
      0., -0.009647147913606022}, {0.010281849472880189`, 
      0., -0.010281215524479519`}, {0.010957716555270416`, 
      0., -0.010956949190523996`}, {0.011678013925523681`, 
      0., -0.01167708507123073}, {0.012445662948585307`, 
      0., -0.012444538624617321`}, {0.013263777199547825`, 
      0., -0.013262416276125594`}, {0.014135675136396565`, 
      0., -0.014134027829974891`}, {0.015064893613806083`, 
      0., -0.015062899666604712`}, {0.01605520229495167, 
      0., -0.01605278877162498}, {0.017110619022395537`, 
      0., -0.01710769764336117}, {0.01823542621354067, 
      0., -0.018231890127587178`}, {0.019434188350960967`, 
      0., -0.019429908229304647`}, {0.020711770643145593`, 
      0., -0.020706589952379048`}, {0.022073358936900045`, 
      0., -0.02206708821836072}, {0.023524480968870103`, 
      0., -0.023516890915784485`}, {0.025071029050467916`, 
      0., -0.025061842130487316`}, {0.02671928428795319, 
      0., -0.026708164605814773`}, {0.02847594244764043, 
      0., -0.02846248347876303}, {0.030348141585262747`, 
      0., -0.030331851333829627`}, {0.032343491568534465`, 
      0., -0.03232377461026333}, {0.03447010563304706, 
      0., -0.03444624139007358}, {0.036736634123947454`, 
      0., -0.03670775058305437}, {0.03915230058955419, 
      0., -0.03911734251054484}, {0.041726940408345854`, 
      0., -0.04168463087091187}, {0.04447104214781987, 
      0., -0.04441983604584404}, {0.047395791872793955`, 
      0., -0.047333819676347144`}, {0.050513120642057666`, 
      0., -0.050438120399438915`}, {0.05383575545614194, 
      0., -0.05374499058927952}, {0.05737727394562454, 
      0., -0.05726743388783013}, {0.06115216311909485, 
      0., -0.061019243237670245`}, {0.06517588252287992, 
      0., -0.06501503904041643}, {0.06946493220104302, 
      0., -0.069270306954771}, {0.07403692588402805, 
      0., -0.0738014347144153}, {0.0789106698774539, 
      0., -0.07862574718276794}, {0.08410624816844482, 
      0., -0.08376153866314129}, {0.08964511431449892, 
      0., -0.08922810124205734}, {0.09555019072749035, 
      0., -0.09504574765219928}, {0.10184597601012477`, 
      0., -0.10123582679007558`}, {0.10855866103963503`, 
      0., -0.10782072960082965`}, {0.1157162545171173, 
      0., -0.11482388253601364`}, {0.12334871870098899`, 
      0., -0.12226972518521492`}, {0.13148811600563548`, 
      0., -0.13018366796337186`}, {0.14016876705154985`, 
      0., -0.13859202488556696`}, {0.14942742057329822`, 
      0., -0.1475219154629108}, {0.15930343528782656`, 
      0., -0.15700112859089205`}, {0.16983897334502437`, 
      0., -0.16705793996295812`}, {0.18107920425344495`, 
      0., -0.1777208730223463}, {0.19307251710105758`, 
      0., -0.18901839177321758`}, {0.2058707373483689, 
      0., -0.2009785119398627}, {0.21952934229768017`, 
      0., -0.21362831505893334`}, {0.23410766633508537`, 
      0., -0.2269933482401624}, {0.2496690829558733, 
      0., -0.24109689074740964`}, {0.26628114513750983`, 
      0., -0.25595906757059267`}, {0.28401565851976796`, 
      0., -0.27159579029312203`}, {0.3029486528221144, 
      0., -0.28801750756186884`}, {0.32316020582730187`, 
      0., -0.3052277524007397}, {0.34473406121398376`, 
      0., -0.3232214829100857}, {0.36775696717467676`, 
      0., -0.3419832283908503}, {0.3923176486275418, 
      0., -0.3614850767641271}, {0.41850531478116615`, 
      0., -0.3816845734886717}, {0.4464076005544783, 
      0., -0.402522648566795}, {0.4761078518298296, 
      0., -0.4239217464701436}, {0.507681699746306, 
      0., -0.4457844001793372}, {0.54119293803655, 0., -0.4679925554986294}, {
      0.576688827206599, 0., -0.4904079980042102}, {0.6141950996702691, 
      0., -0.5128742367962313}, {0.6537111151438071, 
      0., -0.5352201264323727}, {0.6952057788595222, 
      0., -0.5572653361371804}, {0.7386149291063455, 
      0., -0.5788275002332691}, {0.7838408608423746, 
      0., -0.5997305410172946}, {0.8307544350559398, 
      0., -0.6198133256006522}, {0.8791998392921822, 
      0., -0.6389376108931609}, {0.929001594544534, 
      0., -0.6569942416464578}, {0.9799729818689518, 
      0., -0.6739068264063106}, {1.0319248222493083`, 
      0., -0.6896325642042247}, {1.0846735562916359`, 
      0., -0.7041603969141388}, {1.1380478127636227`, 
      0., -0.7175070711716138}, {1.1918930272322013`, 
      0., -0.7297119124984776}, {1.2460740511474957`, 
      0., -0.7408311262947508}, {1.3004759835439699`, 
      0., -0.7509322968066706}, {1.355003621769078, 
      0., -0.7600895365141304}, {1.4095799725876628`, 
      0., -0.7683795173172209}, {1.4641442259919129`, 
      0., -0.7758784367505253}, {1.518649511679431, 
      0., -0.7826598535824683}, {1.5730606648848973`, 
      0., -0.7887932636677998}, {1.6273521439837662`, 
      0., -0.7943432652812347}, {1.6815061758769887`, 
      0., -0.7993691681504054}, {1.7355111580251779`, 
      0., -0.8039249193326853}, {1.7893603156334295`, 
      0., -0.8080592430904346}, {1.8430505950017824`, 
      0., -0.8118159157064077}, {1.8965817655917117`, 
      0., -0.8152341170832211}, {1.949955700721395, 
      0., -0.8183488180306322}, {2.003175807616762, 0., -0.821191175366958}, {
      2.0562465801794407`, 0., -0.823788916810554}, {2.109173251238575, 
      0., -0.8261667047345842}, {2.1619615246033184`, 
      0., -0.8283464728189985}, {2.21461737058201, 0., -0.830347732995137}, {
      2.267146871618272, 0., -0.8321878522771629}, {2.3195561072576547`, 
      0., -0.8338823004486654}, {2.3718510698059054`, 
      0., -0.8354448703754518}, {2.424037603807252, 
      0., -0.8368878731315573}, {2.4761213639067696`, 
      0., -0.838222310286866}, {2.528107786815976, 0., -0.839458025704046}, {
      2.580002074023359, 0., -0.8406038390935522}, {2.6318091826243295`, 
      0., -0.841667663421355}, {2.6835338222245975`, 
      0., -0.8426566080833644}, {2.7351804563277775`, 
      0., -0.8435770695716229}, {2.7867533069770922`, 
      0., -0.8444348111716733}, {2.8382563617026584`, 
      0., -0.8452350330547691}, {2.8896933820462825`, 
      0., -0.8459824339663924}, {2.9410679131079327`, 
      0., -0.846681265565405}, {2.9923832936923827`, 
      0., -0.8473353803363568}, {3, 0., -0.8474324701376029}}], 
    Line3DBox[{{0., -0.15, -1.*^-6}, {
      6.443433194933083*^-8, -0.15, -1.0020737743277588`*^-6}, {
      1.29135996939957*^-7, -0.15, -1.0083037360470293`*^-6}, {
      1.9437392017844482`*^-7, -0.15, -1.0187155694847545`*^-6}, {
      2.604175827966277*^-7, -0.15, -1.0333527257001537`*^-6}, {
      3.275412657362031*^-7, -0.15, -1.052275781813812*^-6}, {
      3.960227023744951*^-7, -0.15, -1.075563453436069*^-6}, {
      4.661470125392186*^-7, -0.15, -1.1033119718036767`*^-6}, {
      5.3820530100713*^-7, -0.15, -1.1356362908537015`*^-6}, {
      6.124959603125292*^-7, -0.15, -1.1726706735639933`*^-6}, {
      6.89326260907065*^-7, -0.15, -1.2145691776717817`*^-6}, {
      7.690150142080328*^-7, -0.15, -1.2615055204808035`*^-6}, {
      8.518946330387656*^-7, -0.15, -1.3136732448486927`*^-6}, {
      9.383079665149491*^-7, -0.15, -1.3712892191755178`*^-6}, {
      1.0286122308558473`*^-6, -0.15, -1.4345932356634524`*^-6}, {
      1.1231827602023882`*^-6, -0.15, -1.5038472988356013`*^-6}, {
      1.2224118457091072`*^-6, -0.15, -1.5793386165067243`*^-6}, {
      1.3267109036521641`*^-6, -0.15, -1.6613804031386458`*^-6}, {
      1.436512528480057*^-6, -0.15, -1.7503129200260717`*^-6}, {
      1.5522727854556216`*^-6, -0.15, -1.8465044763969238`*^-6}, {
      1.6744712289355113`*^-6, -0.15, -1.9503545104569073`*^-6}, {
      1.8036147966794545`*^-6, -0.15, -2.062293646635765*^-6}, {
      1.940238758439581*^-6, -0.15, -2.182786478150043*^-6}, {
      2.0849097320306366`*^-6, -0.15, -2.312332789943245*^-6}, {
      2.2382283525434406`*^-6, -0.15, -2.4514693465684016`*^-6}, {
      2.4008302492228466`*^-6, -0.15, -2.600773470202083*^-6}, {
      2.573389767630285*^-6, -0.15, -2.7608644608034433`*^-6}, {
      2.7566225858631495`*^-6, -0.15, -2.932406325796533*^-6}, {
      2.951288820511898*^-6, -0.15, -3.1161104132683897`*^-6}, {
      3.1581952939892454`*^-6, -0.15, -3.312739182704914*^-6}, {
      3.378200836005567*^-6, -0.15, -3.5231075295948152`*^-6}, {
      3.61221755113906*^-6, -0.15, -3.748088336917419*^-6}, {
      3.86121620556135*^-6, -0.15, -3.988614567270195*^-6}, {
      4.126229739409668*^-6, -0.15, -4.2456836246881784`*^-6}, {
      4.4083570627826935`*^-6, -0.15, -4.520361963377964*^-6}, {
      4.708768507941547*^-6, -0.15, -4.813788644970639*^-6}, {
      5.0287098457947836`*^-6, -0.15, -5.127180876835195*^-6}, {
      5.369507999659964*^-6, -0.15, -5.461838527973099*^-6}, {
      5.732576472376144*^-6, -0.15, -5.81914959442285*^-6}, {
      6.119421361992568*^-6, -0.15, -6.2005958041765445`*^-6}, {
      6.531646939786244*^-6, -0.15, -6.607759422182722*^-6}, {
      6.9709629130371766`*^-6, -0.15, -7.042329212391981*^-6}, {
      7.439191562162873*^-6, -0.15, -7.506107396114734*^-6}, {
      7.938274724274568*^-6, -0.15, -8.001017695340337*^-6}, {
      8.470282461155048*^-6, -0.15, -8.529112703386299*^-6}, {
      9.037421109141385*^-6, -0.15, -9.092582929666342*^-6}, {
      9.642043200808865*^-6, -0.15, -9.693765119550882*^-6}, {
      0.000010286656185943047`, -0.15, -0.000010335152975760652`}, {
      0.000010973933850575575`, -0.15, -0.000011019406488005315`}, {
      0.000011706726697223026`, -0.15, -0.000011749363671065353`}, {
      0.000012488073957163347`, -0.15, -0.000012528052147107163`}, {
      0.000013321216344263034`, -0.15, -0.000013358701555071304`}, {
      0.000014209609413835587`, -0.15, -0.000014244757027707254`}, {
      0.000015156937802206634`, -0.15, -0.000015189893572783509`}, {
      0.000016167130549057407`, -0.15, -0.000016198031275580866`}, {
      0.000017244377535889845`, -0.15, -0.00001727335141544887}, {
      0.000018393146794283704`, -0.15, -0.00001842031387730081}, {
      0.000019618202898414915`, -0.15, -0.000019643675788025543`}, {
      0.000020924626777148146`, -0.15, -0.00002094851119640539}, {
      0.000022317836993089275`, -0.15, -0.000022340231912757613`}, {
      0.000023803611876170983`, -0.15, -0.000023824610294650588`}, {
      0.000025388113839235068`, -0.15, -0.00002540780283894287}, {
      0.000027077914751994338`, -0.15, -0.000027096375901118768`}, {
      0.00002888002311751658, -0.15, -0.000028897333010437952`}, {
      0.00003080191328527931, -0.15, -0.000030818143772824316`}, {
      0.000032851556489941735`, -0.15, -0.00003286677481316332}, {
      0.000035037453682239424`, -0.15, -0.00003505172304761742}, {
      0.000037368671085706535`, -0.15, -0.000037382050626844624`}, {
      0.000039854877581892736`, -0.15, -0.00003986742273932176}, {
      0.000042506384834936774`, -0.15, -0.00004251814767613534}, {
      0.00004533419016956659, -0.15, -0.000045345219475656264`}, {
      0.00004835002208155722, -0.15, -0.000048360363623697136`}, {
      0.00005156638896614365, -0.15, -0.00005157608560207229}, {
      0.00005499663090103541, -0.15, -0.00005500572285228446}, {
      0.000058654975048496585`, -0.15, -0.0000586635000202469}, {
      0.00006255659466489486, -0.15, -0.00006256458795250105}, {
      0.00006671767193484964, -0.15, -0.00006672516671623809}, {
      0.0000711554652159935, -0.15, -0.00007116249257914385}, {
      0.00007588838055895836, -0.15, -0.00007589496964110088}, {
      0.00008093604803883369, -0.15, -0.00008094222617526713}, {
      0.0000863194032180542, -0.15, -0.00008632519599178665}, {
      0.0000920607739040593, -0.15, -0.00009206620533611016}, {
      0.00009818397282551279, -0.15, -0.00009818906541840536}, {
      0.00010471439636318739`, -0.15000000010166337`, \
-0.00010471917120611992`}, {
      0.00011167912986716826`, -0.15000000021729945`, \
-0.00011168360676735046`}, {
      0.00011910706005278342`, -0.15000000034882868`, \
-0.00011911125754583032`}, {
      0.0001270289947580574, -0.1500000004984354, -0.0001270329302174018}, {
      0.00013547779073460855`, -0.15000000066860422`, \
-0.00013548148044931316`}, {
      0.00014448848994706118`, -0.1500000008621612, \
-0.00014449194914730864`}, {
      0.00015409846486912917`, -0.15000000108232084`, \
-0.00015410170783296793`}, {
      0.00016434757350156033`, -0.15000000133273944`, \
-0.00016435061363066813`}, {
      0.0001752783247297733, -0.1500000016175758, -0.00017528117453402943`}, {
      0.00018693605458168586`, -0.15000000194156032`, \
-0.00018693872576077777`}, {
      0.00019936911426552607`, -0.1500000023100736, \
-0.00019937161777958416`}, {
      0.00021262907073702056`, -0.1500000027292357, -0.0002126314168190564}, {
      0.00022677092056696738`, -0.15000000320600784`, \
-0.00022677311875134596`}, {
      0.00024185331803494074`, -0.150000003748308, -0.0002418553771987277}, {
      0.0002579388184017046, -0.15000000436514238`, \
-0.00025794074680266806`}, {
      0.0002750941373723053, -0.1500000050667551, -0.00027509594266134226`}, {
      0.00029339042778768113`, -0.1500000058647981, \
-0.00029339211704989567`}, {
      0.0003129035747692219, -0.15000000677252492`, \
-0.00031290515449428037`}, {
      0.00033371451041796965`, -0.15000000780501055`, \
-0.00033371598654488533`}, {
      0.0003559095495145768, -0.15000000897940197`, -0.0003559109274145519}, {
      0.00037958074750004745`, -0.15000001031520283`, \
-0.00037958203198528004`}, {
      0.0004048262822948104, -0.15000001183459738`, \
-0.00040482747759557395`}, {
      0.00043175086149300606`, -0.15000001356281895`, \
-0.0004317519712385253}, {
      0.0004604661566489217, -0.15000001552856887`, -0.0004604671838312866}, {
      0.0004910912664466505, -0.15000001776449326`, -0.0004910922133670627}, {
      0.0005237532106676704, -0.15000002030772513`, -0.000523754078876672}, {
      0.0005585874570155575, -0.15000002320050107`, -0.000558588247237684}, {
      0.0005957384829933214, -0.15000002649086272`, -0.0005957391950053186}, {
      0.0006353603751225251, -0.1500000302334546, -0.0006353610076361863}, {
      0.0006776174680419281, -0.1500000344904316, -0.0006776180185372486}, {
      0.000722685026104194, -0.15000003933249118`, -0.0007226854906220482}, {
      0.0007707499703007866, -0.15000004484004753`, -0.0007707503431971136}, {
      0.0008220116535442863, -0.15000005110456704`, -0.0008220119271781843}, {
      0.0008766826875044734, -0.15000005823008725`, -0.0008766828518696191}, {
      0.0009349898244485253, -0.15000006633494464`, -0.0009349898667137958}, {
      0.0009971748977322388, -0.15000007555373995`, -0.0009971748016765931}, {
      0.0010634958248365986`, -0.15000008603957343`, \
-0.0010634955701737479`}, {
      0.0011342276771294855`, -0.15000009796658748`, \
-0.0011342272386757981`}, {
      0.0012096638207727435`, -0.1500001115328586, -0.0012096631674416948`}, {
      0.0012901171335199827`, -0.15000012696368697`, \
-0.0012901162270954835`}, {
      0.0013759213024425404`, -0.15000014451533789`, \
-0.0013759200960970041`}, {
      0.0014674322079849794`, -0.15000016447929768`, \
-0.0014674306444638647`}, {
      0.0015650294000656966`, -0.1500001871871144, -0.001565027409502451}, {
      0.0016691176723780932`, -0.15000021301590374`, -0.001669115169627918}, {
      0.0017801287414018832`, -0.15000024239461188`, -0.00178012562281149}, {
      0.001898523037104124, -0.15000027581113867`, -0.001898519176589697}, {
      0.00202479161275562, -0.15000031382044016`, -0.0020247868570476947`}, {
      0.0021594581817988403`, -0.15000035705374443`, \
-0.0021594523446629454`}, {
      0.0023030812902049918`, -0.15000040622903402`, \
-0.0023030741454436914`}, {
      0.0024562566333622016`, -0.1500004621629689, -0.002456247906311213}, {
      0.0026196195270925884`, -0.150000525784448, -0.00261960888431164}, {
      0.0027938475430727963`, -0.15000059815003441`, \
-0.0027938345798373615`}, {
      0.0029796633196000582`, -0.15000068046150025`, -0.002979647544725193}, {
      0.003177837559378945, -0.15000077408578258`, -0.0031778183768087884`}, {
      0.0033891922267851576`, -0.15000088057768163`, -0.003389168913259548}, {
      0.0036146039578949566`, -0.15000100170567787`, \
-0.0036145756358564205`}, {
      0.0038550076974563255`, -0.15000113948129667`, \
-0.0038549733021826503`}, {
      0.004111400577925834, -0.15000129619250765`, -0.004111358817658188}, {
      0.004384846056707881, -0.1500014744417131, -0.004384795364282659}, {
      0.004676478328814595, -0.15000167718895566`, -0.0046764168029886964`}, {
      0.004987507033319107, -0.15000190780106207`, -0.0049874323675929005`}, {
      0.005319222273209401, -0.15000217010753816`, -0.005319131669482276}, {
      0.005672999969566956, -0.15000246846414209`, -0.005672890033393703}, {
      0.006050307572401779, -0.15000280782518977`, -0.006050174185933462}, {
      0.006452710151987363, -0.15000319382579144`, -0.006452548319837668}, {
      0.006881876896143611, -0.15000363287538193`, -0.006881680558413765}, {
      0.007339588040640932, -0.15000413226409456`, -0.007339349846108982}, {
      0.007827742261746474, -0.15000470028374047`, -0.00782745329273111}, {
      0.008348364561902846, -0.15000534636539634`, -0.008348014000510193}, {
      0.008903614681652058, -0.15000608123587789`, -0.00890318940491419}, {
      0.009495796073177248, -0.15000691709568723`, -0.009495280161941403}, {
      0.010127365473277174`, -0.15000786782137635`, -0.010126739616469864`}, {
      0.010800943116192997`, -0.15000894919567037`, -0.010800183888176334`}, {
      0.011519323629515547`, -0.15001017916915022`, -0.011518402613508246`}, {
      0.01228548765941902, -0.15001157815781196`, -0.012284370384199298`}, {
      0.013102614274714113`, -0.15001316938140774`, -0.013101258924844272`}, {
      0.013974094202713613`, -0.15001497924813914`, -0.013972450054064918`}, {
      0.014903543953680976`, -0.15001703779203016`, -0.014901549475775483`}, {
      0.015894820894712967`, -0.1500193791701633, -0.015892401448956126`}, {
      0.016952039338321317`, -0.1500220422279329, -0.01694910438611642}, {
      0.018079587715767835`, -0.15002507114156913`, -0.018076027432209738`}, {
      0.019282146910401185`, -0.15002851614843024`, -0.019277828077076398`}, {
      0.02056470983189875, -0.1500324343769666, -0.020559470855440732`}, {
      0.02193260231847937, -0.1500368907898502, -0.021926247188951486`}, {
      0.02339150546088701, -0.15004195925555708`, -0.023383796424583495`}, {
      0.024947479449316516`, -0.15004772376571324`, -0.024938128122732817`}, {
      0.02660698905254722, -0.15005427981779237`, -0.02659564564630615}, {
      0.028376930847452, -0.15006173598531608`, -0.028363171098760673`}, {
      0.03026466232687209, -0.15007021570058116`, -0.030247971654047252`}, {
      0.03227803302470779, -0.1500798592781605, -0.03225778731434082}, {
      0.03442541780911164, -0.15009082621102213`, -0.034400860121803156`}, {
      0.036715752508045145`, -0.15010329777512202`, -0.03668596483779953}, {
      0.039158572046346984`, -0.15011747998278072`, -0.039122441086241196`}, {
      0.041764051290066766`, -0.15013360693008088`, -0.04172022693614029}, {
      0.04454304881236432, -0.15015194458894787`, -0.04448989387094822}, {
      0.04750715381600893, -0.15017279510051387`, -0.047442683057468724`}, {
      0.05066873647069969, -0.15019650163281867`, -0.05059054278348447}, {
      0.0540410019493424, -0.15022345387285277`, -0.05394616687876581}, {
      0.05763804847633713, -0.15025409423035216`, -0.057523033866494024`}, {
      0.06147492973310574, -0.15028892483852752`, -0.06133544650850682}, {
      0.06556772200172194, -0.15032851544491177`, -0.06539857130476517}, {
      0.06993359646669764, -0.15037351229352758`, -0.06972847738098034}, {
      0.07459089713765445, -0.15042464810729492`, -0.07434217404356663}, {
      0.0795592249014139, -0.15048275328657168`, -0.07925764609220813}, {
      0.08485952826019535, -0.1505487684453193, -0.08449388575047545}, {
      0.09051420136168123, -0.15062375840974834`, -0.09007091979599768}, {
      0.09654718997431638, -0.15070892780425202`, -0.09600983013417645}, {
      0.10298410610358663`, -0.15080563834440217`, -0.10233276565227037`}, {
      0.10985235197643387`, -0.15091542794465634`, -0.10906294270115936`}, {
      0.11718125413288587`, -0.15104003172642827`, -0.11622463096579198`}, {
      0.12500220834398296`, -0.15118140497665705`, -0.12384312078618148`}, {
      0.13334883600534825`, -0.1513417480532275, -0.13194466716150252`}, {
      0.14225715251106233`, -0.15152353315541683`, -0.14055640469239078`}, {
      0.15176574785764263`, -0.15172953276714218`, -0.14970622657365618`}, {
      0.1619159793142802, -0.15196284942825458`, -0.15942261942680902`}, {
      0.17275217535679377`, -0.15222694628212277`, -0.16973444425095818`}, {
      0.1843218491099252, -0.15252567757114557`, -0.18067065207561597`}, {
      0.19667591815767965`, -0.15286331788753452`, -0.19225992104410217`}, {
      0.20986892561116577`, -0.1532445885138003, -0.20453019969931407`}, {
      0.2239592545734383, -0.15367467858291056`, -0.2175081392945353}, {
      0.2390093243723742, -0.15415925802899708`, -0.2312183961996611}, {
      0.25508575186536453`, -0.15470447836645165`, -0.24568278422295764`}, {
      0.2722594544473976, -0.15531695621957542`, -0.26091925639126695`}, {
      0.2906056628230839, -0.15600373324013792`, -0.2769406971264046}, {
      0.3102038009280888, -0.15677220465015695`, -0.2937535098204518}, {
      0.33113717762542755`, -0.15763000725316634`, -0.311355992912666}, {
      0.35349242042208373`, -0.15858485659487215`, -0.3297365114739202}, {
      0.37735856669431417`, -0.15964432239944906`, -0.34887149313246624`}, {
      0.40282571524710775`, -0.1608155320344643, -0.36872330917404217`}, {
      0.42998313469017824`, -0.16210479436597222`, -0.38923814564677306`}, {
      0.4589167315213375, -0.16351714195547337`, -0.41034402567409217`}, {
      0.48970580865303803`, -0.16505579917480884`, -0.4319492102048548}, {
      0.5224191044098748, -0.16672159823362526`, -0.4539412720756311}, {
      0.5571102014409604, -0.16851238418642894`, -0.476187191929774}, {
      0.5938125368646712, -0.17042247183635845`, -0.49853484009502547`}, {
      0.6325344182002504, -0.17244223766194677`, -0.5208161557999001}, {
      0.6732546228422812, -0.1745579413005065, -0.5428521863743206}, {
      0.7159192786130639, -0.1767518650447023, -0.5644598941989858}, {
      0.7604407238676623, -0.17900282924596678`, -0.5854603035573203}, {
      0.806698875207146, -0.18128708579467967`, -0.6056872145325876}, {
      0.8545452829875259, -0.1835795204298407, -0.6249954633156904}, {
      0.9038095934078743, -0.18585502679436267`, -0.6432676620726151}, {
      0.9543076866004959, -0.1880898735658995, -0.6604185568761428}, {
      1.0058504632141398`, -0.19026288636947847`, -0.6763965588376816}, {
      1.0582521987602855`, -0.1923563089803877, -0.6911825091454874}, {
      1.1113375756140589`, -0.1943562782370392, -0.7047861821207487}, {
      1.1649468523002031`, -0.196252920773735, -0.7172412984194413}, {
      1.218939016252352, -0.1980401366592855, -0.7285998779291487}, {
      1.2731930850868427`, -0.19971516500346453`, -0.7389266475314771}, {
      1.3276079185417253`, -0.20127803036979966`, -0.7482940103510689}, {
      1.3821009763253804`, -0.2027309542898003, -0.7567778574404037}, {
      1.4366064366689915`, -0.20407779303616852`, -0.7644543123570463}, {
      1.4910730169020427`, -0.2053235389572142, -0.7713973662330796}, {
      1.545461745756528, -0.2064739027439195, -0.7776772855094934}, {
      1.5997438502768229`, -0.20753497970769316`, -0.7833596443848247}, {
      1.6538988494715476`, -0.20851299428551015`, -0.7885048339089584}, {
      1.7079128951801765`, -0.20941411244493016`, -0.7931679160922848}, {
      1.761777366347437, -0.2102443101115075, -0.7973987146629556}, {
      1.8154877023850418`, -0.2110092860242332, -0.8012420581416861}, {
      1.8690424506750911`, -0.21171440867217778`, -0.8047381125266603}, {
      1.9224424991916655`, -0.21236468859859367`, -0.8079227588072062}, {
      1.9756904651346354`, -0.21296476903071754`, -0.8108279845814952}, {
      2.0287902125894246`, -0.2135189293215866, -0.813482269624273}, {
      2.0817464753720505`, -0.21403109699658535`, -0.815910952932403}, {
      2.134564564668265, -0.21450486526587004`, -0.8181365741899288}, {
      2.1872501444191768`, -0.21494351371017367`, -0.8201791862961479}, {
      2.2398090604359426`, -0.21535003050176268`, -0.8220566380479881}, {
      2.292247211859861, -0.2157271350181876, -0.8237848276204253}, {
      2.3445704558099862`, -0.2160773000759574, -0.8253779284165474}, {
      2.3967845379047183`, -0.21640277328231297`, -0.826848589361025}, {
      2.44889504285039, -0.2167055971990585, -0.828208111930126}, {
      2.500907360507634, -0.21698762815151051`, -0.8294666062487817}, {
      2.552826663822848, -0.21725055361258008`, -0.830633128510361}, {
      2.60465789579051, -0.21749590815799014`, -0.8317158018352258}, {
      2.656405763229734, -0.2177250880321114, -0.8327219225114595}, {
      2.7080747356467656`, -0.21793936439121975`, -0.8336580533759702}, {
      2.7596690478401307`, -0.21813989530684103`, -0.8345301059094136}, {
      2.811192705207923, -0.2183277366197175, -0.8353434124418281}, {
      2.862649490954469, -0.21850385173732406`, -0.8361027897018259}, {
      2.9140429745798704`, -0.21866912046661063`, -0.8368125947926579}, {
      2.9653765211816854`, -0.2188243469700538, -0.8374767745440482}, {
      3, -0.21892904422769105`, -0.8379247508690076}}], 
    Line3DBox[{{0., -0.3, -1.*^-6}, {
      6.678493655910459*^-8, -0.3, -1.0022276892765741`*^-6}, {
      1.3386750780970206`*^-7, -0.3, -1.0089205765157686`*^-6}, {
      2.0154668554143494`*^-7, -0.3, -1.0201085142764823`*^-6}, {
      2.701232041229943*^-7, -0.3, -1.0358415123796642`*^-6}, {
      3.39903381347727*^-7, -0.3, -1.056189472766338*^-6}, {
      4.111980071596534*^-7, -0.3, -1.081243107963027*^-6}, {
      4.843259766391138*^-7, -0.3, -1.1111135414402855`*^-6}, {
      5.596112651760028*^-7, -0.3, -1.1459345694892541`*^-6}, {
      6.373887272375092*^-7, -0.3, -1.1858616454994782`*^-6}, {
      7.180067961183765*^-7, -0.3, -1.231071681772395*^-6}, {
      8.018240914112324*^-7, -0.3, -1.2817663892485147`*^-6}, {
      8.892134632574111*^-7, -0.3, -1.338171984247668*^-6}, {
      9.805641367002497*^-7, -0.3, -1.4005398677556818`*^-6}, {
      1.0762841695417155`*^-6, -0.3, -1.4691471786795621`*^-6}, {
      1.1767998167441179`*^-6, -0.3, -1.5442997167648015`*^-6}, {
      1.2825578682226035`*^-6, -0.3, -1.6263331082461823`*^-6}, {
      1.394029652934908*^-6, -0.3, -1.71561273300299*^-6}, {
      1.51171325322889*^-6, -0.3, -1.8125352049856501`*^-6}, {
      1.6361317098260666`*^-6, -0.3, -1.9175333877777697`*^-6}, {
      1.7678395422205298`*^-6, -0.3, -2.0310749283534105`*^-6}, {
      1.907423618607151*^-6, -0.3, -2.1536656344594187`*^-6}, {
      2.055506008429541*^-6, -0.3, -2.2858515333959365`*^-6}, {
      2.2127462975506236`*^-6, -0.3, -2.4282217077867856`*^-6}, {
      2.3798454781386005`*^-6, -0.3, -2.581410069592885*^-6}, {
      2.557547540632761*^-6, -0.3, -2.746099571689989*^-6}, {
      2.746644283435241*^-6, -0.3, -2.9230238905022468`*^-6}, {
      2.9479783992742266`*^-6, -0.3, -3.1129710894528917`*^-6}, {
      3.162446532496442*^-6, -0.3, -3.3167877917054726`*^-6}, {
      3.3910043609394717`*^-6, -0.3, -3.535381924919711*^-6}, {
      3.634670374988702*^-6, -0.3, -3.7697272163383716`*^-6}, {
      3.894530061252142*^-6, -0.3, -4.020867872323033*^-6}, {
      4.1717410638260034`*^-6, -0.3, -4.289922920032549*^-6}, {
      4.467538506486905*^-6, -0.3, -4.578091033763461*^-6}, {
      4.783240401492533*^-6, -0.3, -4.886655963661626*^-6}, {
      5.120253227446524*^-6, -0.3, -5.216992544158132*^-6}, {
      5.480078473757281*^-6, -0.3, -5.570572547299763*^-6}, {
      5.864319346194713*^-6, -0.3, -5.948971224642474*^-6}, {
      6.274687484623632*^-6, -0.3, -6.35387474309596*^-6}, {
      6.7130116297313*^-6, -0.3, -6.7870866719558956`*^-6}, {
      7.181244425828174*^-6, -0.3, -7.250537344915815*^-6}, {
      7.681471934867809*^-6, -0.3, -7.746291657043595*^-6}, {
      8.21592302779506*^-6, -0.3, -8.27655816692727*^-6}, {
      8.786978760963714*^-6, -0.3, -8.84369948590293*^-6}, {
      9.397183397558899*^-6, -0.3, -9.45024239462441*^-6}, {
      0.000010049255584683492`, -0.3, -0.000010098889257900972`}, {
      0.000010746100503259545`, -0.3, -0.000010792530027594574`}, {
      0.000011490822888526703`, -0.3, -0.00001153425504164126}, {
      0.000012286740657069303`, -0.3, -0.000012327368997168232`}, {
      0.00001313739991711532, -0.3, -0.000013175405447032781`}, {
      0.000014046590610532026`, -0.3, -0.000014082142699571559`}, {
      0.0000150183635220846, -0.3, -0.000015051620528723258`}, {
      0.00001605704822243643, -0.3, -0.000016088158276858134`}, {
      0.00001716727242061475, -0.3, -0.000017196374036197515`}, {
      0.000018353982436232473`, -0.3, -0.000018381205369457523`}, {
      0.000019622465483006438`, -0.3, -0.000019647931062734855`}, {
      0.000020978373130716244`, -0.3, -0.000021002194738343354`}, {
      0.00002242774636934795, -0.3, -0.000022450030114352384`}, {
      0.000023977042582054545`, -0.3, -0.000023997887828529208`}, {
      0.000025633164454551888`, -0.3, -0.000025652664038571083`}, {
      0.000027403490561375354`, -0.3, -0.000027421731314077117`}, {
      0.0000292959082653284, -0.3, -0.000029312971458357415`}, {
      0.000031318848873378776`, -0.3, -0.000031334810609387646`}, {
      0.00003348132534850715, -0.3, -0.000033496256633521026`}, {
      0.000035792972158988854`, -0.3, -0.000035806939564783}, {
      0.000038264088488607336`, -0.3, -0.00003827715422451536}, {
      0.00004090568397544407, -0.3, -0.00004091790623560334}, {
      0.00004372952780693092, -0.3, -0.00004374096101269307}, {
      0.00004674820111162362, -0.3, -0.00004675889622481993}, {
      0.000049975153088467726`, -0.3, -0.0000499851577569037}, {
      0.00005342476085129323, -0.3, -0.00005343411969170071}, {
      0.000057112393595193064`, -0.3, -0.00005712114823950704}, {
      0.00006105448091275595, -0.3, -0.00006106267035825647}, {
      0.00006526858609391412, -0.3, -0.00006527624684045025}, {
      0.00006977348439662157, -0.3000000001002776, -0.00006978065053188749}, {
      0.00007458924661465522, -0.3000000002148738, -0.00007459595005321001}, {
      0.00007973732856008432, -0.300000000345833, -0.0000797435991513294}, {
      0.00008524066661767659, -0.3000000004954918, -0.00008524653232142091}, {
      0.00009112377999846065, -0.3000000006665202, -0.000091129266923227}, {
      0.00009741287992662876, -0.3000000008619696, -0.00009741801246819544}, {
      0.0001041359863976564, -0.30000000108532704`, -0.0001041407874132914}, {
      0.00011132305307885435`, -0.3000000013405774, \
-0.00011132754392926088`}, {
      0.00011900610072265799`, -0.30000000163227475`, \
-0.00011901030138832464`}, {
      0.00012721935984334127`, -0.30000000196562326`, \
-0.00012722328900696182`}, {
      0.00013599942322620426`, -0.30000000234657026`, \
-0.00013600309834724245`}, {
      0.00014538540895911082`, -0.3000000027819123, -0.0001453888463454958}, {
      0.0001554191347082767, -0.3000000032794164, -0.00015542234959911117`}, {
      0.0001661453040401259, -0.30000000384795855`, \
-0.00016614831066260393`}, {
      0.0001776117055793287, -0.30000000449768227`, \
-0.00017761451722295485`}, {
      0.00018986942593492845`, -0.3000000052401794, -0.0001898720549970068}, {
      0.00020297307731271624`, -0.30000000608869687`, \
-0.00020297553532992293`}, {
      0.00021698104080191468`, -0.3000000070583733, \
-0.00021698333853473526`}, {
      0.0002319557265172252, -0.30000000816650885`, \
-0.00023195787395998015`}, {
      0.00024796385163889794`, -0.3000000094328739, -0.0002479658580604297}, {
      0.00026507673766399813`, -0.30000001088006195`, \
-0.0002650786116353576}, {
      0.0002833706281601616, -0.30000001253389247`, -0.0002833723775916395}, {
      0.0003029270284733349, -0.3000000144238717, -0.0003029286606115613}, {
      0.0003238330688411456, -0.3000000165837191, -0.00032383459030045116`}, {
      0.0003461818926075196, -0.3000000190519689, -0.0003461833093541502}, {
      0.00037007307119617824`, -0.30000002187265745`, \
-0.00037007438854760416`}, {
      0.00039561304773806834`, -0.3000000250961092, \
-0.00039561427034712877`}, {
      0.00042291561130662923`, -0.30000002877983417`, \
-0.0004229167431452081}, {
      0.00045210240390118264`, -0.30000003298955435`, \
-0.00045210344820306215`}, {
      0.0004833034623926922, -0.30000003780037593`, \
-0.00048330442160383956`}, {
      0.0005166577978904463, -0.30000004329812957`, -0.000516658673586675}, {
      0.0005523140150832487, -0.3000000495809015, -0.0005523148078700134}, {
      0.0005904309743276877, -0.3000000567607835, -0.0005904316837097919}, {
      0.0006311784994258328, -0.30000006496587295`, -0.00063117912364903}, {
      0.000674738134260248, -0.300000074342558, -0.0006747386700968372}, {
      0.0007213039516352518, -0.30000008505812925`, -0.0007213043941288693}, {
      0.0007710834179417777, -0.30000009730376465`, -0.0007710837600978929}, {
      0.0008242983175084023, -0.30000011129794, -0.0008242985498950338}, {
      0.0008811857407324859, -0.3000001272903271, -0.0008811858510022799}, {
      0.0009419991404183611, -0.3000001455662477, -0.0009419991127118349}, {
      0.0010070094610130503`, -0.3000001664517644, -0.001007009275231507}, {
      0.00107650634578046, -0.3000001903194975, -0.0010765059766938226`}, {
      0.0011507994272908625`, -0.30000021759527296`, \
-0.0011507988434443434`}, {
      0.0012302197069769044`, -0.3000002487657197, -0.0012302188693516635`}, {
      0.0013151210299046294`, -0.300000284386951, -0.0013151198902767423`}, {
      0.0014058816613267988`, -0.30000032509448626`, \
-0.0014058801602674098`}, {
      0.0015029059720567627`, -0.30000037161458903`, \
-0.0015029040364780975`}, {
      0.0016066262401614735`, -0.3000004247772238, -0.001606623780321936}, {
      0.0017175045770139482`, -0.3000004855308628, -0.0017175014828545102`}, {
      0.0018360349862832602`, -0.3000005549594074, -0.0018360311229556245`}, {
      0.0019627455650519975`, -0.30000063430152496`, \
-0.0019627407674441904`}, {
      0.0020982008568583314`, -0.30000072497274655`, -0.002098194922915674}, {
      0.0022430043671724798`, -0.30000082859072014`, \
-0.0022429970497267813`}, {
      0.00239780125250794, -0.30000094700406876`, -0.0023977922493015366`}, {
      0.0025632811951723598`, -0.3000010823253693, -0.002563270136666823}, {
      0.0027401814764751843`, -0.3000012369688391, -0.0027401679109564756`}, {
      0.002929290262103052, -0.3000014136934033, -0.002929273637484363}, {
      0.0031314501143230346`, -0.3000016156519103, -0.0031314297559121534`}, {
      0.0033475617466864893`, -0.3000018464473736, -0.0033475368300262226`}, {
      0.003578588037997289, -0.3000021101972418, -0.003578557555683911}, {
      0.0038255583234666646`, -0.3000024116068439, -0.0038255210446115832`}, {
      0.004089572982219352, -0.3000027560533173, -0.004089527402928417}, {
      0.004371808341655212, -0.300003149681517, -0.004371752624527085}, {
      0.00467352192058243, -0.3000035995136125, -0.0046734538208001815`}, {
      0.004996058034577381, -0.3000041135743275, -0.004995974809615338}, {
      0.005340853788648212, -0.30000470103405236`, -0.005340752087967455}, {
      0.005709445484036219, -0.300005372372379, -0.005709321214332599}, {
      0.006103475467860875, -0.30000613956497046`, -0.006103323628446886}, {
      0.006524699456323306, -0.30000701629709164`, -0.006524513938024497}, {
      0.006974994364334822, -0.3000080182076023, -0.006974767703818182}, {
      0.007456366676750825, -0.30000916316775256`, -0.0074560897564061685`}, {
      0.007970961398864078, -0.30001047159973976`, -0.00797062308017506}, {
      0.008521071626473854, -0.30001196684068937`, -0.008520658302141453}, {
      0.009109148778704546, -0.3000136755585268, -0.009108643825520594}, {
      0.009737813539817574, -0.30001562822712485`, -0.009737196650299144}, {
      0.010409867559563387`, -0.3000178596691579, -0.010409113925489264`}, {
      0.011128305965176409`, -0.30002040967628824`, -0.011127385280217946`}, {
      0.01189633074194574, -0.30002332371767126`, -0.011895205983320157`}, {
      0.012717365043424684`, -0.30002665374931803`, -0.012715990983629086`}, {
      0.013595068496803983`, -0.3000304591386215, -0.01359338988565323}, {
      0.014533353573793735`, -0.3000348077203672, -0.014531302917757671`}, {
      0.015536403102579196`, -0.3000397770028418, -0.015533897952261478`}, {
      0.016608689002072616`, -0.30004545554525963`, -0.01660562863895439}, {
      0.017754992325830336`, -0.3000519445306965, -0.01775125371532304}, {
      0.01898042470968629, -0.3000593595620851, -0.018975857558149956`}, {
      0.02029045132444037, -0.30006783271265514`, -0.020284872041950338`}, {
      0.02169091544289653, -0.30007751486653583`, -0.021684099769763085`}, {
      0.02318806473925757, -0.30008857839015346`, -0.023179738740879578`}, {
      0.02478857944843795, -0.3001012201806114, -0.02477840851789721}, {
      0.02649960252336704, -0.30011566514351806`, -0.026487177951666656`}, {
      0.02832877193993959, -0.30013217015980026`, -0.02831359451683554}, {
      0.030284255312075535`, -0.3001510286089982, -0.03026571530223716}, {
      0.03237478699353109, -0.30017257552546367`, -0.03235213968868502}, {
      0.03460970785885192, -0.3001971934738677, -0.034582043730999594`}, {
      0.036999007973375755`, -0.3002253192415513, -0.036965216240340215`}, {
      0.03955337238171724, -0.3002574514575978, -0.03951209653593558}, {
      0.04228423026595588, -0.3002941592621327, -0.042233813800639605`}, {
      0.04520380774908359, -0.3003360921643009, -0.045142227930600444`}, {
      0.0483251846464476, -0.30038399124362886`, -0.048249971713548064`}, {
      0.05166235549825047, -0.30043870186698907`, -0.05157049410014941}, {
      0.05523029524993295, -0.30050118811200355`, -0.055118104245355334`}, {
      0.05904502998470661, -0.3005725491071835, -0.05890801588781925}, {
      0.06312371315377599, -0.30065403751898007`, -0.06295639150065316}, {
      0.06748470779487076, -0.3007470804355627, -0.06728038548042173}, {
      0.0721476752783006, -0.3008533029155852, -0.07189818543667753}, {
      0.07713367117111376, -0.30097455448607985`, -0.07682905039354627}, {
      0.08246524886267029, -0.30111293888501756`, -0.08209334440844993}, {
      0.0881665716466235, -0.3012708473483421, -0.08771256373990557}, {
      0.0942635340010443, -0.30145099573483136`, -0.09370935524351869}, {
      0.10078389284419922`, -0.3016564657601081, -0.10010752312788083`}, {
      0.10775740955923041`, -0.3018907505670492, -0.10693202054315319`}, {
      0.11521600356329816`, -0.3021578047851741, -0.11420892168585822`}, {
      0.12319391812623297`, -0.3024620991151235, -0.12196536916355255`}, {
      0.13172789899268278`, -0.3028086793015312, -0.1302294902518051}, {
      0.1408573860910586, -0.30320322910976033`, -0.13903027437354845`}, {
      0.1506247181679111, -0.3036521365754355, -0.1483974026216071}, {
      0.16107534949306637`, -0.3041625623208501, -0.1583610184216881}, {
      0.17225807673791116`, -0.30474250809289494`, -0.16895142650359207`}, {
      0.18422527260224805`, -0.3054008828298687, -0.18019870524759446`}, {
      0.19703312057890637`, -0.30614756245969166`, -0.19213221527830465`}, {
      0.21074184217715586`, -0.3069934382158226, -0.20477998503360811`}, {
      0.2254159037028243, -0.30795044647700814`, -0.21816795218499851`}, {
      0.2411241839964256, -0.30903157095199507`, -0.23231903861647235`}, {
      0.25794007701821803`, -0.3102508054298101, -0.24725203677564145`}, {
      0.2759414935252364, -0.3116230623500524, -0.26298028746315394`}, {
      0.295210714119739, -0.31316400927352156`, -0.2795101347497447}, {
      0.31583403176931957`, -0.3148898122852154, -0.29683915434710784`}, {
      0.3379011061896317, -0.31681676304031803`, -0.314954169478147}, {
      0.3615039369052394, -0.31896076554426306`, -0.3338290954659602}, {
      0.3867353495351432, -0.32133666128603067`, -0.3534226931893527}, {
      0.41368688613914556`, -0.32395737896424814`, -0.3736763636711084}, {
      0.44244600302881926`, -0.32683291005506543`, -0.3945121805578173}, {
      0.4730925182305451, -0.32996913603691014`, -0.4158314289969063}, {
      0.5056943263482147, -0.33336656826049843`, -0.4375139865310714}, {
      0.5403025183313295, -0.3370191055983919, -0.4594189235068815}, {
      0.5769462055781716, -0.34091296191782233`, -0.4813866882329358}, {
      0.6156275325864738, -0.34502595296086047`, -0.5032431439417595}, {
      0.6563175277198465, -0.3493273430738574, -0.5248055182700354}, {
      0.6989535249913433, -0.35377841842736363`, -0.5458900169217267}, {
      0.7434388252851661, -0.3583338648901891, -0.5663204909085279}, {
      0.7896450154164585, -0.3629438933553869, -0.5859372260974094}, {
      0.8374169510219144, -0.367556903399873, -0.6046047595236947}, {
      0.8865799302492232, -0.3721223538166144, -0.6222177044808056}, {
      0.936948180895877, -0.37659345908121306`, -0.6387038924702999}, {
      0.9883335812519436, -0.38092937329487647`, -0.6540246268059791}, {
      1.0405535882958867`, -0.38509664204801297`, -0.6681723419865085}, {
      1.093437615165644, -0.3890698557918118, -0.6811663334297628}, {
      1.1468314752982347`, -0.39283157783002937`, -0.6930473869541509}, {
      1.2005998741214876`, -0.39637171269640115`, -0.703872101927513}, {
      1.2546271972636585`, -0.39968651661534166`, -0.7137075305293694}, {
      1.308816987094755, -0.40277744064192456`, -0.7226265301134435}, {
      1.3630905311120634`, -0.4056499578691693, -0.7307040127673007}, {
      1.4173849422709395`, -0.40831247735611165`, -0.7380141128794442}, {
      1.4716510310355502`, -0.4107754021710105, -0.7446281896989364}, {
      1.5258511809041928`, -0.4130503536401865, -0.7506135301377144}, {
      1.5799573607829678`, -0.4151495600044983, -0.7560326029636338}, {
      1.6339493461865136`, -0.41708539379941934`, -0.7609427243895414}, {
      1.6878131776843661`, -0.4188700358717764, -0.7653960152654676}, {
      1.741539856816664, -0.4205152424853373, -0.7694395538280221}, {
      1.79512426327494, -0.42203219338183945`, -0.7731156507449787}, {
      1.8485642689762722`, -0.4234314014821381, -0.7764621928638084}, {
      1.90186002186454, -0.42472266819182214`, -0.7795130179549405}, {
      1.9550133727026615`, -0.4259150714753128, -0.7822982949647412}, {
      2.0080274202907025`, -0.4270169767124536, -0.7848448933577121}, {
      2.0609061534951594`, -0.4280360627510862, -0.7871767316397609}, {
      2.1136541716203365`, -0.4289793575127929, -0.7893150996976371}, {
      2.166276467665484, -0.42985327903941634`, -0.7912789526645609}, {
      2.2187782617279996`, -0.4306636790466899, -0.7930851760316731}, {
      2.2711648741709087`, -0.4314158869428034, -0.7947488229796923}, {
      2.3234416301671934`, -0.4321147529333527, -0.7962833256369191}, {
      2.375613788889898, -0.4327646893208488, -0.7977006823474269}, {
      2.4276864919744323`, -0.4333697094586514, -0.7990116231776239}, {
      2.4796647269812504`, -0.43393346406922123`, -0.800225755885013}, {
      2.531553302474667, -0.43445927481099916`, -0.8013516944783234}, {
      2.5833568320447307`, -0.43495016509699586`, -0.8023971723527776}, {
      2.63507972516641, -0.4354088882464671, -0.8033691418143113}, {
      2.6867261832414977`, -0.43583795310020584`, -0.8042738616290355}, {
      2.7383001995265017`, -0.43623964725843917`, -0.805116974059668}, {
      2.789805561933056, -0.4366160581142979, -0.8059035726853067}, {
      2.8412458579112463`, -0.43696909185986643`, -0.8066382621481172}, {
      2.892624480802896, -0.4373004906392209, -0.8073252108317279}, {
      2.9439446371910845`, -0.4376118480159883, -0.8079681973516353}, {
      2.995209354881731, -0.43790462291349525`, -0.808570651627272}, {
      3, -0.4379319824835207, -0.8086269504769404}}], 
    Line3DBox[{{0., -0.44999999999999996`, -1.*^-6}, {
      7.134723414501347*^-8, -0.44999999999999996`, -1.002542063741177*^-6}, {
      1.4305837688518765`*^-7, -0.44999999999999996`, \
-1.0101810105623227`*^-6}, {
      2.154967734152932*^-7, -0.44999999999999996`, \
-1.0229558643313247`*^-6}, {
      2.890307745408398*^-7, -0.44999999999999996`, \
-1.0409314566069097`*^-6}, {
      3.640341036395112*^-7, -0.44999999999999996`, -1.064199334435632*^-6}, {
      4.4088804002153466`*^-7, -0.44999999999999996`, \
-1.0928777431872995`*^-6}, {
      5.199836035066605*^-7, -0.44999999999999996`, \
-1.1271124025440586`*^-6}, {
      6.017236607023236*^-7, -0.44999999999999996`, \
-1.1670770179160928`*^-6}, {
      6.865217775678005*^-7, -0.44999999999999996`, -1.21297574013234*^-6}, {
      7.748099131855509*^-7, -0.44999999999999996`, -1.265041541940066*^-6}, {
      8.670378183571346*^-7, -0.44999999999999996`, \
-1.3235385759616437`*^-6}, {
      9.6367354829077*^-7, -0.44999999999999996`, -1.3887647722497255`*^-6}, {
      1.0652085561463318`*^-6, -0.44999999999999996`, \
-1.461051658050996*^-6}, {
      1.1721596345192777`*^-6, -0.44999999999999996`, \
-1.5407663385801718`*^-6}, {
      1.285070111620071*^-6, -0.44999999999999996`, \
-1.6283143916790711`*^-6}, {
      1.4045138632817459`*^-6, -0.44999999999999996`, \
-1.7241410520422314`*^-6}, {
      1.5310981915573519`*^-6, -0.44999999999999996`, \
-1.8287334743582048`*^-6}, {
      1.6654670801943373`*^-6, -0.44999999999999996`, \
-1.9426230827057118`*^-6}, {
      1.8083033922776558`*^-6, -0.44999999999999996`, \
-2.0663891291609994`*^-6}, {
      1.9603334524247734`*^-6, -0.44999999999999996`, \
-2.2006607406434344`*^-6}, {
      2.122329607354318*^-6, -0.44999999999999996`, \
-2.3461210774190357`*^-6}, {
      2.29511596518892*^-6, -0.44999999999999996`, -2.503509232443332*^-6}, {
      2.4795705080124257`*^-6, -0.44999999999999996`, \
-2.673625815426528*^-6}, {
      2.676631910984807*^-6, -0.44999999999999996`, -2.857334891403352*^-6}, {
      2.887301540214653*^-6, -0.44999999999999996`, -3.055570929247529*^-6}, {
      3.112650182286899*^-6, -0.44999999999999996`, -3.269342042412968*^-6}, {
      3.3538238237944027`*^-6, -0.44999999999999996`, \
-3.4997347832486412`*^-6}, {
      3.6120489408216634`*^-6, -0.44999999999999996`, \
-3.747920175204181*^-6}, {
      3.888637958257981*^-6, -0.44999999999999996`, -4.015160415276889*^-6}, {
      4.184997189944022*^-6, -0.44999999999999996`, -4.302814069690691*^-6}, {
      4.502633338245304*^-6, -0.44999999999999996`, -4.612343609884963*^-6}, {
      4.843161439475326*^-6, -0.44999999999999996`, -4.945322571021944*^-6}, {
      5.208312188759989*^-6, -0.44999999999999996`, -5.303444415856724*^-6}, {
      5.599942458101949*^-6, -0.44999999999999996`, -5.688529464798932*^-6}, {
      6.020043757360849*^-6, -0.44999999999999996`, -6.102535105637641*^-6}, {
      6.470751292042781*^-6, -0.44999999999999996`, -6.547566799171606*^-6}, {
      6.954356739842578*^-6, -0.44999999999999996`, -7.025886890073013*^-6}, {
      7.473318681215185*^-6, -0.44999999999999996`, -7.539927313395222*^-6}, {
      8.03027572549071*^-6, -0.44999999999999996`, -8.092301339177262*^-6}, {
      8.628059431525398*^-6, -0.44999999999999996`, -8.685817347708354*^-6}, {
      9.269708933152438*^-6, -0.44999999999999996`, -9.323492880685393*^-6}, {
      9.958486438784107*^-6, -0.44999999999999996`, \
-0.000010008569934267623`}, {
      0.00001069789384721814, -0.44999999999999996`, \
-0.000010744531411366596`}, {
      0.000011491690361231996`, -0.44999999999999996`, \
-0.000011535119018371788`}, {
      0.000012343911716900317`, -0.44999999999999996`, \
-0.000012384352171810618`}, {
      0.000013258890686692433`, -0.44999999999999996`, \
-0.000013296548448239219`}, {
      0.000014241278921281758`, -0.44999999999999996`, \
-0.000014276345721189373`}, {
      0.000015296071206466793`, -0.44999999999999996`, \
-0.000015328725134568974`}, {
      0.000016428630063719618`, -0.44999999999999996`, \
-0.000016459037218669332`}, {
      0.000017644713524115053`, -0.44999999999999996`, \
-0.0000176730285835542}, {
      0.000018950504366774897`, -0.44999999999999996`, \
-0.000018976871171115328`}, {
      0.00002035264130409333, -0.44999999999999996`, \
-0.000020377193881954313`}, {
      0.000021858252921625866`, -0.44999999999999996`, \
-0.000021881116089563407`}, {
      0.000023474993835572113`, -0.44999999999999996`, \
-0.000023496283920627453`}, {
      0.000025211083801706954`, -0.44999999999999996`, \
-0.00002523090893666175}, {
      0.00002707534915203755, -0.44999999999999996`, \
-0.00002709381023531901}, {
      0.000029077268072715166`, -0.44999999999999996`, \
-0.00002909445888378475}, {
      0.00003122701845449571, -0.44999999999999996`, \
-0.00003124302640777641}, {
      0.0000335355298459224, -0.44999999999999996`, \
-0.000033550436296778154`}, {
      0.00003601453888371683, -0.44999999999999996`, \
-0.00003602841967638939}, {
      0.000038676649086372284`, -0.44999999999999996`, \
-0.00003868957482701747}, {
      0.00004153539488308933, -0.44999999999999996`, \
-0.000041547431283133285`}, {
      0.00004460531043319484, -0.44999999999999996`, \
-0.000044616518609488505`}, {
      0.000047902003423066026`, -0.44999999999999996`, \
-0.000047912440366753464`}, {
      0.00005144223452298444, -0.44999999999999996`, \
-0.00005145195333548419}, {
      0.00005524400264978194, -0.4500000001144316, -0.00005525305265930006}, {
      0.00005932663625072962, -0.45000000024639875`, -0.0000593350635583017}, \
{0.00006371089186736032, -0.4500000003985885, -0.00006371873928333221}, {
      0.00006841905943403426, -0.4500000005740999, -0.00006842636685719879}, {
      0.00007347507571674198, -0.45000000077650665`, \
-0.00007348188026932538}, {
      0.00007890464595649392, -0.4500000010099302, -0.0000789109822112461}, {
      0.00008473537456994377, -0.4500000012791236, -0.00008474127473836306}, {
      0.0000909969055243023, -0.4500000015895682, -0.00009100239957006011}, {
      0.00009772107299872647, -0.4500000019475854, -0.00009772618884181891}, {
      0.00010494206328769456`, -0.4500000023604651, \
-0.00010494682688700984`}, {
      0.00011269658854432877`, -0.45000000283661457`, \
-0.00011270102409584594`}, {
      0.000121024073489525, -0.45000000338572915`, -0.00012102820349288676`}, \
{0.0001299668558188694, -0.4500000040189901, -0.0001299707011989128}, {
      0.0001395704014408362, -0.450000004749292, -0.00013957398168172215`}, {
      0.00014988353565243242`, -0.45000000559150544`, \
-0.00014988686887831127`}, {
      0.00016095869137068116`, -0.45000000656277966`, \
-0.00016096179442038952`}, {
      0.0001728521756997754, -0.45000000768289206`, -0.0001728550642074028}, {
      0.0001856244561933367, -0.4500000089746505, -0.00018562714467813246`}, {
      0.0001993404682976118, -0.45000001046435806`, \
-0.00019934297020581177`}, {
      0.0002140699454583209, -0.4500000121823485, -0.00021407227325988856`}, {
      0.00022988777369645474`, -0.45000001416360386`, \
-0.00022988993888594376`}, {
      0.00024687437228847675`, -0.4500000164484669, \
-0.00024687638547313435`}, {
      0.00026511610265612717`, -0.45000001908346243`, \
-0.0002651179735751421}, {
      0.000284705707430874, -0.4500000221222448, -0.00028470744497678023`}, {
      0.0003057427819649852, -0.45000002562669034`, -0.0003057443941986388}, {
      0.0003283342806727297, -0.45000002966815716`, -0.0003283357748504603}, {
      0.0003525950608180716, -0.4500000343289385, -0.0003525964433652916}, {
      0.0003786484664476143, -0.45000003970393804`, -0.000378649742944441}, {
      0.00040662695549228744`, -0.45000004590260256`, \
-0.00040662813062700804`}, {
      0.00043667277319004604`, -0.4500000530511505, -0.0004366738507076153}, {
      0.00046893867527488106`, -0.45000006129514186`, \
-0.0004689396579039847}, {
      0.0005035887046206662, -0.4500000708024424, -0.0005035895939385976}, {
      0.0005407990252356432, -0.45000008176664147`, -0.0005407998215345792}, {
      0.0005807588179098019, -0.4500000944109939, -0.0005807595200027806}, {
      0.0006236712420348896, -0.4500001089929663, -0.000623671847005898}, {
      0.0006697544684918599, -0.45000012580947896`, -0.0006697549713829874}, {
      0.0007192427888586797, -0.45000014520295245`, -0.0007192431822818432}, {
      0.000772387806591622, -0.45000016756827954`, -0.0007723880802220415}, {
      0.0008294597162035784, -0.45000019336086605`, -0.0008294598561737848}, {
      0.0008907486769837668, -0.45000022310590393`, -0.0008907486651110251}, {
      0.0009565662882200244, -0.4500002574090649, -0.0009565661010406529}, {
      0.001027247173423457, -0.45000029696883337`, -0.0010272467810018705`}, {
      0.0011031506816229135`, -0.4500003425907285, -0.0011031500460690583`}, {
      0.001184662714373776, -0.4500003952037061, -0.0011846617880028607`}, {
      0.001272197687775233, -0.4500004558790736, -0.0012721964108204978`}, {
      0.0013662006394634767`, -0.4500005258523035, -0.0013661989372528928`}, {
      0.0014671494913179638`, -0.45000060654818935`, \
-0.0014671472707571433`}, {
      0.0015755574793625807`, -0.45000069960985634`, -0.00157555462458688}, {
      0.0016919757632381295`, -0.4500008069322173, -0.0016919721302231616`}, {
      0.0018169962285139436`, -0.45000093070055475`, \
-0.0018169916383961844`}, {
      0.00195125449609164, -0.45000107343501533`, -0.0019512487268952532`}, {
      0.0020954331540118873`, -0.45000123804192116`, -0.00209542593040186}, {
      0.0022502652281093903`, -0.4500014278729435, -0.0022502562086948678`}, {
      0.002416537909168609, -0.4500016467933431, -0.0024165266707820163`}, {
      0.0025950965555548607`, -0.45000189926066547`, \
-0.0025950825737781234`}, {
      0.0027868489916898194`, -0.4500021904154936, -0.0027868316167323844`}, {
      0.002992770124247682, -0.4500025261861045, -0.0029927485510775793`}, {
      0.0032139068995856225`, -0.45000291340915893`, \
-0.0032138801309295065`}, {
      0.0034513836276418314`, -0.4500033599688808, -0.0034513504281681305`}, {
      0.003706407699430694, -0.45000387495755684`, -0.0037063665390040406`}, {
      0.0039802757272633105`, -0.4500044688606219, -0.003980224710665457}, {
      0.004274380138988578, -0.45000515377009426`, -0.004274316918883395}, {
      0.004590216259880932, -0.4500059436307007, -0.004590137929028119}, {
      0.004929389918304029, -0.45000685452369543`, -0.004929292876068856}, {
      0.005293625613964022, -0.45000790499414217`, -0.005293505401001193}, {
      0.005684775290472045, -0.45000911642830876`, -0.005684626383991867}, {
      0.006104827757043486, -0.4500105134888415, -0.0061046433172681795`}, {
      0.006555918807525755, -0.4500121246165558, -0.006555690363694642}, {
      0.007040342088549708, -0.45001398260902786`, -0.007040059150068968}, {
      0.007560560772502126, -0.4500161252877265, -0.007560210347392086}, {
      0.008119220095205354, -0.45001859626721136`, -0.00811878609375178}, {
      0.008719160822718808, -0.4500214458419846, -0.00871862331896814}, {
      0.009363433716558966, -0.4500247320089527, -0.00936276803377898}, {
      0.010055315071906426`, -0.45002852164618323`, -0.010054490650064822`}, {
      0.010798323409067502`, -0.45003289187177986`, -0.010797302402389304`}, {
      0.011596237404619859`, -0.4500379316103071, -0.0115949729449178}, {
      0.012453115155346216`, -0.4500437433983439, -0.012451549201506158`}, {
      0.013373314875290207`, -0.45005044546551, -0.013371375550346388`}, {
      0.014361517134119525`, -0.45005817413277904`, -0.014359115427899477`}, {
      0.015422748753511212`, -0.4500670865761697, -0.015419774439804043`}, {
      0.016562408487556475`, -0.4500773640110982, -0.016558725068843205`}, {
      0.017786294623303056`, -0.45008921536091745`, -0.01778173307165151}, {
      0.019100634648607184`, -0.45010288148259026`, -0.01909498565636066}, {
      0.020512117146559216`, -0.45011864003321495`, -0.02050512153245881}, {
      0.022027926089007832`, -0.4501368110734011, -0.022019262921310942`}, {
      0.023655777716277224`, -0.45015776351747916`, -0.023645049610489244`}, {
      0.025403960206215638`, -0.4501819225564167, -0.025390675126577205`}, {
      0.027281376353418776`, -0.45020977819731883`, -0.02726492508854931}, {
      0.029297589499053155`, -0.45024189508373574`, -0.029277217786082128`}, {
      0.03146287297340444, -0.45027892378390094`, -0.031437647002847235`}, {
      0.033788263337363976`, -0.45032161375969293`, -0.033757027072271545`}, {
      0.036285617735844156`, -0.4503708282577289, -0.036246940110320695`}, {
      0.03896767570590119, -0.4504275613956927, -0.038919785313974546`}, {
      0.041848125815482584`, -0.45049295775181625`, -0.04178883014202646}, {
      0.04494167754553951, -0.4505683348032877, -0.04486826310273652}, {
      0.04826413886905844, -0.4506552085999699, -0.048173247755905535`}, {
      0.05183250002559246, -0.4507553231026214, -0.05171997738926786}, {
      0.055665024039183345`, -0.4508706836588478, -0.0555257296436145}, {
      0.05978134458095752, -0.45100359513376054`, -0.05960892012915257}, {
      0.06420257183450723, -0.4511567052534814, -0.0639891537869246}, {
      0.06895140708108614, -0.45133305375485794`, -0.06868727239125808}, {
      0.07405226678023039, -0.45153612795927234`, -0.07372539614748454}, {
      0.07953141697561147, -0.4517699253955514, -0.07912695679627298}, {
      0.08541711889928695, -0.4520390240775005, -0.08491671897181279}, {
      0.09173978667007363, -0.4523486609829398, -0.09112078575290061}, {
      0.09853215796851605, -0.45270481916642463`, -0.09776658336828517}, {
      0.1058294784996445, -0.4531143237446152, -0.10488281884305331`}, {
      0.11366970089308887`, -0.45358494669196625`, -0.11249940297354362`}, {
      0.12209369839177477`, -0.4541255199366672, -0.12064732936847486`}, {
      0.1311454931798312, -0.4547460556034822, -0.129358498374327}, {
      0.14087249840618427`, -0.45545787134962845`, -0.1386654725076329}, {
      0.15132577174745973`, -0.4562737175063308, -0.14860114756430237`}, {
      0.1625602765539604, -0.4572079010820347, -0.15919832092609043`}, {
      0.1746351440143949, -0.45827639950091736`, -0.17048913586221348`}, {
      0.18761392607644656`, -0.459496954133834, -0.18250437805624045`}, {
      0.20156482372541507`, -0.4608891301279015, -0.1952725985509017}, {
      0.2165608682532808, -0.4624743246900506, -0.20881903638721672`}, {
      0.2326800239297402, -0.46427570084420633`, -0.22316431530561917`}, {
      0.2500051686624986, -0.46631801793078026`, -0.23832289324781425`}, {
      0.2686238946701353, -0.4686273241854619, -0.2543012527892107}, {
      0.28862805422785176`, -0.4712304714751459, -0.2710958372840861}, {
      0.31011295740569256`, -0.47415440914471996`, -0.2886907640684576}, {
      0.33317611206378184`, -0.4774252152050386, -0.3070553852516054}, {
      0.3579153859748663, -0.4810668319504134, -0.3261418204360292}, {
      0.3844264742877353, -0.48509949349192005`, -0.34588265401462864`}, {
      0.4127995828915463, -0.4895378687179724, -0.3661890681003685}, {
      0.4431153015043757, -0.494388997583015, -0.3869497592621829}, {
      0.4754397497456075, -0.49965017025721475`, -0.4080310423381771}, {
      0.5098192375073186, -0.5053069793045469, -0.429278547467032}, {
      0.5462748738331242, -0.5113318465746661, -0.4505208323594112}, {
      0.5847977487198462, -0.5176833611173884, -0.4715750337965651}, {
      0.6253454381736265, -0.5243067309253444, -0.4922543703862227}, {
      0.6678405727767385, -0.5311355284075906, -0.5123769281697266}, {
      0.7121720123811004, -0.5380947027251946, -0.5317748067997683}, {
      0.758198789037639, -0.5451045841802189, -0.5503024978838081}, {
      0.8057564973673192, -0.5520853891885587, -0.5678434057930838}, {
      0.8546653640542451, -0.5589616232289157, -0.5843137239706673}, {
      0.9047389550650915, -0.5656658139128187, -0.5996633661495959}, {
      0.9557924570376255, -0.5721411723748936, -0.6138741726907447}, {
      1.0076496798819856`, -0.5783430171015941, -0.6269560170983418}, {
      1.0601482764473626`, -0.5842390233109569, -0.6389416379949394}, {
      1.1131430429863505`, -0.5898085247531323, -0.6498810134678641}, {
      1.1665074580250125`, -0.5950411708461768, -0.65983593787517}, {
      1.220133794485893, -0.5999352405107148, -0.6688752388167131}, {
      1.2739322040740615`, -0.6044958624717002, -0.6770708542496059}, {
      1.3278291541882346`, -0.6087333195671607, -0.6844948178383264}, {
      1.3817655326163276`, -0.6126615436657086, -0.691217087648379}, {
      1.4356946544519769`, -0.6162968500887942, -0.6973040937038562}, {
      1.489580328691785, -0.6196569196993753, -0.7028178599805246}, {
      1.5433950785360637`, -0.6227600117778664, -0.7078155613991507}, {
      1.5971185622060116`, -0.6256243779873463, -0.7123493943354989}, {
      1.6507362088525976`, -0.6282678433075959, -0.7164666618195137}, {
      1.704238063951198, -0.6307075205273239, -0.7202099970402936}, {
      1.7576178272512126`, -0.632959628312852, -0.7236176685425003}, {
      1.810872061069212, -0.635039387416202, -0.7267239267021028}, {
      1.8639995452820783`, -0.6369609742810345, -0.7295593636990338}, {
      1.9170007562100675`, -0.6387375156351482, -0.7321512686803618}, {
      1.9698774486063286`, -0.6403811113958473, -0.73452396669664}, {
      2.022632322502849, -0.6419028763026765, -0.7366991348620426}, {
      2.075268759289558, -0.6433129931653846, -0.738696092532971}, {
      2.127790613893053, -0.6446207725497152, -0.7405320645264447}, {
      2.1802020521609298`, -0.6458347152088117, -0.7422224178258925}, {
      2.232507424505209, -0.646962574690142, -0.7437808730872139}, {
      2.284711168513279, -0.6480114183836806, -0.7452196927383499}, {
      2.3368177346180783`, -0.6489876858912549, -0.7465498476880894}, {
      2.3888315300617435`, -0.6498972440419524, -0.7477811647144693}, {
      2.4407568773222525`, -0.6507454381959518, -0.7489224565526508}, {
      2.4925979839331625`, -0.6515371397014658, -0.7499816365895804}, {
      2.5443589212419697`, -0.6522767895215656, -0.7509658199270336}, {
      2.596043610148722, -0.6529684381483777, -0.7518814124148399}, {
      2.6476558122652687`, -0.6536157819857107, -0.7527341890943859}, {
      2.6991991252553604`, -0.6542221964181983, -0.7535293633363633}, {
      2.7506769813719036`, -0.6547907658033605, -0.7542716478104464}, {
      2.802092648412453, -0.6553243106283887, -0.7549653082903398}, {
      2.853449232477612, -0.6558254120701414, -0.7556142111762171}, {
      2.9047496820475702`, -0.6562964341878511, -0.7562218655079271}, {
      2.955996792996107, -0.6567395439655705, -0.7567914601458919}, {
      3, -0.6571200190970178, -0.7572805411945357}}], 
    Line3DBox[{{0., -0.6, -1.*^-6}, {
      7.966242453778674*^-8, -0.6, -1.0031679677782165`*^-6}, {
      1.5982874414332617`*^-7, -0.6, -1.0126919673296451`*^-6}, {
      2.410073221102551*^-7, -0.6, -1.0286323527130694`*^-6}, {
      3.237132307610731*^-7, -0.6, -1.0510899848905436`*^-6}, {
      4.0846995616895115`*^-7, -0.6, -1.080207299467184*^-6}, {
      4.958149581260597*^-7, -0.6, -1.116168630338855*^-6}, {
      5.863010754289038*^-7, -0.6, -1.1592020536019024`*^-6}, {
      6.805020352713257*^-7, -0.6, -1.20958003494637*^-6}, {
      7.790149181763504*^-7, -0.6, -1.267621622797299*^-6}, {
      8.824632254363677*^-7, -0.6, -1.3336949654079318`*^-6}, {
      9.915028243836363*^-7, -0.6, -1.4082184290545567`*^-6}, {
      1.1068246678865269`*^-6, -0.6, -1.4916641232990753`*^-6}, {
      1.2291589335113028`*^-6, -0.6, -1.5845611109612272`*^-6}, {
      1.3592812055953326`*^-6, -0.6, -1.6874976144333035`*^-6}, {
      1.4980159522565942`*^-6, -0.6, -1.8011257962263185`*^-6}, {
      1.6462419260524005`*^-6, -0.6, -1.926165814609562*^-6}, {
      1.804898670825312*^-6, -0.6, -2.063409573997201*^-6}, {
      1.974990957363396*^-6, -0.6, -2.213727037357415*^-6}, {
      2.1575962683231646`*^-6, -0.6, -2.3780707891250872`*^-6}, {
      2.3538718605922823`*^-6, -0.6, -2.5574818423286764`*^-6}, {
      2.5650616342511726`*^-6, -0.6, -2.753096643228282*^-6}, {
      2.792503484396626*^-6, -0.6, -2.9661547559689366`*^-6}, {
      3.0376385326281363`*^-6, -0.6, -3.1980060349018836`*^-6}, {
      3.302019446134877*^-6, -0.6, -3.4501199288394305`*^-6}, {
      3.5873218737898955`*^-6, -0.6, -3.7240932826499644`*^-6}, {
      3.895353140830065*^-6, -0.6, -4.02166227898114*^-6}, {
      4.228064755489368*^-6, -0.6, -4.34471243638805*^-6}, {
      4.587565198103897*^-6, -0.6, -4.6952901370201686`*^-6}, {
      4.9761320536841974`*^-6, -0.6, -5.075616783760655*^-6}, {
      5.396227312367623*^-6, -0.6, -5.488102029929633*^-6}, {
      5.850512505358708*^-6, -0.6, -5.935359498737442*^-6}, {
      6.341866025042803*^-6, -0.6, -6.4202228945442*^-6}, {
      6.873401130316037*^-6, -0.6, -6.945764184519457*^-6}, {
      7.448485518631518*^-6, -0.6, -7.515313213897554*^-6}, {
      8.070762831428064*^-6, -0.6, -8.132478638142032*^-6}, {
      8.744175736375208*^-6, -0.6, -8.801170790085483*^-6}, {
      9.472991033730625*^-6, -0.6, -9.525626330472663*^-6}, {
      0.000010261826378629162`, -0.6, -0.00001031043540070326}, {
      0.00001111567971522896, -0.6, -0.000011160570529700403`}, {
      0.000012039961043251015`, -0.6, -0.00001208141803981509}, {
      0.00001304052654496819, -0.6, -0.000013078812323689824`}, {
      0.0000141237157257236, -0.6, -0.000014159072774364945`}, {
      0.000015296391483507826`, -0.6, -0.00001532904392112678}, {
      0.000016565983816266942`, -0.6, -0.00001659613857188567}, {
      0.000017940536793788674`, -0.6, -0.00001796838488365336}, {
      0.00001942875942691038, -0.6, -0.000019454477325420624`}, {
      0.000021040080996614087`, -0.6, -0.00002106383161622855}, {
      0.000022784710682482025`, -0.6, -0.0000228066444968091}, {
      0.000024673702280973754`, -0.6, -0.000024693958301481556`}, {
      0.000026719024302568726`, -0.6, -0.00002673773086020153}, {
      0.000028933635736675955`, -0.6, -0.000028950911328779123`}, {
      0.00003133156813753918, -0.6, -0.00003134752225468653}, {
      0.00003392801460466383, -0.6, -0.000033942748344997835`}, {
      0.00003673942601308858, -0.6, -0.000036753032707190084`}, {
      0.000039783615203098854`, -0.6000000001091956, \
-0.00003979618107288167}, {
      0.00004307986990793968, -0.6000000002372297, -0.00004309147454667639}, {
      0.00004664907490048348, -0.6000000003873521, -0.00004665979182735772}, {
      0.00005051384434162842, -0.6000000005633737, \
-0.000050523741469545095`}, {
      0.00005469866509203078, -0.6000000007697623, -0.00005470780509935663}, {
      0.000059230051794284675`, -0.6000000010117571, \
-0.00005923849259176804}, {
      0.00006413671490969004, -0.6000000012955007, -0.00006414450999225902}, {
      0.00006944974265579308, -0.6000000016281956, -0.00006945694136569936}, {
      0.00007520279789342707, -0.6000000020182868, -0.00007520944582704246}, {
      0.0000814323314920522, -0.6000000024756765, -0.00008143847072194383}, {
      0.00008817781320316944, -0.6000000030119749, -0.0000881834826297993}, {
      0.00009548198184281131, -0.6000000036407951, -0.00009548721731462756}, {
      0.00010339111596788464`, -0.6000000043780991, -0.0001033959506077712}, {
      0.00011195532716171946`, -0.6000000052426024, \
-0.00011195979153834072`}, {
      0.00012122887751200564`, -0.6000000062562495, \
-0.00012123299984364999`}, {
      0.000131270523425155, -0.6000000074447704, -0.00013127432973880797`}, {
      0.00014214388789933322`, -0.6000000088383345, \
-0.00014214740217964277`}, {
      0.00015391786362658585`, -0.6000000104723155, \
-0.00015392110796578882`}, {
      0.0001666670494863301, -0.6000000123881903, -0.00016667004422963406`}, {
      0.00018047222321229429`, -0.600000014634591, -0.0001804749870600886}, {
      0.0001954208531826299, -0.6000000172685395, -0.00019542340330060305`}, {
      0.00021160765260653234`, -0.6000000203568956, \
-0.00021161000473330916`}, {
      0.0002291351796399001, -0.6000000239780534, -0.0002291373481390928}, {
      0.0002481144871769335, -0.6000000282239316, -0.0002481164850906514}, {
      0.00026866582646344745`, -0.6000000332023065, \
-0.00026866766556649444`}, {
      0.00029091940900029435`, -0.6000000390395483, \
-0.00029092109983314953`}, {
      0.0003150162315661229, -0.600000045883828, -0.0003150177834204011}, {
      0.0003411089695466271, -0.6000000539088794, -0.00034111039045598926`}, {
      0.0003693629442849313, -0.6000000633184085, -0.00036936424096443125`}, {
      0.00039995717053814127`, -0.6000000743512643, \
-0.00039995834830163906`}, {
      0.0004330854907048535, -0.6000000872875024, -0.000433086553332235}, {
      0.00046895780300066075`, -0.6000001024554928, \
-0.00046895875254322777`}, {
      0.0005078013913550303, -0.6000001202402561, -0.0005078022278813244}, {
      0.0005498623654646476, -0.6000001410932356, -0.0005498630867278635}, {
      0.0005954072201321105, -0.6000001655437578, -0.0005954078211265788}, {
      0.0006447245237663512, -0.6000001942124674, -0.0006447249961423188}, {
      0.0006981267467378309, -0.6000002278270823, -0.0006981270780475018}, {
      0.0007559522411712853, -0.6000002672408649, -0.0007559524139138662}, {
      0.0008185673847389719, -0.6000003134542811, -0.0008185673751237488}, {
      0.0008863689020205878, -0.6000003676403952, -0.0008863686783871242}, {
      0.0009597863781408396, -0.6000004311746461, -0.000959785898952402}, {
      0.0010392849806192088`, -0.6000005056697599, -0.0010392841919074293`}, {
      0.0011253684066843876`, -0.6000005930166858, -0.0011253672387818334`}, {
      0.0012185820747090397`, -0.6000006954325934, -0.001218580438108279}, {
      0.0013195165800089933`, -0.60000081551715, -0.0013195143600960673`}, {
      0.0014288114369022456`, -0.6000009563185068, -0.0014288084872573087`}, {
      0.0015471591307337615`, -0.6000011214106667, -0.0015471552646276945`}, {
      0.001675309505559245, -0.6000013149841996, -0.0016753044851455625`}, {
      0.001814074515285831, -0.6000015419526045, -0.0018140680378773205`}, {
      0.001964333368390137, -0.6000018080770199, -0.0019643250490298113`}, {
      0.002127038098822196, -0.6000021201124445, -0.002127027448150441}, {
      0.0023032195984105355`, -0.6000024859791795, -0.0023032059945602068`}, {
      0.002493994149010176, -0.600002914963841, -0.0024939768019234484`}, {
      0.0027005704958149254`, -0.6000034179550413, -0.0027005484019314266`}, {
      0.0029242575066792194`, -0.6000040077197176, -0.002924229391409132}, {
      0.0031664724660345972`, -0.6000046992271143, -0.0031664367107121227`}, {
      0.0034287500559997525`, -0.6000055100286346, -0.003428704605144422}, {
      0.003712752081670872, -0.6000064607031901, -0.0037126943252414526`}, {
      0.004020278002303554, -0.6000075753793362, -0.00402020462620424}, {
      0.004353276335232484, -0.6000088823474224, -0.004353183131514129}, {
      0.004713857004939682, -0.6000104147772627, -0.004713738630827498}, {
      0.0051043047157049454`, -0.6000122115594995, -0.005104154387665155}, {
      0.0055270934328219, -0.6000143182919532, -0.00552690253814807}, {
      0.00598490206443786, -0.6000167884359109, -0.005984659668135527}, {
      0.006480631443783328, -0.6000196846715852, -0.0064803236625259365`}, {
      0.00701742271988955, -0.6000230804869885, -0.007017031927226803}, {
      0.007598677273958814, -0.6000270620403302, -0.007598181091305535}, {
      0.008228078288389862, -0.6000317303429052, -0.008227448304072604}, {
      0.008909614106143132, -0.6000372038174611, -0.008908814249245101}, {
      0.009647603529752547, -0.6000436212964042, -0.009646588005769173}, {
      0.010446723221920928`, -0.6000511455351548, -0.010445433892214535`}, {
      0.011312037383389062`, -0.6000599673287352, -0.011310400438675917`}, {
      0.01224902989874062, -0.6000703103345806, -0.012246951636567695`}, {
      0.013263639157135671`, -0.6000824367219221, -0.013261000622205813`}, {
      0.014362295772771424`, -0.6000966537883013, -0.014358945954186738`}, {
      0.015551963449328257`, -0.600113321707257, -0.015547710646661751`}, {
      0.016840183253927613`, -0.600132862598479, -0.016834784119891557`}, {
      0.018235121589417494`, -0.6001557711432843, -0.018228267224911523`}, {
      0.019745622179319765`, -0.6001826270047381, -0.019736920489437374`}, {
      0.02138126240778037, -0.600214109353765, -0.0213702157155964}, {
      0.023152414387624182`, -0.6002510138508576, -0.02313839103453761}, {
      0.02507031116343909, -0.6002942724881886, -0.025052509485710167`}, {
      0.027147118493818456`, -0.6003449767597551, -0.027124521136136108`}, {
      0.02939601269782262, -0.6004044046982475, -0.029367328682943394`}, {
      0.031831265095709126`, -0.6004740523970931, -0.03179485638524201}, {
      0.03446833362333235, -0.6005556707247809, -0.03442212204216916}, {
      0.03732396225354338, -0.600651308035878, -0.0372653115639089}, {
      0.04041628891647032, -0.6007633597881673, -0.04034185546089107}, {
      0.04376496267346856, -0.6008946260861298, -0.043670506289790016`}, {
      0.04739127096602093, -0.6010483782840924, -0.047271415726877715`}, {
      0.05131827782931711, -0.6012284358921806, -0.05116620946958702}, {
      0.05557097402771401, -0.6014392551260955, -0.055378057571407596`}, {
      0.06017644013076547, -0.6016860305148295, -0.059931737064297455`}, {
      0.06516402359588774, -0.6019748110100481, -0.06485368278227155}, {
      0.07056553094415034, -0.6023126320004834, -0.07017202113007259}, {
      0.07641543608932834, -0.6027076644872136, -0.07591658009737927}, {
      0.08275110577717393, -0.6031693823702786, -0.08211886705408904}, {
      0.08961304286704455, -0.6037087482649277, -0.08881200372790038}, {
      0.09704514777573463, -0.6043384174156738, -0.09603060521940675}, {
      0.10509499770839423`, -0.6050729579895004, -0.10381058692535289`}, {
      0.11381414218837126`, -0.6059290841552637, -0.11218887982206785`}, {
      0.12325841167773036`, -0.6069258957089894, -0.12120303076879287`}, {
      0.13348823349541145`, -0.6080851143656708, -0.13089066047787917`}, {
      0.1445689454492063, -0.6094313019659493, -0.14128874786489976`}, {
      0.15657109216627507`, -0.6109920395028737, -0.15243270615569432`}, {
      0.16957068151147064`, -0.6127980378782543, -0.16435521422516058`}, {
      0.18364936814730592`, -0.614883141618563, -0.17708476744487353`}, {
      0.19889451767969563`, -0.6172841756893741, -0.19064391765426422`}, {
      0.2153990876496707, -0.6200405738534199, -0.20504718423236676`}, {
      0.23326124114977265`, -0.6231937163843726, -0.22029864077996847`}, {
      0.2525835864609278, -0.6267858982813025, -0.2363892181980594}, {
      0.2734719150977387, -0.6308588509355388, -0.2532938183109917}, {
      0.29603329706851034`, -0.6354517567239398, -0.2709684044103037}, {
      0.32037339555734184`, -0.6405987347323949, -0.28934732416754794`}, {
      0.3465928966060371, -0.6463258438486587, -0.30834121736228204`}, {
      0.3747830272159649, -0.6526477501544622, -0.3278359466849235}, {
      0.40502026868875546`, -0.6595643333574629, -0.3476930335070702}, {
      0.4373605602047099, -0.6670576417947188, -0.3677520420213608}, {
      0.4718335077139699, -0.6750897095367769, -0.3878351965829792}, {
      0.5084373134554776, -0.6836017716170274, -0.40775422230466674`}, {
      0.5471352463929651, -0.6925153073235991, -0.4273189968746196}, {
      0.5878544080926286, -0.701735089816238, -0.44634717883850966`}, {
      0.63048727517951, -0.7111540602598394, -0.4646736639694408}, {
      0.6748960549239186, -0.7206594703177467, -0.48215864185008084`}, {
      0.7209193885804647, -0.7301394685345591, -0.4986932369604885}, {
      0.7683805290914458, -0.7394892362624055, -0.5142021730981294}, {
      0.8170959272007016, -0.7486159258766312, -0.5286434556075843}, {
      0.8668832207082563, -0.7574419554163094, -0.5420055540664233}, {
      0.9175678815468312, -0.765906560870763, -0.5543028669578466}, {
      0.9689881263760023, -0.7739657981361806, -0.5655703245027869}, {
      1.0209980299922854`, -0.7815913634017235, -0.5758578793355794}, {
      1.0734690267482794`, -0.7887686571532998, -0.5852254287169598}, {
      1.1262901211038938`, -0.7954944822264072, -0.5937384856661192}, {
      1.179367168207111, -0.8017746816873899, -0.6014647228922463}, {
      1.232621559555233, -0.8076219238503443, -0.6084713757029057}, {
      1.2859885888138909`, -0.8130537527810111, -0.6148234086727768}, {
      1.3394157029048794`, -0.8180909539066501, -0.620582314499002}, {
      1.3928607782892777`, -0.82275623759773, -0.6258054076036081}, {
      1.4462905088862856`, -0.8270732157481214, -0.630545486707117}, {
      1.4996789519571603`, -0.8310656326786542, -0.6348507602450599}, {
      1.5530062503718065`, -0.8347568074469986, -0.6387649500409164}, {
      1.6062575316212748`, -0.8381692460798011, -0.6423275087240843}, {
      1.659421973225369, -0.8413243866317371, -0.6455739034847675}, {
      1.7124920185959582`, -0.844242445542328, -0.6485359325016973}, {
      1.765462725204141, -0.8469423394433714, -0.6512420509667386}, {
      1.8183312267771385`, -0.849441661801446, -0.6537176915222284}, {
      1.8710962923240113`, -0.8517566983115319, -0.6559855696467635}, {
      1.9237579664645994`, -0.8539024687270406, -0.6580659685653056}, {
      1.9763172774383662`, -0.8558927858571518, -0.6599770010394751}, {
      2.028776001074845, -0.8577403248699039, -0.6617348472513002}, {
      2.0811364707911064`, -0.859456697909826, -0.6633539691895789}, {
      2.133401425284152, -0.861052530470936, -0.6648473026787796}, {
      2.1855738869866808`, -0.8625375370484167, -0.6662264286005392}, {
      2.2376570655554078`, -0.8639205944007712, -0.6675017250517394}, {
      2.2896542816763032`, -0.8652098113508918, -0.6686825022351343}, {
      2.3415689073207466`, -0.8664125944891388, -0.6697771218406421}, {
      2.393404319292194, -0.8675357094535592, -0.6707931025836458}, {
      2.4451638634856314`, -0.8685853376823988, -0.6717372134453601}, {
      2.4968508277611483`, -0.8695671286856322, -0.6726155560257564}, {
      2.548468421725533, -0.8704862479833461, -0.6734336372821901}, {
      2.6000197620367302`, -0.8713474209230663, -0.6741964337933063}, {
      2.6515078621078425`, -0.8721549726257796, -0.6749084485618756}, {
      2.702935625300727, -0.8729128643291023, -0.6755737612539717}, {
      2.754305840872904, -0.8736247264014989, -0.6761960726662108}, {
      2.8056211820827617`, -0.8742938882978287, -0.6767787441177217}, {
      2.856884205972839, -0.8749234057168868, -0.6773248323787283}, {
      2.9080973544442874`, -0.8755160852082168, -0.6778371206724633}, {
      2.9592629563113437`, -0.876074506459929, -0.6783181462207956}, {
      3, -0.8765191104535806, -0.6787011292809516}}], 
    Line3DBox[{{0., -0.75, -1.*^-6}, {
      9.63963064743451*^-8, -0.75, -1.0046354071927043`*^-6}, {
      1.9368661135595524`*^-7, -0.75, -1.0185845398707027`*^-6}, {
      2.9277219354065394`*^-7, -0.75, -1.0419768208726156`*^-6}, {
      3.945722579769716*^-7, -0.75, -1.075028998784386*^-6}, {
      5.000304178869435*^-7, -0.75, -1.118047491888238*^-6}, {
      6.101244585261265*^-7, -0.75, -1.171431096447165*^-6}, {
      7.25874418968571*^-7, -0.75, -1.2356750053097076`*^-6}, {
      8.483536795257067*^-7, -0.75, -1.3113746753845724`*^-6}, {
      9.786979083421743*^-7, -0.75, -1.3992317865490546`*^-6}, {
      1.1181156443379474`*^-6, -0.75, -1.5000607458398724`*^-6}, {
      1.2678991738375305`*^-6, -0.75, -1.614796472853357*^-6}, {
      1.4294373446889662`*^-6, -0.75, -1.7445024769575526`*^-6}, {
      1.6042270872713448`*^-6, -0.75, -1.8903817652468372`*^-6}, {
      1.7938893749448946`*^-6, -0.75, -2.053786316291479*^-6}, {
      2.000182426303128*^-6, -0.75, -2.2362311052043297`*^-6}, {
      2.225018646927855*^-6, -0.75, -2.4394076219655577`*^-6}, {
      2.4704828192016027`*^-6, -0.75, -2.665199139810544*^-6}, {
      2.7388502928594414`*^-6, -0.75, -2.9156991936871426`*^-6}, {
      3.032609198143228*^-6, -0.75, -3.1932299776221868`*^-6}, {
      3.354482637941926*^-6, -0.75, -3.5003646809847865`*^-6}, {
      3.7074547512577334`*^-6, -0.75, -3.839950575259027*^-6}, {
      4.094797965599732*^-6, -0.75, -4.215135797456632*^-6}, {
      4.5201032298130855`*^-6, -0.75, -4.629398640437455*^-6}, {
      4.987313430624421*^-6, -0.75, -5.086579678426582*^-6}, {
      5.500759892968026*^-6, -0.75, -5.590917423877726*^-6}, {
      6.0652028434297415`*^-6, -0.75, -6.147087319231559*^-6}, {
      6.685875017895697*^-6, -0.75, -6.760245596022907*^-6}, {
      7.368530476186218*^-6, -0.75, -7.4360767796588286`*^-6}, {
      8.119498050856585*^-6, -0.75, -8.18084628580741*^-6}, {
      8.945739826372636*^-6, -0.75, -9.001458697990456*^-6}, {
      9.854915676788622*^-6, -0.75, -9.90552178490242*^-6}, {
      0.000010855454435045279`, -0.75, -0.000010901416875420529`}, {
      0.000011956631857642982`, -0.75, -0.000011998376736394562`}, {
      0.000013168656749468971`, -0.75, -0.000013206571037077934`}, {
      0.000014502765521255142`, -0.75, -0.000014537200715991115`}, {
      0.00001597132640164618, -0.75, -0.000016002601780958107`}, {
      0.000017587954126325297`, -0.75, -0.0000176163596478643}, {
      0.000019367636143653748`, -0.75, -0.00001939343510190799}, {
      0.00002132687148216251, -0.75, -0.00002135030307379744}, {
      0.00002348382381144244, -0.75, -0.000023505105273719663`}, {
      0.000025858489793059814`, -0.7500000001004329, \
-0.000025877818420070944`}, {
      0.000028472884473670578`, -0.7500000002221848, \
-0.000028490439431753182`}, {
      0.00003135124533353748, -0.7500000003697812, -0.00003136718940426131}, {
      0.000034520257080197857`, -0.750000000548708, -0.00003453473806586776}, \
{0.00003800929896617459, -0.7500000007656158, -0.000038022451098092504`}, {
      0.000041850717164656715`, -0.7500000010285669, \
-0.000041862662371352015`}, {
      0.000046080124665008025`, -0.7500000013473349, \
-0.00004609097368412919}, {
      0.000050736731420752723`, -0.7500000017337681, \
-0.000050746584833175586`}, {
      0.0000558637078752209, -0.75000000220223, -0.00005587265700766191}, {
      0.00006150858516042804, -0.7500000027701328, -0.00006151671295246705}, {
      0.00006772369576068202, -0.750000003458585, -0.00006773107752871205}, {
      0.00007456665867598787, -0.7500000042931757, -0.00007457336280604881}, {
      0.00008210091359232288, -0.750000005304926, -0.00008210700217460718}, {
      0.00009039630902298428, -0.7500000065314417, -0.0000904018384161286}, {
      0.0000995297498489209, -0.7500000080183113, -0.000099534771210673}, {
      0.00010958591031167732`, -0.7500000098208005, \
-0.00010959047003122244`}, {
      0.00012065801897156642`, -0.750000012005906, -0.00012066215913244997`}, \
{0.00013284872305687224`, -0.7500000146548464, -0.0001328524817622209}, {
      0.00014627104004820567`, -0.7500000178660805, \
-0.00014627445177643565`}, {
      0.0001610494054488071, -0.7500000217589667, -0.0001610525013500728}, {
      0.00017732082640882735`, -0.7500000264782004, -0.0001773236345424802}, {
      0.0001952361518861213, -0.750000032199191, -0.0001952386974229335}, {
      0.00021496147112664204`, -0.7500000391345826, -0.0002149637765226108}, {
      0.00023667965345885886`, -0.7500000475421572, -0.0002366817385466974}, {
      0.0002605920436155512, -0.7500000577344168, -0.0002605939256805411}, {
      0.00028692032837301375`, -0.750000070090198, -0.0002869220221307047}, {
      0.0003159085917569124, -0.7500000850687535, -0.00031591010925730956`}, {
      0.0003478255778841421, -0.7500001032268219, -0.0003478269283291974}, {
      0.0003829671824402782, -0.7500001252393207, -0.0003829683718512321}, {
      0.0004216591958571126, -0.7500001519244327, -0.00042166022658451105`}, {
      0.00046426032363953653`, -0.7500001842740164, -0.0004642611936592275}, {
      0.0005111655118405442, -0.7500002234904717, -0.0005111662137645295}, {
      0.0005628096085141138, -0.7500002710314319, -0.0005628101282204665}, {
      0.0006196713950802501, -0.7500003286639407, -0.0006196717098538723}, {
      0.0006822780249882714, -0.7500003985301308, -0.0006822781009961197}, {
      0.0007512099108136968, -0.7500004832268417, -0.0007512096997085619}, {
      0.0008271061051054208, -0.7500005859021386, -0.0008271055394553264}, {
      0.0009106702248499194, -0.7500007103723176, -0.0009106692120217102}, {
      0.0010026769744906204`, -0.7500008612637462, -0.0010026753884498055`}, {
      0.0011039793279505976`, -0.750001044184809, -0.001103976998304328}, {
      0.0012155164362508324`, -0.7500012659343489, -0.0012155131335944826`}, {
      0.0013383223340088977`, -0.750001534754349, -0.0013383177503556002`}, {
      0.0014735355255291029`, -0.7500018606362416, -0.0014735292481699192`}, {
      0.0016224095393325179`, -0.7500022556922253, -0.0016224010159295427`}, {
      0.0017863245489481143`, -0.7500027346053835, -0.0017863130409307899`}, {
      0.0019668001676661174`, -0.7500033151753216, -0.001966784688016003}, {
      0.0021655095358248657`, -0.7500040189795867, -0.0021654887660241253`}, {
      0.0023842948311694925`, -0.7500048721754271, -0.002384267010340591}, {
      0.002625184345994646, -0.7500059064716538, -0.0026251471229227674`}, {
      0.002890411289276908, -0.7500071603066699, -0.002890361524898331}, {
      0.0031824344879655252`, -0.7500086802763714, -0.003182367991739322}, {
      0.003503961179148294, -0.7500105228648676, -0.003503872357190696}, {
      0.0038579721041339388`, -0.7500127565421729, -0.0038578534895886835`}, {
      0.0042477491367420095`, -0.75001546430657, -0.004247590762983943}, {
      0.004676905701468897, -0.7500187467657526, -0.004676694265556576}, {
      0.0051494202629016935`, -0.7500227258706972, -0.00514913800911397}, {
      0.0056696731960151825`, -0.7500275494402027, -0.005669296425844902}, {
      0.006242487378043925, -0.7500333966430339, -0.006241984461728737}, {
      0.006873172876742989, -0.7500404846396117, -0.006872501599668853}, {
      0.0075675761473108305`, -0.7500490766274404, -0.007566680168957824}, {
      0.00833213419135701, -0.7500594915853853, -0.008330938320225495}, {
      0.009173934176362667, -0.7500721160732124, -0.009172338065364995}, {
      0.010100779063443728`, -0.7500874185164935, -0.010098648798361042`}, {
      0.011121259845216346`, -0.7501059664953875, -0.011118416723104848`}, {
      0.012244835054518004`, -0.7501284476616378, -0.012241040614927725`}, {
      0.013481918268973082`, -0.7501556950344352, -0.0134768543293085}, {
      0.014843974406175998`, -0.7501887175760314, -0.014837216438049083`}, {
      0.0163436256797885, -0.7502287371258615, -0.0163346073121532}, {
      0.01799476816816048, -0.7502772329813829, -0.017982733870976344`}, {
      0.01981270003399946, -0.7503359956586814, -0.019796642064716263`}, {
      0.021814262525592296`, -0.7504071916495109, -0.02179283693317667}, {
      0.02401799498600248, -0.7504934413160275, -0.023989409763278347`}, {
      0.026444305194528686`, -0.7505979124300121, -0.0264061714188148}, {
      0.02911565646114702, -0.7507244322659823, -0.029064790296817997`}, {
      0.03205677298420537, -0.7508776215870693, -0.03198893252229461}, {
      0.03529486505561157, -0.7510630542987815, -0.035204400859581535`}, {
      0.0388598757425548, -0.7512874469536169, -0.038739267310217325`}, {
      0.042784750669318874`, -0.7515588826113462, -0.04262399238175343}, {
      0.047105732434497775`, -0.7518870737056411, -0.04689152142830114}, {
      0.05186268097824308, -0.752283668401595, -0.05157734514459536}, {
      0.057099420785712125`, -0.7527626042512567, -0.056719507095563976`}, {
      0.06286411506335955, -0.7533405114817178, -0.06235853594668643}, {
      0.06920966578574239, -0.7540371655903517, -0.06853727373256951}, {
      0.07619413653555909, -0.7548759845515436, -0.07530056406593515}, {
      0.0838811919949762, -0.7558845591919603, -0.08269475583878663}, {
      0.09234054329816309, -0.7570951953690911, -0.09076696921977051}, {
      0.10164838156044727`, -0.7585454326257897, -0.09956406264580067}, {
      0.11188777191824967`, -0.7602784852201728, -0.10913123385914449`}, {
      0.1231489663745037, -0.7623435274806347, -0.1195101877476301}, {
      0.13552957470387525`, -0.764795716891003, -0.13073681305063126`}, {
      0.14913450807920045`, -0.7676958175193715, -0.14283833459224166`}, {
      0.16407558045163753`, -0.7711092585701727, -0.15582995438986358`}, {
      0.1804706207207978, -0.7751044471813606, -0.16971107043325034`}, {
      0.19844192064666258`, -0.7797501650300689, -0.18446127008798627`}, {
      0.21811383064896728`, -0.7851119326698094, -0.20003643286024547`}, {
      0.23960933513142887`, -0.7912473417344731, -0.21636542884099644`}, {
      0.2630455114456545, -0.7982005431487837, -0.23334803073640312`}, {
      0.2885279199424485, -0.8059963289722204, -0.2508547164639715}, {
      0.31614418996749916`, -0.8146345133455176, -0.2687289638684537}, {
      0.3459573322700006, -0.8240855241501497, -0.2867923810380007}, {
      0.37799955832478116`, -0.8342881600501544, -0.30485257447158054`}, {
      0.41226752849786213`, -0.8451502653351495, -0.3227131085091921}, {
      0.44871989469631524`, -0.8565526175283019, -0.34018440294732893`}, {
      0.4872777123490606, -0.8683557064675193, -0.35709412798986767`}, {
      0.527827822619431, -0.8804084922688028, -0.37329570842600507`}, {
      0.570228781303068, -0.892557858288323, -0.38867394122269094`}, {
      0.6143184951363705, -0.9046574372925326, -0.4031473316884553}, {
      0.659922532853628, -0.9165747656703259, -0.4166673653176926}, {
      0.7068621303666218, -0.9281961829527052, -0.42921538341476356`}, {
      0.7549611451298458, -0.939429376974665, -0.4407979390689591}, {
      0.8040515309970246, -0.9502038504934983, -0.4514414922917693}, {
      0.853977206144806, -0.9604697969742446, -0.4611871362023605}, {
      0.904596414082483, -0.9701959309970627, -0.470085819716601}, {
      0.9557828131921808, -0.97936676810116, -0.47819431528493866`}, {
      1.007425584236075, -0.9879797427227013, -0.48557201011925333`}, {
      1.0594288414664417`, -0.9960424333490002, -0.49227848621474796`}, {
      1.111710596085203, -1.0035700568264905`, -0.4983717919571943}, {
      1.1642014703744423`, -1.0105833102000292`, -0.5039072831230246}, {
      1.2168433096213938`, -1.0171065801378647`, -0.5089369101502219}, {
      1.269587793841656, -1.0231665034784754`, -0.5135088407872775}, {
      1.3223951149390305`, -1.028790842519112, -0.5176673250425503}, {
      1.3752327575031198`, -1.0340076302346608`, -0.5214527281139778}, {
      1.4280744018607807`, -1.038844539456191, -0.5249016742003114}, {
      1.4808989547397315`, -1.0433284330370245`, -0.5280472587165381}, {
      1.5336897044415962`, -1.0474850570682146`, -0.5309192982261958}, {
      1.5864335924268929`, -1.0513388449309364`, -0.5335445965618761}, {
      1.63912059062087, -1.0549128056049748`, -0.5359472125158095}, {
      1.6917431727503394`, -1.058228474779078, -0.5381487195715767}, {
      1.7442958680324683`, -1.0613059117555028`, -0.5401684518144342}, {
      1.796774886146825, -1.0641637288722436`, -0.5420237327428111}, {
      1.8491778033537654`, -1.066819143222706, -0.5437300854842706}, {
      1.901503300693319, -1.069288042910251, -0.5453014241124867}, {
      1.9537509462944418`, -1.0715850620223855`, -0.5467502265330099}, {
      2.005921014876523, -1.0737236600334956`, -0.5480876898784803}, {
      2.058014338496012, -1.0757162025250782`, -0.5493238696195406}, {
      2.1100321834636824`, -1.077574041017101, -0.5504678037220748}, {
      2.1619761491277116`, -1.0793075903909959`, -0.5515276232119367}, {
      2.213848084887295, -1.0809264029011416`, -0.5525106504785657}, {
      2.265650022377944, -1.0824392381556878`, -0.553423486582273}, {
      2.317384120262009, -1.0838541287295775`, -0.5542720887426624}, {
      2.369052619476023, -1.0851784412766603`, -0.5550618390885546}, {
      2.420657807139703, -1.0864189331525624`, -0.5557976056501318}, {
      2.4722019876288757`, -1.0875818046601204`, -0.556483796476435}, {
      2.52368745956425, -1.0886727470959032`, -0.5571244076686325}, {
      2.575116497677092, -1.089696986818328, -0.5577230660332301}, {
      2.6264913386877073`, -1.0906593255816914`, -0.5582830669803348}, {
      2.6778141704786385`, -1.0915641773911442`, -0.5588074082204258}, {
      2.7290871239662597`, -1.0924156021349962`, -0.5592988197486642}, {
      2.7803122671759493`, -1.0932173362456339`, -0.5597597905482261}, {
      2.8314916011105464`, -1.093972820630863, -0.560192592392981}, {
      2.882627057072179, -1.0946852261052578`, -0.5605993010845253}, {
      2.9337204951561024`, -1.0953574765372365`, -0.5609818154185535}, {
      2.984773703683918, -1.0959922699129396`, -0.5613418741402819}, {
      3, -1.0961815930194918`, -0.5614492593751441}}], 
    Line3DBox[{{0., -0.8999999999999999, -1.*^-6}, {
      1.465698823428751*^-7, -0.8999999999999999, -1.0106843457002216`*^-6}, {
      2.962716132545117*^-7, -0.8999999999999999, -1.0429655740649054`*^-6}, {
      4.523043253880178*^-7, -0.8999999999999999, -1.0975334615932973`*^-6}, {
      6.180022658837846*^-7, -0.8999999999999999, -1.1755540173520624`*^-6}, {
      7.969059631159191*^-7, -0.8999999999999999, -1.2786945199104919`*^-6}, {
      9.928385247413383*^-7, -0.8999999999999999, -1.4091588268505606`*^-6}, {
      1.2099864386585537`*^-6, -0.8999999999999999, \
-1.5697349821063224`*^-6}, {
      1.452990187185515*^-6, -0.8999999999999999, -1.7638540249057294`*^-6}, {
      1.7270421258603356`*^-6, -0.8999999999999999, -1.995664229217233*^-6}, {
      2.0379985252006594`*^-6, -0.8999999999999999, -2.27011890837035*^-6}, {
      2.3925040374707387`*^-6, -0.8999999999999999, \
-2.5930828060027324`*^-6}, {
      2.7981340704073425`*^-6, -0.8999999999999999, -2.971457080427524*^-6}, {
      3.263556290598541*^-6, -0.8999999999999999, -3.4133271140037162`*^-6}, {
      3.798716013221317*^-6, -0.8999999999999999, -3.928135130751879*^-6}, {
      4.415048904742475*^-6, -0.8999999999999999, -4.52688178142071*^-6}, {
      5.12572507030871*^-6, -0.8999999999999999, -5.222361478178697*^-6}, {
      5.945930650766179*^-6, -0.8999999999999999, -6.02943562787205*^-6}, {
      6.893192316764313*^-6, -0.8999999999999999, -6.9653502103332345`*^-6}, {
      7.987751676693452*^-6, -0.8999999999999999, -8.050104410339301*^-6}, {
      9.252997952341795*^-6, -0.8999999999999999, -9.306877832068441*^-6}, {
      0.000010715967605819572`, -0.8999999999999999, \
-0.000010762525980325966`}, {
      0.000012407922199866816`, -0.8999999999999999, \
-0.00001244815399544828}, {
      0.000014365016435613169`, -0.9000000001240995, \
-0.00001439978130316071}, {
      0.000016629070618201228`, -0.9000000002902985, \
-0.00001665911140813307}, {
      0.000019248464347268406`, -0.9000000005128784, \
-0.000019274422986232753`}, {
      0.000022279170328160028`, -0.9000000008109659, \
-0.00002230160152237324}, {
      0.00002578595044016695, -0.9000000012101756, \
-0.000025805333490166334`}, {
      0.00002984373956993924, -0.9000000017448123, \
-0.000029860488645684583`}, {
      0.00003453924689364828, -0.9000000024608177, -0.00003455371985372336}, {
      0.00003997280869814209, -0.9000000034197188, -0.00003998531476233666}, {
      0.00004626053246898117, -0.9000000047039146, \
-0.000046271338756084996`}, {
      0.000053536777880838855`, -0.9000000064237575, \
-0.000053546115159145205`}, {
      0.00006195702791390615, -0.9000000087270351, -0.000061965095476414}, {
      0.00007170121128199128, -0.90000001181167, -0.00007170818116847847}, {
      0.00008297754725960348, -0.9000000159427275, -0.00008298356784567422}, {
      0.00009602699500270876, -0.900000021475193, -0.00009603219408272723}, {
      0.00011112840250803374`, -0.9000000288844757, \
-0.00011113288983837191`}, {
      0.00012860446515882792`, -0.9000000388072614, \
-0.00012860833455496663`}, {
      0.00014882862123586239`, -0.9000000520962226, \
-0.00014883195217412997`}, {
      0.00017223303170731967`, -0.9000000698932891, \
-0.00017223589039690017`}, {
      0.00019931781480918477`, -0.9000000937277741, -0.0001993202546342679}, {
      0.00023066173272786548`, -0.9000001256477881, \
-0.00023066379388226772`}, {
      0.00026693455871396824`, -0.900000168396231, -0.0002669362667383926}, {
      0.00030891138887053645`, -0.9000002256464872, -0.0003089127515869075}, {
      0.000357489204361981, -0.9000003023180722, -0.00035749020644431707`}, {
      0.0004137060378612305, -0.9000004049993533, -0.00041370663184000893`}, {
      0.0004787631536514389, -0.9000005425136618, -0.00047876324546219224`}, {
      0.0005540507151041467, -0.9000007266774315, -0.00055405014125534}, {
      0.0006411774876608856, -0.9000009733154916, -0.0006411759794642606}, {
      0.0007420052114676562, -0.9000013036207218, -0.000742002339281995}, {
      0.0008586883773109723, -0.9000017459748407, -0.0008586834638416047}, {
      0.0009937202544731398, -0.9000023383866713, -0.000993712240167018}, {
      0.0011499861520105335`, -0.9000031317571955, -0.0011499733862325614`}, {
      0.0013308250483773448`, -0.9000041942515874, -0.0013308049656080999`}, {
      0.001540100901399345, -0.9000056171532406, -0.0015400695192741615`}, {
      0.001782285154734713, -0.9000075227016112, -0.0017822362960301507`}, {
      0.0020625521920063826`, -0.9000100745852097, -0.002062476278897225}, {
      0.002386889759947074, -0.900013491987496, -0.0023867719455445305`}, {
      0.002762226691656061, -0.9000180683856399, -0.0027620439648329016`}, {
      0.0031965806150993283`, -0.9000241967049589, -0.003196297314861797}, {
      0.003699228734783367, -0.900032402968037, -0.0036987896013242626`}, {
      0.004280905230008388, -0.9000433912896321, -0.004280224641368071}, {
      0.004954029323672025, -0.9000581040114911, -0.004952974627654946}, {
      0.00573296864086906, -0.9000778020150245, -0.0057313343499476}, {
      0.00663434309111738, -0.9001041718815416, -0.006631810946242317}, {
      0.007677375158079984, -0.9001394686944053, -0.0076734523532692046`}, {
      0.008884293138378897, -0.9001867060151131, -0.008878216825658966}, {
      0.010280794486388502`, -0.9002499080407276, -0.01027138428445006}, {
      0.011896576909226648`, -0.9003344432676268, -0.01188200737040854}, {
      0.013765945074690636`, -0.9004474641778494, -0.013743395220974033`}, {
      0.015928500518401417`, -0.9005984833881584, -0.01589361515606632}, {
      0.018429921208707768`, -0.9008001228639454, -0.01837598524163044}, {
      0.021322834697999567`, -0.9010690780456014, -0.021239512232852205`}, {
      0.02466778402078236, -0.9014273407580807, -0.02453920239952535}, {
      0.02853427725206294, -0.9019037193970307, -0.02833613483352653}, {
      0.03300189813296203, -0.9025356751375196, -0.03269713648503844}, {
      0.03816143396725662, -0.9033714481770784, -0.03769383663094056}, {
      0.044115945024829795`, -0.9044723640308479, -0.043400813475674704`}, {
      0.050981653680620624`, -0.9059150712763276, -0.04989249697342}, {
      0.05888846931131413, -0.9077932604842719, -0.05723849829510074}, {
      0.06797988850307982, -0.9102181647022204, -0.06549715790273677}, {
      0.07841193074024518, -0.9133169092275373, -0.07470741216267938}, {
      0.09035071524048378, -0.917227698317479, -0.08487961632050624}, {
      0.10396830366156465`, -0.922091093586123, -0.09598667321707381}, {
      0.11943658755509501`, -0.9280374165592626, -0.10795747213590348`}, {
      0.13691933113123209`, -0.9351715556332953, -0.12067484664279797`}, {
      0.15656295981693966`, -0.9435577807490064, -0.1339796438067071}, {
      0.17848717485139987`, -0.9532078936703905, -0.1476810353190579}, {
      0.20277676037689074`, -0.9640756101950395, -0.16157140773259085`}, {
      0.22947586218018515`, -0.9760585060813644, -0.17544287504230816`}, {
      0.25858555295149754`, -0.9890068434545266, -0.18910225896367977`}, {
      0.2900648357396278, -1.0027370226280237`, -0.20238224451827572`}, {
      0.32383462257929163`, -1.0170468057408006`, -0.2151477803131333}, {
      0.35978383591155944`, -1.0317297869486466`, -0.22729801740044914`}, {
      0.39777666064060113`, -1.0465874275988705`, -0.2387648121558621}, {
      0.4376600655845333, -1.061437893770102, -0.24950903642904193`}, {
      0.4792709182512726, -1.076121656874798, -0.2595158092630929}, {
      0.5224422520570962, -1.0905042623490506`, -0.26878948238627004`}, {
      0.5670084572510616, -1.1044768703134067`, -0.2773489134659866}, {
      0.6128093320139911, -1.1179552014762626`, -0.2852233148668189}, {
      0.6596930441290106, -1.1308774552152234`, -0.292448790396325}, {
      0.7075181222568138, -1.1432016592313916`, -0.29906556185700206`}, {
      0.7561546291428581, -1.1549027954047972`, -0.3051158257936424}, {
      0.8054846773397217, -1.165969942530749, -0.3106421529274213}, {
      0.8554024401895737, -1.1764035910283397`, -0.3156863356907166}, {
      0.9058137938697337, -1.1862132188928423`, -0.32028859391631787`}, {
      0.9566357052966055, -1.195415170380532, -0.3244870590934945}, {
      1.0077954589681972`, -1.2040308461384672`, -0.328317470001516}, {
      1.0592297954446077`, -1.2120851924383398`, -0.3318130248781381}, {
      1.1108840162008304`, -1.219605464827354, -0.3350043465096148}, {
      1.1627110944642247`, -1.2266202353410531`, -0.3379195262971232}, {
      1.2146708193830538`, -1.2331586104355627`, -0.3405842213765883}, {
      1.2667289912378465`, -1.2392496274835398`, -0.3430217853474096}, {
      1.318856678063257, -1.2449217999476523`, -0.3452534182884984}, {
      1.3710295386168845`, -1.2502027844364596`, -0.3472983257213497}, {
      1.423227212745956, -1.2551191462507127`, -0.3491738792276168}, {
      1.4754327775316058`, -1.2596962034189954`, -0.35089577372947606`}, {
      1.527632265849533, -1.2639579324075316`, -0.3524781781544887}, {
      1.5798142429400102`, -1.267926921567634, -0.35393387746464006`}, {
      1.6319694360407797`, -1.2716243609133713`, -0.3552744049383825}, {
      1.684090411955331, -1.2750700589973472`, -0.35651016423943627`}, {
      1.7361712974929326`, -1.278282479492327, -0.35765054125302603`}, {
      1.7882075379403666`, -1.2812787916213346`, -0.3587040059703496}, {
      1.8401956890458868`, -1.2840749298445386`, -0.3596782048945873}, {
      1.8921332383683744`, -1.2866856592444689`, -0.3605800445564112}, {
      1.9440184522373691`, -1.2891246438869055`, -0.3614157667861095}, {
      1.9958502449611324`, -1.2914045161052272`, -0.3621910164097926}, {
      2.0476280672961544`, -1.2935369451894363`, -0.36291090203103693`}, {
      2.099351811544038, -1.295532704382095, -0.3635800505357856}, {
      2.1510217309658364`, -1.2974017354129261`, -0.36420265592392004`}, {
      2.2026383714977418`, -1.2991532100594188`, -0.3647825230303222}, {
      2.254202514015423, -1.3007955884170563`, -0.3653231066547757}, {
      2.305715125628342, -1.3023366737117612`, -0.36582754657597333`}, {
      2.357177318691856, -1.3037836635986522`, -0.36629869888174615`}, {
      2.408590316406007, -1.3051431979732133`, -0.3667391640063784}, {
      2.4599554240279806`, -1.3064214033799055`, -0.36715131182712607`}, {
      2.5112740048626665`, -1.307623934144267, -0.36753730413612273`}, {
      2.5625474603148524`, -1.3087560103817746`, -0.3678991147708593}, {
      2.6137772133895205`, -1.3098224530534333`, -0.368238547656358}, {
      2.6649646951154646`, -1.310827716246816, -0.368557252984926}, {
      2.7161113334438145`, -1.3117759168641185`, -0.36885674173482497`}, {
      2.7672185442386636`, -1.3126708618973133`, -0.36913839870714826`}, {
      2.8182877240332926`, -1.313516073465918, -0.3694034942404596}, {
      2.8693202442737054`, -1.3143148117861874`, -0.3696531947451235}, {
      2.9203174468125033`, -1.3150700962324273`, -0.3698885721835448}, {
      2.971280640451431, -1.3157847246421643`, -0.3701106126085528}, {
      3, -1.3161874401860187`, -0.37023573935875814`}}], 
    Line3DBox[{{0., -1.000001, 0.}, {
      0.0011312323423716627`, -1.0032898250994993`, 0.}, {
      0.0070020263912524815`, -1.0058736690197863`, 0.}, {
      0.01516856240356814, -1.011046050957896, 0.}, {
      0.026025492597341653`, -1.0182304014537078`, 0.}, {
      0.03963470155667449, -1.0271707885512913`, 0.}, {
      0.05598296480284253, -1.037672389672608, 0.}, {
      0.07502843801875392, -1.0495442357249523`, 0.}, {
      0.09671088599000162, -1.0625898168231476`, 0.}, {
      0.12095454840421604`, -1.0766085187990855`, 0.}, {
      0.1476694336193151, -1.0913997852710215`, 0.}, {
      0.1767525082673613, -1.1067677334295511`, 0.}, {
      0.20808918496792728`, -1.1225254102317272`, 0.}, {
      0.24155517228390255`, -1.1384983478641602`, 0.}, {
      0.2770186214205868, -1.1545272796254027`, 0.}, {
      0.31434245274734324`, -1.1704699883125536`, 0.}, {
      0.3533867317507632, -1.186202329278039, 0.}, {
      0.39401097210064256`, -1.2016185156582764`, 0.}, {
      0.4360762639452556, -1.2166307802246765`, 0.}, {
      0.4794471520017683, -1.2311685405832273`, 0.}, {
      0.5239932158160809, -1.2451771951713921`, 0.}, {
      0.5695903304691667, -1.258616669658633, 0.}, {
      0.6161216079709821, -1.2714598197743088`, 0.}, {
      0.6634780366182957, -1.2836907797777175`, 0.}, {
      0.7115588475200119, -1.295303327827025, 0.}, {
      0.7602716446973695, -1.3062993219763022`, 0.}, {
      0.8095323383668719, -1.3166872445179647`, 0.}, {
      0.8592649210781389, -1.3264808785344986`, 0.}, {
      0.909401124182561, -1.3356981291099805`, 0.}, {
      0.9598799884452605, -1.3443599926896337`, 0.}, {
      1.0106473781455716`, -1.3524896713923698`, 0.}, {
      1.0616554632558046`, -1.3601118243967103`, 0.}, {
      1.1128621896174355`, -1.3672519455054861`, 0.}, {
      1.1642307526954905`, -1.3739358543138813`, 0.}, {
      1.2157290866306674`, -1.3801892877450368`, 0.}, {
      1.2673293769911262`, -1.3860375788015873`, 0.}, {
      1.3190076028621371`, -1.3915054099788293`, 0.}, {
      1.3707431116747844`, -1.396616629709743, 0.}, {
      1.422518228415169, -1.4013941213200645`, 0.}, {
      1.4743178995123336`, -1.4058597151562395`, 0.}, {
      1.5261293707124612`, -1.4100341357344917`, 0.}, {
      1.5779418975467678`, -1.4139369768942782`, 0.}, {
      1.6297464865339826`, -1.4175866989922494`, 0.}, {
      1.6815356649751894`, -1.4210006431259425`, 0.}, {
      1.733303277056194, -1.424195058222766, 0.}, {
      1.7850443039347397`, -1.4271851375694267`, 0.}, {
      1.836754705527748, -1.4299850619946273`, 0.}, {
      1.8884312818041131`, -1.4326080474612573`, 0.}, {
      1.9400715515133227`, -1.4350663952825506`, 0.}, {
      1.9916736464254339`, -1.4373715435594916`, 0.}, {
      2.0432362193133344`, -1.4395341187537096`, 0.}, {
      2.094758364066164, -1.441563986570333, 0.}, {
      2.1462395464779127`, -1.4434703015371315`, 0.}, {
      2.1976795444038957`, -1.4452615548373213`, 0.}, {
      2.2490783961176892`, -1.4469456200902573`, 0.}, {
      2.3004363558308767`, -1.4485297968826982`, 0.}, {
      2.3517538554569435`, -1.450020851938372, 0.}, {
      2.4030314718087946`, -1.4514250578794132`, 0.}, {
      2.454269898516879, -1.4527482295834973`, 0.}, {
      2.505469922042308, -1.4539957581781113`, 0.}, {
      2.5566324012372594`, -1.4551726427409093`, 0.}, {
      2.607758249974119, -1.456283519794529, 0.}, {
      2.6588484224259448`, -1.457332690697312, 0.}, {
      2.709903900634728, -1.4583241470394408`, 0.}, {
      2.7609256840512937`, -1.459261594158208, 0.}, {
      2.8119147807721965`, -1.4601484728873975`, 0.}, {
      2.8628722002353113`, -1.4609879796547678`, 0.}, {
      2.913798947167554, -1.4617830850390348`, 0.}, {
      2.964696016605837, -1.4625365508939467`, 0.}, {
      3, -1.4630591811027869`, 0.}}]}, 
   Line3DBox[{{3, 1.4630591811027869`, 0.}, {
     3, 1.3161874401860187`, -0.37023573935875814`}, {
     3, 1.0961815930194918`, -0.5614492593751441}, {
     3, 0.8765191104535806, -0.6787011292809516}, {
     3, 0.6571200190970178, -0.7572805411945357}, {
     3, 0.4379319824835207, -0.8086269504769404}, {
     3, 0.21892904422769105`, -0.8379247508690076}, {
     3, 0., -0.8474324701376029}, {
     3, -0.21892904422769105`, -0.8379247508690076}, {
     3, -0.4379319824835207, -0.8086269504769404}, {
     3, -0.6571200190970178, -0.7572805411945357}, {
     3, -0.8765191104535806, -0.6787011292809516}, {
     3, -1.0961815930194918`, -0.5614492593751441}, {
     3, -1.3161874401860187`, -0.37023573935875814`}, {
     3, -1.4630591811027869`, 0.}}], 
   Line3DBox[{{-3, 1.4630591811027869`, 0.}, {-3, 
      1.3161874401860187`, -0.37023573935875814`}, {-3, 
      1.0961815930194918`, -0.5614492593751441}, {-3, 
      0.8765191104535806, -0.6787011292809516}, {-3, 
      0.6571200190970178, -0.7572805411945357}, {-3, 
      0.4379319824835207, -0.8086269504769404}, {-3, 
      0.21892904422769105`, -0.8379247508690076}, {-3, 
      0., -0.8474324701376029}, {-3, -0.21892904422769105`, \
-0.8379247508690076}, {-3, -0.4379319824835207, -0.8086269504769404}, {-3, \
-0.6571200190970178, -0.7572805411945357}, {-3, -0.8765191104535806, \
-0.6787011292809516}, {-3, -1.0961815930194918`, -0.5614492593751441}, {-3, \
-1.3161874401860187`, -0.37023573935875814`}, {-3, -1.4630591811027869`, 
      0.}}], Line3DBox[{{0.9950041652780258, -0.09983341664682815, 0}, {
     1., 0., 0}, {0.9950041652780258, 0.09983341664682815, 0}, {
     0.9800665778412416, 0.19866933079506122`, 0}, {
     0.955336489125606, 0.2955202066613396, 0}, {
     0.9210609940028851, 0.3894183423086505, 0}, {
     0.8775825618903728, 0.479425538604203, 0}, {
     0.8253356149096782, 0.5646424733950355, 0}, {
     0.7648421872844884, 0.6442176872376911, 0}, {
     0.6967067093471654, 0.7173560908995228, 0}, {
     0.6216099682706644, 0.7833269096274834, 0}, {
     0.5403023058681398, 0.8414709848078965, 0}, {
     0.4535961214255773, 0.8912073600614354, 0}, {
     0.3623577544766734, 0.9320390859672264, 0}, {
     0.26749882862458735`, 0.963558185417193, 0}, {
     0.16996714290024081`, 0.9854497299884603, 0}, {
     0.0707372016677029, 0.9974949866040544, 0}, {-0.029199522301288815`, 
      0.9995736030415051, 0}, {-0.12884449429552486`, 0.9916648104524686, 
      0}, {-0.2272020946930871, 0.9738476308781951, 0}, {-0.3232895668635036, 
      0.9463000876874145, 0}, {-0.4161468365471424, 0.9092974268256817, 
      0}, {-0.5048461045998576, 0.8632093666488737, 0}, {-0.5885011172553458, 
      0.8084964038195901, 0}, {-0.6662760212798244, 0.74570521217672, 
      0}, {-0.7373937155412458, 0.6754631805511506, 0}, {-0.8011436155469337, 
      0.5984721441039564, 0}, {-0.8568887533689473, 0.5155013718214642, 
      0}, {-0.9040721420170612, 0.4273798802338298, 0}, {-0.9422223406686583, 
      0.33498815015590466`, 0}, {-0.9709581651495907, 0.23924932921398198`, 
      0}, {-0.9899924966004454, 0.1411200080598672, 0}, {-0.9991351502732795, 
      0.04158066243329049, 0}, {-0.9982947757947531, -0.058374143427580086`, 
      0}, {-0.9874797699088649, -0.15774569414324865`, 
      0}, {-0.9667981925794609, -0.25554110202683167`, 
      0}, {-0.9364566872907963, -0.35078322768961984`, 
      0}, {-0.896758416334147, -0.44252044329485246`, 
      0}, {-0.848100031710408, -0.5298361409084934, 
      0}, {-0.7909677119144165, -0.6118578909427193, 
      0}, {-0.7259323042001399, -0.6877661591839741, 
      0}, {-0.6536436208636119, -0.7568024953079282, 
      0}, {-0.5748239465332685, -0.8182771110644108, 
      0}, {-0.4902608213406994, -0.8715757724135882, 
      0}, {-0.40079917207997545`, -0.9161659367494549, 
      0}, {-0.30733286997841935`, -0.951602073889516, 
      0}, {-0.2107957994307797, -0.977530117665097, 
      0}, {-0.11215252693505398`, -0.9936910036334645, 
      0}, {-0.01238866346289056, -0.9999232575641008, 0}, {
     0.08749898343944727, -0.9961646088358406, 0}, {
     0.18651236942257576`, -0.9824526126243325, 0}, {
     0.28366218546322625`, -0.9589242746631385, 0}, {
     0.37797774271298107`, -0.9258146823277321, 0}, {
     0.4685166713003771, -0.8834546557201531, 0}, {
     0.5543743361791615, -0.8322674422239008, 0}, {
     0.6346928759426347, -0.7727644875559871, 0}, {
     0.70866977429126, -0.7055403255703919, 0}, {
     0.7755658785102502, -0.6312666378723208, 0}, {
     0.8347127848391598, -0.5506855425976376, 0}, {
     0.8855195169413194, -0.4646021794137566, 0}, {
     0.9274784307440359, -0.373876664830236, 0}, {
     0.960170286650366, -0.27941549819892586`, 0}, {
     0.9832684384425847, -0.18216250427209502`, 0}, {
     0.9965420970232175, -0.0830894028174964, 0}}]},
  PlotRange->{{-3, 3}, {-3, 3}, {-1, 0}}]], "Output",
 CellChangeTimes->{3.460678664916978*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 11:",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" Approximate dividing streamsurfaces for a shallow circular lake \
overlying a semi-infinite, saturated aquifer with regional flow in the \
positive ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox[" direction (",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", 
    RowBox[{"1", " "}]], TraditionalForm]]],
 StyleBox["=1). The box is drawn purely to aid the eye, and does not indicate \
the presence of boundary conditions other than for the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane.",
  FontFamily->"Times"]
}], "Special1",
 CellMargins->{{36, 74}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True,
 FontSize->10],

Cell[TextData[{
 StyleBox["Figure 11 shows the shape of the capture/release zones for simple \
steady flow near a shallow circular lake, with the upstream and downstream \
terminal points of the flow paths joined by lines, indicating the cross \
sectional form of the capture zones. In this idealised case, the \
capture/release zones have infinite extent in the ",
  FontFamily->"Times"],
 StyleBox["x",
  FontFamily->"Courier"],
 StyleBox[" direction. However the widths and depths of the zones tend to \
limiting values. These values can be estimated numerically using \
high-resolution flow paths calculated in section 2.3.4. The list ",
  FontFamily->"Times"],
 StyleBox["DiskPathz",
  FontFamily->"Courier"],
 StyleBox[" contains an approximate principal dividing streamline in the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane for the perfect conducting unit disk. The last point on the \
streamline is:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["DiskPathz[[-1]]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "24.587090054551158`"}], ",", "1.4800468325188458`"}], 
  "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.460678669604478*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell["\<\
Hence the corresponding estimate (measured 14 radii away from the lake) of \
the limiting width of the capture/release zones is\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["2 DiskPathz[[-1,2]]", "Input",
 AspectRatioFixed->True],

Cell[BoxData["2.9600936650376917`"], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.460678673073228*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
 StyleBox["Since the system is scale independent, we may say that the maximum \
width of the capture and release zones for the shallow lake system is \
approximately three times the radius of the lake. Depth information is held \
in the list ",
  FontFamily->"Times"],
 StyleBox["DiskPathy",
  FontFamily->"Courier"],
 StyleBox[", the last point of which is:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["DiskPathy[[-1]]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "14.73290066835396`"}], ",", 
   RowBox[{"-", "0.8601312960298633`"}]}], "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.460678675807603*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell["\<\
Hence the corresponding estimate (measured 14 radii away from the lake) of \
the limiting depth of the capture/release zones is\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["-DiskPathy[[-1,2]]", "Input",
 AspectRatioFixed->True],

Cell[BoxData["0.8601312960298633`"], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.460678678635728*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell["\<\
That is, the limiting depth of the capture/release zones is approximately 90% \
of the lake radius.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["It is worthwhile restating the assumptions under which these \
calculations were made. Firstly the saturated aquifer system was assumed to \
be of semi-infinite extent (the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "\[LessEqual]", "0"}], TraditionalForm]]],
 StyleBox[" half-space), and the aquifer hydraulic conductivity was assumed \
to be uniform and isotropic. The lake was assumed to be a perfectly circular \
thin disk with infinite hydraulic conductivity. Vertical recharge (",
  FontFamily->"Times"],
 StyleBox["i.e.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" distributed flow normal to the ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "0"}], TraditionalForm]]],
 StyleBox[" plane) to the lake and to the aquifer was assumed to be zero.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
In practice, these conditions are never satisfied. Aquifers are rarely \
uniform and isotropic, and never infinite in extent, especially in the \
vertical. Recharge is never zero and even circular lakes always have non-zero \
depth. Even so, perhaps the most stringent assumption is of steady flow. \
Characteristic flow times associated with lakes are of the order or months or \
years, depending largely on the aquifer hydraulic conductivity, hence \
periodic seasonal fluctuations in recharge and other boundary conditions \
cannot be neglected [Townley 1995], and would give rise to capture/release \
zone geometries that were periodic in time. Nevertheless the preceding \
results provide valuable conceptual tools for the study of more realistic \
three-dimensional lake-aquifer systems.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2  Further Work", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Whilst the foregoing analysis has yielded some useful results, \
there are still many possibilities for further study. Firstly, we have \
developed a fully algebraic expression for the velocity field near a variety \
of embedded conductors and resistors, but in the absence of suitable \
algebraic techniques we have relied upon numerical integration procedures to \
calculate flow paths. Analysis of the algebraic velocity expressions might \
also throw light on the angle of intersection of the dividing streamlines \
with the centre line of the circular disk conductor. Numerical indications \
(see Figure 8) are that the streamlines intersect at 45 degrees, but it \
should be possible to derive an exact relationship. Another area that \
deserves attention is the incorporation of ",
  FontFamily->"Times"],
 StyleBox["anisotropy",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" into the present equations, ",
  FontFamily->"Times"],
 StyleBox["i.e.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" where the conductivity factor ",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[" can be written (",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox["x",
  FontFamily->"Times",
  FontSize->10,
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox[", ",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox["y",
  FontFamily->"Times",
  FontSize->10,
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox[", ",
  FontFamily->"Times"],
 StyleBox["K",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox["z",
  FontFamily->"Times",
  FontSize->10,
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["). This might be done through appropriate scaling relationships \
[Bear 1979b], and would be relevant to many hydrological systems.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Finally, we mention that it is possible to extend these results to \
",
  FontFamily->"Times"],
 StyleBox["bounded systems",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[", where the conductor is embedded in a medium that has limited \
extent in the ",
  FontFamily->"Times"],
 StyleBox["y",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" and ",
  FontFamily->"Times"],
 StyleBox["z",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" directions, by a method of linear superposition. This would \
provide results more directly applicable to physical lake-aquifer systems, \
but is beyond the scope of the present paper.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.  Summary", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["In this paper we have used a standard expression for \
three-dimensional Laplace flow near an embedded ellipsoid to study the \
characteristics of flow fields near a variety of conductors. In doing so we \
have developed general, closed form expressions for the flow potential near \
an arbitrary ellipsoid and several degenerate and limiting cases. We have \
also discussed the use of numerical particle tracking techniques to map out \
critical flow paths, known as dividing streamlines, for the flow regimes. \
These techniques were applied to both numerical and analytical velocity \
fields determined from the calculated flow potentials. All these calculations \
were done using standard and simple ",
  FontFamily->"Times"],
 StyleBox["Mathematica",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" coding techniques.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["This paper was prepared from a notebook developed with ",
  FontFamily->"Times"],
 StyleBox["Mathematica",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" version 3.0 on a PowerMac 6100, with a remote kernel executing on \
a Sun SPARC 20 workstation running the Solaris 2.5 operating system.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.  References", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Abramowitz, M. and Stegun, I.A. (1965) \"Handbook of Mathematical \
Functions\", Dover, New York, pp589-90.\n\nBear, J. (1979a) \"Hydraulics of \
Groundwater\", McGraw-Hill, New York, pp160-169. ",
  FontFamily->"Times"],
 StyleBox["\n",
  FontFamily->"Times",
  FontSize->9],
 StyleBox["\nBear, J. (1979b) ",
  FontFamily->"Times"],
 StyleBox["op. cit.",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[", pp169-171.\n\nCarslaw, H.S. and Jaeger, J.C. (1959) \"Conduction \
of Heat in Solids\", Second Edition, Oxford University Press, Oxford, \
pp427-428.\n\nGradshteyn, I.S. and Ryzhik, I.M. (1965) \"Table of Integrals, \
Series and Products\", Academic Press, New York.\n\nMaeder R. (1991) \
\"Programming in ",
  FontFamily->"Times"],
 StyleBox["Mathematica",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox["\", Second Edition, Addison-Wesley, New York.\n\nNield, S.P., \
Townley, L.R. and Barr, A.D. (1994) \"A framework for quantitative analysis \
of surface water - groundwater interaction: Flow geometry in a vertical \
section\", ",
  FontFamily->"Times"],
 StyleBox["Water Resources Research",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontFamily->"Times"],
 StyleBox["30",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox["(8), 2461-2475.\n\nToth, J. (1962) \"A theory of groundwater \
motion in small drainage basins in central Alberta, Canada\", ",
  FontFamily->"Times"],
 StyleBox["Journal of Geophysical Research",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontFamily->"Times"],
 StyleBox["67",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox["(11), 4375-4387.\n\nTownley, L.R. (1995) \"The response of \
aquifers to periodic forcing\", ",
  FontFamily->"Times"],
 StyleBox["Advances in Water Resources",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontFamily->"Times"],
 StyleBox["18",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox["(3), 125-146.\n\nTownley, L.R. and Davidson, M.R. (1988) \
\"Definition of a capture zone for shallow water table lakes\", ",
  FontFamily->"Times"],
 StyleBox["Journal of Hydrology",
  FontFamily->"Times",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontFamily->"Times"],
 StyleBox["104",
  FontFamily->"Times",
  FontWeight->"Bold"],
 StyleBox[", 53-76.",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["About the Authors", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Michael G. Trefry\n",
  FontFamily->"Times"],
 StyleBox["E-mail:  ",
  FontFamily->"Times",
  FontSize->9,
  FontWeight->"Plain"],
 StyleBox["mike.trefry@per.clw.csiro.au\n",
  FontFamily->"Courier",
  FontSize->9,
  FontWeight->"Plain"],
 StyleBox["WWW:  ",
  FontFamily->"Times",
  FontSize->9,
  FontWeight->"Plain"],
 StyleBox["http://www.clw.csiro.au/staff/MTrefry/",
  FontFamily->"Courier",
  FontSize->9,
  FontWeight->"Plain"]
}], "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Michael Trefry studied at the University of Western Australia, gaining his \
PhD in molecular physics and quantum chemistry in 1990. After post-doctoral \
research on van der Waals complexes at Cambridge University (UK), he joined \
CSIRO in 1993 to work on high resolution 3D groundwater simulations and \
reactive transport in composite media.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Lloyd R. Townley\n",
  FontFamily->"Times"],
 StyleBox["E-mail:  ",
  FontFamily->"Times",
  FontSize->9,
  FontWeight->"Plain"],
 StyleBox["LTownley@Townley.com.au\n",
  FontFamily->"Courier",
  FontSize->9,
  FontWeight->"Plain"],
 StyleBox["WWW:  ",
  FontFamily->"Times",
  FontSize->9,
  FontWeight->"Plain"],
 StyleBox["http://www.ozemail.com.au/~ltownley/",
  FontFamily->"Courier",
  FontSize->9,
  FontWeight->"Plain"]
}], "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Lloyd Townley first trained as a civil engineer, but after obtaining his PhD \
at MIT in 1983, has become a specialist in groundwater hydrology. His main \
interests are in mathematical approaches to surface water - groundwater \
interaction, the response of aquifers to periodic forcing, and inverse \
problems for characterising hydrological systems.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{966, 981},
WindowMargins->{{4, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.563, 842.375},
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{54, 54}, {72, 72}}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowSelection->True,
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
Magnification->1,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions", "Subtitle"], 
      Cell[
      "Modify the definitions below to change the default appearance of all \
cells in a given style.  Make modifications to any definition using commands \
in the Format menu.", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section"], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, ScriptMinSize -> 
          9], 
         Cell[
          StyleData[All, "Presentation"], PageWidth -> WindowWidth, 
          ScriptMinSize -> 12, FontSize -> 16], 
         Cell[
          StyleData[All, "Condensed"], PageWidth -> WindowWidth, 
          CellBracketOptions -> {"Margins" -> {1, 1}, "Widths" -> {0, 5}}, 
          ScriptMinSize -> 8, FontSize -> 11], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, ScriptMinSize -> 
          5, FontSize -> 10, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section"], 
         Cell[
         "The options defined for the style below will be used at the \
Notebook level.", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"]}, {
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, CellFrameLabelMargins -> 
          6, StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], CellMargins -> {{12, Inherited}, {20, 40}}, 
             CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> 
             False, CounterIncrements -> "Title", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 36, FontWeight -> "Bold"], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{24, 10}, {20, 40}}, LineSpacing -> {1, 0}, 
             FontSize -> 44], 
            Cell[
             StyleData["Title", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 8}}, FontSize -> 20], 
            Cell[
             StyleData["Title", "Printout"], 
             CellMargins -> {{2, 10}, {15, 30}}, FontSize -> 24]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], 
             CellMargins -> {{12, Inherited}, {10, 15}}, 
             CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> 
             False, CounterIncrements -> "Subtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Helvetica", 
             FontSize -> 24], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{24, 10}, {15, 20}}, LineSpacing -> {1, 0}, 
             FontSize -> 36], 
            Cell[
             StyleData["Subtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 4}}, FontSize -> 14], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{2, 10}, {10, 15}}, FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], 
             CellMargins -> {{12, Inherited}, {10, 20}}, 
             CellGroupingRules -> {"TitleGrouping", 20}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Helvetica", FontSize -> 14, 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 20}}, LineSpacing -> {1, 0}, 
             FontSize -> 24], 
            Cell[
             StyleData["Subsubtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {8, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{2, 10}, {8, 10}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellDingbat -> None, 
             CellMargins -> {{9, Inherited}, {8, 24}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 16, FontWeight -> "Bold"], 
            Cell[
             StyleData["Section", "Presentation"], 
             CellMargins -> {{9, 10}, {11, 32}}, LineSpacing -> {1, 0}, 
             FontSize -> 24], 
            Cell[
             StyleData["Section", "Condensed"], 
             CellMargins -> {{9, Inherited}, {6, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{9, 0}, {7, 22}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> None, 
             CellMargins -> {{9, Inherited}, {8, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontSize -> 14, 
             FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "Presentation"], CellDingbat -> None, 
             CellMargins -> {{9, 10}, {11, 32}}, LineSpacing -> {1, 0}, 
             FontSize -> 22], 
            Cell[
             StyleData["Subsection", "Condensed"], CellDingbat -> None, 
             CellMargins -> {{9, Inherited}, {6, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Subsection", "Printout"], CellDingbat -> None, 
             CellMargins -> {{9, 0}, {7, 22}}, FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> None, 
             CellMargins -> {{9, Inherited}, {8, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["Subsubsection", "Presentation"], CellDingbat -> None, 
             CellMargins -> {{9, 10}, {11, 26}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Subsubsection", "Condensed"], CellDingbat -> None, 
             CellMargins -> {{9, Inherited}, {6, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Subsubsection", "Printout"], CellDingbat -> None, 
             CellMargins -> {{9, 0}, {7, 14}}, FontSize -> 11]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Body Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{12, 10}, {7, 7}}, 
             LineSpacing -> {1, 3}, CounterIncrements -> "Text"], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 5}], 
            Cell[
             StyleData["Text", "Condensed"], CellMargins -> {{8, 10}, {6, 6}},
              LineSpacing -> {1, 1}], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{2, 2}, {6, 6}}]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SmallText"], CellMargins -> {{12, 10}, {6, 6}}, 
             LineSpacing -> {1, 3}, CounterIncrements -> "SmallText", 
             FontFamily -> "Helvetica", FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Presentation"], 
             CellMargins -> {{24, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             FontSize -> 12], 
            Cell[
             StyleData["SmallText", "Condensed"], 
             CellMargins -> {{8, 10}, {5, 5}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Printout"], 
             CellMargins -> {{2, 2}, {5, 5}}, FontSize -> 7]}, Closed]]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input/Output", "Section"], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellMargins -> {{45, 10}, {5, 7}}, 
             Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
             CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{11, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             ShowStringCharacters -> True, NumberMarks -> True, 
             CounterIncrements -> "Input", FontWeight -> "Bold"], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{72, Inherited}, {8, 10}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Input", "Condensed"], 
             CellMargins -> {{40, 10}, {2, 3}}], 
            Cell[
             StyleData["Input", "Printout"], CellMargins -> {{39, 0}, {4, 6}},
              FontSize -> 9]}, Closed]], 
         Cell[
          StyleData["InputOnly"], Evaluatable -> True, CellGroupingRules -> 
          "InputGrouping", CellHorizontalScrolling -> True, DefaultFormatType -> 
          DefaultInputFormatType, AutoItalicWords -> {}, FormatType -> 
          InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
          CounterIncrements -> "Input", StyleMenuListing -> None, FontWeight -> 
          "Bold"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellMargins -> {{47, 10}, {7, 5}}, 
             CellEditDuplicate -> True, CellGroupingRules -> "OutputGrouping",
              CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, 
             CellLabelMargins -> {{11, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             CounterIncrements -> "Output"], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{72, Inherited}, {10, 8}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Output", "Condensed"], 
             CellMargins -> {{41, Inherited}, {3, 2}}], 
            Cell[
             StyleData["Output", "Printout"], 
             CellMargins -> {{39, 0}, {6, 4}}, FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], 
             CellMargins -> {{45, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             CellLabelMargins -> {{11, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             CounterIncrements -> "Message", StyleMenuListing -> None, 
             FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Message", "Presentation"], 
             CellMargins -> {{72, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Message", "Condensed"], 
             CellMargins -> {{41, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 8, FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], 
             CellMargins -> {{45, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, CellLabelMargins -> {{11, Inherited}, {
               Inherited, Inherited}}, DefaultFormatType -> 
             DefaultOutputFormatType, AutoItalicWords -> {}, FormatType -> 
             InputForm, CounterIncrements -> "Print", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{72, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Print", "Condensed"], 
             CellMargins -> {{41, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], 
             CellMargins -> {{4, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Graphics", 
             ImageMargins -> {{43, Inherited}, {Inherited, 0}}, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["Graphics", "Presentation"], 
             ImageMargins -> {{62, Inherited}, {Inherited, 0}}], 
            Cell[
             StyleData["Graphics", "Condensed"], ImageSize -> {175, 175}, 
             ImageMargins -> {{38, Inherited}, {Inherited, 0}}], 
            Cell[
             StyleData["Graphics", "Printout"], ImageSize -> {250, 250}, 
             ImageMargins -> {{30, Inherited}, {Inherited, 0}}, FontSize -> 
             9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["CellLabel", "Presentation"], FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "Condensed"], FontSize -> 9], 
            Cell[
             StyleData["CellLabel", "Printout"], FontFamily -> "Courier", 
             FontSize -> 8, FontSlant -> "Italic", FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Formulas and Programming", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineFormula"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, ScriptLevel -> 1, 
             SingleLetterItalics -> True], 
            Cell[
             StyleData["InlineFormula", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 5}], 
            Cell[
             StyleData["InlineFormula", "Condensed"], 
             CellMargins -> {{8, 10}, {6, 6}}, LineSpacing -> {1, 1}], 
            Cell[
             StyleData["InlineFormula", "Printout"], 
             CellMargins -> {{2, 0}, {6, 6}}]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{42, Inherited}, {Inherited, Inherited}}, 
             CellHorizontalScrolling -> True, ScriptLevel -> 0, 
             SingleLetterItalics -> True, StyleMenuListing -> None, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             LineSpacing -> {1, 5}], 
            Cell[
             StyleData["DisplayFormula", "Condensed"], LineSpacing -> {1, 1}], 
            Cell[
             StyleData["DisplayFormula", "Printout"]]}, Open]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headers and Footers", "Section"], 
         Cell[
          StyleData["Header"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontSize -> 10, FontSlant -> "Italic"], 
         Cell[
          StyleData["Footer"], CellMargins -> {{0, 0}, {0, 4}}, 
          StyleMenuListing -> None, FontSize -> 9, FontSlant -> "Italic"], 
         Cell[
          StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Times", FontSize -> 10]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Palette Styles", "Section"], 
         Cell[
         "The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.", "Text"], 
         Cell[
          StyleData["Paste"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, After]}]& )}], 
         Cell[
          StyleData["Evaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["EvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionMove[
                FrontEnd`InputNotebook[], All, Cell, 1], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Hyperlink Styles", "Section"], 
         Cell[
         "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Presentation"]], 
            Cell[
             StyleData["Hyperlink", "Condensed"]], 
            Cell[
             StyleData["Hyperlink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "The following styles are for linking automatically to the on-line \
help system.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Presentation"]], 
            Cell[
             StyleData["MainBookLink", "Condensed"]], 
            Cell[
             StyleData["MainBookLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLink", "Presentation"]], 
            Cell[
             StyleData["AddOnsLink", "Condensed"]], 
            Cell[
             StyleData["AddOnLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuideLink", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Presentation"]], 
            Cell[
             StyleData["RefGuideLink", "Condensed"]], 
            Cell[
             StyleData["RefGuideLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Presentation"]], 
            Cell[
             StyleData["GettingStartedLink", "Condensed"]], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Presentation"]], 
            Cell[
             StyleData["OtherInformationLink", "Condensed"]], 
            Cell[
             StyleData["OtherInformationLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Placeholder Styles", "Section"], 
         Cell[
         "The cells below define styles useful for making placeholder objects \
in palette templates.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Placeholder"], Editable -> False, Selectable -> False,
              StyleBoxAutoDelete -> True, Placeholder -> True, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["Placeholder", "Presentation"]], 
            Cell[
             StyleData["Placeholder", "Condensed"]], 
            Cell[
             StyleData["Placeholder", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SelectionPlaceholder"], Editable -> False, Selectable -> 
             False, StyleBoxAutoDelete -> True, Placeholder -> Primary, 
             StyleMenuListing -> None, DrawHighlighted -> True], 
            Cell[
             StyleData["SelectionPlaceholder", "Presentation"]], 
            Cell[
             StyleData["SelectionPlaceholder", "Condensed"]], 
            Cell[
             StyleData["SelectionPlaceholder", "Printout"]]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["FormatType Styles", "Section"], 
         Cell[
         "The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.", "Text"], 
         Cell[
          StyleData["CellExpression"], PageWidth -> Infinity, 
          CellMargins -> {{6, Inherited}, {Inherited, Inherited}}, 
          ShowCellLabel -> False, ShowSpecialCharacters -> False, 
          AllowInlineCells -> False, AutoItalicWords -> {}, StyleMenuListing -> 
          None, FontFamily -> "Courier", Background -> GrayLevel[1]], 
         Cell[
          StyleData["InputForm"], AllowInlineCells -> False, StyleMenuListing -> 
          None, FontFamily -> "Courier"], 
         Cell[
          StyleData["OutputForm"], PageWidth -> Infinity, TextAlignment -> 
          Left, LineSpacing -> {1, -5}, StyleMenuListing -> None, FontFamily -> 
          "Courier"], 
         Cell[
          StyleData["StandardForm"], LineSpacing -> {1.25, 0}, 
          StyleMenuListing -> None, FontFamily -> "Courier"], 
         Cell[
          StyleData["TraditionalForm"], LineSpacing -> {1.25, 0}, 
          SingleLetterItalics -> True, TraditionalFunctionNotation -> True, 
          DelimiterMatching -> None, StyleMenuListing -> None], 
         Cell[
         "The style defined below is mixed in to any cell that is in an \
inline cell within another.", "Text"], 
         Cell[
          StyleData["InlineCell"], TextAlignment -> Left, ScriptLevel -> 1, 
          StyleMenuListing -> None], 
         Cell[
          StyleData["InlineCellEditing"], StyleMenuListing -> None, 
          Background -> RGBColor[1, 0.749996, 0.8]]}, Open]]}, Open]]}, 
  Visible -> False, FrontEndVersion -> 
  "7.0 for Microsoft Windows (32-bit) (February 18, 2009)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "compatibility-yes"->{
  Cell[562549, 11230, 79432, 1391, 372, "Output",
   CellTags->"compatibility-yes"],
  Cell[673816, 13418, 93796, 1620, 372, "Output",
   CellTags->"compatibility-yes"]},
 "Info3460704292-7240887"->{
  Cell[406226, 8466, 1625, 24, 976, "Print",
   CellTags->"Info3460704292-7240887"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"compatibility-yes", 1634086, 29987},
 {"Info3460704292-7240887", 1634286, 29992}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 264, 9, 62, "Subsubtitle"],
Cell[CellGroupData[{
Cell[834, 33, 196, 9, 235, "Title",
 Evaluatable->False],
Cell[1033, 44, 1061, 34, 56, "Input"],
Cell[2097, 80, 1219, 39, 259, "Subsubtitle",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[3341, 123, 130, 3, 51, "Section",
 Evaluatable->False],
Cell[3474, 128, 853, 14, 83, "Text",
 Evaluatable->False,
 PageBreakBelow->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[4364, 147, 138, 3, 51, "Section",
 Evaluatable->False],
Cell[4505, 152, 319, 7, 47, "Text",
 Evaluatable->False],
Cell[4827, 161, 1005, 40, 41, "Text",
 Evaluatable->False],
Cell[5835, 203, 662, 28, 29, "Text",
 Evaluatable->False],
Cell[6500, 233, 2142, 84, 65, "Text",
 Evaluatable->False],
Cell[8645, 319, 653, 26, 29, "Text",
 Evaluatable->False],
Cell[9301, 347, 775, 31, 34, "Text",
 Evaluatable->False],
Cell[10079, 380, 819, 24, 65, "Text",
 Evaluatable->False],
Cell[10901, 406, 422, 17, 29, "Text",
 Evaluatable->False],
Cell[11326, 425, 676, 26, 29, "Text",
 Evaluatable->False],
Cell[12005, 453, 725, 20, 65, "Text",
 Evaluatable->False],
Cell[12733, 475, 808, 17, 83, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[13578, 497, 107, 2, 51, "Section",
 Evaluatable->False],
Cell[13688, 501, 809, 19, 65, "Text",
 Evaluatable->False],
Cell[14500, 522, 1155, 40, 47, "Text",
 Evaluatable->False],
Cell[15658, 564, 923, 35, 49, "Text",
 Evaluatable->False],
Cell[16584, 601, 151, 5, 29, "Text",
 Evaluatable->False],
Cell[16738, 608, 1585, 64, 43, "Text",
 Evaluatable->False],
Cell[18326, 674, 65, 2, 29, "Text",
 Evaluatable->False],
Cell[18394, 678, 2920, 117, 69, "Text",
 Evaluatable->False],
Cell[21317, 797, 602, 25, 29, "Text",
 Evaluatable->False],
Cell[21922, 824, 2583, 94, 149, "Text",
 Evaluatable->False],
Cell[24508, 920, 88, 2, 29, "Text",
 Evaluatable->False],
Cell[24599, 924, 886, 33, 37, "Text",
 Evaluatable->False],
Cell[25488, 959, 279, 9, 29, "Text",
 Evaluatable->False],
Cell[25770, 970, 1215, 50, 29, "Text",
 Evaluatable->False],
Cell[26988, 1022, 541, 20, 32, "Text",
 Evaluatable->False],
Cell[27532, 1044, 1019, 42, 32, "Text",
 Evaluatable->False],
Cell[28554, 1088, 103, 2, 29, "Text",
 Evaluatable->False],
Cell[28660, 1092, 904, 34, 29, "Text",
 Evaluatable->False],
Cell[29567, 1128, 1974, 62, 86, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[31566, 1194, 111, 2, 45, "Subsection",
 Evaluatable->False],
Cell[31680, 1198, 1184, 42, 47, "Text",
 Evaluatable->False],
Cell[32867, 1242, 663, 21, 50, "Input"],
Cell[33533, 1265, 388, 13, 29, "Text",
 Evaluatable->False],
Cell[33924, 1280, 494, 14, 27, "Input"],
Cell[34421, 1296, 533, 20, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[34979, 1320, 1311, 38, 49, "Input"],
Cell[36293, 1360, 6947, 123, 263, "Output"]
}, Open  ]],
Cell[43255, 1486, 960, 37, 21, "Special1",
 Evaluatable->False],
Cell[44218, 1525, 676, 21, 47, "Text",
 Evaluatable->False],
Cell[44897, 1548, 525, 18, 50, "Input"],
Cell[45425, 1568, 522, 15, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[45972, 1587, 497, 14, 53, "Text"],
Cell[46472, 1603, 109, 3, 29, "Text"]
}, Open  ]],
Cell[46596, 1609, 4004, 122, 147, "Input"],
Cell[50603, 1733, 416, 16, 34, "Text",
 Evaluatable->False],
Cell[51022, 1751, 656, 22, 45, "Input"],
Cell[51681, 1775, 499, 15, 47, "Text",
 Evaluatable->False],
Cell[52183, 1792, 303, 9, 27, "Input"],
Cell[52489, 1803, 175, 6, 27, "Input"],
Cell[52667, 1811, 293, 9, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[52985, 1824, 185, 6, 36, "Input"],
Cell[53173, 1832, 415, 14, 56, "Output"]
}, Open  ]],
Cell[53603, 1849, 586, 18, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[54214, 1871, 418, 13, 54, "Input"],
Cell[54635, 1886, 348, 11, 47, "Output"]
}, Open  ]],
Cell[54998, 1900, 69, 2, 29, "Text",
 Evaluatable->False],
Cell[55070, 1904, 669, 24, 71, "Input"],
Cell[55742, 1930, 322, 13, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[56089, 1947, 508, 16, 45, "Input"],
Cell[56600, 1965, 4570, 143, 373, "Output"]
}, Open  ]],
Cell[61185, 2111, 496, 19, 29, "Text",
 Evaluatable->False],
Cell[61684, 2132, 339, 11, 27, "Input"],
Cell[62026, 2145, 398, 13, 49, "Input"],
Cell[62427, 2160, 536, 16, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[62988, 2180, 679, 22, 66, "Input"],
Cell[63670, 2204, 137, 2, 27, "Output"],
Cell[63810, 2208, 137, 2, 27, "Output"],
Cell[63950, 2212, 138, 2, 27, "Output"]
}, Open  ]],
Cell[64103, 2217, 155, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[64283, 2226, 1258, 40, 131, "Input"],
Cell[65544, 2268, 136, 2, 27, "Output"],
Cell[65683, 2272, 138, 2, 27, "Output"],
Cell[65824, 2276, 138, 2, 27, "Output"]
}, Open  ]],
Cell[65977, 2281, 800, 26, 47, "Text",
 Evaluatable->False],
Cell[66780, 2309, 323, 10, 29, "Text",
 Evaluatable->False],
Cell[67106, 2321, 1102, 35, 46, "Input"],
Cell[68211, 2358, 31, 0, 29, "Text"],
Cell[68245, 2360, 2360, 68, 84, "Input"],
Cell[70608, 2430, 735, 22, 47, "Text",
 Evaluatable->False],
Cell[71346, 2454, 1170, 33, 64, "Input"],
Cell[72519, 2489, 847, 28, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[73391, 2521, 1869, 47, 91, "Input"],
Cell[75263, 2570, 112522, 1927, 372, "Output"]
}, Open  ]],
Cell[187800, 4500, 867, 31, 22, "Special1",
 Evaluatable->False],
Cell[188670, 4533, 1498, 51, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[190193, 4588, 756, 21, 52, "Input"],
Cell[190952, 4611, 165767, 2735, 295, 153052, 2525, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[356734, 7349, 970, 34, 22, "Special1",
 Evaluatable->False],
Cell[357707, 7385, 684, 19, 47, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[358428, 7409, 99, 2, 45, "Subsection",
 Evaluatable->False],
Cell[358530, 7413, 1468, 38, 101, "Text",
 Evaluatable->False],
Cell[360001, 7453, 386, 12, 29, "Text",
 Evaluatable->False],
Cell[360390, 7467, 603, 19, 45, "Input"],
Cell[360996, 7488, 390, 8, 47, "Text",
 Evaluatable->False],
Cell[361389, 7498, 1045, 28, 67, "Input"],
Cell[362437, 7528, 1037, 27, 67, "Input"],
Cell[363477, 7557, 1027, 26, 67, "Input"],
Cell[364507, 7585, 750, 24, 47, "Text",
 Evaluatable->False],
Cell[365260, 7611, 924, 26, 27, "Input"],
Cell[366187, 7639, 325, 10, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[366537, 7653, 224, 4, 28, "Input"],
Cell[366764, 7659, 35790, 688, 372, "Output"]
}, Open  ]],
Cell[402569, 8350, 827, 29, 20, "Special1",
 Evaluatable->False],
Cell[403399, 8381, 869, 21, 65, "Text",
 Evaluatable->False],
Cell[404271, 8404, 142, 4, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[404438, 8412, 166, 3, 28, "Input"],
Cell[404607, 8417, 161, 2, 27, "Output"]
}, Open  ]],
Cell[404783, 8422, 127, 2, 28, "Input"],
Cell[404913, 8426, 1227, 33, 101, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[406165, 8463, 58, 1, 28, "Input"],
Cell[406226, 8466, 1625, 24, 976, "Print",
 CellTags->"Info3460704292-7240887"]
}, Open  ]],
Cell[407866, 8493, 750, 20, 65, "Text",
 Evaluatable->False],
Cell[408619, 8515, 1041, 24, 83, "Text",
 Evaluatable->False],
Cell[409663, 8541, 383, 8, 79, "Input"],
Cell[410049, 8551, 146, 4, 45, "Input"],
Cell[410198, 8557, 148, 4, 45, "Input"],
Cell[410349, 8563, 222, 6, 79, "Input"],
Cell[410574, 8571, 146, 4, 45, "Input"],
Cell[410723, 8577, 148, 4, 45, "Input"],
Cell[410874, 8583, 226, 6, 29, "Text",
 Evaluatable->False],
Cell[411103, 8591, 194, 7, 96, "Input"],
Cell[411300, 8600, 331, 10, 29, "Text",
 Evaluatable->False],
Cell[411634, 8612, 937, 27, 68, "Input"],
Cell[412574, 8641, 95, 2, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[412694, 8647, 264, 6, 28, "Input"],
Cell[412961, 8655, 143665, 2377, 387, "Output"]
}, Open  ]],
Cell[556641, 11035, 745, 25, 20, "Special1",
 Evaluatable->False],
Cell[557389, 11062, 1540, 41, 101, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[558966, 11108, 87, 2, 45, "Subsection",
 Evaluatable->False],
Cell[559056, 11112, 804, 23, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[559885, 11139, 108, 2, 41, "Subsubsection",
 Evaluatable->False],
Cell[559996, 11143, 1097, 33, 65, "Text",
 Evaluatable->False],
Cell[561096, 11178, 152, 5, 29, "Text",
 Evaluatable->False],
Cell[561251, 11185, 221, 6, 79, "Input"],
Cell[561475, 11193, 109, 2, 29, "Text",
 Evaluatable->False],
Cell[561587, 11197, 265, 8, 113, "Input"],
Cell[561855, 11207, 100, 2, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[561980, 11213, 566, 15, 215, "Input"],
Cell[562549, 11230, 79432, 1391, 372, "Output",
 CellTags->"compatibility-yes"]
}, Open  ]],
Cell[641996, 12624, 775, 25, 33, "Special1",
 Evaluatable->False],
Cell[642774, 12651, 733, 16, 65, "Text",
 Evaluatable->False],
Cell[643510, 12669, 909, 30, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[644444, 12703, 63, 1, 28, "Input"],
Cell[644510, 12706, 173, 5, 27, "Output"]
}, Open  ]],
Cell[644698, 12714, 428, 17, 29, "Text",
 Evaluatable->False],
Cell[645129, 12733, 207, 7, 96, "Input"],
Cell[CellGroupData[{
Cell[645361, 12744, 59, 1, 28, "Input"],
Cell[645423, 12747, 173, 5, 27, "Output"]
}, Open  ]],
Cell[645611, 12755, 558, 20, 29, "Text",
 Evaluatable->False],
Cell[646172, 12777, 208, 7, 96, "Input"],
Cell[646383, 12786, 220, 9, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[646628, 12799, 63, 1, 28, "Input"],
Cell[646694, 12802, 174, 5, 27, "Output"]
}, Open  ]],
Cell[646883, 12810, 882, 27, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[647790, 12841, 663, 19, 49, "Input"],
Cell[648456, 12862, 16420, 278, 251, "Output"]
}, Open  ]],
Cell[664891, 13143, 816, 25, 33, "Special1",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[665744, 13173, 109, 2, 41, "Subsubsection",
 Evaluatable->False],
Cell[665856, 13177, 681, 16, 65, "Text",
 Evaluatable->False],
Cell[666540, 13195, 2434, 66, 235, "Input"],
Cell[668977, 13263, 134, 4, 29, "Text",
 Evaluatable->False],
Cell[669114, 13269, 845, 23, 46, "Input"],
Cell[669962, 13294, 840, 23, 46, "Input"],
Cell[670805, 13319, 840, 23, 46, "Input"],
Cell[671648, 13344, 818, 26, 47, "Text",
 Evaluatable->False],
Cell[672469, 13372, 247, 7, 96, "Input"],
Cell[672719, 13381, 263, 8, 113, "Input"],
Cell[672985, 13391, 211, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[673221, 13400, 592, 16, 232, "Input"],
Cell[673816, 13418, 93796, 1620, 372, "Output",
 CellTags->"compatibility-yes"]
}, Open  ]],
Cell[767627, 15041, 776, 25, 33, "Special1",
 Evaluatable->False],
Cell[768406, 15068, 534, 10, 65, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[768977, 15083, 238, 9, 41, "Subsubsection",
 Evaluatable->False],
Cell[769218, 15094, 1271, 39, 65, "Text",
 Evaluatable->False],
Cell[770492, 15135, 289, 10, 29, "Text",
 Evaluatable->False],
Cell[770784, 15147, 665, 21, 50, "Input"],
Cell[771452, 15170, 312, 9, 27, "Input"],
Cell[771767, 15181, 257, 9, 29, "Text",
 Evaluatable->False],
Cell[772027, 15192, 239, 8, 29, "Text",
 Evaluatable->False],
Cell[772269, 15202, 389, 14, 37, "Input"],
Cell[772661, 15218, 426, 16, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[773112, 15238, 435, 13, 51, "Input"],
Cell[773550, 15253, 794, 30, 74, "Output"]
}, Open  ]],
Cell[774359, 15286, 97, 2, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[774481, 15292, 403, 12, 36, "Input"],
Cell[774887, 15306, 274, 9, 48, "Output"]
}, Open  ]],
Cell[775176, 15318, 328, 13, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[775529, 15335, 519, 17, 45, "Input"],
Cell[776051, 15354, 1224, 42, 90, "Output"]
}, Open  ]],
Cell[777290, 15399, 520, 17, 34, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[777835, 15420, 435, 13, 51, "Input"],
Cell[778273, 15435, 774, 29, 80, "Output"]
}, Open  ]],
Cell[779062, 15467, 68, 2, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[779155, 15473, 477, 15, 42, "Input"],
Cell[779635, 15490, 269, 9, 48, "Output"]
}, Open  ]],
Cell[779919, 15502, 68, 2, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[780012, 15508, 519, 17, 45, "Input"],
Cell[780534, 15527, 1189, 41, 90, "Output"]
}, Open  ]],
Cell[781738, 15571, 394, 11, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[782157, 15586, 405, 13, 27, "Input"],
Cell[782565, 15601, 70, 1, 27, "Output"]
}, Open  ]],
Cell[782650, 15605, 1362, 49, 47, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[784049, 15659, 107, 2, 41, "Subsubsection",
 Evaluatable->False],
Cell[784159, 15663, 946, 26, 65, "Text",
 Evaluatable->False],
Cell[785108, 15691, 2259, 86, 69, "Input"],
Cell[787370, 15779, 468, 15, 29, "Text",
 Evaluatable->False],
Cell[787841, 15796, 291, 8, 27, "Input"],
Cell[788135, 15806, 1110, 45, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[789270, 15855, 556, 20, 47, "Input"],
Cell[789829, 15877, 1542, 52, 93, "Output"]
}, Open  ]],
Cell[791386, 15932, 217, 8, 29, "Text",
 Evaluatable->False],
Cell[791606, 15942, 709, 25, 65, "Input"],
Cell[792318, 15969, 400, 16, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[792743, 15989, 556, 20, 47, "Input"],
Cell[793302, 16011, 1104, 39, 91, "Output"]
}, Open  ]],
Cell[794421, 16053, 96, 2, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[794542, 16059, 61, 1, 28, "Input"],
Cell[794606, 16062, 70, 1, 27, "Output"]
}, Open  ]],
Cell[794691, 16066, 247, 6, 29, "Text",
 Evaluatable->False],
Cell[794941, 16074, 680, 22, 27, "Input"],
Cell[795624, 16098, 406, 12, 47, "Text",
 Evaluatable->False],
Cell[796033, 16112, 501, 16, 45, "Input"],
Cell[796537, 16130, 501, 16, 48, "Input"],
Cell[797041, 16148, 501, 16, 46, "Input"],
Cell[797545, 16166, 711, 23, 47, "Text",
 Evaluatable->False],
Cell[798259, 16191, 226, 7, 96, "Input"],
Cell[798488, 16200, 225, 7, 96, "Input"],
Cell[798716, 16209, 1030, 27, 83, "Text",
 Evaluatable->False],
Cell[799749, 16238, 219, 6, 79, "Input"],
Cell[799971, 16246, 219, 6, 79, "Input"],
Cell[800193, 16254, 381, 12, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[800599, 16270, 974, 30, 49, "Input"],
Cell[801576, 16302, 172215, 2828, 192, "Output"]
}, Open  ]],
Cell[973806, 19133, 488, 16, 26, "Text",
 Evaluatable->False],
Cell[974297, 19151, 318, 11, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[974640, 19166, 853, 26, 49, "Input"],
Cell[975496, 19194, 161726, 2656, 192, "Output"]
}, Open  ]],
Cell[1137237, 21853, 468, 16, 20, "Special1",
 Evaluatable->False],
Cell[1137708, 21871, 441, 8, 65, "Text",
 Evaluatable->False]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1138210, 21886, 93, 2, 51, "Section",
 Evaluatable->False],
Cell[1138306, 21890, 2133, 57, 137, "Text",
 Evaluatable->False],
Cell[1140442, 21949, 794, 13, 83, "Text",
 Evaluatable->False],
Cell[1141239, 21964, 668, 11, 83, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1141932, 21979, 102, 2, 45, "Subsection",
 Evaluatable->False],
Cell[1142037, 21983, 703, 16, 65, "Text",
 Evaluatable->False],
Cell[1142743, 22001, 624, 15, 47, "Text",
 Evaluatable->False],
Cell[1143370, 22018, 146, 5, 62, "Input"],
Cell[1143519, 22025, 391, 13, 29, "Text",
 Evaluatable->False],
Cell[1143913, 22040, 308, 8, 113, "Input"],
Cell[1144224, 22050, 547, 20, 29, "Text",
 Evaluatable->False],
Cell[1144774, 22072, 165, 5, 62, "Input"],
Cell[1144942, 22079, 1439, 46, 65, "Text",
 Evaluatable->False],
Cell[1146384, 22127, 317, 9, 130, "Input"],
Cell[1146704, 22138, 338, 13, 29, "Text",
 Evaluatable->False],
Cell[1147045, 22153, 152, 5, 62, "Input"],
Cell[1147200, 22160, 528, 19, 29, "Text",
 Evaluatable->False],
Cell[1147731, 22181, 163, 6, 79, "Input"],
Cell[1147897, 22189, 94, 1, 28, "Input"],
Cell[1147994, 22192, 155, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1148174, 22201, 1833, 53, 69, "Input"],
Cell[1150010, 22256, 438887, 6568, 262, "Output"]
}, Open  ]],
Cell[1588912, 28827, 872, 28, 36, "Special1",
 Evaluatable->False],
Cell[1589787, 28857, 1066, 25, 83, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1590878, 28886, 57, 1, 28, "Input"],
Cell[1590938, 28889, 219, 7, 27, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[1591172, 28899, 197, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1591394, 28908, 61, 1, 28, "Input"],
Cell[1591458, 28911, 134, 3, 27, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[1591607, 28917, 457, 12, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1592089, 28933, 57, 1, 28, "Input"],
Cell[1592149, 28936, 234, 7, 27, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[1592398, 28946, 197, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1592620, 28955, 60, 1, 28, "Input"],
Cell[1592683, 28958, 134, 3, 27, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[1592832, 28964, 169, 5, 29, "Text",
 Evaluatable->False],
Cell[1593004, 28971, 928, 24, 65, "Text",
 Evaluatable->False],
Cell[1593935, 28997, 863, 14, 101, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[1594835, 29016, 85, 2, 45, "Subsection",
 Evaluatable->False],
Cell[1594923, 29020, 2112, 61, 124, "Text",
 Evaluatable->False],
Cell[1597038, 29083, 762, 24, 47, "Text",
 Evaluatable->False]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1597849, 29113, 76, 2, 51, "Section",
 Evaluatable->False],
Cell[1597928, 29117, 943, 19, 83, "Text",
 Evaluatable->False],
Cell[1598874, 29138, 412, 11, 47, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[1599323, 29154, 79, 2, 51, "Section",
 Evaluatable->False],
Cell[1599405, 29158, 2421, 72, 371, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[1601863, 29235, 82, 2, 51, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1601970, 29241, 529, 21, 69, "Subsubsection",
 Evaluatable->False],
Cell[1602502, 29264, 415, 8, 47, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[1602954, 29277, 521, 21, 69, "Subsubsection",
 Evaluatable->False],
Cell[1603478, 29300, 422, 8, 47, "Text",
 Evaluatable->False]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
